/* Dialogs.c generated by valac 0.36.6, the Vala compiler
 * generated from Dialogs.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* namespace for future migration of AppWindow alert and other question dialogs into single*/
/* place: http://trac.yorba.org/ticket/3452*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>


#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_SAVED_SEARCH (saved_search_get_type ())
#define SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH, SavedSearch))
#define SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH, SavedSearchClass))
#define IS_SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH))
#define IS_SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH))
#define SAVED_SEARCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH, SavedSearchClass))

typedef struct _SavedSearch SavedSearch;
typedef struct _SavedSearchClass SavedSearchClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
typedef struct _BatchImportResultPrivate BatchImportResultPrivate;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define TYPE_IMPORT_RESULT (import_result_get_type ())

#define TYPE_DUPLICATED_FILE (duplicated_file_get_type ())
#define DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUPLICATED_FILE, DuplicatedFile))
#define DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUPLICATED_FILE, DuplicatedFileClass))
#define IS_DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUPLICATED_FILE))
#define IS_DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUPLICATED_FILE))
#define DUPLICATED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUPLICATED_FILE, DuplicatedFileClass))

typedef struct _DuplicatedFile DuplicatedFile;
typedef struct _DuplicatedFileClass DuplicatedFileClass;
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;
typedef struct _ImportUIQuestionParamsPrivate ImportUIQuestionParamsPrivate;
typedef struct _ImportUIParamSpecQuestionParams ImportUIParamSpecQuestionParams;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;
typedef struct _ImportManifestPrivate ImportManifestPrivate;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_TEXT_ENTRY_DIALOG_MEDIATOR (text_entry_dialog_mediator_get_type ())
#define TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator))
#define TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))

typedef struct _TextEntryDialogMediator TextEntryDialogMediator;
typedef struct _TextEntryDialogMediatorClass TextEntryDialogMediatorClass;
typedef struct _TextEntryDialogMediatorPrivate TextEntryDialogMediatorPrivate;

#define TYPE_TEXT_ENTRY_DIALOG (text_entry_dialog_get_type ())
#define TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialog))
#define TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))
#define IS_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG))
#define IS_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG))
#define TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))

typedef struct _TextEntryDialog TextEntryDialog;
typedef struct _TextEntryDialogClass TextEntryDialogClass;
typedef struct _ParamSpecTextEntryDialogMediator ParamSpecTextEntryDialogMediator;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (multi_text_entry_dialog_mediator_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))

typedef struct _MultiTextEntryDialogMediator MultiTextEntryDialogMediator;
typedef struct _MultiTextEntryDialogMediatorClass MultiTextEntryDialogMediatorClass;
typedef struct _MultiTextEntryDialogMediatorPrivate MultiTextEntryDialogMediatorPrivate;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG (multi_text_entry_dialog_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialog))
#define MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define IS_MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define MULTI_TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))

typedef struct _MultiTextEntryDialog MultiTextEntryDialog;
typedef struct _MultiTextEntryDialogClass MultiTextEntryDialogClass;
typedef struct _ParamSpecMultiTextEntryDialogMediator ParamSpecMultiTextEntryDialogMediator;

#define TYPE_EVENT_RENAME_DIALOG (event_rename_dialog_get_type ())
#define EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialog))
#define EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))
#define IS_EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_RENAME_DIALOG))
#define IS_EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_RENAME_DIALOG))
#define EVENT_RENAME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))

typedef struct _EventRenameDialog EventRenameDialog;
typedef struct _EventRenameDialogClass EventRenameDialogClass;
typedef struct _EventRenameDialogPrivate EventRenameDialogPrivate;

#define TYPE_EDIT_TITLE_DIALOG (edit_title_dialog_get_type ())
#define EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialog))
#define EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))
#define IS_EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_TITLE_DIALOG))
#define IS_EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_TITLE_DIALOG))
#define EDIT_TITLE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))

typedef struct _EditTitleDialog EditTitleDialog;
typedef struct _EditTitleDialogClass EditTitleDialogClass;
typedef struct _EditTitleDialogPrivate EditTitleDialogPrivate;

#define TYPE_EDIT_COMMENT_DIALOG (edit_comment_dialog_get_type ())
#define EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog))
#define EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))
#define IS_EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_COMMENT_DIALOG))
#define IS_EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_COMMENT_DIALOG))
#define EDIT_COMMENT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))

typedef struct _EditCommentDialog EditCommentDialog;
typedef struct _EditCommentDialogClass EditCommentDialogClass;
typedef struct _EditCommentDialogPrivate EditCommentDialogPrivate;

#define TYPE_TAGS_DIALOG (tags_dialog_get_type ())
#define TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAGS_DIALOG, TagsDialog))
#define TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAGS_DIALOG, TagsDialogClass))
#define IS_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAGS_DIALOG))
#define IS_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAGS_DIALOG))
#define TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAGS_DIALOG, TagsDialogClass))

typedef struct _TagsDialog TagsDialog;
typedef struct _TagsDialogClass TagsDialogClass;
typedef struct _TagsDialogPrivate TagsDialogPrivate;

#define TYPE_HIERARCHICAL_TAG_INDEX (hierarchical_tag_index_get_type ())
#define HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndex))
#define HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))
#define IS_HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HIERARCHICAL_TAG_INDEX))
#define IS_HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HIERARCHICAL_TAG_INDEX))
#define HIERARCHICAL_TAG_INDEX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))

typedef struct _HierarchicalTagIndex HierarchicalTagIndex;
typedef struct _HierarchicalTagIndexClass HierarchicalTagIndexClass;
#define _hierarchical_tag_index_unref0(var) ((var == NULL) ? NULL : (var = (hierarchical_tag_index_unref (var), NULL)))

#define TYPE_ADD_TAGS_DIALOG (add_tags_dialog_get_type ())
#define ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialog))
#define ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))
#define IS_ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_TAGS_DIALOG))
#define IS_ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_TAGS_DIALOG))
#define ADD_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))

typedef struct _AddTagsDialog AddTagsDialog;
typedef struct _AddTagsDialogClass AddTagsDialogClass;
typedef struct _AddTagsDialogPrivate AddTagsDialogPrivate;

#define TYPE_MODIFY_TAGS_DIALOG (modify_tags_dialog_get_type ())
#define MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog))
#define MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))
#define IS_MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MODIFY_TAGS_DIALOG))
#define IS_MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MODIFY_TAGS_DIALOG))
#define MODIFY_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))

typedef struct _ModifyTagsDialog ModifyTagsDialog;
typedef struct _ModifyTagsDialogClass ModifyTagsDialogClass;
typedef struct _ModifyTagsDialogPrivate ModifyTagsDialogPrivate;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_TAG_SOURCE_COLLECTION (tag_source_collection_get_type ())
#define TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollection))
#define TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))
#define IS_TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_SOURCE_COLLECTION))
#define IS_TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_SOURCE_COLLECTION))
#define TAG_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))

typedef struct _TagSourceCollection TagSourceCollection;
typedef struct _TagSourceCollectionClass TagSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define TYPE_VIDEO_SOURCE (video_source_get_type ())
#define VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE, VideoSource))
#define VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE, VideoSourceClass))
#define IS_VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE))
#define IS_VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE))
#define VIDEO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE, VideoSourceClass))

typedef struct _VideoSource VideoSource;
typedef struct _VideoSourceClass VideoSourceClass;

#define TYPE_VIDEO (video_get_type ())
#define VIDEO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO, Video))
#define VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO, VideoClass))
#define IS_VIDEO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO))
#define IS_VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO))
#define VIDEO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO, VideoClass))

typedef struct _Video Video;
typedef struct _VideoClass VideoClass;

#define TYPE_PROGRESS_DIALOG (progress_dialog_get_type ())
#define PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROGRESS_DIALOG, ProgressDialog))
#define PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROGRESS_DIALOG, ProgressDialogClass))
#define IS_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROGRESS_DIALOG))
#define IS_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROGRESS_DIALOG))
#define PROGRESS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROGRESS_DIALOG, ProgressDialogClass))

typedef struct _ProgressDialog ProgressDialog;
typedef struct _ProgressDialogClass ProgressDialogClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

struct _BatchImportResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportResultPrivate * priv;
	BatchImportJob* job;
	GFile* file;
	gchar* src_identifier;
	gchar* dest_identifier;
	ImportResult result;
	gchar* errmsg;
	DuplicatedFile* duplicate_of;
};

struct _BatchImportResultClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportResult *self);
};

struct _ImportUIQuestionParams {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportUIQuestionParamsPrivate * priv;
	gchar* question;
	gchar* yes_button;
	gchar* no_button;
};

struct _ImportUIQuestionParamsClass {
	GTypeClass parent_class;
	void (*finalize) (ImportUIQuestionParams *self);
};

struct _ImportUIParamSpecQuestionParams {
	GParamSpec parent_instance;
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
	GTimer* timer;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};

struct _TextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TextEntryDialogMediatorPrivate * priv;
};

struct _TextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (TextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (TextEntryDialogMediator* self, const gchar* text);
};

struct _TextEntryDialogMediatorPrivate {
	TextEntryDialog* dialog;
};

typedef gboolean (*TextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _MultiTextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	MultiTextEntryDialogMediatorPrivate * priv;
};

struct _MultiTextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (MultiTextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (MultiTextEntryDialogMediator* self, const gchar* text);
};

struct _MultiTextEntryDialogMediatorPrivate {
	MultiTextEntryDialog* dialog;
};

typedef gboolean (*MultiTextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecMultiTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _EventRenameDialog {
	TextEntryDialogMediator parent_instance;
	EventRenameDialogPrivate * priv;
};

struct _EventRenameDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EventRenameDialog* self);
};

struct _EditTitleDialog {
	TextEntryDialogMediator parent_instance;
	EditTitleDialogPrivate * priv;
};

struct _EditTitleDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditTitleDialog* self);
};

struct _EditCommentDialog {
	MultiTextEntryDialogMediator parent_instance;
	EditCommentDialogPrivate * priv;
};

struct _EditCommentDialogClass {
	MultiTextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditCommentDialog* self);
};

struct _TagsDialog {
	TextEntryDialogMediator parent_instance;
	TagsDialogPrivate * priv;
};

struct _TagsDialogClass {
	TextEntryDialogMediatorClass parent_class;
};

struct _AddTagsDialog {
	TagsDialog parent_instance;
	AddTagsDialogPrivate * priv;
};

struct _AddTagsDialogClass {
	TagsDialogClass parent_class;
};

struct _ModifyTagsDialog {
	TagsDialog parent_instance;
	ModifyTagsDialogPrivate * priv;
};

struct _ModifyTagsDialogClass {
	TagsDialogClass parent_class;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);

extern GFile* export_ui_current_export_dir;
GFile* export_ui_current_export_dir = NULL;
static gpointer import_ui_question_params_parent_class = NULL;
static gpointer text_entry_dialog_mediator_parent_class = NULL;
static gpointer multi_text_entry_dialog_mediator_parent_class = NULL;
static gpointer event_rename_dialog_parent_class = NULL;
static gpointer edit_title_dialog_parent_class = NULL;
static gpointer edit_comment_dialog_parent_class = NULL;
static gpointer tags_dialog_parent_class = NULL;
static gpointer add_tags_dialog_parent_class = NULL;
static gpointer modify_tags_dialog_parent_class = NULL;
extern TagSourceCollection* tag_global;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;

GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType tag_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_tag (Tag* tag);
gint tag_get_sources_count (Tag* self);
gchar* tag_get_user_visible_name (Tag* self);
gboolean app_window_negate_affirm_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent);
#define RESOURCES_DELETE_TAG_TITLE _ ("Delete Tag")
GType saved_search_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_saved_search (SavedSearch* search);
gchar* data_object_get_name (DataObject* self);
#define RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE _ ("Delete Search")
gboolean dialogs_confirm_warn_developer_changed (gint number);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
GFile* export_ui_choose_file (const gchar* current_file_basename);
gboolean video_reader_is_supported_video_filename (const gchar* filename);
#define RESOURCES_SAVE_LABEL _ ("_Save")
GFile* export_ui_choose_dir (const gchar* user_title);
#define RESOURCES_OK_LABEL _ ("_OK")
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
void open_external_editor_error_dialog (GError* err, Photo* photo);
void app_window_error_message (const gchar* message, GtkWindow* parent);
GFile* media_source_get_master_file (MediaSource* self);
gchar* resources_launch_editor_failed (GError* err);
GtkResponseType export_error_dialog (GFile* dest, gboolean photos_remaining);
GtkResponseType app_window_affirm_cancel_question (const gchar* message, const gchar* affirmative, const gchar* title, GtkWindow* parent);
#define IMPORT_UI_REPORT_FAILURE_COUNT 4
#define IMPORT_UI_SAVE_RESULTS_BUTTON_NAME _ ("Save Details…")
#define IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE _ ("Save Details")
#define IMPORT_UI_SAVE_RESULTS_RESPONSE_ID 1024
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_result (GValue* value, gpointer v_object);
void value_take_batch_import_result (GValue* value, gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
gchar* import_ui_generate_import_failure_list (GeeList* failed, gboolean show_dest_id);
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_job (GValue* value, gpointer v_object);
void value_take_batch_import_job (GValue* value, gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType import_result_get_type (void) G_GNUC_CONST;
GType duplicated_file_get_type (void) G_GNUC_CONST;
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void import_ui_value_set_question_params (GValue* value, gpointer v_object);
void import_ui_value_take_question_params (GValue* value, gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
enum  {
	IMPORT_UI_QUESTION_PARAMS_DUMMY_PROPERTY
};
ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button);
ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button);
static void import_ui_question_params_finalize (ImportUIQuestionParams * obj);
gboolean import_ui_import_has_photos (GeeCollection* import_collection);
GType photo_file_format_get_type (void) G_GNUC_CONST;
PhotoFileFormat photo_file_format_get_by_file_extension (GFile* file);
gboolean import_ui_import_has_videos (GeeCollection* import_collection);
gboolean video_reader_is_supported_video_file (GFile* file);
gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg);
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_import_manifest (GValue* value, gpointer v_object);
void value_take_import_manifest (GValue* value, gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest);
#define RESOURCES_APP_VERSION _VERSION
GFile* duplicated_file_get_file (DuplicatedFile* self);
gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question);
void import_ui_save_import_results (GtkWindow* chooser_dialog_parent, const gchar* results_log);
#define RESOURCES_SAVE_AS_LABEL _ ("Save _As")
gpointer text_entry_dialog_mediator_ref (gpointer instance);
void text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_text_entry_dialog_mediator (const GValue* value);
GType text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType text_entry_dialog_get_type (void) G_GNUC_CONST;
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorPrivate))
enum  {
	TEXT_ENTRY_DIALOG_MEDIATOR_DUMMY_PROPERTY
};
TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter);
TextEntryDialog* text_entry_dialog_new (void);
TextEntryDialog* text_entry_dialog_construct (GType object_type);
void text_entry_dialog_setup (TextEntryDialog* self, TextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter);
gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self, const gchar* text);
static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self);
static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self, const gchar* text);
gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self);
gchar* text_entry_dialog_execute (TextEntryDialog* self);
static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator * obj);
gpointer multi_text_entry_dialog_mediator_ref (gpointer instance);
void multi_text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value);
GType multi_text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType multi_text_entry_dialog_get_type (void) G_GNUC_CONST;
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorPrivate))
enum  {
	MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_DUMMY_PROPERTY
};
MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text);
MultiTextEntryDialog* multi_text_entry_dialog_new (void);
MultiTextEntryDialog* multi_text_entry_dialog_construct (GType object_type);
void multi_text_entry_dialog_setup (MultiTextEntryDialog* self, MultiTextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text);
gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text);
static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self);
static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text);
gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self);
gchar* multi_text_entry_dialog_execute (MultiTextEntryDialog* self);
static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator * obj);
gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape);
gchar* guarded_markup_escape_text (const gchar* plain);
GType event_rename_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EVENT_RENAME_DIALOG_DUMMY_PROPERTY
};
EventRenameDialog* event_rename_dialog_new (const gchar* event_name);
EventRenameDialog* event_rename_dialog_construct (GType object_type, const gchar* event_name);
gchar* event_rename_dialog_execute (EventRenameDialog* self);
static gchar* event_rename_dialog_real_execute (EventRenameDialog* self);
gchar* event_prep_event_name (const gchar* name);
GType edit_title_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EDIT_TITLE_DIALOG_DUMMY_PROPERTY
};
EditTitleDialog* edit_title_dialog_new (const gchar* photo_title);
EditTitleDialog* edit_title_dialog_construct (GType object_type, const gchar* photo_title);
gchar* edit_title_dialog_execute (EditTitleDialog* self);
static gchar* edit_title_dialog_real_execute (EditTitleDialog* self);
gchar* media_source_prep_title (const gchar* title);
static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
GType edit_comment_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EDIT_COMMENT_DIALOG_DUMMY_PROPERTY
};
EditCommentDialog* edit_comment_dialog_new (const gchar* comment, gboolean is_event);
EditCommentDialog* edit_comment_dialog_construct (GType object_type, const gchar* comment, gboolean is_event);
gchar* edit_comment_dialog_execute (EditCommentDialog* self);
static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self);
gchar* media_source_prep_comment (const gchar* comment);
static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base, const gchar* text);
GtkResponseType remove_from_library_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message, gint count);
GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message);
gboolean revert_editable_dialog (GtkWindow* owner, GeeCollection* photos);
gboolean photo_has_editable (Photo* self);
gboolean remove_offline_dialog (GtkWindow* owner, gint count);
#define MAX_OBJECTS_DISPLAYED 3
void multiple_object_error_dialog (GeeArrayList* objects, const gchar* message, const gchar* title);
gchar* data_object_to_string (DataObject* self);
GType tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	TAGS_DIALOG_DUMMY_PROPERTY
};
TagsDialog* tags_dialog_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text);
gpointer hierarchical_tag_index_ref (gpointer instance);
void hierarchical_tag_index_unref (gpointer instance);
GParamSpec* param_spec_hierarchical_tag_index (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_hierarchical_tag_index (GValue* value, gpointer v_object);
void value_take_hierarchical_tag_index (GValue* value, gpointer v_object);
gpointer value_get_hierarchical_tag_index (const GValue* value);
GType hierarchical_tag_index_get_type (void) G_GNUC_CONST;
HierarchicalTagIndex* hierarchical_tag_index_get_global_index (void);
GeeCollection* hierarchical_tag_index_get_all_tags (HierarchicalTagIndex* self);
GType add_tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	ADD_TAGS_DIALOG_DUMMY_PROPERTY
};
AddTagsDialog* add_tags_dialog_new (void);
AddTagsDialog* add_tags_dialog_construct (GType object_type);
#define RESOURCES_ADD_TAGS_TITLE NC_ ("Dialog Title", "Add Tags")
gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1);
gchar** tag_prep_tag_names (gchar** names, int names_length1, int* result_length1);
static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
#define TAG_PATH_SEPARATOR_STRING "/"
GType modify_tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	MODIFY_TAGS_DIALOG_DUMMY_PROPERTY
};
ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source);
ModifyTagsDialog* modify_tags_dialog_construct (GType object_type, MediaSource* source);
#define RESOURCES_MODIFY_TAGS_LABEL _ ("Modify Tags")
static gchar* modify_tags_dialog_get_initial_text (MediaSource* source);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType tag_source_collection_get_type (void) G_GNUC_CONST;
GeeList* tag_source_collection_fetch_for_source (TagSourceCollection* self, MediaSource* source);
GeeCollection* tag_get_terminal_tags (GeeCollection* tags);
gchar* hierarchical_tag_utilities_get_basename (const gchar* in_path);
gchar* tag_get_path (Tag* self);
GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self);
gboolean is_string_empty (const gchar* s);
gchar** hierarchical_tag_index_get_paths_for_names_array (HierarchicalTagIndex* self, gchar** names, int names_length1, int* result_length1);
Tag* tag_for_path (const gchar* name);
static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
GtkResponseType copy_files_dialog (void);
GType library_photo_get_type (void) G_GNUC_CONST;
void remove_photos_from_library (GeeCollection* photos);
void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text);
GType video_source_get_type (void) G_GNUC_CONST;
GType video_get_type (void) G_GNUC_CONST;
void media_source_collection_filter_media (GeeCollection* media, GeeCollection* photos, GeeCollection* videos);
void page_window_set_busy_cursor (PageWindow* self);
GType progress_dialog_get_type (void) G_GNUC_CONST;
ProgressDialog* progress_dialog_new (GtkWindow* owner, const gchar* text, GCancellable* cancellable);
ProgressDialog* progress_dialog_construct (GType object_type, GtkWindow* owner, const gchar* text, GCancellable* cancellable);
gboolean progress_dialog_monitor (ProgressDialog* self, guint64 count, guint64 total, gboolean do_event_loop);
static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self);
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_remove_from_app (MediaSourceCollection* self, GeeCollection* sources, gboolean delete_backing, ProgressMonitor monitor, void* monitor_target, GeeList* not_removed);
GType video_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_delete_backing_files (MediaSourceCollection* self, GeeCollection* sources, ProgressMonitor monitor, void* monitor_target, GeeList* not_deleted);
void app_window_error_message_with_title (const gchar* title, const gchar* message, GtkWindow* parent, gboolean should_escape);
void progress_dialog_close (ProgressDialog* self);
void page_window_set_normal_cursor (PageWindow* self);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


gboolean dialogs_confirm_delete_tag (Tag* tag) {
	gboolean result = FALSE;
	gint count = 0;
	Tag* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gchar* msg = NULL;
	gint _tmp3_;
	Tag* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gint _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
#line 11 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TAG (tag), FALSE);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag;
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = tag_get_sources_count (_tmp0_);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = _tmp1_;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = count;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 912 "Dialogs.c"
	}
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = tag;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = tag_get_user_visible_name (_tmp4_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_strdup_printf (ngettext ("This will remove the tag “%s” from one photo. Continue?", "This will remove the tag “%s” from %d photos. Continue?", (gulong) _tmp3_), _tmp6_, _tmp7_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp9_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = msg;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = app_window_negate_affirm_question (_tmp10_, _ ("_Cancel"), _ ("_Delete"), RESOURCES_DELETE_TAG_TITLE, NULL);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp11_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 942 "Dialogs.c"
}


gboolean dialogs_confirm_delete_saved_search (SavedSearch* search) {
	gboolean result = FALSE;
	gchar* msg = NULL;
	SavedSearch* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
#line 24 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SAVED_SEARCH (search), FALSE);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = search;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_OBJECT, DataObject));
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf (_ ("This will remove the saved search “%s”. Continue?"), _tmp2_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp4_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = app_window_negate_affirm_question (msg, _ ("_Cancel"), _ ("_Delete"), RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE, NULL);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp5_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 979 "Dialogs.c"
}


gboolean dialogs_confirm_warn_developer_changed (gint number) {
	gboolean result = FALSE;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	gint _tmp2_;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	gint response = 0;
	gint _tmp5_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_get_instance ();
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = number;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "<span weight=\"bold\" size=\"larger\">%s</span>", ngettext ("Switching developers will undo all changes you have made to this photo" \
" in Shotwell", "Switching developers will undo all changes you have made to these phot" \
"os in Shotwell", (gulong) _tmp2_));
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp3_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 39 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, NULL);
#line 40 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Switch Developer"), GTK_RESPONSE_YES, NULL);
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = _tmp5_;
#line 44 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response == ((gint) GTK_RESPONSE_YES);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1025 "Dialogs.c"
}


GFile* export_ui_choose_file (const gchar* current_file_basename) {
	GFile* result = NULL;
	GFile* _tmp0_;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_;
	gboolean _tmp5_;
	gchar* file_chooser_title = NULL;
	gchar* _tmp6_;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp7_;
	AppWindow* _tmp8_;
	AppWindow* _tmp9_;
	GtkFileChooserDialog* _tmp10_;
	GtkFileChooserDialog* _tmp11_;
	GtkFileChooserDialog* _tmp12_;
	GtkFileChooserDialog* _tmp13_;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GtkFileChooserDialog* _tmp17_;
	const gchar* _tmp18_;
	GtkFileChooserDialog* _tmp19_;
	GFile* file = NULL;
	GtkFileChooserDialog* _tmp20_;
	gint _tmp21_;
	GtkFileChooserDialog* _tmp28_;
#line 54 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (current_file_basename != NULL, NULL);
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 1061 "Dialogs.c"
		const gchar* _tmp1_;
		GFile* _tmp2_;
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 1072 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = current_file_basename;
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = video_reader_is_supported_video_filename (_tmp4_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Export Video");
#line 1082 "Dialogs.c"
	} else {
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Export Photo");
#line 1086 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strdup (_tmp3_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file_chooser_title = _tmp6_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = file_chooser_title;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = app_window_get_instance ();
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp10_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp9_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp11_;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = chooser;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = chooser;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = export_ui_current_export_dir;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_file_get_path (_tmp14_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp16_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = chooser;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = current_file_basename;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp18_);
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = chooser;
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 69 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file = NULL;
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = chooser;
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_dialog_get_type (), GtkDialog));
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp21_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 1142 "Dialogs.c"
		GtkFileChooserDialog* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GFile* _tmp25_;
		GFile* _tmp26_;
		GFile* _tmp27_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = chooser;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = g_file_new_for_path (_tmp24_);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (file);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		file = _tmp25_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp24_);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = file;
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = g_file_get_parent (_tmp26_);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp27_;
#line 1171 "Dialogs.c"
	}
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = chooser;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget));
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = file;
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (file_chooser_title);
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1185 "Dialogs.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self ? g_object_ref (self) : NULL;
#line 1192 "Dialogs.c"
}


GFile* export_ui_choose_dir (const gchar* user_title) {
	GFile* result = NULL;
	GFile* _tmp0_;
	const gchar* _tmp3_;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp4_;
	AppWindow* _tmp5_;
	AppWindow* _tmp6_;
	GtkFileChooserDialog* _tmp7_;
	GtkFileChooserDialog* _tmp8_;
	GtkFileChooserDialog* _tmp9_;
	GFile* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GtkFileChooserDialog* _tmp13_;
	GFile* dir = NULL;
	GtkFileChooserDialog* _tmp14_;
	gint _tmp15_;
	GtkFileChooserDialog* _tmp22_;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 1219 "Dialogs.c"
		const gchar* _tmp1_;
		GFile* _tmp2_;
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 1230 "Dialogs.c"
	}
#line 83 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = user_title;
#line 83 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == NULL) {
#line 84 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_title = _ ("Export Photos");
#line 1238 "Dialogs.c"
	}
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = user_title;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = app_window_get_instance ();
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp6_);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp8_;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = chooser;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = export_ui_current_export_dir;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = g_file_get_path (_tmp10_);
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp12_);
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp12_);
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = chooser;
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 92 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dir = NULL;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = chooser;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_dialog_get_type (), GtkDialog));
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp15_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 1280 "Dialogs.c"
		GtkFileChooserDialog* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		GFile* _tmp19_;
		GFile* _tmp20_;
		GFile* _tmp21_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = chooser;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = _tmp17_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = g_file_new_for_path (_tmp18_);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dir);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dir = _tmp19_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp18_);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = dir;
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp21_;
#line 1309 "Dialogs.c"
	}
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = chooser;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget));
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = dir;
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1321 "Dialogs.c"
}


void open_external_editor_error_dialog (GError* err, Photo* photo) {
	gboolean _tmp0_ = FALSE;
	GError* _tmp1_;
#line 107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PHOTO (photo));
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = err;
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_error_matches (_tmp1_, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED)) {
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 1336 "Dialogs.c"
	} else {
		GError* _tmp2_;
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = err;
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = g_error_matches (_tmp2_, G_FILE_ERROR, G_FILE_ERROR_PERM);
#line 1343 "Dialogs.c"
	}
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 1347 "Dialogs.c"
		Photo* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = photo;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_MEDIA_SOURCE, MediaSource));
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = g_file_get_parent (_tmp5_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = g_file_get_path (_tmp7_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = g_strdup_printf (_ ("Shotwell couldn’t create a file for editing this photo because you do " \
"not have permission to write to %s."), _tmp9_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = _tmp10_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp11_, NULL);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp11_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp9_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp5_);
#line 1385 "Dialogs.c"
	} else {
		GError* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = err;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = resources_launch_editor_failed (_tmp12_);
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp13_;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp14_, NULL);
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp14_);
#line 1400 "Dialogs.c"
	}
}


GtkResponseType export_error_dialog (GFile* dest, gboolean photos_remaining) {
	GtkResponseType result = 0;
	gchar* message = NULL;
	GFile* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkResponseType response = 0;
	gboolean _tmp5_;
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_IS_FILE (dest), 0);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = dest;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_file_get_path (_tmp0_);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strconcat (_ ("Unable to export the following photo due to a file error.\n\n"), _tmp2_, NULL);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp4_;
#line 124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = GTK_RESPONSE_NONE;
#line 126 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = photos_remaining;
#line 126 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 1437 "Dialogs.c"
		const gchar* _tmp6_;
		gchar* _tmp7_;
		const gchar* _tmp8_;
		GtkResponseType _tmp9_;
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = message;
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strconcat (_tmp6_, _ ("\n\nWould you like to continue exporting?"), NULL);
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp7_;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = message;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = app_window_affirm_cancel_question (_tmp8_, _ ("Con_tinue"), NULL, NULL);
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		response = _tmp9_;
#line 1456 "Dialogs.c"
	} else {
		const gchar* _tmp10_;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = message;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp10_, NULL);
#line 1463 "Dialogs.c"
	}
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response;
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1471 "Dialogs.c"
}


gchar* import_ui_generate_import_failure_list (GeeList* failed, gboolean show_dest_id) {
	gchar* result = NULL;
	GeeList* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gchar* list = NULL;
	gchar* _tmp3_;
	gint remaining = 0;
	GeeList* _tmp28_;
	gint _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
#line 143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_LIST (failed), NULL);
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = failed;
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection));
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 1501 "Dialogs.c"
	}
#line 147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup ("");
#line 147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	list = _tmp3_;
#line 1507 "Dialogs.c"
	{
		gint ctr = 0;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ctr = 0;
#line 1512 "Dialogs.c"
		{
			gboolean _tmp4_ = FALSE;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = TRUE;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 1519 "Dialogs.c"
				gboolean _tmp6_ = FALSE;
				gint _tmp7_;
				const gchar* _tmp12_ = NULL;
				gboolean _tmp13_;
				const gchar* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				gchar* _tmp27_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp4_) {
#line 1530 "Dialogs.c"
					gint _tmp5_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp5_ = ctr;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					ctr = _tmp5_ + 1;
#line 1536 "Dialogs.c"
				}
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = FALSE;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = ctr;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp7_ < IMPORT_UI_REPORT_FAILURE_COUNT) {
#line 1544 "Dialogs.c"
					gint _tmp8_;
					GeeList* _tmp9_;
					gint _tmp10_;
					gint _tmp11_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = ctr;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = failed;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp10_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp11_ = _tmp10_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = _tmp8_ < _tmp11_;
#line 1559 "Dialogs.c"
				} else {
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = FALSE;
#line 1563 "Dialogs.c"
				}
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 1569 "Dialogs.c"
				}
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = show_dest_id;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_) {
#line 1575 "Dialogs.c"
					GeeList* _tmp14_;
					gint _tmp15_;
					gpointer _tmp16_;
					BatchImportResult* _tmp17_;
					const gchar* _tmp18_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = failed;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = ctr;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = gee_list_get (_tmp14_, _tmp15_);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = (BatchImportResult*) _tmp16_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = _tmp17_->dest_identifier;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = _tmp18_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp17_);
#line 1595 "Dialogs.c"
				} else {
					GeeList* _tmp19_;
					gint _tmp20_;
					gpointer _tmp21_;
					BatchImportResult* _tmp22_;
					const gchar* _tmp23_;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = failed;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = ctr;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp21_ = gee_list_get (_tmp19_, _tmp20_);
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp22_ = (BatchImportResult*) _tmp21_;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp23_ = _tmp22_->src_identifier;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = _tmp23_;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp22_);
#line 1616 "Dialogs.c"
				}
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = list;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp25_ = g_strdup_printf ("%s\n", _tmp12_);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = _tmp25_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = g_strconcat (_tmp24_, _tmp26_, NULL);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (list);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				list = _tmp27_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp26_);
#line 1632 "Dialogs.c"
			}
		}
	}
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = failed;
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = _tmp29_;
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remaining = _tmp30_ - IMPORT_UI_REPORT_FAILURE_COUNT;
#line 154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = remaining;
#line 154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp31_ > 0) {
#line 1648 "Dialogs.c"
		const gchar* _tmp32_;
		gint _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = list;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = remaining;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = g_strdup_printf (_ ("(and %d more)\n"), _tmp33_);
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = _tmp34_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = g_strconcat (_tmp32_, _tmp35_, NULL);
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (list);
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		list = _tmp36_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp35_);
#line 1670 "Dialogs.c"
	}
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = list;
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1676 "Dialogs.c"
}


ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button) {
	ImportUIQuestionParams* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (question != NULL, NULL);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (yes_button != NULL, NULL);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (no_button != NULL, NULL);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ImportUIQuestionParams*) g_type_create_instance (object_type);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = question;
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->question = _tmp1_;
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = yes_button;
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->yes_button = _tmp3_;
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = no_button;
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->no_button = _tmp5_;
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 1722 "Dialogs.c"
}


ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button) {
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return import_ui_question_params_construct (IMPORT_UI_TYPE_QUESTION_PARAMS, question, yes_button, no_button);
#line 1729 "Dialogs.c"
}


static void import_ui_value_question_params_init (GValue* value) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 1736 "Dialogs.c"
}


static void import_ui_value_question_params_free_value (GValue* value) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (value->data[0].v_pointer);
#line 1745 "Dialogs.c"
	}
}


static void import_ui_value_question_params_copy_value (const GValue* src_value, GValue* dest_value) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = import_ui_question_params_ref (src_value->data[0].v_pointer);
#line 1755 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1759 "Dialogs.c"
	}
}


static gpointer import_ui_value_question_params_peek_pointer (const GValue* value) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 1767 "Dialogs.c"
}


static gchar* import_ui_value_question_params_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 1774 "Dialogs.c"
		ImportUIQuestionParams * object;
		object = collect_values[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1781 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1785 "Dialogs.c"
		}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = import_ui_question_params_ref (object);
#line 1789 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 1793 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 1797 "Dialogs.c"
}


static gchar* import_ui_value_question_params_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	ImportUIQuestionParams ** object_p;
	object_p = collect_values[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1808 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 1814 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 1818 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = import_ui_question_params_ref (value->data[0].v_pointer);
#line 1822 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 1826 "Dialogs.c"
}


GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ImportUIParamSpecQuestionParams* spec;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 1840 "Dialogs.c"
}


gpointer import_ui_value_get_question_params (const GValue* value) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 1849 "Dialogs.c"
}


void import_ui_value_set_question_params (GValue* value, gpointer v_object) {
	ImportUIQuestionParams * old;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_ref (value->data[0].v_pointer);
#line 1869 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 1873 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 1879 "Dialogs.c"
	}
}


void import_ui_value_take_question_params (GValue* value, gpointer v_object) {
	ImportUIQuestionParams * old;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 1898 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 1902 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 1908 "Dialogs.c"
	}
}


static void import_ui_question_params_class_init (ImportUIQuestionParamsClass * klass) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	import_ui_question_params_parent_class = g_type_class_peek_parent (klass);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((ImportUIQuestionParamsClass *) klass)->finalize = import_ui_question_params_finalize;
#line 1918 "Dialogs.c"
}


static void import_ui_question_params_instance_init (ImportUIQuestionParams * self) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 1925 "Dialogs.c"
}


static void import_ui_question_params_finalize (ImportUIQuestionParams * obj) {
	ImportUIQuestionParams * self;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 163 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 1941 "Dialogs.c"
}


GType import_ui_question_params_get_type (void) {
	static volatile gsize import_ui_question_params_type_id__volatile = 0;
	if (g_once_init_enter (&import_ui_question_params_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { import_ui_value_question_params_init, import_ui_value_question_params_free_value, import_ui_value_question_params_copy_value, import_ui_value_question_params_peek_pointer, "p", import_ui_value_question_params_collect_value, "p", import_ui_value_question_params_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (ImportUIQuestionParamsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_ui_question_params_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportUIQuestionParams), 0, (GInstanceInitFunc) import_ui_question_params_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType import_ui_question_params_type_id;
		import_ui_question_params_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ImportUIQuestionParams", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&import_ui_question_params_type_id__volatile, import_ui_question_params_type_id);
	}
	return import_ui_question_params_type_id__volatile;
}


gpointer import_ui_question_params_ref (gpointer instance) {
	ImportUIQuestionParams * self;
	self = instance;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 1966 "Dialogs.c"
}


void import_ui_question_params_unref (gpointer instance) {
	ImportUIQuestionParams * self;
	self = instance;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		IMPORT_UI_QUESTION_PARAMS_GET_CLASS (self)->finalize (self);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1979 "Dialogs.c"
	}
}


gboolean import_ui_import_has_photos (GeeCollection* import_collection) {
	gboolean result = FALSE;
#line 172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 1988 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeCollection* _tmp0_;
		GeeIterator* _tmp1_;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = import_collection;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp1_;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 2001 "Dialogs.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			gboolean _tmp6_ = FALSE;
			BatchImportResult* _tmp7_;
			GFile* _tmp8_;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 2018 "Dialogs.c"
			}
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _current_result_it;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp5_;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = current_result;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp7_->file;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp8_ != NULL) {
#line 2032 "Dialogs.c"
				BatchImportResult* _tmp9_;
				GFile* _tmp10_;
				PhotoFileFormat _tmp11_;
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = current_result;
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _tmp9_->file;
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = photo_file_format_get_by_file_extension (_tmp10_);
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = _tmp11_ != PHOTO_FILE_FORMAT_UNKNOWN;
#line 2044 "Dialogs.c"
			} else {
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 2048 "Dialogs.c"
			}
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2060 "Dialogs.c"
			}
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 2064 "Dialogs.c"
		}
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 2068 "Dialogs.c"
	}
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2074 "Dialogs.c"
}


gboolean import_ui_import_has_videos (GeeCollection* import_collection) {
	gboolean result = FALSE;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 2082 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeCollection* _tmp0_;
		GeeIterator* _tmp1_;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = import_collection;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp1_;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 2095 "Dialogs.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			gboolean _tmp6_ = FALSE;
			BatchImportResult* _tmp7_;
			GFile* _tmp8_;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 2112 "Dialogs.c"
			}
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _current_result_it;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp5_;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = current_result;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp7_->file;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp8_ != NULL) {
#line 2126 "Dialogs.c"
				BatchImportResult* _tmp9_;
				GFile* _tmp10_;
				gboolean _tmp11_;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = current_result;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _tmp9_->file;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = video_reader_is_supported_video_file (_tmp10_);
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = _tmp11_;
#line 2138 "Dialogs.c"
			} else {
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 2142 "Dialogs.c"
			}
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2154 "Dialogs.c"
			}
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 2158 "Dialogs.c"
		}
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 2162 "Dialogs.c"
	}
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2168 "Dialogs.c"
}


gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg) {
	gchar* result = NULL;
	gboolean has_photos = FALSE;
	GeeCollection* _tmp0_;
	gboolean _tmp1_;
	gboolean has_videos = FALSE;
	GeeCollection* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_;
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (photos_msg != NULL, NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (videos_msg != NULL, NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (both_msg != NULL, NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (neither_msg != NULL, NULL);
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = import_collection;
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = import_ui_import_has_photos (_tmp0_);
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_photos = _tmp1_;
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = import_collection;
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = import_ui_import_has_videos (_tmp2_);
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_videos = _tmp3_;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = has_photos;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 2208 "Dialogs.c"
		gboolean _tmp6_;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = has_videos;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp6_;
#line 2214 "Dialogs.c"
	} else {
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = FALSE;
#line 2218 "Dialogs.c"
	}
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 2222 "Dialogs.c"
		const gchar* _tmp7_;
		gchar* _tmp8_;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = both_msg;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = g_strdup (_tmp7_);
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp8_;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 2233 "Dialogs.c"
	} else {
		gboolean _tmp9_;
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = has_photos;
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_) {
#line 2240 "Dialogs.c"
			const gchar* _tmp10_;
			gchar* _tmp11_;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = photos_msg;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = g_strdup (_tmp10_);
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp11_;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 2251 "Dialogs.c"
		} else {
			gboolean _tmp12_;
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = has_videos;
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp12_) {
#line 2258 "Dialogs.c"
				const gchar* _tmp13_;
				gchar* _tmp14_;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = videos_msg;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = g_strdup (_tmp13_);
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp14_;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2269 "Dialogs.c"
			} else {
				const gchar* _tmp15_;
				gchar* _tmp16_;
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = neither_msg;
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = g_strdup (_tmp15_);
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp16_;
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2281 "Dialogs.c"
			}
		}
	}
}


gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_;
	gchar* header = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GTimeVal _tmp7_ = {0};
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GString* _tmp14_;
	const gchar* _tmp15_;
	gchar* subhead = NULL;
	ImportManifest* _tmp16_;
	GeeList* _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	ImportManifest* _tmp20_;
	GeeList* _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	gchar* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	const gchar* _tmp27_;
	ImportManifest* _tmp28_;
	GeeList* _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
	ImportManifest* _tmp32_;
	GeeList* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	const gchar* _tmp39_;
	gchar* _tmp40_;
	GString* _tmp41_;
	const gchar* _tmp42_;
	gchar* current_file_summary = NULL;
	gchar* _tmp43_;
	ImportManifest* _tmp44_;
	GeeList* _tmp45_;
	gint _tmp46_;
	gint _tmp47_;
	ImportManifest* _tmp82_;
	GeeList* _tmp83_;
	gint _tmp84_;
	gint _tmp85_;
	ImportManifest* _tmp116_;
	GeeList* _tmp117_;
	gint _tmp118_;
	gint _tmp119_;
	ImportManifest* _tmp150_;
	GeeList* _tmp151_;
	gint _tmp152_;
	gint _tmp153_;
	ImportManifest* _tmp184_;
	GeeList* _tmp185_;
	gint _tmp186_;
	gint _tmp187_;
	ImportManifest* _tmp222_;
	GeeList* _tmp223_;
	gint _tmp224_;
	gint _tmp225_;
	ImportManifest* _tmp256_;
	GeeList* _tmp257_;
	gint _tmp258_;
	gint _tmp259_;
	GString* _tmp290_;
	const gchar* _tmp291_;
	gchar* _tmp292_;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), NULL);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_string_new ("");
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strconcat (_ ("Import Results Report"), " (Shotwell ", NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strconcat (_tmp2_, RESOURCES_APP_VERSION, NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strconcat (_tmp4_, " @ ", NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_get_current_time (&_tmp7_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_time_val_to_iso8601 (&_tmp7_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_strconcat (_tmp6_, _tmp9_, NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strconcat (_tmp11_, ")\n\n", NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header = _tmp13_;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = builder;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = header;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp14_, _tmp15_);
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = manifest;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = _tmp16_->all;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_COLLECTION, GeeCollection));
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _tmp18_;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = manifest;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = _tmp20_->all;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_COLLECTION, GeeCollection));
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = _tmp22_;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = g_strdup_printf (ngettext ("Attempted to import %d file.", "Attempted to import %d files.", (gulong) _tmp19_), _tmp23_);
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp24_;
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = subhead;
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = g_strconcat (_tmp25_, " ", NULL);
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp26_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = subhead;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = manifest;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = _tmp28_->success;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_COLLECTION, GeeCollection));
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = manifest;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = _tmp32_->success;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_COLLECTION, GeeCollection));
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = _tmp34_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = g_strdup_printf (ngettext ("Of these, %d file was successfully imported.", "Of these, %d files were successfully imported.", (gulong) _tmp31_), _tmp35_);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = _tmp36_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = g_strconcat (_tmp27_, _tmp37_, NULL);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp38_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp37_);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = subhead;
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = g_strconcat (_tmp39_, "\n\n", NULL);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp40_;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = builder;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = subhead;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp41_, _tmp42_);
#line 221 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = g_strdup ("");
#line 221 "/home/jens/Source/shotwell/src/Dialogs.vala"
	current_file_summary = _tmp43_;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = manifest;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = _tmp44_->already_imported;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, GEE_TYPE_COLLECTION, GeeCollection));
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = _tmp46_;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp47_ > 0) {
#line 2505 "Dialogs.c"
		GString* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = builder;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp49_ = g_strconcat (_ ("Duplicate Photos/Videos Not Imported:"), "\n\n", NULL);
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _tmp49_;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp48_, _tmp50_);
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp50_);
#line 2519 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp51_;
			GeeList* _tmp52_;
			GeeList* _tmp53_;
			gint _result_size = 0;
			GeeList* _tmp54_;
			gint _tmp55_;
			gint _tmp56_;
			gint _result_index = 0;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp51_ = manifest;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp52_ = _tmp51_->already_imported;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp53_ = _g_object_ref0 (_tmp52_);
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp53_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp54_ = _result_list;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp55_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, GEE_TYPE_COLLECTION, GeeCollection));
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = _tmp55_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp56_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 2550 "Dialogs.c"
				gint _tmp57_;
				gint _tmp58_;
				gint _tmp59_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp60_;
				gint _tmp61_;
				gpointer _tmp62_;
				BatchImportResult* _tmp63_;
				const gchar* _tmp64_;
				gchar* _tmp65_;
				gchar* _tmp66_;
				gchar* _tmp67_;
				gchar* _tmp68_;
				gchar* _tmp69_;
				gchar* _tmp70_;
				BatchImportResult* _tmp71_;
				DuplicatedFile* _tmp72_;
				GFile* _tmp73_;
				GFile* _tmp74_;
				gchar* _tmp75_;
				gchar* _tmp76_;
				gchar* _tmp77_;
				gchar* _tmp78_;
				gchar* _tmp79_;
				GString* _tmp80_;
				const gchar* _tmp81_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp57_ = _result_index;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp57_ + 1;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp58_ = _result_index;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp59_ = _result_size;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp58_ < _tmp59_)) {
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 2589 "Dialogs.c"
				}
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp60_ = _result_list;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp61_ = _result_index;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp62_ = gee_list_get (_tmp60_, _tmp61_);
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp62_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp63_ = _result_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp64_ = _tmp63_->src_identifier;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp65_ = g_strconcat (_tmp64_, " ", NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp66_ = _tmp65_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp67_ = g_strconcat (_tmp66_, _ ("duplicates existing media item"), NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp68_ = _tmp67_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp69_ = g_strconcat (_tmp68_, "\n\t", NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp70_ = _tmp69_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp71_ = _result_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp72_ = _tmp71_->duplicate_of;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp73_ = duplicated_file_get_file (_tmp72_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp74_ = _tmp73_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp75_ = g_file_get_path (_tmp74_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp76_ = _tmp75_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp77_ = g_strconcat (_tmp70_, _tmp76_, NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp78_ = _tmp77_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp79_ = g_strconcat (_tmp78_, "\n\n", NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp79_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp78_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp76_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp74_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp70_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp68_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp66_);
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp80_ = builder;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp81_ = current_file_summary;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp80_, _tmp81_);
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 2657 "Dialogs.c"
			}
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 2661 "Dialogs.c"
		}
	}
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = manifest;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = _tmp82_->camera_failed;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, GEE_TYPE_COLLECTION, GeeCollection));
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp85_ = _tmp84_;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp85_ > 0) {
#line 2674 "Dialogs.c"
		GString* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = builder;
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = g_strconcat (_ ("Photos/Videos Not Imported Due to Camera Errors:"), "\n\n", NULL);
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = _tmp87_;
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp86_, _tmp88_);
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp88_);
#line 2688 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp89_;
			GeeList* _tmp90_;
			GeeList* _tmp91_;
			gint _result_size = 0;
			GeeList* _tmp92_;
			gint _tmp93_;
			gint _tmp94_;
			gint _result_index = 0;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp89_ = manifest;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp90_ = _tmp89_->camera_failed;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp91_ = _g_object_ref0 (_tmp90_);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp91_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp92_ = _result_list;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp93_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp92_, GEE_TYPE_COLLECTION, GeeCollection));
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = _tmp93_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp94_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 2719 "Dialogs.c"
				gint _tmp95_;
				gint _tmp96_;
				gint _tmp97_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp98_;
				gint _tmp99_;
				gpointer _tmp100_;
				BatchImportResult* _tmp101_;
				const gchar* _tmp102_;
				gchar* _tmp103_;
				gchar* _tmp104_;
				gchar* _tmp105_;
				gchar* _tmp106_;
				gchar* _tmp107_;
				gchar* _tmp108_;
				BatchImportResult* _tmp109_;
				const gchar* _tmp110_;
				gchar* _tmp111_;
				gchar* _tmp112_;
				gchar* _tmp113_;
				GString* _tmp114_;
				const gchar* _tmp115_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp95_ = _result_index;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp95_ + 1;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp96_ = _result_index;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp97_ = _result_size;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp96_ < _tmp97_)) {
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 2754 "Dialogs.c"
				}
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp98_ = _result_list;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp99_ = _result_index;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp100_ = gee_list_get (_tmp98_, _tmp99_);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp100_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp101_ = _result_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp102_ = _tmp101_->src_identifier;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp103_ = g_strconcat (_tmp102_, "\n\t", NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp104_ = _tmp103_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp105_ = g_strconcat (_tmp104_, _ ("error message:"), NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp106_ = _tmp105_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp107_ = g_strconcat (_tmp106_, " ", NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp108_ = _tmp107_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp109_ = _result_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp110_ = _tmp109_->errmsg;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp111_ = g_strconcat (_tmp108_, _tmp110_, NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp112_ = _tmp111_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp113_ = g_strconcat (_tmp112_, "\n\n", NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp113_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp112_);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp108_);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp106_);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp104_);
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp114_ = builder;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp115_ = current_file_summary;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp114_, _tmp115_);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 2810 "Dialogs.c"
			}
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 2814 "Dialogs.c"
		}
	}
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp116_ = manifest;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp117_ = _tmp116_->skipped_files;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp118_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, GEE_TYPE_COLLECTION, GeeCollection));
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp119_ = _tmp118_;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp119_ > 0) {
#line 2827 "Dialogs.c"
		GString* _tmp120_;
		gchar* _tmp121_;
		gchar* _tmp122_;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp120_ = builder;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp121_ = g_strconcat (_ ("Files Not Imported Because They Weren’t Recognized as Photos or Videos" \
":"), "\n\n", NULL);
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp122_ = _tmp121_;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp120_, _tmp122_);
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp122_);
#line 2841 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp123_;
			GeeList* _tmp124_;
			GeeList* _tmp125_;
			gint _result_size = 0;
			GeeList* _tmp126_;
			gint _tmp127_;
			gint _tmp128_;
			gint _result_index = 0;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp123_ = manifest;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp124_ = _tmp123_->skipped_files;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp125_ = _g_object_ref0 (_tmp124_);
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp125_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp126_ = _result_list;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp127_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, GEE_TYPE_COLLECTION, GeeCollection));
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp128_ = _tmp127_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp128_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 2872 "Dialogs.c"
				gint _tmp129_;
				gint _tmp130_;
				gint _tmp131_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp132_;
				gint _tmp133_;
				gpointer _tmp134_;
				BatchImportResult* _tmp135_;
				const gchar* _tmp136_;
				gchar* _tmp137_;
				gchar* _tmp138_;
				gchar* _tmp139_;
				gchar* _tmp140_;
				gchar* _tmp141_;
				gchar* _tmp142_;
				BatchImportResult* _tmp143_;
				const gchar* _tmp144_;
				gchar* _tmp145_;
				gchar* _tmp146_;
				gchar* _tmp147_;
				GString* _tmp148_;
				const gchar* _tmp149_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp129_ = _result_index;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp129_ + 1;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp130_ = _result_index;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp131_ = _result_size;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp130_ < _tmp131_)) {
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 2907 "Dialogs.c"
				}
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp132_ = _result_list;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp133_ = _result_index;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp134_ = gee_list_get (_tmp132_, _tmp133_);
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp134_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp135_ = _result_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp136_ = _tmp135_->src_identifier;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp137_ = g_strconcat (_tmp136_, "\n\t", NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp138_ = _tmp137_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp139_ = g_strconcat (_tmp138_, _ ("error message:"), NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp140_ = _tmp139_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp141_ = g_strconcat (_tmp140_, " ", NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp142_ = _tmp141_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp143_ = _result_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp144_ = _tmp143_->errmsg;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp145_ = g_strconcat (_tmp142_, _tmp144_, NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp146_ = _tmp145_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp147_ = g_strconcat (_tmp146_, "\n\n", NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp147_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp146_);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp142_);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp140_);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp138_);
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp148_ = builder;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp149_ = current_file_summary;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp148_, _tmp149_);
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 2963 "Dialogs.c"
			}
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 2967 "Dialogs.c"
		}
	}
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp150_ = manifest;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp151_ = _tmp150_->skipped_photos;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp152_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp151_, GEE_TYPE_COLLECTION, GeeCollection));
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp153_ = _tmp152_;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp153_ > 0) {
#line 2980 "Dialogs.c"
		GString* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp154_ = builder;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp155_ = g_strconcat (_ ("Photos/Videos Not Imported Because They Weren’t in a Format Shotwell U" \
"nderstands:"), "\n\n", NULL);
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp156_ = _tmp155_;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp154_, _tmp156_);
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp156_);
#line 2994 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp157_;
			GeeList* _tmp158_;
			GeeList* _tmp159_;
			gint _result_size = 0;
			GeeList* _tmp160_;
			gint _tmp161_;
			gint _tmp162_;
			gint _result_index = 0;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp157_ = manifest;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp158_ = _tmp157_->skipped_photos;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp159_ = _g_object_ref0 (_tmp158_);
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp159_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp160_ = _result_list;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp161_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp160_, GEE_TYPE_COLLECTION, GeeCollection));
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp162_ = _tmp161_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp162_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3025 "Dialogs.c"
				gint _tmp163_;
				gint _tmp164_;
				gint _tmp165_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp166_;
				gint _tmp167_;
				gpointer _tmp168_;
				BatchImportResult* _tmp169_;
				const gchar* _tmp170_;
				gchar* _tmp171_;
				gchar* _tmp172_;
				gchar* _tmp173_;
				gchar* _tmp174_;
				gchar* _tmp175_;
				gchar* _tmp176_;
				BatchImportResult* _tmp177_;
				const gchar* _tmp178_;
				gchar* _tmp179_;
				gchar* _tmp180_;
				gchar* _tmp181_;
				GString* _tmp182_;
				const gchar* _tmp183_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp163_ = _result_index;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp163_ + 1;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp164_ = _result_index;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp165_ = _result_size;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp164_ < _tmp165_)) {
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3060 "Dialogs.c"
				}
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp166_ = _result_list;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp167_ = _result_index;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp168_ = gee_list_get (_tmp166_, _tmp167_);
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp168_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp169_ = _result_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp170_ = _tmp169_->src_identifier;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp171_ = g_strconcat (_tmp170_, "\n\t", NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp172_ = _tmp171_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp173_ = g_strconcat (_tmp172_, _ ("error message:"), NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp174_ = _tmp173_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp175_ = g_strconcat (_tmp174_, " ", NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp176_ = _tmp175_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp177_ = _result_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp178_ = _tmp177_->errmsg;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp179_ = g_strconcat (_tmp176_, _tmp178_, NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp180_ = _tmp179_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp181_ = g_strconcat (_tmp180_, "\n\n", NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp181_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp180_);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp176_);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp174_);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp172_);
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp182_ = builder;
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp183_ = current_file_summary;
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp182_, _tmp183_);
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3116 "Dialogs.c"
			}
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3120 "Dialogs.c"
		}
	}
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp184_ = manifest;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp185_ = _tmp184_->write_failed;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp186_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp185_, GEE_TYPE_COLLECTION, GeeCollection));
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp187_ = _tmp186_;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp187_ > 0) {
#line 3133 "Dialogs.c"
		GString* _tmp188_;
		gchar* _tmp189_;
		gchar* _tmp190_;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp188_ = builder;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp189_ = g_strconcat (_ ("Photos/Videos Not Imported Because Shotwell Couldn’t Copy Them into it" \
"s Library:"), "\n\n", NULL);
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp190_ = _tmp189_;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp188_, _tmp190_);
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp190_);
#line 3147 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp191_;
			GeeList* _tmp192_;
			GeeList* _tmp193_;
			gint _result_size = 0;
			GeeList* _tmp194_;
			gint _tmp195_;
			gint _tmp196_;
			gint _result_index = 0;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp191_ = manifest;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp192_ = _tmp191_->write_failed;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp193_ = _g_object_ref0 (_tmp192_);
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp193_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp194_ = _result_list;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp195_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp194_, GEE_TYPE_COLLECTION, GeeCollection));
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp196_ = _tmp195_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp196_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3178 "Dialogs.c"
				gint _tmp197_;
				gint _tmp198_;
				gint _tmp199_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp200_;
				gint _tmp201_;
				gpointer _tmp202_;
				BatchImportResult* _tmp203_;
				const gchar* _tmp204_;
				BatchImportResult* _tmp205_;
				const gchar* _tmp206_;
				gchar* _tmp207_;
				gchar* _tmp208_;
				gchar* _tmp209_;
				gchar* _tmp210_;
				gchar* _tmp211_;
				gchar* _tmp212_;
				gchar* _tmp213_;
				gchar* _tmp214_;
				BatchImportResult* _tmp215_;
				const gchar* _tmp216_;
				gchar* _tmp217_;
				gchar* _tmp218_;
				gchar* _tmp219_;
				GString* _tmp220_;
				const gchar* _tmp221_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp197_ = _result_index;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp197_ + 1;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp198_ = _result_index;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp199_ = _result_size;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp198_ < _tmp199_)) {
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3217 "Dialogs.c"
				}
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp200_ = _result_list;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp201_ = _result_index;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp202_ = gee_list_get (_tmp200_, _tmp201_);
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp202_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp203_ = _result_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp204_ = _tmp203_->src_identifier;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp205_ = _result_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp206_ = _tmp205_->dest_identifier;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp207_ = g_strdup_printf (_ ("couldn’t copy %s\n\tto %s"), _tmp204_, _tmp206_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp208_ = _tmp207_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp209_ = g_strconcat (_tmp208_, "\n\t", NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp210_ = _tmp209_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp211_ = g_strconcat (_tmp210_, _ ("error message:"), NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp212_ = _tmp211_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp213_ = g_strconcat (_tmp212_, " ", NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp214_ = _tmp213_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp215_ = _result_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp216_ = _tmp215_->errmsg;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp217_ = g_strconcat (_tmp214_, _tmp216_, NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp218_ = _tmp217_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp219_ = g_strconcat (_tmp218_, "\n\n", NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp219_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp218_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp214_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp212_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp210_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp208_);
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp220_ = builder;
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp221_ = current_file_summary;
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp220_, _tmp221_);
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3283 "Dialogs.c"
			}
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3287 "Dialogs.c"
		}
	}
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp222_ = manifest;
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp223_ = _tmp222_->corrupt_files;
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp224_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp223_, GEE_TYPE_COLLECTION, GeeCollection));
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp225_ = _tmp224_;
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp225_ > 0) {
#line 3300 "Dialogs.c"
		GString* _tmp226_;
		gchar* _tmp227_;
		gchar* _tmp228_;
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp226_ = builder;
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp227_ = g_strconcat (_ ("Photos/Videos Not Imported Because Files Are Corrupt:"), "\n\n", NULL);
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp228_ = _tmp227_;
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp226_, _tmp228_);
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp228_);
#line 3314 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp229_;
			GeeList* _tmp230_;
			GeeList* _tmp231_;
			gint _result_size = 0;
			GeeList* _tmp232_;
			gint _tmp233_;
			gint _tmp234_;
			gint _result_index = 0;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp229_ = manifest;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp230_ = _tmp229_->corrupt_files;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp231_ = _g_object_ref0 (_tmp230_);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp231_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp232_ = _result_list;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp233_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp232_, GEE_TYPE_COLLECTION, GeeCollection));
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp234_ = _tmp233_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp234_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3345 "Dialogs.c"
				gint _tmp235_;
				gint _tmp236_;
				gint _tmp237_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp238_;
				gint _tmp239_;
				gpointer _tmp240_;
				BatchImportResult* _tmp241_;
				const gchar* _tmp242_;
				gchar* _tmp243_;
				gchar* _tmp244_;
				gchar* _tmp245_;
				gchar* _tmp246_;
				gchar* _tmp247_;
				gchar* _tmp248_;
				BatchImportResult* _tmp249_;
				const gchar* _tmp250_;
				gchar* _tmp251_;
				gchar* _tmp252_;
				gchar* _tmp253_;
				GString* _tmp254_;
				const gchar* _tmp255_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp235_ = _result_index;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp235_ + 1;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp236_ = _result_index;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp237_ = _result_size;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp236_ < _tmp237_)) {
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3380 "Dialogs.c"
				}
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp238_ = _result_list;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp239_ = _result_index;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp240_ = gee_list_get (_tmp238_, _tmp239_);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp240_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp241_ = _result_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp242_ = _tmp241_->src_identifier;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp243_ = g_strconcat (_tmp242_, "\n\t", NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp244_ = _tmp243_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp245_ = g_strconcat (_tmp244_, _ ("error message:"), NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp246_ = _tmp245_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp247_ = g_strconcat (_tmp246_, " |", NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp248_ = _tmp247_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp249_ = _result_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp250_ = _tmp249_->errmsg;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp251_ = g_strconcat (_tmp248_, _tmp250_, NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp252_ = _tmp251_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp253_ = g_strconcat (_tmp252_, "|\n\n", NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp253_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp252_);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp248_);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp246_);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp244_);
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp254_ = builder;
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp255_ = current_file_summary;
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp254_, _tmp255_);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3436 "Dialogs.c"
			}
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3440 "Dialogs.c"
		}
	}
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp256_ = manifest;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp257_ = _tmp256_->failed;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp258_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp257_, GEE_TYPE_COLLECTION, GeeCollection));
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp259_ = _tmp258_;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp259_ > 0) {
#line 3453 "Dialogs.c"
		GString* _tmp260_;
		gchar* _tmp261_;
		gchar* _tmp262_;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp260_ = builder;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp261_ = g_strconcat (_ ("Photos/Videos Not Imported for Other Reasons:"), "\n\n", NULL);
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp262_ = _tmp261_;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp260_, _tmp262_);
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp262_);
#line 3467 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp263_;
			GeeList* _tmp264_;
			GeeList* _tmp265_;
			gint _result_size = 0;
			GeeList* _tmp266_;
			gint _tmp267_;
			gint _tmp268_;
			gint _result_index = 0;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp263_ = manifest;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp264_ = _tmp263_->failed;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp265_ = _g_object_ref0 (_tmp264_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp265_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp266_ = _result_list;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp267_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp266_, GEE_TYPE_COLLECTION, GeeCollection));
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp268_ = _tmp267_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp268_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3498 "Dialogs.c"
				gint _tmp269_;
				gint _tmp270_;
				gint _tmp271_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp272_;
				gint _tmp273_;
				gpointer _tmp274_;
				BatchImportResult* _tmp275_;
				const gchar* _tmp276_;
				gchar* _tmp277_;
				gchar* _tmp278_;
				gchar* _tmp279_;
				gchar* _tmp280_;
				gchar* _tmp281_;
				gchar* _tmp282_;
				BatchImportResult* _tmp283_;
				const gchar* _tmp284_;
				gchar* _tmp285_;
				gchar* _tmp286_;
				gchar* _tmp287_;
				GString* _tmp288_;
				const gchar* _tmp289_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp269_ = _result_index;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp269_ + 1;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp270_ = _result_index;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp271_ = _result_size;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp270_ < _tmp271_)) {
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3533 "Dialogs.c"
				}
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp272_ = _result_list;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp273_ = _result_index;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp274_ = gee_list_get (_tmp272_, _tmp273_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp274_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp275_ = _result_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp276_ = _tmp275_->src_identifier;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp277_ = g_strconcat (_tmp276_, "\n\t", NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp278_ = _tmp277_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp279_ = g_strconcat (_tmp278_, _ ("error message:"), NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp280_ = _tmp279_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp281_ = g_strconcat (_tmp280_, " ", NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp282_ = _tmp281_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp283_ = _result_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp284_ = _tmp283_->errmsg;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp285_ = g_strconcat (_tmp282_, _tmp284_, NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp286_ = _tmp285_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp287_ = g_strconcat (_tmp286_, "\n\n", NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp287_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp286_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp282_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp280_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp278_);
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp288_ = builder;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp289_ = current_file_summary;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp288_, _tmp289_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3589 "Dialogs.c"
			}
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3593 "Dialogs.c"
		}
	}
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp290_ = builder;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp291_ = _tmp290_->str;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp292_ = g_strdup (_tmp291_);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp292_;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (current_file_summary);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (header);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_string_free0 (builder);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 3614 "Dialogs.c"
}


gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question) {
	gboolean result = FALSE;
	gchar* message = NULL;
	gchar* _tmp0_;
	ImportManifest* _tmp1_;
	GeeList* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	ImportManifest* _tmp49_;
	GeeList* _tmp50_;
	gint _tmp51_;
	gint _tmp52_;
	ImportManifest* _tmp111_;
	GeeList* _tmp112_;
	gint _tmp113_;
	gint _tmp114_;
	ImportManifest* _tmp173_;
	GeeList* _tmp174_;
	gint _tmp175_;
	gint _tmp176_;
	ImportManifest* _tmp235_;
	GeeList* _tmp236_;
	gint _tmp237_;
	gint _tmp238_;
	ImportManifest* _tmp297_;
	GeeList* _tmp298_;
	gint _tmp299_;
	gint _tmp300_;
	ImportManifest* _tmp325_;
	GeeList* _tmp326_;
	gint _tmp327_;
	gint _tmp328_;
	ImportManifest* _tmp346_;
	GeeList* _tmp347_;
	gint _tmp348_;
	gint _tmp349_;
	ImportManifest* _tmp408_;
	GeeList* _tmp409_;
	gint _tmp410_;
	gint _tmp411_;
	gint total = 0;
	ImportManifest* _tmp453_;
	GeeList* _tmp454_;
	gint _tmp455_;
	gint _tmp456_;
	ImportManifest* _tmp457_;
	GeeList* _tmp458_;
	gint _tmp459_;
	gint _tmp460_;
	ImportManifest* _tmp461_;
	GeeList* _tmp462_;
	gint _tmp463_;
	gint _tmp464_;
	ImportManifest* _tmp465_;
	GeeList* _tmp466_;
	gint _tmp467_;
	gint _tmp468_;
	ImportManifest* _tmp469_;
	GeeList* _tmp470_;
	gint _tmp471_;
	gint _tmp472_;
	ImportManifest* _tmp473_;
	GeeList* _tmp474_;
	gint _tmp475_;
	gint _tmp476_;
	ImportManifest* _tmp477_;
	GeeList* _tmp478_;
	gint _tmp479_;
	gint _tmp480_;
	ImportManifest* _tmp481_;
	GeeList* _tmp482_;
	gint _tmp483_;
	gint _tmp484_;
	ImportManifest* _tmp485_;
	GeeList* _tmp486_;
	gint _tmp487_;
	gint _tmp488_;
	gint _tmp489_;
	ImportManifest* _tmp490_;
	GeeList* _tmp491_;
	gint _tmp492_;
	gint _tmp493_;
	gint _tmp494_;
	GtkMessageDialog* dialog = NULL;
	gint dialog_response = 0;
	ImportUIQuestionParams* _tmp497_;
	gint _tmp575_;
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), FALSE);
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((question == NULL) || IMPORT_UI_IS_QUESTION_PARAMS (question), FALSE);
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup ("");
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp0_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = manifest;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_->already_imported;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_ > 0) {
#line 3723 "Dialogs.c"
		gchar* photos_message = NULL;
		ImportManifest* _tmp5_;
		GeeList* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		ImportManifest* _tmp9_;
		GeeList* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		gchar* _tmp13_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp14_;
		GeeList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		ImportManifest* _tmp18_;
		GeeList* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		gchar* _tmp22_;
		gchar* both_message = NULL;
		ImportManifest* _tmp23_;
		GeeList* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		ImportManifest* _tmp27_;
		GeeList* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		gchar* _tmp31_;
		const gchar* _tmp32_;
		ImportManifest* _tmp33_;
		GeeList* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
		const gchar* _tmp37_;
		const gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		const gchar* _tmp42_;
		ImportManifest* _tmp43_;
		GeeList* _tmp44_;
		gboolean _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = manifest;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_->already_imported;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = manifest;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_->already_imported;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection));
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp11_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = g_strdup_printf (ngettext ("1 duplicate photo was not imported:\n", "%d duplicate photos were not imported:\n", (gulong) _tmp8_), _tmp12_);
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp13_;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = manifest;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_->already_imported;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_COLLECTION, GeeCollection));
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = manifest;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_->already_imported;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_COLLECTION, GeeCollection));
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _tmp20_;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = g_strdup_printf (ngettext ("1 duplicate video was not imported:\n", "%d duplicate videos were not imported:\n", (gulong) _tmp17_), _tmp21_);
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp22_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = manifest;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_->already_imported;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_COLLECTION, GeeCollection));
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = _tmp25_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = manifest;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_->already_imported;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = _tmp29_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = g_strdup_printf (ngettext ("1 duplicate photo/video was not imported:\n", "%d duplicate photos/videos were not imported:\n", (gulong) _tmp26_), _tmp30_);
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp31_;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = manifest;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = _tmp33_->already_imported;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = photos_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = videos_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = both_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = both_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, GEE_TYPE_COLLECTION, GeeCollection), _tmp35_, _tmp36_, _tmp37_, _tmp38_);
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = _tmp39_;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = g_strconcat (_tmp32_, _tmp40_, NULL);
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp41_;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp40_);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = message;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = manifest;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = _tmp43_->already_imported;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = show_dest_id;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp46_ = import_ui_generate_import_failure_list (_tmp44_, _tmp45_);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = _tmp46_;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = g_strconcat (_tmp42_, _tmp47_, NULL);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp48_;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp47_);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 3883 "Dialogs.c"
	}
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = manifest;
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = _tmp49_->failed;
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GEE_TYPE_COLLECTION, GeeCollection));
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = _tmp51_;
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp52_ > 0) {
#line 3895 "Dialogs.c"
		const gchar* _tmp53_;
		gint _tmp54_;
		gint _tmp55_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp58_;
		GeeList* _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
		ImportManifest* _tmp62_;
		GeeList* _tmp63_;
		gint _tmp64_;
		gint _tmp65_;
		gchar* _tmp66_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp67_;
		GeeList* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		ImportManifest* _tmp71_;
		GeeList* _tmp72_;
		gint _tmp73_;
		gint _tmp74_;
		gchar* _tmp75_;
		gchar* both_message = NULL;
		ImportManifest* _tmp76_;
		GeeList* _tmp77_;
		gint _tmp78_;
		gint _tmp79_;
		ImportManifest* _tmp80_;
		GeeList* _tmp81_;
		gint _tmp82_;
		gint _tmp83_;
		gchar* _tmp84_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp85_;
		GeeList* _tmp86_;
		gint _tmp87_;
		gint _tmp88_;
		ImportManifest* _tmp89_;
		GeeList* _tmp90_;
		gint _tmp91_;
		gint _tmp92_;
		gchar* _tmp93_;
		const gchar* _tmp94_;
		ImportManifest* _tmp95_;
		GeeList* _tmp96_;
		const gchar* _tmp97_;
		const gchar* _tmp98_;
		const gchar* _tmp99_;
		const gchar* _tmp100_;
		gchar* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
		const gchar* _tmp104_;
		ImportManifest* _tmp105_;
		GeeList* _tmp106_;
		gboolean _tmp107_;
		gchar* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = message;
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp54_ = strlen (_tmp53_);
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp55_ = _tmp54_;
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp55_ > 0) {
#line 3964 "Dialogs.c"
			const gchar* _tmp56_;
			gchar* _tmp57_;
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = message;
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp57_ = g_strconcat (_tmp56_, "\n", NULL);
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp57_;
#line 3975 "Dialogs.c"
		}
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = manifest;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = _tmp58_->failed;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_COLLECTION, GeeCollection));
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = _tmp60_;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = manifest;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = _tmp62_->failed;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, GEE_TYPE_COLLECTION, GeeCollection));
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = _tmp64_;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = g_strdup_printf (ngettext ("1 photo failed to import due to a file or hardware error:\n", "%d photos failed to import due to a file or hardware error:\n", (gulong) _tmp61_), _tmp65_);
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp66_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = manifest;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = _tmp67_->failed;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_COLLECTION, GeeCollection));
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = _tmp69_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = manifest;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = _tmp71_->failed;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, GEE_TYPE_COLLECTION, GeeCollection));
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp74_ = _tmp73_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp75_ = g_strdup_printf (ngettext ("1 video failed to import due to a file or hardware error:\n", "%d videos failed to import due to a file or hardware error:\n", (gulong) _tmp70_), _tmp74_);
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp75_;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = manifest;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp77_ = _tmp76_->failed;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp78_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, GEE_TYPE_COLLECTION, GeeCollection));
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp79_ = _tmp78_;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = manifest;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = _tmp80_->failed;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, GEE_TYPE_COLLECTION, GeeCollection));
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = _tmp82_;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = g_strdup_printf (ngettext ("1 photo/video failed to import due to a file or hardware error:\n", "%d photos/videos failed to import due to a file or hardware error:\n", (gulong) _tmp79_), _tmp83_);
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp84_;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = manifest;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = _tmp85_->failed;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp86_, GEE_TYPE_COLLECTION, GeeCollection));
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = _tmp87_;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = manifest;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = _tmp89_->failed;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp90_, GEE_TYPE_COLLECTION, GeeCollection));
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = _tmp91_;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp93_ = g_strdup_printf (ngettext ("1 file failed to import due to a file or hardware error:\n", "%d files failed to import due to a file or hardware error:\n", (gulong) _tmp88_), _tmp92_);
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp93_;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp94_ = message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp95_ = manifest;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp96_ = _tmp95_->failed;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp97_ = photos_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp98_ = videos_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp99_ = both_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp100_ = neither_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp101_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, GEE_TYPE_COLLECTION, GeeCollection), _tmp97_, _tmp98_, _tmp99_, _tmp100_);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp102_ = _tmp101_;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp103_ = g_strconcat (_tmp94_, _tmp102_, NULL);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp103_;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp102_);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp104_ = message;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp105_ = manifest;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp106_ = _tmp105_->failed;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp107_ = show_dest_id;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp108_ = import_ui_generate_import_failure_list (_tmp106_, _tmp107_);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp109_ = _tmp108_;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp110_ = g_strconcat (_tmp104_, _tmp109_, NULL);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp110_;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp109_);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4111 "Dialogs.c"
	}
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp111_ = manifest;
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp112_ = _tmp111_->write_failed;
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp113_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp112_, GEE_TYPE_COLLECTION, GeeCollection));
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp114_ = _tmp113_;
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp114_ > 0) {
#line 4123 "Dialogs.c"
		const gchar* _tmp115_;
		gint _tmp116_;
		gint _tmp117_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp120_;
		GeeList* _tmp121_;
		gint _tmp122_;
		gint _tmp123_;
		ImportManifest* _tmp124_;
		GeeList* _tmp125_;
		gint _tmp126_;
		gint _tmp127_;
		gchar* _tmp128_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp129_;
		GeeList* _tmp130_;
		gint _tmp131_;
		gint _tmp132_;
		ImportManifest* _tmp133_;
		GeeList* _tmp134_;
		gint _tmp135_;
		gint _tmp136_;
		gchar* _tmp137_;
		gchar* both_message = NULL;
		ImportManifest* _tmp138_;
		GeeList* _tmp139_;
		gint _tmp140_;
		gint _tmp141_;
		ImportManifest* _tmp142_;
		GeeList* _tmp143_;
		gint _tmp144_;
		gint _tmp145_;
		gchar* _tmp146_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp147_;
		GeeList* _tmp148_;
		gint _tmp149_;
		gint _tmp150_;
		ImportManifest* _tmp151_;
		GeeList* _tmp152_;
		gint _tmp153_;
		gint _tmp154_;
		gchar* _tmp155_;
		const gchar* _tmp156_;
		ImportManifest* _tmp157_;
		GeeList* _tmp158_;
		const gchar* _tmp159_;
		const gchar* _tmp160_;
		const gchar* _tmp161_;
		const gchar* _tmp162_;
		gchar* _tmp163_;
		gchar* _tmp164_;
		gchar* _tmp165_;
		const gchar* _tmp166_;
		ImportManifest* _tmp167_;
		GeeList* _tmp168_;
		gboolean _tmp169_;
		gchar* _tmp170_;
		gchar* _tmp171_;
		gchar* _tmp172_;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp115_ = message;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = strlen (_tmp115_);
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp117_ = _tmp116_;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp117_ > 0) {
#line 4192 "Dialogs.c"
			const gchar* _tmp118_;
			gchar* _tmp119_;
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp118_ = message;
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp119_ = g_strconcat (_tmp118_, "\n", NULL);
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp119_;
#line 4203 "Dialogs.c"
		}
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp120_ = manifest;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp121_ = _tmp120_->write_failed;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp122_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, GEE_TYPE_COLLECTION, GeeCollection));
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = _tmp122_;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp124_ = manifest;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp125_ = _tmp124_->write_failed;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp126_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, GEE_TYPE_COLLECTION, GeeCollection));
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp127_ = _tmp126_;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp128_ = g_strdup_printf (ngettext ("1 photo failed to import because the photo library folder was not writ" \
"able:\n", "%d photos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp123_), _tmp127_);
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp128_;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp129_ = manifest;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp130_ = _tmp129_->write_failed;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp131_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp130_, GEE_TYPE_COLLECTION, GeeCollection));
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp132_ = _tmp131_;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp133_ = manifest;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp134_ = _tmp133_->write_failed;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp135_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, GEE_TYPE_COLLECTION, GeeCollection));
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp136_ = _tmp135_;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp137_ = g_strdup_printf (ngettext ("1 video failed to import because the photo library folder was not writ" \
"able:\n", "%d videos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp132_), _tmp136_);
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp137_;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp138_ = manifest;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp139_ = _tmp138_->write_failed;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp140_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp139_, GEE_TYPE_COLLECTION, GeeCollection));
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp141_ = _tmp140_;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp142_ = manifest;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp143_ = _tmp142_->write_failed;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp144_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp143_, GEE_TYPE_COLLECTION, GeeCollection));
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp145_ = _tmp144_;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp146_ = g_strdup_printf (ngettext ("1 photo/video failed to import because the photo library folder was no" \
"t writable:\n", "%d photos/videos failed to import because the photo library folder was" \
" not writable:\n", (gulong) _tmp141_), _tmp145_);
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp146_;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp147_ = manifest;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp148_ = _tmp147_->write_failed;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp149_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, GEE_TYPE_COLLECTION, GeeCollection));
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp150_ = _tmp149_;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp151_ = manifest;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp152_ = _tmp151_->write_failed;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp153_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp152_, GEE_TYPE_COLLECTION, GeeCollection));
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp154_ = _tmp153_;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp155_ = g_strdup_printf (ngettext ("1 file failed to import because the photo library folder was not writa" \
"ble:\n", "%d files failed to import because the photo library folder was not wri" \
"table:\n", (gulong) _tmp150_), _tmp154_);
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp155_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp156_ = message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp157_ = manifest;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp158_ = _tmp157_->write_failed;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp159_ = photos_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp160_ = videos_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp161_ = both_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp162_ = neither_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp163_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp158_, GEE_TYPE_COLLECTION, GeeCollection), _tmp159_, _tmp160_, _tmp161_, _tmp162_);
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp164_ = _tmp163_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp165_ = g_strconcat (_tmp156_, _tmp164_, NULL);
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp165_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp164_);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp166_ = message;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp167_ = manifest;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp168_ = _tmp167_->write_failed;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp169_ = show_dest_id;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp170_ = import_ui_generate_import_failure_list (_tmp168_, _tmp169_);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp171_ = _tmp170_;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp172_ = g_strconcat (_tmp166_, _tmp171_, NULL);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp172_;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp171_);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4339 "Dialogs.c"
	}
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp173_ = manifest;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp174_ = _tmp173_->camera_failed;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp175_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp174_, GEE_TYPE_COLLECTION, GeeCollection));
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp176_ = _tmp175_;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp176_ > 0) {
#line 4351 "Dialogs.c"
		const gchar* _tmp177_;
		gint _tmp178_;
		gint _tmp179_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp182_;
		GeeList* _tmp183_;
		gint _tmp184_;
		gint _tmp185_;
		ImportManifest* _tmp186_;
		GeeList* _tmp187_;
		gint _tmp188_;
		gint _tmp189_;
		gchar* _tmp190_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp191_;
		GeeList* _tmp192_;
		gint _tmp193_;
		gint _tmp194_;
		ImportManifest* _tmp195_;
		GeeList* _tmp196_;
		gint _tmp197_;
		gint _tmp198_;
		gchar* _tmp199_;
		gchar* both_message = NULL;
		ImportManifest* _tmp200_;
		GeeList* _tmp201_;
		gint _tmp202_;
		gint _tmp203_;
		ImportManifest* _tmp204_;
		GeeList* _tmp205_;
		gint _tmp206_;
		gint _tmp207_;
		gchar* _tmp208_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp209_;
		GeeList* _tmp210_;
		gint _tmp211_;
		gint _tmp212_;
		ImportManifest* _tmp213_;
		GeeList* _tmp214_;
		gint _tmp215_;
		gint _tmp216_;
		gchar* _tmp217_;
		const gchar* _tmp218_;
		ImportManifest* _tmp219_;
		GeeList* _tmp220_;
		const gchar* _tmp221_;
		const gchar* _tmp222_;
		const gchar* _tmp223_;
		const gchar* _tmp224_;
		gchar* _tmp225_;
		gchar* _tmp226_;
		gchar* _tmp227_;
		const gchar* _tmp228_;
		ImportManifest* _tmp229_;
		GeeList* _tmp230_;
		gboolean _tmp231_;
		gchar* _tmp232_;
		gchar* _tmp233_;
		gchar* _tmp234_;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp177_ = message;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp178_ = strlen (_tmp177_);
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp179_ = _tmp178_;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp179_ > 0) {
#line 4420 "Dialogs.c"
			const gchar* _tmp180_;
			gchar* _tmp181_;
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp180_ = message;
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp181_ = g_strconcat (_tmp180_, "\n", NULL);
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp181_;
#line 4431 "Dialogs.c"
		}
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp182_ = manifest;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp183_ = _tmp182_->camera_failed;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp184_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp183_, GEE_TYPE_COLLECTION, GeeCollection));
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp185_ = _tmp184_;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp186_ = manifest;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp187_ = _tmp186_->camera_failed;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp188_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp187_, GEE_TYPE_COLLECTION, GeeCollection));
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp189_ = _tmp188_;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp190_ = g_strdup_printf (ngettext ("1 photo failed to import due to a camera error:\n", "%d photos failed to import due to a camera error:\n", (gulong) _tmp185_), _tmp189_);
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp190_;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp191_ = manifest;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp192_ = _tmp191_->camera_failed;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp193_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp192_, GEE_TYPE_COLLECTION, GeeCollection));
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp194_ = _tmp193_;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp195_ = manifest;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp196_ = _tmp195_->camera_failed;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp197_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp196_, GEE_TYPE_COLLECTION, GeeCollection));
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp198_ = _tmp197_;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp199_ = g_strdup_printf (ngettext ("1 video failed to import due to a camera error:\n", "%d videos failed to import due to a camera error:\n", (gulong) _tmp194_), _tmp198_);
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp199_;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp200_ = manifest;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp201_ = _tmp200_->camera_failed;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp202_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp201_, GEE_TYPE_COLLECTION, GeeCollection));
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp203_ = _tmp202_;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp204_ = manifest;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp205_ = _tmp204_->camera_failed;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp206_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp205_, GEE_TYPE_COLLECTION, GeeCollection));
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp207_ = _tmp206_;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp208_ = g_strdup_printf (ngettext ("1 photo/video failed to import due to a camera error:\n", "%d photos/videos failed to import due to a camera error:\n", (gulong) _tmp203_), _tmp207_);
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp208_;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp209_ = manifest;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp210_ = _tmp209_->camera_failed;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp211_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp210_, GEE_TYPE_COLLECTION, GeeCollection));
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp212_ = _tmp211_;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp213_ = manifest;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp214_ = _tmp213_->camera_failed;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp215_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp214_, GEE_TYPE_COLLECTION, GeeCollection));
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp216_ = _tmp215_;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp217_ = g_strdup_printf (ngettext ("1 file failed to import due to a camera error:\n", "%d files failed to import due to a camera error:\n", (gulong) _tmp212_), _tmp216_);
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp217_;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp218_ = message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp219_ = manifest;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp220_ = _tmp219_->camera_failed;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp221_ = photos_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp222_ = videos_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp223_ = both_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp224_ = neither_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp225_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp220_, GEE_TYPE_COLLECTION, GeeCollection), _tmp221_, _tmp222_, _tmp223_, _tmp224_);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp226_ = _tmp225_;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp227_ = g_strconcat (_tmp218_, _tmp226_, NULL);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp227_;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp226_);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp228_ = message;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp229_ = manifest;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp230_ = _tmp229_->camera_failed;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp231_ = show_dest_id;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp232_ = import_ui_generate_import_failure_list (_tmp230_, _tmp231_);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp233_ = _tmp232_;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp234_ = g_strconcat (_tmp228_, _tmp233_, NULL);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp234_;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp233_);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4567 "Dialogs.c"
	}
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp235_ = manifest;
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp236_ = _tmp235_->corrupt_files;
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp237_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp236_, GEE_TYPE_COLLECTION, GeeCollection));
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp238_ = _tmp237_;
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp238_ > 0) {
#line 4579 "Dialogs.c"
		const gchar* _tmp239_;
		gint _tmp240_;
		gint _tmp241_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp244_;
		GeeList* _tmp245_;
		gint _tmp246_;
		gint _tmp247_;
		ImportManifest* _tmp248_;
		GeeList* _tmp249_;
		gint _tmp250_;
		gint _tmp251_;
		gchar* _tmp252_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp253_;
		GeeList* _tmp254_;
		gint _tmp255_;
		gint _tmp256_;
		ImportManifest* _tmp257_;
		GeeList* _tmp258_;
		gint _tmp259_;
		gint _tmp260_;
		gchar* _tmp261_;
		gchar* both_message = NULL;
		ImportManifest* _tmp262_;
		GeeList* _tmp263_;
		gint _tmp264_;
		gint _tmp265_;
		ImportManifest* _tmp266_;
		GeeList* _tmp267_;
		gint _tmp268_;
		gint _tmp269_;
		gchar* _tmp270_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp271_;
		GeeList* _tmp272_;
		gint _tmp273_;
		gint _tmp274_;
		ImportManifest* _tmp275_;
		GeeList* _tmp276_;
		gint _tmp277_;
		gint _tmp278_;
		gchar* _tmp279_;
		const gchar* _tmp280_;
		ImportManifest* _tmp281_;
		GeeList* _tmp282_;
		const gchar* _tmp283_;
		const gchar* _tmp284_;
		const gchar* _tmp285_;
		const gchar* _tmp286_;
		gchar* _tmp287_;
		gchar* _tmp288_;
		gchar* _tmp289_;
		const gchar* _tmp290_;
		ImportManifest* _tmp291_;
		GeeList* _tmp292_;
		gboolean _tmp293_;
		gchar* _tmp294_;
		gchar* _tmp295_;
		gchar* _tmp296_;
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp239_ = message;
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp240_ = strlen (_tmp239_);
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp241_ = _tmp240_;
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp241_ > 0) {
#line 4648 "Dialogs.c"
			const gchar* _tmp242_;
			gchar* _tmp243_;
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp242_ = message;
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp243_ = g_strconcat (_tmp242_, "\n", NULL);
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp243_;
#line 4659 "Dialogs.c"
		}
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp244_ = manifest;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp245_ = _tmp244_->corrupt_files;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp246_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp245_, GEE_TYPE_COLLECTION, GeeCollection));
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp247_ = _tmp246_;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp248_ = manifest;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp249_ = _tmp248_->corrupt_files;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp250_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp249_, GEE_TYPE_COLLECTION, GeeCollection));
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp251_ = _tmp250_;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp252_ = g_strdup_printf (ngettext ("1 photo failed to import because it was corrupt:\n", "%d photos failed to import because they were corrupt:\n", (gulong) _tmp247_), _tmp251_);
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp252_;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp253_ = manifest;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp254_ = _tmp253_->corrupt_files;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp255_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp254_, GEE_TYPE_COLLECTION, GeeCollection));
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp256_ = _tmp255_;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp257_ = manifest;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp258_ = _tmp257_->corrupt_files;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp259_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp258_, GEE_TYPE_COLLECTION, GeeCollection));
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp260_ = _tmp259_;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp261_ = g_strdup_printf (ngettext ("1 video failed to import because it was corrupt:\n", "%d videos failed to import because they were corrupt:\n", (gulong) _tmp256_), _tmp260_);
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp261_;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp262_ = manifest;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp263_ = _tmp262_->corrupt_files;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp264_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp263_, GEE_TYPE_COLLECTION, GeeCollection));
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp265_ = _tmp264_;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp266_ = manifest;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp267_ = _tmp266_->corrupt_files;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp268_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp267_, GEE_TYPE_COLLECTION, GeeCollection));
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp269_ = _tmp268_;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp270_ = g_strdup_printf (ngettext ("1 photo/video failed to import because it was corrupt:\n", "%d photos/videos failed to import because they were corrupt:\n", (gulong) _tmp265_), _tmp269_);
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp270_;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp271_ = manifest;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp272_ = _tmp271_->corrupt_files;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp273_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp272_, GEE_TYPE_COLLECTION, GeeCollection));
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp274_ = _tmp273_;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp275_ = manifest;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp276_ = _tmp275_->corrupt_files;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp277_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp276_, GEE_TYPE_COLLECTION, GeeCollection));
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp278_ = _tmp277_;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp279_ = g_strdup_printf (ngettext ("1 file failed to import because it was corrupt:\n", "%d files failed to import because it was corrupt:\n", (gulong) _tmp274_), _tmp278_);
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp279_;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp280_ = message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp281_ = manifest;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp282_ = _tmp281_->corrupt_files;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp283_ = photos_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp284_ = videos_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp285_ = both_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp286_ = neither_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp287_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp282_, GEE_TYPE_COLLECTION, GeeCollection), _tmp283_, _tmp284_, _tmp285_, _tmp286_);
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp288_ = _tmp287_;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp289_ = g_strconcat (_tmp280_, _tmp288_, NULL);
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp289_;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp288_);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp290_ = message;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp291_ = manifest;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp292_ = _tmp291_->corrupt_files;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp293_ = show_dest_id;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp294_ = import_ui_generate_import_failure_list (_tmp292_, _tmp293_);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp295_ = _tmp294_;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp296_ = g_strconcat (_tmp290_, _tmp295_, NULL);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp296_;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp295_);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4795 "Dialogs.c"
	}
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp297_ = manifest;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp298_ = _tmp297_->skipped_photos;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp299_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp298_, GEE_TYPE_COLLECTION, GeeCollection));
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp300_ = _tmp299_;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp300_ > 0) {
#line 4807 "Dialogs.c"
		const gchar* _tmp301_;
		gint _tmp302_;
		gint _tmp303_;
		gchar* skipped_photos_message = NULL;
		ImportManifest* _tmp306_;
		GeeList* _tmp307_;
		gint _tmp308_;
		gint _tmp309_;
		ImportManifest* _tmp310_;
		GeeList* _tmp311_;
		gint _tmp312_;
		gint _tmp313_;
		gchar* _tmp314_;
		const gchar* _tmp315_;
		const gchar* _tmp316_;
		gchar* _tmp317_;
		const gchar* _tmp318_;
		ImportManifest* _tmp319_;
		GeeList* _tmp320_;
		gboolean _tmp321_;
		gchar* _tmp322_;
		gchar* _tmp323_;
		gchar* _tmp324_;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp301_ = message;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp302_ = strlen (_tmp301_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp303_ = _tmp302_;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp303_ > 0) {
#line 4839 "Dialogs.c"
			const gchar* _tmp304_;
			gchar* _tmp305_;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp304_ = message;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp305_ = g_strconcat (_tmp304_, "\n", NULL);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp305_;
#line 4850 "Dialogs.c"
		}
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp306_ = manifest;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp307_ = _tmp306_->skipped_photos;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp308_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp307_, GEE_TYPE_COLLECTION, GeeCollection));
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp309_ = _tmp308_;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp310_ = manifest;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp311_ = _tmp310_->skipped_photos;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp312_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp311_, GEE_TYPE_COLLECTION, GeeCollection));
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp313_ = _tmp312_;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp314_ = g_strdup_printf (ngettext ("1 unsupported photo skipped:\n", "%d unsupported photos skipped:\n", (gulong) _tmp309_), _tmp313_);
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_photos_message = _tmp314_;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp315_ = message;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp316_ = skipped_photos_message;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp317_ = g_strconcat (_tmp315_, _tmp316_, NULL);
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp317_;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp318_ = message;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp319_ = manifest;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp320_ = _tmp319_->skipped_photos;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp321_ = show_dest_id;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp322_ = import_ui_generate_import_failure_list (_tmp320_, _tmp321_);
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp323_ = _tmp322_;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp324_ = g_strconcat (_tmp318_, _tmp323_, NULL);
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp324_;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp323_);
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_photos_message);
#line 4904 "Dialogs.c"
	}
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp325_ = manifest;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp326_ = _tmp325_->skipped_files;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp327_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp326_, GEE_TYPE_COLLECTION, GeeCollection));
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp328_ = _tmp327_;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp328_ > 0) {
#line 4916 "Dialogs.c"
		const gchar* _tmp329_;
		gint _tmp330_;
		gint _tmp331_;
		gchar* skipped_files_message = NULL;
		ImportManifest* _tmp334_;
		GeeList* _tmp335_;
		gint _tmp336_;
		gint _tmp337_;
		ImportManifest* _tmp338_;
		GeeList* _tmp339_;
		gint _tmp340_;
		gint _tmp341_;
		gchar* _tmp342_;
		const gchar* _tmp343_;
		const gchar* _tmp344_;
		gchar* _tmp345_;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp329_ = message;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp330_ = strlen (_tmp329_);
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp331_ = _tmp330_;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp331_ > 0) {
#line 4941 "Dialogs.c"
			const gchar* _tmp332_;
			gchar* _tmp333_;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp332_ = message;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp333_ = g_strconcat (_tmp332_, "\n", NULL);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp333_;
#line 4952 "Dialogs.c"
		}
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp334_ = manifest;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp335_ = _tmp334_->skipped_files;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp336_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp335_, GEE_TYPE_COLLECTION, GeeCollection));
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp337_ = _tmp336_;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp338_ = manifest;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp339_ = _tmp338_->skipped_files;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp340_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp339_, GEE_TYPE_COLLECTION, GeeCollection));
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp341_ = _tmp340_;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp342_ = g_strdup_printf (ngettext ("1 non-image file skipped.\n", "%d non-image files skipped.\n", (gulong) _tmp337_), _tmp341_);
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_files_message = _tmp342_;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp343_ = message;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp344_ = skipped_files_message;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp345_ = g_strconcat (_tmp343_, _tmp344_, NULL);
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp345_;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_files_message);
#line 4986 "Dialogs.c"
	}
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp346_ = manifest;
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp347_ = _tmp346_->aborted;
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp348_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp347_, GEE_TYPE_COLLECTION, GeeCollection));
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp349_ = _tmp348_;
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp349_ > 0) {
#line 4998 "Dialogs.c"
		const gchar* _tmp350_;
		gint _tmp351_;
		gint _tmp352_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp355_;
		GeeList* _tmp356_;
		gint _tmp357_;
		gint _tmp358_;
		ImportManifest* _tmp359_;
		GeeList* _tmp360_;
		gint _tmp361_;
		gint _tmp362_;
		gchar* _tmp363_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp364_;
		GeeList* _tmp365_;
		gint _tmp366_;
		gint _tmp367_;
		ImportManifest* _tmp368_;
		GeeList* _tmp369_;
		gint _tmp370_;
		gint _tmp371_;
		gchar* _tmp372_;
		gchar* both_message = NULL;
		ImportManifest* _tmp373_;
		GeeList* _tmp374_;
		gint _tmp375_;
		gint _tmp376_;
		ImportManifest* _tmp377_;
		GeeList* _tmp378_;
		gint _tmp379_;
		gint _tmp380_;
		gchar* _tmp381_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp382_;
		GeeList* _tmp383_;
		gint _tmp384_;
		gint _tmp385_;
		ImportManifest* _tmp386_;
		GeeList* _tmp387_;
		gint _tmp388_;
		gint _tmp389_;
		gchar* _tmp390_;
		const gchar* _tmp391_;
		ImportManifest* _tmp392_;
		GeeList* _tmp393_;
		const gchar* _tmp394_;
		const gchar* _tmp395_;
		const gchar* _tmp396_;
		const gchar* _tmp397_;
		gchar* _tmp398_;
		gchar* _tmp399_;
		gchar* _tmp400_;
		const gchar* _tmp401_;
		ImportManifest* _tmp402_;
		GeeList* _tmp403_;
		gboolean _tmp404_;
		gchar* _tmp405_;
		gchar* _tmp406_;
		gchar* _tmp407_;
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp350_ = message;
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp351_ = strlen (_tmp350_);
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp352_ = _tmp351_;
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp352_ > 0) {
#line 5067 "Dialogs.c"
			const gchar* _tmp353_;
			gchar* _tmp354_;
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp353_ = message;
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp354_ = g_strconcat (_tmp353_, "\n", NULL);
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp354_;
#line 5078 "Dialogs.c"
		}
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp355_ = manifest;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp356_ = _tmp355_->aborted;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp357_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp356_, GEE_TYPE_COLLECTION, GeeCollection));
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp358_ = _tmp357_;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp359_ = manifest;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp360_ = _tmp359_->aborted;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp361_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp360_, GEE_TYPE_COLLECTION, GeeCollection));
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp362_ = _tmp361_;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp363_ = g_strdup_printf (ngettext ("1 photo skipped due to user cancel:\n", "%d photos skipped due to user cancel:\n", (gulong) _tmp358_), _tmp362_);
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp363_;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp364_ = manifest;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp365_ = _tmp364_->aborted;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp366_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp365_, GEE_TYPE_COLLECTION, GeeCollection));
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp367_ = _tmp366_;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp368_ = manifest;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp369_ = _tmp368_->aborted;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp370_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp369_, GEE_TYPE_COLLECTION, GeeCollection));
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp371_ = _tmp370_;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp372_ = g_strdup_printf (ngettext ("1 video skipped due to user cancel:\n", "%d videos skipped due to user cancel:\n", (gulong) _tmp367_), _tmp371_);
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp372_;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp373_ = manifest;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp374_ = _tmp373_->aborted;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp375_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp374_, GEE_TYPE_COLLECTION, GeeCollection));
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp376_ = _tmp375_;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp377_ = manifest;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp378_ = _tmp377_->aborted;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp379_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp378_, GEE_TYPE_COLLECTION, GeeCollection));
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp380_ = _tmp379_;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp381_ = g_strdup_printf (ngettext ("1 photo/video skipped due to user cancel:\n", "%d photos/videos skipped due to user cancel:\n", (gulong) _tmp376_), _tmp380_);
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp381_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp382_ = manifest;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp383_ = _tmp382_->aborted;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp384_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp383_, GEE_TYPE_COLLECTION, GeeCollection));
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp385_ = _tmp384_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp386_ = manifest;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp387_ = _tmp386_->aborted;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp388_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp387_, GEE_TYPE_COLLECTION, GeeCollection));
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp389_ = _tmp388_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp390_ = g_strdup_printf (ngettext ("1 file skipped due to user cancel:\n", "%d file skipped due to user cancel:\n", (gulong) _tmp385_), _tmp389_);
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp390_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp391_ = message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp392_ = manifest;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp393_ = _tmp392_->aborted;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp394_ = photos_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp395_ = videos_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp396_ = both_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp397_ = neither_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp398_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp393_, GEE_TYPE_COLLECTION, GeeCollection), _tmp394_, _tmp395_, _tmp396_, _tmp397_);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp399_ = _tmp398_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp400_ = g_strconcat (_tmp391_, _tmp399_, NULL);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp400_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp399_);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp401_ = message;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp402_ = manifest;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp403_ = _tmp402_->aborted;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp404_ = show_dest_id;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp405_ = import_ui_generate_import_failure_list (_tmp403_, _tmp404_);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp406_ = _tmp405_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp407_ = g_strconcat (_tmp401_, _tmp406_, NULL);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp407_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp406_);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 5214 "Dialogs.c"
	}
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp408_ = manifest;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp409_ = _tmp408_->success;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp410_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp409_, GEE_TYPE_COLLECTION, GeeCollection));
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp411_ = _tmp410_;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp411_ > 0) {
#line 5226 "Dialogs.c"
		const gchar* _tmp412_;
		gint _tmp413_;
		gint _tmp414_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp417_;
		GeeList* _tmp418_;
		gint _tmp419_;
		gint _tmp420_;
		ImportManifest* _tmp421_;
		GeeList* _tmp422_;
		gint _tmp423_;
		gint _tmp424_;
		gchar* _tmp425_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp426_;
		GeeList* _tmp427_;
		gint _tmp428_;
		gint _tmp429_;
		ImportManifest* _tmp430_;
		GeeList* _tmp431_;
		gint _tmp432_;
		gint _tmp433_;
		gchar* _tmp434_;
		gchar* both_message = NULL;
		ImportManifest* _tmp435_;
		GeeList* _tmp436_;
		gint _tmp437_;
		gint _tmp438_;
		ImportManifest* _tmp439_;
		GeeList* _tmp440_;
		gint _tmp441_;
		gint _tmp442_;
		gchar* _tmp443_;
		const gchar* _tmp444_;
		ImportManifest* _tmp445_;
		GeeList* _tmp446_;
		const gchar* _tmp447_;
		const gchar* _tmp448_;
		const gchar* _tmp449_;
		gchar* _tmp450_;
		gchar* _tmp451_;
		gchar* _tmp452_;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp412_ = message;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp413_ = strlen (_tmp412_);
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp414_ = _tmp413_;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp414_ > 0) {
#line 5277 "Dialogs.c"
			const gchar* _tmp415_;
			gchar* _tmp416_;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp415_ = message;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp416_ = g_strconcat (_tmp415_, "\n", NULL);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp416_;
#line 5288 "Dialogs.c"
		}
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp417_ = manifest;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp418_ = _tmp417_->success;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp419_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp418_, GEE_TYPE_COLLECTION, GeeCollection));
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp420_ = _tmp419_;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp421_ = manifest;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp422_ = _tmp421_->success;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp423_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp422_, GEE_TYPE_COLLECTION, GeeCollection));
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp424_ = _tmp423_;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp425_ = g_strdup_printf (ngettext ("1 photo successfully imported.\n", "%d photos successfully imported.\n", (gulong) _tmp420_), _tmp424_);
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp425_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp426_ = manifest;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp427_ = _tmp426_->success;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp428_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp427_, GEE_TYPE_COLLECTION, GeeCollection));
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp429_ = _tmp428_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp430_ = manifest;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp431_ = _tmp430_->success;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp432_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp431_, GEE_TYPE_COLLECTION, GeeCollection));
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp433_ = _tmp432_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp434_ = g_strdup_printf (ngettext ("1 video successfully imported.\n", "%d videos successfully imported.\n", (gulong) _tmp429_), _tmp433_);
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp434_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp435_ = manifest;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp436_ = _tmp435_->success;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp437_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp436_, GEE_TYPE_COLLECTION, GeeCollection));
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp438_ = _tmp437_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp439_ = manifest;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp440_ = _tmp439_->success;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp441_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp440_, GEE_TYPE_COLLECTION, GeeCollection));
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp442_ = _tmp441_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp443_ = g_strdup_printf (ngettext ("1 photo/video successfully imported.\n", "%d photos/videos successfully imported.\n", (gulong) _tmp438_), _tmp442_);
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp443_;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp444_ = message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp445_ = manifest;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp446_ = _tmp445_->success;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp447_ = photos_message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp448_ = videos_message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp449_ = both_message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp450_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp446_, GEE_TYPE_COLLECTION, GeeCollection), _tmp447_, _tmp448_, _tmp449_, "");
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp451_ = _tmp450_;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp452_ = g_strconcat (_tmp444_, _tmp451_, NULL);
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp452_;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp451_);
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 5380 "Dialogs.c"
	}
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp453_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp454_ = _tmp453_->success;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp455_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp454_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp456_ = _tmp455_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp457_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp458_ = _tmp457_->failed;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp459_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp458_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp460_ = _tmp459_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp461_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp462_ = _tmp461_->camera_failed;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp463_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp462_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp464_ = _tmp463_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp465_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp466_ = _tmp465_->skipped_photos;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp467_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp466_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp468_ = _tmp467_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp469_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp470_ = _tmp469_->skipped_files;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp471_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp470_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp472_ = _tmp471_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp473_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp474_ = _tmp473_->corrupt_files;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp475_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp474_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp476_ = _tmp475_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp477_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp478_ = _tmp477_->already_imported;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp479_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp478_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp480_ = _tmp479_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp481_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp482_ = _tmp481_->aborted;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp483_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp482_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp484_ = _tmp483_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp485_ = manifest;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp486_ = _tmp485_->write_failed;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp487_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp486_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp488_ = _tmp487_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	total = (((((((_tmp456_ + _tmp460_) + _tmp464_) + _tmp468_) + _tmp472_) + _tmp476_) + _tmp480_) + _tmp484_) + _tmp488_;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp489_ = total;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp490_ = manifest;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp491_ = _tmp490_->all;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp492_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp491_, GEE_TYPE_COLLECTION, GeeCollection));
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp493_ = _tmp492_;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp489_ == _tmp493_, "total == manifest.all.size");
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp494_ = total;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp494_ == 0) {
#line 5472 "Dialogs.c"
		const gchar* _tmp495_;
		gchar* _tmp496_;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp495_ = message;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp496_ = g_strconcat (_tmp495_, _ ("No photos or videos imported.\n"), NULL);
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp496_;
#line 5483 "Dialogs.c"
	}
#line 525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = NULL;
#line 526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_response = (gint) GTK_RESPONSE_NONE;
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp497_ = question;
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp497_ == NULL) {
#line 5493 "Dialogs.c"
		AppWindow* _tmp498_;
		AppWindow* _tmp499_;
		const gchar* _tmp500_;
		GtkMessageDialog* _tmp501_;
		GtkMessageDialog* _tmp502_;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp503_;
		GtkWidget* _tmp504_;
		GtkWidget* _tmp505_;
		GtkWidget* _tmp506_;
		ImportManifest* _tmp507_;
		GeeList* _tmp508_;
		gint _tmp509_;
		gint _tmp510_;
		ImportManifest* _tmp511_;
		GeeList* _tmp512_;
		gint _tmp513_;
		gint _tmp514_;
		GtkWidget* ok_button = NULL;
		GtkMessageDialog* _tmp515_;
		GtkWidget* _tmp516_;
		GtkWidget* _tmp517_;
		GtkMessageDialog* _tmp518_;
		GtkWidget* _tmp519_;
		GtkWindow* dialog_parent = NULL;
		GtkMessageDialog* _tmp520_;
		GtkContainer* _tmp521_;
		GtkWindow* _tmp522_;
		GtkMessageDialog* _tmp523_;
		gint _tmp524_;
		GtkMessageDialog* _tmp525_;
		gint _tmp526_;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp498_ = app_window_get_instance ();
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp499_ = _tmp498_;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp500_ = message;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp501_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp499_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "%s", _tmp500_);
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp501_);
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp501_;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp499_);
#line 530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp502_ = dialog;
#line 530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp502_, gtk_window_get_type (), GtkWindow), _ ("Import Complete"));
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp503_ = dialog;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp504_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp503_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp505_ = _g_object_ref0 (_tmp504_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp505_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp506_ = save_results_button;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp507_ = manifest;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp508_ = _tmp507_->success;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp509_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp508_, GEE_TYPE_COLLECTION, GeeCollection));
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp510_ = _tmp509_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp511_ = manifest;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp512_ = _tmp511_->all;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp513_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp512_, GEE_TYPE_COLLECTION, GeeCollection));
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp514_ = _tmp513_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp506_, _tmp510_ < _tmp514_);
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp515_ = dialog;
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp516_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp515_, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp517_ = _g_object_ref0 (_tmp516_);
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ok_button = _tmp517_;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp518_ = dialog;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp519_ = ok_button;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp518_, gtk_window_get_type (), GtkWindow), _tmp519_);
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp520_ = dialog;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp521_ = (GtkContainer*) gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp520_, gtk_widget_get_type (), GtkWidget));
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp522_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp521_, gtk_window_get_type (), GtkWindow));
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_parent = _tmp522_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp523_ = dialog;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp524_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp523_, gtk_dialog_get_type (), GtkDialog));
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = _tmp524_;
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp525_ = dialog;
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp525_, gtk_widget_get_type (), GtkWidget));
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp526_ = dialog_response;
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp526_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID) {
#line 5610 "Dialogs.c"
			GtkWindow* _tmp527_;
			ImportManifest* _tmp528_;
			gchar* _tmp529_;
			gchar* _tmp530_;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp527_ = dialog_parent;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp528_ = manifest;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp529_ = import_ui_create_result_report_from_manifest (_tmp528_);
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp530_ = _tmp529_;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (_tmp527_, _tmp530_);
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp530_);
#line 5627 "Dialogs.c"
		}
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog_parent);
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (ok_button);
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 5635 "Dialogs.c"
	} else {
		const gchar* _tmp531_;
		ImportUIQuestionParams* _tmp532_;
		const gchar* _tmp533_;
		gchar* _tmp534_;
		gchar* _tmp535_;
		gchar* _tmp536_;
		AppWindow* _tmp537_;
		AppWindow* _tmp538_;
		const gchar* _tmp539_;
		GtkMessageDialog* _tmp540_;
		GtkMessageDialog* _tmp541_;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp542_;
		GtkWidget* _tmp543_;
		GtkWidget* _tmp544_;
		GtkWidget* _tmp545_;
		ImportManifest* _tmp546_;
		GeeList* _tmp547_;
		gint _tmp548_;
		gint _tmp549_;
		ImportManifest* _tmp550_;
		GeeList* _tmp551_;
		gint _tmp552_;
		gint _tmp553_;
		GtkWidget* no_button = NULL;
		GtkMessageDialog* _tmp554_;
		ImportUIQuestionParams* _tmp555_;
		const gchar* _tmp556_;
		GtkWidget* _tmp557_;
		GtkWidget* _tmp558_;
		GtkMessageDialog* _tmp559_;
		ImportUIQuestionParams* _tmp560_;
		const gchar* _tmp561_;
		GtkMessageDialog* _tmp562_;
		GtkWidget* _tmp563_;
		GtkMessageDialog* _tmp564_;
		gint _tmp565_;
		GtkMessageDialog* _tmp573_;
		GtkMessageDialog* _tmp574_;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp531_ = message;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp532_ = question;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp533_ = _tmp532_->question;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp534_ = g_strconcat ("\n", _tmp533_, NULL);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp535_ = _tmp534_;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp536_ = g_strconcat (_tmp531_, _tmp535_, NULL);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp536_;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp535_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp537_ = app_window_get_instance ();
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp538_ = _tmp537_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp539_ = message;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp540_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp538_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp539_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp540_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp540_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp538_);
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp541_ = dialog;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp541_, gtk_window_get_type (), GtkWindow), _ ("Import Complete"));
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp542_ = dialog;
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp543_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp542_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp544_ = _g_object_ref0 (_tmp543_);
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp544_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp545_ = save_results_button;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp546_ = manifest;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp547_ = _tmp546_->success;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp548_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp547_, GEE_TYPE_COLLECTION, GeeCollection));
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp549_ = _tmp548_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp550_ = manifest;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp551_ = _tmp550_->all;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp552_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp551_, GEE_TYPE_COLLECTION, GeeCollection));
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp553_ = _tmp552_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp545_, _tmp549_ < _tmp553_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp554_ = dialog;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp555_ = question;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp556_ = _tmp555_->no_button;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp557_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp554_, gtk_dialog_get_type (), GtkDialog), _tmp556_, (gint) GTK_RESPONSE_NO);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp558_ = _g_object_ref0 (_tmp557_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		no_button = _tmp558_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp559_ = dialog;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp560_ = question;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp561_ = _tmp560_->yes_button;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp559_, gtk_dialog_get_type (), GtkDialog), _tmp561_, (gint) GTK_RESPONSE_YES);
#line 555 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp562_ = dialog;
#line 555 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp563_ = no_button;
#line 555 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp562_, gtk_window_get_type (), GtkWindow), _tmp563_);
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp564_ = dialog;
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp565_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp564_, gtk_dialog_get_type (), GtkDialog));
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = _tmp565_;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 5776 "Dialogs.c"
			gint _tmp566_;
			GtkMessageDialog* _tmp567_;
			ImportManifest* _tmp568_;
			gchar* _tmp569_;
			gchar* _tmp570_;
			GtkMessageDialog* _tmp571_;
			gint _tmp572_;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp566_ = dialog_response;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!(_tmp566_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID)) {
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 5790 "Dialogs.c"
			}
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp567_ = dialog;
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp568_ = manifest;
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp569_ = import_ui_create_result_report_from_manifest (_tmp568_);
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp570_ = _tmp569_;
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (G_TYPE_CHECK_INSTANCE_CAST (_tmp567_, gtk_window_get_type (), GtkWindow), _tmp570_);
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp570_);
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp571_ = dialog;
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp572_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp571_, gtk_dialog_get_type (), GtkDialog));
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
			dialog_response = _tmp572_;
#line 5810 "Dialogs.c"
		}
#line 563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp573_ = dialog;
#line 563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp573_, gtk_widget_get_type (), GtkWidget));
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp574_ = dialog;
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp574_, gtk_widget_get_type (), GtkWidget));
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (no_button);
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 5824 "Dialogs.c"
	}
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp575_ = dialog_response;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp575_ == ((gint) GTK_RESPONSE_YES);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 5836 "Dialogs.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
#line 1428 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 5880 "Dialogs.c"
	}
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 5886 "Dialogs.c"
}


void import_ui_save_import_results (GtkWindow* chooser_dialog_parent, const gchar* results_log) {
	GtkFileChooserDialog* chooser_dialog = NULL;
	GtkWindow* _tmp0_;
	GtkFileChooserDialog* _tmp1_;
	GtkFileChooserDialog* _tmp2_;
	GtkFileChooserDialog* _tmp3_;
	const gchar* _tmp4_;
	GtkFileChooserDialog* _tmp5_;
	GtkFileChooserDialog* _tmp6_;
	gint dialog_result = 0;
	GtkFileChooserDialog* _tmp7_;
	gint _tmp8_;
	GFile* chosen_file = NULL;
	GtkFileChooserDialog* _tmp9_;
	GFile* _tmp10_;
	GtkFileChooserDialog* _tmp11_;
	GtkFileChooserDialog* _tmp12_;
	gboolean _tmp13_ = FALSE;
	gint _tmp14_;
	GError * _inner_error_ = NULL;
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((chooser_dialog_parent == NULL) || GTK_IS_WINDOW (chooser_dialog_parent));
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (results_log != NULL);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = chooser_dialog_parent;
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE, _tmp0_, GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_AS_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser_dialog = _tmp1_;
#line 574 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = chooser_dialog;
#line 574 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 575 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = chooser_dialog;
#line 575 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_get_home_dir ();
#line 575 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp4_);
#line 576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = chooser_dialog;
#line 576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), "Shotwell Import Log.txt");
#line 577 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = chooser_dialog;
#line 577 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = chooser_dialog;
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog));
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_result = _tmp8_;
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = chooser_dialog;
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = gtk_file_chooser_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chosen_file = _tmp10_;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = chooser_dialog;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = chooser_dialog;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget));
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = dialog_result;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 5964 "Dialogs.c"
		GFile* _tmp15_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = chosen_file;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp15_ != NULL;
#line 5970 "Dialogs.c"
	} else {
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = FALSE;
#line 5974 "Dialogs.c"
	}
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp13_) {
#line 5978 "Dialogs.c"
		{
			GFileOutputStream* outstream = NULL;
			GFile* _tmp16_;
			GFileOutputStream* _tmp17_;
			GFileOutputStream* _tmp18_;
			const gchar* _tmp19_;
			guint8* _tmp20_;
			gint _tmp20__length1;
			guint8* _tmp21_;
			gint _tmp21__length1;
			GFileOutputStream* _tmp22_;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = chosen_file;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = g_file_replace (_tmp16_, NULL, FALSE, G_FILE_CREATE_NONE, NULL, &_inner_error_);
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			outstream = _tmp17_;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5998 "Dialogs.c"
				goto __catch437_g_error;
			}
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = outstream;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = results_log;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = string_get_data (_tmp19_, &_tmp20__length1);
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _tmp20_;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21__length1 = _tmp20__length1;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_write (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, g_output_stream_get_type (), GOutputStream), _tmp21_, (gsize) _tmp21__length1, NULL, &_inner_error_);
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 6017 "Dialogs.c"
				goto __catch437_g_error;
			}
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = outstream;
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_close (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, g_output_stream_get_type (), GOutputStream), NULL, &_inner_error_);
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 6028 "Dialogs.c"
				goto __catch437_g_error;
			}
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (outstream);
#line 6033 "Dialogs.c"
		}
		goto __finally437;
		__catch437_g_error:
		{
			GError* err = NULL;
			GFile* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			GError* _tmp26_;
			const gchar* _tmp27_;
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			err = _inner_error_;
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_inner_error_ = NULL;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = chosen_file;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = g_file_get_path (_tmp23_);
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = _tmp24_;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = err;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _tmp26_->message;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("Dialogs.vala:590: couldn't save import results to log file %s: %s", _tmp25_, _tmp27_);
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp25_);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_error_free0 (err);
#line 6064 "Dialogs.c"
		}
		__finally437:
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chosen_file);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chooser_dialog);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_clear_error (&_inner_error_);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return;
#line 6079 "Dialogs.c"
		}
	}
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chosen_file);
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser_dialog);
#line 6086 "Dialogs.c"
}


static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self) {
	gboolean result;
	result = text_entry_dialog_mediator_on_modify_validate ((TextEntryDialogMediator*) self, text);
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6095 "Dialogs.c"
}


TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter) {
	TextEntryDialogMediator* self = NULL;
	TextEntryDialog* _tmp0_;
	TextEntryDialog* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GeeCollection* _tmp5_;
	const gchar* _tmp6_;
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((completion_list == NULL) || GEE_IS_COLLECTION (completion_list), NULL);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TextEntryDialogMediator*) g_type_create_instance (object_type);
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text_entry_dialog_new ();
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp0_;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = title;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = label;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = initial_text;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = completion_list;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = completion_delimiter;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_setup (_tmp1_, _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type, self, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6140 "Dialogs.c"
}


static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self, const gchar* text) {
	gboolean result = FALSE;
#line 607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6152 "Dialogs.c"
}


gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self, const gchar* text) {
#line 607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 6161 "Dialogs.c"
}


gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self) {
	gchar* result = NULL;
	TextEntryDialog* _tmp0_;
	gchar* _tmp1_;
#line 611 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text_entry_dialog_execute (_tmp0_);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6179 "Dialogs.c"
}


static void value_text_entry_dialog_mediator_init (GValue* value) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 6186 "Dialogs.c"
}


static void value_text_entry_dialog_mediator_free_value (GValue* value) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 6195 "Dialogs.c"
	}
}


static void value_text_entry_dialog_mediator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 6205 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6209 "Dialogs.c"
	}
}


static gpointer value_text_entry_dialog_mediator_peek_pointer (const GValue* value) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6217 "Dialogs.c"
}


static gchar* value_text_entry_dialog_mediator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 6224 "Dialogs.c"
		TextEntryDialogMediator * object;
		object = collect_values[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6231 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6235 "Dialogs.c"
		}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = text_entry_dialog_mediator_ref (object);
#line 6239 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6243 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6247 "Dialogs.c"
}


static gchar* value_text_entry_dialog_mediator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TextEntryDialogMediator ** object_p;
	object_p = collect_values[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6258 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 6264 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 6268 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6272 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6276 "Dialogs.c"
}


GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecTextEntryDialogMediator* spec;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 6290 "Dialogs.c"
}


gpointer value_get_text_entry_dialog_mediator (const GValue* value) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6299 "Dialogs.c"
}


void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	TextEntryDialogMediator * old;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6319 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6323 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 6329 "Dialogs.c"
	}
}


void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	TextEntryDialogMediator * old;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 6348 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6352 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 6358 "Dialogs.c"
	}
}


static void text_entry_dialog_mediator_class_init (TextEntryDialogMediatorClass * klass) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->finalize = text_entry_dialog_mediator_finalize;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (TextEntryDialogMediatorPrivate));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) text_entry_dialog_mediator_real_on_modify_validate;
#line 6372 "Dialogs.c"
}


static void text_entry_dialog_mediator_instance_init (TextEntryDialogMediator * self) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 6381 "Dialogs.c"
}


static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator * obj) {
	TextEntryDialogMediator * self;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 6393 "Dialogs.c"
}


GType text_entry_dialog_mediator_get_type (void) {
	static volatile gsize text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_text_entry_dialog_mediator_init, value_text_entry_dialog_mediator_free_value, value_text_entry_dialog_mediator_copy_value, value_text_entry_dialog_mediator_peek_pointer, "p", value_text_entry_dialog_mediator_collect_value, "p", value_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TextEntryDialogMediator), 0, (GInstanceInitFunc) text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType text_entry_dialog_mediator_type_id;
		text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&text_entry_dialog_mediator_type_id__volatile, text_entry_dialog_mediator_type_id);
	}
	return text_entry_dialog_mediator_type_id__volatile;
}


gpointer text_entry_dialog_mediator_ref (gpointer instance) {
	TextEntryDialogMediator * self;
	self = instance;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 6418 "Dialogs.c"
}


void text_entry_dialog_mediator_unref (gpointer instance) {
	TextEntryDialogMediator * self;
	self = instance;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6431 "Dialogs.c"
	}
}


static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self) {
	gboolean result;
	result = multi_text_entry_dialog_mediator_on_modify_validate ((MultiTextEntryDialogMediator*) self, text);
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6441 "Dialogs.c"
}


MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text) {
	MultiTextEntryDialogMediator* self = NULL;
	MultiTextEntryDialog* _tmp0_;
	MultiTextEntryDialog* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (MultiTextEntryDialogMediator*) g_type_create_instance (object_type);
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = multi_text_entry_dialog_new ();
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp0_;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = title;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = label;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = initial_text;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_setup (_tmp1_, _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type, self, _tmp2_, _tmp3_, _tmp4_);
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6478 "Dialogs.c"
}


static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text) {
	gboolean result = FALSE;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6490 "Dialogs.c"
}


gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text) {
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 6499 "Dialogs.c"
}


gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self) {
	gchar* result = NULL;
	MultiTextEntryDialog* _tmp0_;
	gchar* _tmp1_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = multi_text_entry_dialog_execute (_tmp0_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6517 "Dialogs.c"
}


static void value_multi_text_entry_dialog_mediator_init (GValue* value) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 6524 "Dialogs.c"
}


static void value_multi_text_entry_dialog_mediator_free_value (GValue* value) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 6533 "Dialogs.c"
	}
}


static void value_multi_text_entry_dialog_mediator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 6543 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6547 "Dialogs.c"
	}
}


static gpointer value_multi_text_entry_dialog_mediator_peek_pointer (const GValue* value) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6555 "Dialogs.c"
}


static gchar* value_multi_text_entry_dialog_mediator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 6562 "Dialogs.c"
		MultiTextEntryDialogMediator * object;
		object = collect_values[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6569 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6573 "Dialogs.c"
		}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (object);
#line 6577 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6581 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6585 "Dialogs.c"
}


static gchar* value_multi_text_entry_dialog_mediator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	MultiTextEntryDialogMediator ** object_p;
	object_p = collect_values[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6596 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 6602 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 6606 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6610 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6614 "Dialogs.c"
}


GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecMultiTextEntryDialogMediator* spec;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 6628 "Dialogs.c"
}


gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6637 "Dialogs.c"
}


void value_set_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	MultiTextEntryDialogMediator * old;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6657 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6661 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 6667 "Dialogs.c"
	}
}


void value_take_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	MultiTextEntryDialogMediator * old;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 6686 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6690 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 6696 "Dialogs.c"
	}
}


static void multi_text_entry_dialog_mediator_class_init (MultiTextEntryDialogMediatorClass * klass) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->finalize = multi_text_entry_dialog_mediator_finalize;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (MultiTextEntryDialogMediatorPrivate));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (MultiTextEntryDialogMediator *, const gchar*)) multi_text_entry_dialog_mediator_real_on_modify_validate;
#line 6710 "Dialogs.c"
}


static void multi_text_entry_dialog_mediator_instance_init (MultiTextEntryDialogMediator * self) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 6719 "Dialogs.c"
}


static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator * obj) {
	MultiTextEntryDialogMediator * self;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 6731 "Dialogs.c"
}


GType multi_text_entry_dialog_mediator_get_type (void) {
	static volatile gsize multi_text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&multi_text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_multi_text_entry_dialog_mediator_init, value_multi_text_entry_dialog_mediator_free_value, value_multi_text_entry_dialog_mediator_copy_value, value_multi_text_entry_dialog_mediator_peek_pointer, "p", value_multi_text_entry_dialog_mediator_collect_value, "p", value_multi_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (MultiTextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) multi_text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MultiTextEntryDialogMediator), 0, (GInstanceInitFunc) multi_text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType multi_text_entry_dialog_mediator_type_id;
		multi_text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "MultiTextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&multi_text_entry_dialog_mediator_type_id__volatile, multi_text_entry_dialog_mediator_type_id);
	}
	return multi_text_entry_dialog_mediator_type_id__volatile;
}


gpointer multi_text_entry_dialog_mediator_ref (gpointer instance) {
	MultiTextEntryDialogMediator * self;
	self = instance;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 6756 "Dialogs.c"
}


void multi_text_entry_dialog_mediator_unref (gpointer instance) {
	MultiTextEntryDialogMediator * self;
	self = instance;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6769 "Dialogs.c"
	}
}


gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape) {
	gchar* result = NULL;
	gboolean _tmp0_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
#line 638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = should_escape;
#line 638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 6787 "Dialogs.c"
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = primary_text;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = guarded_markup_escape_text (_tmp1_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp2_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = secondary_text;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = guarded_markup_escape_text (_tmp4_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp3_, _tmp6_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp6_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp3_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp8_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 6820 "Dialogs.c"
	}
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = primary_text;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = guarded_markup_escape_text (_tmp9_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = secondary_text;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp11_, _tmp12_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp14_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6840 "Dialogs.c"
}


EventRenameDialog* event_rename_dialog_construct (GType object_type, const gchar* event_name) {
	EventRenameDialog* self = NULL;
	const gchar* _tmp0_;
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = event_name;
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EventRenameDialog*) text_entry_dialog_mediator_construct (object_type, _ ("Rename Event"), _ ("Name:"), _tmp0_, NULL, NULL);
#line 649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6853 "Dialogs.c"
}


EventRenameDialog* event_rename_dialog_new (const gchar* event_name) {
#line 649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return event_rename_dialog_construct (TYPE_EVENT_RENAME_DIALOG, event_name);
#line 6860 "Dialogs.c"
}


static gchar* event_rename_dialog_real_execute (EventRenameDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event_prep_event_name (_tmp1_);
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6884 "Dialogs.c"
}


gchar* event_rename_dialog_execute (EventRenameDialog* self) {
#line 653 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EVENT_RENAME_DIALOG (self), NULL);
#line 653 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EVENT_RENAME_DIALOG_GET_CLASS (self)->execute (self);
#line 6893 "Dialogs.c"
}


static void event_rename_dialog_class_init (EventRenameDialogClass * klass) {
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
	event_rename_dialog_parent_class = g_type_class_peek_parent (klass);
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EventRenameDialogClass *) klass)->execute = (gchar* (*) (EventRenameDialog *)) event_rename_dialog_real_execute;
#line 6902 "Dialogs.c"
}


static void event_rename_dialog_instance_init (EventRenameDialog * self) {
}


GType event_rename_dialog_get_type (void) {
	static volatile gsize event_rename_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&event_rename_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EventRenameDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) event_rename_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EventRenameDialog), 0, (GInstanceInitFunc) event_rename_dialog_instance_init, NULL };
		GType event_rename_dialog_type_id;
		event_rename_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EventRenameDialog", &g_define_type_info, 0);
		g_once_init_leave (&event_rename_dialog_type_id__volatile, event_rename_dialog_type_id);
	}
	return event_rename_dialog_type_id__volatile;
}


EditTitleDialog* edit_title_dialog_construct (GType object_type, const gchar* photo_title) {
	EditTitleDialog* self = NULL;
	const gchar* _tmp0_;
#line 661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = photo_title;
#line 661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditTitleDialog*) text_entry_dialog_mediator_construct (object_type, C_ ("Dialog Title", "Edit Title"), _ ("Title:"), _tmp0_, NULL, NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6931 "Dialogs.c"
}


EditTitleDialog* edit_title_dialog_new (const gchar* photo_title) {
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_title_dialog_construct (TYPE_EDIT_TITLE_DIALOG, photo_title);
#line 6938 "Dialogs.c"
}


static gchar* edit_title_dialog_real_execute (EditTitleDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_title (_tmp1_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6962 "Dialogs.c"
}


gchar* edit_title_dialog_execute (EditTitleDialog* self) {
#line 665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_TITLE_DIALOG (self), NULL);
#line 665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_TITLE_DIALOG_GET_CLASS (self)->execute (self);
#line 6971 "Dialogs.c"
}


static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	EditTitleDialog * self;
	gboolean result = FALSE;
#line 669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_TITLE_DIALOG, EditTitleDialog);
#line 669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6986 "Dialogs.c"
}


static void edit_title_dialog_class_init (EditTitleDialogClass * klass) {
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_title_dialog_parent_class = g_type_class_peek_parent (klass);
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditTitleDialogClass *) klass)->execute = (gchar* (*) (EditTitleDialog *)) edit_title_dialog_real_execute;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) edit_title_dialog_real_on_modify_validate;
#line 6997 "Dialogs.c"
}


static void edit_title_dialog_instance_init (EditTitleDialog * self) {
}


GType edit_title_dialog_get_type (void) {
	static volatile gsize edit_title_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_title_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditTitleDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_title_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditTitleDialog), 0, (GInstanceInitFunc) edit_title_dialog_instance_init, NULL };
		GType edit_title_dialog_type_id;
		edit_title_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EditTitleDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_title_dialog_type_id__volatile, edit_title_dialog_type_id);
	}
	return edit_title_dialog_type_id__volatile;
}


EditCommentDialog* edit_comment_dialog_construct (GType object_type, const gchar* comment, gboolean is_event) {
	EditCommentDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_;
	gchar* title_tmp = NULL;
	gchar* _tmp2_;
	const gchar* _tmp3_;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = is_event;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Edit Event Comment");
#line 7030 "Dialogs.c"
	} else {
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Edit Photo/Video Comment");
#line 7034 "Dialogs.c"
	}
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strdup (_tmp0_);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title_tmp = _tmp2_;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = comment;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditCommentDialog*) multi_text_entry_dialog_mediator_construct (object_type, title_tmp, _ ("Comment:"), _tmp3_);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title_tmp);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 7048 "Dialogs.c"
}


EditCommentDialog* edit_comment_dialog_new (const gchar* comment, gboolean is_event) {
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_comment_dialog_construct (TYPE_EDIT_COMMENT_DIALOG, comment, is_event);
#line 7055 "Dialogs.c"
}


static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _multi_text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator));
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_comment (_tmp1_);
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7079 "Dialogs.c"
}


gchar* edit_comment_dialog_execute (EditCommentDialog* self) {
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_COMMENT_DIALOG (self), NULL);
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_COMMENT_DIALOG_GET_CLASS (self)->execute (self);
#line 7088 "Dialogs.c"
}


static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base, const gchar* text) {
	EditCommentDialog * self;
	gboolean result = FALSE;
#line 687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog);
#line 687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7103 "Dialogs.c"
}


static void edit_comment_dialog_class_init (EditCommentDialogClass * klass) {
#line 674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_comment_dialog_parent_class = g_type_class_peek_parent (klass);
#line 674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditCommentDialogClass *) klass)->execute = (gchar* (*) (EditCommentDialog *)) edit_comment_dialog_real_execute;
#line 674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (MultiTextEntryDialogMediator *, const gchar*)) edit_comment_dialog_real_on_modify_validate;
#line 7114 "Dialogs.c"
}


static void edit_comment_dialog_instance_init (EditCommentDialog * self) {
}


GType edit_comment_dialog_get_type (void) {
	static volatile gsize edit_comment_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_comment_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditCommentDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_comment_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditCommentDialog), 0, (GInstanceInitFunc) edit_comment_dialog_instance_init, NULL };
		GType edit_comment_dialog_type_id;
		edit_comment_dialog_type_id = g_type_register_static (TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, "EditCommentDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_comment_dialog_type_id__volatile, edit_comment_dialog_type_id);
	}
	return edit_comment_dialog_type_id__volatile;
}


GtkResponseType remove_from_library_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message, gint count) {
	GtkResponseType result = 0;
	gchar* trash_action = NULL;
	gint _tmp0_;
	gchar* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp2_;
	const gchar* _tmp3_;
	GtkMessageDialog* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkResponseType _result_ = 0;
	gint _tmp9_;
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (ngettext ("Remove and _Trash File", "Remove and _Trash Files", (gulong) _tmp0_));
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	trash_action = _tmp1_;
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = owner;
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = user_message;
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp2_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CANCEL, "%s", _tmp3_);
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp4_);
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Remove From Library"), (gint) GTK_RESPONSE_NO);
#line 701 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), trash_action, (gint) GTK_RESPONSE_YES);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = title;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = user_message;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = build_alert_body_text (_tmp5_, _tmp6_, TRUE);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp8_);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp8_);
#line 708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp9_;
#line 710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (trash_action);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7201 "Dialogs.c"
}


GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message) {
	GtkResponseType result = 0;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp0_;
	const gchar* _tmp1_;
	GtkMessageDialog* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GtkResponseType _result_ = 0;
	gint _tmp7_;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = owner;
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = user_message;
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp1_);
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp2_);
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp2_;
#line 720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Keep"), (gint) GTK_RESPONSE_NO);
#line 721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Delete"), (gint) GTK_RESPONSE_YES);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_NO);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = title;
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = user_message;
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = build_alert_body_text (_tmp3_, _tmp4_, TRUE);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp6_);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp7_;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 730 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 730 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 730 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7263 "Dialogs.c"
}


gboolean revert_editable_dialog (GtkWindow* owner, GeeCollection* photos) {
	gboolean result = FALSE;
	gint count = 0;
	gint _tmp9_;
	const gchar* _tmp10_ = NULL;
	gint _tmp11_;
	gchar* headline = NULL;
	gchar* _tmp12_;
	gchar* msg = NULL;
	gint _tmp13_;
	gint _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_ = NULL;
	gint _tmp17_;
	gchar* action = NULL;
	gchar* _tmp18_;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp19_;
	const gchar* _tmp20_;
	GtkMessageDialog* _tmp21_;
	GtkMessageDialog* _tmp22_;
	GtkMessageDialog* _tmp23_;
	const gchar* _tmp24_;
	GtkMessageDialog* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp30_;
	gint _tmp31_;
	GtkMessageDialog* _tmp32_;
	GtkResponseType _tmp33_;
#line 733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (photos), FALSE);
#line 734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = 0;
#line 7306 "Dialogs.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeCollection* _tmp0_;
		GeeIterator* _tmp1_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = photos;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_photo_it = _tmp1_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 7319 "Dialogs.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			Photo* photo = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			Photo* _tmp6_;
			gboolean _tmp7_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _photo_it;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 7335 "Dialogs.c"
			}
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _photo_it;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			photo = (Photo*) _tmp5_;
#line 736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = photo;
#line 736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = photo_has_editable (_tmp6_);
#line 736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp7_) {
#line 7349 "Dialogs.c"
				gint _tmp8_;
#line 737 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = count;
#line 737 "/home/jens/Source/shotwell/src/Dialogs.vala"
				count = _tmp8_ + 1;
#line 7355 "Dialogs.c"
			}
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (photo);
#line 7359 "Dialogs.c"
		}
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_photo_it);
#line 7363 "Dialogs.c"
	}
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = count;
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ == 0) {
#line 741 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 741 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7373 "Dialogs.c"
	}
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = count;
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_ == 1) {
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _ ("Revert External Edit?");
#line 7381 "Dialogs.c"
	} else {
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _ ("Revert External Edits?");
#line 7385 "Dialogs.c"
	}
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strdup (_tmp10_);
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	headline = _tmp12_;
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = count;
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = count;
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_strdup_printf (ngettext ("This will destroy all changes made to the external file. Continue?", "This will destroy all changes made to %d external files. Continue?", (gulong) _tmp13_), _tmp14_);
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp15_;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = count;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp17_ == 1) {
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _ ("Re_vert External Edit");
#line 7405 "Dialogs.c"
	} else {
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _ ("Re_vert External Edits");
#line 7409 "Dialogs.c"
	}
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = g_strdup (_tmp16_);
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	action = _tmp18_;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = owner;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = msg;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp19_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp20_);
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp21_);
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp21_;
#line 753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = dialog;
#line 753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = dialog;
#line 754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = action;
#line 754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_dialog_get_type (), GtkDialog), _tmp24_, (gint) GTK_RESPONSE_YES);
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = dialog;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = headline;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = msg;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = build_alert_body_text (_tmp26_, _tmp27_, TRUE);
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = _tmp28_;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (_tmp25_, _tmp29_);
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp29_);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = dialog;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_dialog_get_type (), GtkDialog));
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp31_;
#line 760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = dialog;
#line 760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = _result_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp33_ == GTK_RESPONSE_YES;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (action);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (headline);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7473 "Dialogs.c"
}


gboolean remove_offline_dialog (GtkWindow* owner, gint count) {
	gboolean result = FALSE;
	gint _tmp0_;
	gchar* msg = NULL;
	gint _tmp1_;
	gint _tmp2_;
	gchar* _tmp3_;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp4_;
	const gchar* _tmp5_;
	GtkMessageDialog* _tmp6_;
	GtkMessageDialog* _tmp7_;
	GtkMessageDialog* _tmp8_;
	const gchar* _tmp9_ = NULL;
	gint _tmp10_;
	GtkMessageDialog* _tmp11_;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp12_;
	gint _tmp13_;
	GtkMessageDialog* _tmp14_;
	GtkResponseType _tmp15_;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == 0) {
#line 767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7508 "Dialogs.c"
	}
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = count;
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = count;
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf (ngettext ("This will remove the photo from the library. Continue?", "This will remove %d photos from the library. Continue?", (gulong) _tmp1_), _tmp2_);
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp3_;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = owner;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = msg;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp4_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp5_);
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp6_;
#line 776 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = dialog;
#line 776 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = dialog;
#line 777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_dialog_get_type (), GtkDialog), _ ("_Remove"), (gint) GTK_RESPONSE_OK);
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = count;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp10_ == 1) {
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _ ("Remove Photo From Library");
#line 7542 "Dialogs.c"
	} else {
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _ ("Remove Photos From Library");
#line 7546 "Dialogs.c"
	}
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = dialog;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_window_get_type (), GtkWindow), _tmp9_);
#line 780 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = dialog;
#line 780 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_dialog_get_type (), GtkDialog));
#line 780 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp13_;
#line 782 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = dialog;
#line 782 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget));
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = _result_;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp15_ == GTK_RESPONSE_OK;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7572 "Dialogs.c"
}


void multiple_object_error_dialog (GeeArrayList* objects, const gchar* message, const gchar* title) {
	gchar* dialog_message = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gint remainder = 0;
	GeeArrayList* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp30_;
	AppWindow* _tmp31_;
	const gchar* _tmp32_;
	GtkMessageDialog* _tmp33_;
	GtkMessageDialog* _tmp34_;
	const gchar* _tmp35_;
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_ARRAY_LIST (objects));
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (message != NULL);
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = message;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strconcat (_tmp0_, "\n", NULL);
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_message = _tmp1_;
#line 7604 "Dialogs.c"
	{
		gint i = 0;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 7609 "Dialogs.c"
		{
			gboolean _tmp2_ = FALSE;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = TRUE;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 7616 "Dialogs.c"
				gboolean _tmp4_ = FALSE;
				gint _tmp5_;
				const gchar* _tmp10_;
				GeeArrayList* _tmp11_;
				gint _tmp12_;
				gpointer _tmp13_;
				DataObject* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp2_) {
#line 7631 "Dialogs.c"
					gint _tmp3_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp3_ = i;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					i = _tmp3_ + 1;
#line 7637 "Dialogs.c"
				}
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp2_ = FALSE;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp5_ = i;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp5_ < MAX_OBJECTS_DISPLAYED) {
#line 7645 "Dialogs.c"
					GeeArrayList* _tmp6_;
					gint _tmp7_;
					gint _tmp8_;
					gint _tmp9_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = objects;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = _tmp7_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = i;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = _tmp8_ > _tmp9_;
#line 7660 "Dialogs.c"
				} else {
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = FALSE;
#line 7664 "Dialogs.c"
				}
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp4_) {
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 7670 "Dialogs.c"
				}
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = dialog_message;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = objects;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = i;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp12_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = (DataObject*) _tmp13_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = data_object_to_string (_tmp14_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = _tmp15_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp17_ = g_strconcat ("\n", _tmp16_, NULL);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = _tmp17_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = g_strconcat (_tmp10_, _tmp18_, NULL);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (dialog_message);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				dialog_message = _tmp19_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp18_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp16_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp14_);
#line 7702 "Dialogs.c"
			}
		}
	}
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = objects;
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remainder = _tmp22_ - MAX_OBJECTS_DISPLAYED;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = remainder;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp23_ > 0) {
#line 7718 "Dialogs.c"
		const gchar* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = dialog_message;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = remainder;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = remainder;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = g_strdup_printf (ngettext ("\n\nAnd %d other.", "\n\nAnd %d others.", (gulong) _tmp25_), _tmp26_);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = g_strconcat (_tmp24_, _tmp28_, NULL);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (dialog_message);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_message = _tmp29_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp28_);
#line 7743 "Dialogs.c"
	}
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = app_window_get_instance ();
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = dialog_message;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", _tmp32_);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp33_);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = _tmp33_;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp31_);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp34_;
#line 805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = title;
#line 805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _tmp35_);
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (dialog_message);
#line 7773 "Dialogs.c"
}


TagsDialog* tags_dialog_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text) {
	TagsDialog* self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	HierarchicalTagIndex* _tmp3_;
	HierarchicalTagIndex* _tmp4_;
	GeeCollection* _tmp5_;
	GeeCollection* _tmp6_;
#line 812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = label;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = initial_text;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = hierarchical_tag_index_get_global_index ();
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = hierarchical_tag_index_get_all_tags (_tmp4_);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TagsDialog*) text_entry_dialog_mediator_construct (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp6_, ",");
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp6_);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp4_);
#line 812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 7812 "Dialogs.c"
}


static void tags_dialog_class_init (TagsDialogClass * klass) {
#line 811 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 7819 "Dialogs.c"
}


static void tags_dialog_instance_init (TagsDialog * self) {
}


GType tags_dialog_get_type (void) {
	static volatile gsize tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsDialog), 0, (GInstanceInitFunc) tags_dialog_instance_init, NULL };
		GType tags_dialog_type_id;
		tags_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "TagsDialog", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&tags_dialog_type_id__volatile, tags_dialog_type_id);
	}
	return tags_dialog_type_id__volatile;
}


AddTagsDialog* add_tags_dialog_construct (GType object_type) {
	AddTagsDialog* self = NULL;
	gchar* title = NULL;
	gchar* _tmp0_;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (g_dpgettext2 (NULL, "Dialog Title", RESOURCES_ADD_TAGS_TITLE));
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title = _tmp0_;
#line 822 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (AddTagsDialog*) tags_dialog_construct (object_type, title, _ ("Tags (separated by commas):"), NULL);
#line 819 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title);
#line 819 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 7853 "Dialogs.c"
}


AddTagsDialog* add_tags_dialog_new (void) {
#line 819 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return add_tags_dialog_construct (TYPE_ADD_TAGS_DIALOG);
#line 7860 "Dialogs.c"
}


gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1) {
	gchar** result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gchar** _tmp6_;
	gint _tmp6__length1;
	gint _tmp7_;
	gchar** _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
	gchar** _tmp10_;
	gint _tmp10__length1;
#line 825 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADD_TAGS_DIALOG (self), NULL);
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 7890 "Dialogs.c"
		gchar** _tmp2_;
		gint _tmp2__length1;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = NULL;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2__length1 = 0;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (result_length1) {
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
			*result_length1 = _tmp2__length1;
#line 7901 "Dialogs.c"
		}
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp2_;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7909 "Dialogs.c"
	}
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_ = g_strsplit (_tmp3_, ",", 0);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__length1 = _vala_array_length (_tmp4_);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = tag_prep_tag_names (_tmp6_, _vala_array_length (_tmp4_), &_tmp7_);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = _tmp7_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10__length1 = _tmp9__length1;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (result_length1) {
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*result_length1 = _tmp10__length1;
#line 7935 "Dialogs.c"
	}
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp10_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7943 "Dialogs.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1403 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1403 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 7963 "Dialogs.c"
}


static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	AddTagsDialog * self;
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	gchar** names = NULL;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gint _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	gint names_length1;
	gint _names_size_;
	gchar** _tmp9_;
	gint _tmp9__length1;
#line 835 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_ADD_TAGS_DIALOG, AddTagsDialog);
#line 835 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = string_contains (_tmp0_, TAG_PATH_SEPARATOR_STRING);
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 8000 "Dialogs.c"
	}
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = text;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_ = g_strsplit (_tmp2_, ",", 0);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = _vala_array_length (_tmp3_);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = tag_prep_tag_names (_tmp5_, _vala_array_length (_tmp3_), &_tmp6_);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8__length1 = _tmp6_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = _tmp8_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names_length1 = _tmp8__length1;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_names_size_ = names_length1;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = names;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = names_length1;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp9__length1 > 0;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8034 "Dialogs.c"
}


static void add_tags_dialog_class_init (AddTagsDialogClass * klass) {
#line 818 "/home/jens/Source/shotwell/src/Dialogs.vala"
	add_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 818 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) add_tags_dialog_real_on_modify_validate;
#line 8043 "Dialogs.c"
}


static void add_tags_dialog_instance_init (AddTagsDialog * self) {
}


GType add_tags_dialog_get_type (void) {
	static volatile gsize add_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&add_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AddTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) add_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AddTagsDialog), 0, (GInstanceInitFunc) add_tags_dialog_instance_init, NULL };
		GType add_tags_dialog_type_id;
		add_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "AddTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&add_tags_dialog_type_id__volatile, add_tags_dialog_type_id);
	}
	return add_tags_dialog_type_id__volatile;
}


ModifyTagsDialog* modify_tags_dialog_construct (GType object_type, MediaSource* source) {
	ModifyTagsDialog* self = NULL;
	MediaSource* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = source;
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = modify_tags_dialog_get_initial_text (_tmp0_);
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ModifyTagsDialog*) tags_dialog_construct (object_type, RESOURCES_MODIFY_TAGS_LABEL, _ ("Tags (separated by commas):"), _tmp2_);
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 8082 "Dialogs.c"
}


ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source) {
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return modify_tags_dialog_construct (TYPE_MODIFY_TAGS_DIALOG, source);
#line 8089 "Dialogs.c"
}


static gchar* modify_tags_dialog_get_initial_text (MediaSource* source) {
	gchar* result = NULL;
	GeeCollection* source_tags = NULL;
	TagSourceCollection* _tmp0_;
	MediaSource* _tmp1_;
	GeeList* _tmp2_;
	GeeCollection* _tmp3_;
	GeeCollection* terminal_tags = NULL;
	GeeCollection* _tmp4_;
	GeeCollection* _tmp5_;
	GeeSortedSet* tag_basenames = NULL;
	GeeTreeSet* _tmp6_;
	gchar* text = NULL;
#line 853 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag_global;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = source;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = tag_source_collection_fetch_for_source (_tmp0_, _tmp1_);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	source_tags = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection);
#line 855 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = source_tags;
#line 855 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == NULL) {
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (source_tags);
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 8126 "Dialogs.c"
	}
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = source_tags;
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = tag_get_terminal_tags (_tmp4_);
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
	terminal_tags = _tmp5_;
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = gee_tree_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_basenames = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_SORTED_SET, GeeSortedSet);
#line 8138 "Dialogs.c"
	{
		GeeIterator* _tag_it = NULL;
		GeeCollection* _tmp7_;
		GeeIterator* _tmp8_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = terminal_tags;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ITERABLE, GeeIterable));
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tag_it = _tmp8_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 8151 "Dialogs.c"
			GeeIterator* _tmp9_;
			gboolean _tmp10_;
			Tag* tag = NULL;
			GeeIterator* _tmp11_;
			gpointer _tmp12_;
			GeeSortedSet* _tmp13_;
			Tag* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tag_it;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp10_) {
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 8171 "Dialogs.c"
			}
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tag_it;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			tag = (Tag*) _tmp12_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = tag_basenames;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = tag;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = tag_get_path (_tmp14_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = _tmp15_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = hierarchical_tag_utilities_get_basename (_tmp16_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = _tmp17_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection), _tmp18_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp18_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp16_);
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (tag);
#line 8199 "Dialogs.c"
		}
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tag_it);
#line 8203 "Dialogs.c"
	}
#line 864 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 8207 "Dialogs.c"
	{
		GeeIterator* _name_it = NULL;
		GeeSortedSet* _tmp19_;
		GeeIterator* _tmp20_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = tag_basenames;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ITERABLE, GeeIterable));
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_name_it = _tmp20_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 8220 "Dialogs.c"
			GeeIterator* _tmp21_;
			gboolean _tmp22_;
			gchar* name = NULL;
			GeeIterator* _tmp23_;
			gpointer _tmp24_;
			const gchar* _tmp25_;
			const gchar* _tmp29_;
			const gchar* _tmp30_;
			gchar* _tmp31_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _name_it;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp22_) {
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 8238 "Dialogs.c"
			}
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = _name_it;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = (gchar*) _tmp24_;
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = text;
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp25_ == NULL) {
#line 8250 "Dialogs.c"
				gchar* _tmp26_;
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = g_strdup ("");
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp26_;
#line 8258 "Dialogs.c"
			} else {
				const gchar* _tmp27_;
				gchar* _tmp28_;
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = text;
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp28_ = g_strconcat (_tmp27_, ", ", NULL);
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp28_;
#line 8270 "Dialogs.c"
			}
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = text;
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = name;
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = g_strconcat (_tmp29_, _tmp30_, NULL);
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (text);
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			text = _tmp31_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (name);
#line 8284 "Dialogs.c"
		}
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_name_it);
#line 8288 "Dialogs.c"
	}
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (tag_basenames);
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (terminal_tags);
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (source_tags);
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8300 "Dialogs.c"
}


GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self) {
	GeeArrayList* result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	GeeArrayList* new_tags = NULL;
	GeeArrayList* _tmp2_;
	const gchar* _tmp3_;
	gboolean _tmp4_;
	gchar** tag_names = NULL;
	const gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	gint _tmp9_;
	gchar** _tmp10_;
	gchar** _tmp11_;
	gint _tmp11__length1;
	gint tag_names_length1;
	gint _tag_names_size_;
	HierarchicalTagIndex* _tmp12_;
	HierarchicalTagIndex* _tmp13_;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gint _tmp15_;
	gchar** _tmp16_;
	gchar** _tmp17_;
	gint _tmp17__length1;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MODIFY_TAGS_DIALOG (self), NULL);
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 8349 "Dialogs.c"
	}
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_array_list_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_tags = _tmp2_;
#line 885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = is_string_empty (_tmp3_);
#line 885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = new_tags;
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 8367 "Dialogs.c"
	}
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = text;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ",", 0);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8__length1 = _vala_array_length (_tmp6_);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = tag_prep_tag_names (_tmp8_, _vala_array_length (_tmp6_), &_tmp9_);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11__length1 = _tmp9_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = (_vala_array_free (_tmp8_, _tmp8__length1, (GDestroyNotify) g_free), NULL);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp11_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp11__length1;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = hierarchical_tag_index_get_global_index ();
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = tag_names;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14__length1 = tag_names_length1;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = hierarchical_tag_index_get_paths_for_names_array (_tmp13_, _tmp14_, _tmp14__length1, &_tmp15_);
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp16_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp15_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp13_);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = tag_names;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17__length1 = tag_names_length1;
#line 8415 "Dialogs.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection = _tmp17_;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection_length1 = _tmp17__length1;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (name_it = 0; name_it < _tmp17__length1; name_it = name_it + 1) {
#line 8427 "Dialogs.c"
			gchar* _tmp18_;
			gchar* name = NULL;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = g_strdup (name_collection[name_it]);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = _tmp18_;
#line 8434 "Dialogs.c"
			{
				GeeArrayList* _tmp19_;
				const gchar* _tmp20_;
				Tag* _tmp21_;
				Tag* _tmp22_;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = new_tags;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = name;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = tag_for_path (_tmp20_);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = _tmp21_;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp22_);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp22_);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (name);
#line 8454 "Dialogs.c"
			}
		}
	}
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = new_tags;
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8466 "Dialogs.c"
}


static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	ModifyTagsDialog * self;
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gboolean _tmp1_;
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog);
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = string_contains (_tmp0_, TAG_PATH_SEPARATOR_STRING);
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = !_tmp1_;
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8487 "Dialogs.c"
}


static void modify_tags_dialog_class_init (ModifyTagsDialogClass * klass) {
#line 847 "/home/jens/Source/shotwell/src/Dialogs.vala"
	modify_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 847 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) modify_tags_dialog_real_on_modify_validate;
#line 8496 "Dialogs.c"
}


static void modify_tags_dialog_instance_init (ModifyTagsDialog * self) {
}


GType modify_tags_dialog_get_type (void) {
	static volatile gsize modify_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&modify_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ModifyTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) modify_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ModifyTagsDialog), 0, (GInstanceInitFunc) modify_tags_dialog_instance_init, NULL };
		GType modify_tags_dialog_type_id;
		modify_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "ModifyTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&modify_tags_dialog_type_id__volatile, modify_tags_dialog_type_id);
	}
	return modify_tags_dialog_type_id__volatile;
}


GtkResponseType copy_files_dialog (void) {
	GtkResponseType result = 0;
	gchar* msg = NULL;
	gchar* _tmp0_;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp1_;
	AppWindow* _tmp2_;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	GtkResponseType _result_ = 0;
	gint _tmp5_;
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (_ ("Shotwell can copy the photos into your library folder or it can import" \
" them without copying."));
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp0_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL, "%s", msg);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp3_);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("Co_py Photos"), (gint) GTK_RESPONSE_ACCEPT);
#line 914 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Import in Place"), (gint) GTK_RESPONSE_REJECT);
#line 915 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _ ("Import to Library"));
#line 917 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 917 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp5_;
#line 919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8565 "Dialogs.c"
}


void remove_photos_from_library (GeeCollection* photos) {
	const gchar* _tmp0_ = NULL;
	GeeCollection* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GeeCollection* _tmp4_;
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (photos));
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = photos;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_collection_get_size (_tmp1_);
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == 1) {
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Removing Photo From Library");
#line 8587 "Dialogs.c"
	} else {
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Removing Photos From Library");
#line 8591 "Dialogs.c"
	}
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = photos;
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remove_from_app (_tmp4_, _ ("Remove From Library"), _tmp0_);
#line 8597 "Dialogs.c"
}


static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self) {
	gboolean result;
	result = progress_dialog_monitor ((ProgressDialog*) self, current, total, do_event_loop);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8606 "Dialogs.c"
}


void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text) {
	GeeCollection* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GeeArrayList* photos = NULL;
	GeeArrayList* _tmp3_;
	GeeArrayList* videos = NULL;
	GeeArrayList* _tmp4_;
	GeeCollection* _tmp5_;
	GeeArrayList* _tmp6_;
	GeeArrayList* _tmp7_;
	gchar* user_message = NULL;
	gboolean _tmp8_ = FALSE;
	GeeArrayList* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	GtkResponseType _result_ = 0;
	AppWindow* _tmp39_;
	AppWindow* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	GeeCollection* _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
	GtkResponseType _tmp46_;
	GtkResponseType _tmp47_;
	gboolean _tmp48_ = FALSE;
	GtkResponseType _tmp49_;
	gboolean delete_backing = FALSE;
	GtkResponseType _tmp51_;
	AppWindow* _tmp52_;
	AppWindow* _tmp53_;
	ProgressDialog* progress = NULL;
	ProgressMonitor monitor = NULL;
	void* monitor_target;
	GDestroyNotify monitor_target_destroy_notify;
	GeeCollection* _tmp54_;
	gint _tmp55_;
	gint _tmp56_;
	GeeArrayList* not_removed_photos = NULL;
	GeeArrayList* _tmp62_;
	GeeArrayList* not_removed_videos = NULL;
	GeeArrayList* _tmp63_;
	LibraryPhotoSourceCollection* _tmp64_;
	GeeArrayList* _tmp65_;
	gboolean _tmp66_;
	ProgressMonitor _tmp67_;
	void* _tmp67__target;
	GeeArrayList* _tmp68_;
	VideoSourceCollection* _tmp69_;
	GeeArrayList* _tmp70_;
	gboolean _tmp71_;
	ProgressMonitor _tmp72_;
	void* _tmp72__target;
	GeeArrayList* _tmp73_;
	gint num_not_removed = 0;
	GeeArrayList* _tmp74_;
	gint _tmp75_;
	gint _tmp76_;
	GeeArrayList* _tmp77_;
	gint _tmp78_;
	gint _tmp79_;
	gboolean _tmp80_ = FALSE;
	gboolean _tmp81_;
	ProgressDialog* _tmp117_;
	AppWindow* _tmp119_;
	AppWindow* _tmp120_;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (sources));
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (dialog_title != NULL);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (progress_dialog_text != NULL);
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = sources;
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (_tmp0_);
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 932 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 8693 "Dialogs.c"
	}
#line 934 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 934 "/home/jens/Source/shotwell/src/Dialogs.vala"
	photos = _tmp3_;
#line 935 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 935 "/home/jens/Source/shotwell/src/Dialogs.vala"
	videos = _tmp4_;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = sources;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photos;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = videos;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_filter_media (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	user_message = NULL;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = photos;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp11_) {
#line 8721 "Dialogs.c"
		GeeArrayList* _tmp12_;
		gboolean _tmp13_;
		gboolean _tmp14_;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = videos;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_COLLECTION, GeeCollection));
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp13_;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = !_tmp14_;
#line 8733 "Dialogs.c"
	} else {
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = FALSE;
#line 8737 "Dialogs.c"
	}
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_) {
#line 8741 "Dialogs.c"
		GeeCollection* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GeeCollection* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		gchar* _tmp21_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = sources;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gee_collection_get_size (_tmp15_);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = sources;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gee_collection_get_size (_tmp18_);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = _tmp19_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = g_strdup_printf (ngettext ("This will remove the photo/video from your Shotwell library. Would you" \
" also like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos/videos from your Shotwell library. Would yo" \
"u also like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp17_), _tmp20_);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_message = _tmp21_;
#line 8767 "Dialogs.c"
	} else {
		GeeArrayList* _tmp22_;
		gboolean _tmp23_;
		gboolean _tmp24_;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = videos;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_COLLECTION, GeeCollection));
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp24_) {
#line 8780 "Dialogs.c"
			GeeCollection* _tmp25_;
			gint _tmp26_;
			gint _tmp27_;
			GeeCollection* _tmp28_;
			gint _tmp29_;
			gint _tmp30_;
			gchar* _tmp31_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = sources;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = gee_collection_get_size (_tmp25_);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _tmp26_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = sources;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = gee_collection_get_size (_tmp28_);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = _tmp29_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = g_strdup_printf (ngettext ("This will remove the video from your Shotwell library. Would you also " \
"like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d videos from your Shotwell library. Would you also " \
"like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp27_), _tmp30_);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp31_;
#line 8806 "Dialogs.c"
		} else {
			GeeCollection* _tmp32_;
			gint _tmp33_;
			gint _tmp34_;
			GeeCollection* _tmp35_;
			gint _tmp36_;
			gint _tmp37_;
			gchar* _tmp38_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp32_ = sources;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp33_ = gee_collection_get_size (_tmp32_);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp34_ = _tmp33_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp35_ = sources;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp36_ = gee_collection_get_size (_tmp35_);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp37_ = _tmp36_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp38_ = g_strdup_printf (ngettext ("This will remove the photo from your Shotwell library. Would you also " \
"like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos from your Shotwell library. Would you also " \
"like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp34_), _tmp37_);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp38_;
#line 8833 "Dialogs.c"
		}
	}
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = app_window_get_instance ();
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = _tmp39_;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = dialog_title;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = user_message;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = sources;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = gee_collection_get_size (_tmp43_);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = _tmp44_;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = remove_from_library_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_window_get_type (), GtkWindow), _tmp41_, _tmp42_, _tmp45_);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = _tmp46_;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp40_);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp47_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = _result_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp49_ != GTK_RESPONSE_YES) {
#line 8862 "Dialogs.c"
		GtkResponseType _tmp50_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _result_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = _tmp50_ != GTK_RESPONSE_NO;
#line 8868 "Dialogs.c"
	} else {
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = FALSE;
#line 8872 "Dialogs.c"
	}
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp48_) {
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (videos);
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (photos);
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 8884 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _result_;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	delete_backing = _tmp51_ == GTK_RESPONSE_YES;
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = app_window_get_instance ();
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = _tmp52_;
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_busy_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, TYPE_PAGE_WINDOW, PageWindow));
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp53_);
#line 962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress = NULL;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = sources;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = gee_collection_get_size (_tmp54_);
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = _tmp55_;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp56_ >= 20) {
#line 8914 "Dialogs.c"
		AppWindow* _tmp57_;
		AppWindow* _tmp58_;
		const gchar* _tmp59_;
		ProgressDialog* _tmp60_;
		ProgressDialog* _tmp61_;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = app_window_get_instance ();
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = _tmp57_;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = progress_dialog_text;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = progress_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_window_get_type (), GtkWindow), _tmp59_, NULL);
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp60_);
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (progress);
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress = _tmp60_;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp58_);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = progress;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = NULL;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = NULL;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = NULL;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = _progress_dialog_monitor_progress_monitor;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = g_object_ref (_tmp61_);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = g_object_unref;
#line 8952 "Dialogs.c"
	}
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_photos = _tmp62_;
#line 970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_videos = _tmp63_;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = library_photo_global;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = photos;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = delete_backing;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = monitor;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67__target = monitor_target;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = not_removed_photos;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, GEE_TYPE_COLLECTION, GeeCollection), _tmp66_, _tmp67_, _tmp67__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_LIST, GeeList));
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = video_global;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = videos;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = delete_backing;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = monitor;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72__target = monitor_target;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = not_removed_videos;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp70_, GEE_TYPE_COLLECTION, GeeCollection), _tmp71_, _tmp72_, _tmp72__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, GEE_TYPE_LIST, GeeList));
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = not_removed_photos;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = _tmp75_;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = not_removed_videos;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = _tmp78_;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	num_not_removed = _tmp76_ + _tmp79_;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = delete_backing;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp81_) {
#line 9008 "Dialogs.c"
		gint _tmp82_;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = num_not_removed;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = _tmp82_ > 0;
#line 9014 "Dialogs.c"
	} else {
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = FALSE;
#line 9018 "Dialogs.c"
	}
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp80_) {
#line 9022 "Dialogs.c"
		gchar* not_deleted_message = NULL;
		gint _tmp83_;
		gint _tmp84_;
		gchar* _tmp85_;
		GtkResponseType result_delete = 0;
		AppWindow* _tmp86_;
		AppWindow* _tmp87_;
		const gchar* _tmp88_;
		const gchar* _tmp89_;
		GtkResponseType _tmp90_;
		GtkResponseType _tmp91_;
		GtkResponseType _tmp92_;
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = num_not_removed;
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = num_not_removed;
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = g_strdup_printf (ngettext ("The photo or video cannot be moved to your desktop trash. Delete this " \
"file?", "%d photos/videos cannot be moved to your desktop trash. Delete these f" \
"iles?", (gulong) _tmp83_), _tmp84_);
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		not_deleted_message = _tmp85_;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = app_window_get_instance ();
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = _tmp86_;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = dialog_title;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = not_deleted_message;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = remove_from_filesystem_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, gtk_window_get_type (), GtkWindow), _tmp88_, _tmp89_);
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = _tmp90_;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp87_);
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result_delete = _tmp91_;
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = result_delete;
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (GTK_RESPONSE_YES == _tmp92_) {
#line 9063 "Dialogs.c"
			GeeArrayList* not_deleted_photos = NULL;
			GeeArrayList* _tmp93_;
			GeeArrayList* not_deleted_videos = NULL;
			GeeArrayList* _tmp94_;
			LibraryPhotoSourceCollection* _tmp95_;
			GeeArrayList* _tmp96_;
			ProgressMonitor _tmp97_;
			void* _tmp97__target;
			GeeArrayList* _tmp98_;
			VideoSourceCollection* _tmp99_;
			GeeArrayList* _tmp100_;
			ProgressMonitor _tmp101_;
			void* _tmp101__target;
			GeeArrayList* _tmp102_;
			gint num_not_deleted = 0;
			GeeArrayList* _tmp103_;
			gint _tmp104_;
			gint _tmp105_;
			GeeArrayList* _tmp106_;
			gint _tmp107_;
			gint _tmp108_;
			gint _tmp109_;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp93_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_photos = _tmp93_;
#line 989 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 989 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_videos = _tmp94_;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp95_ = library_photo_global;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp96_ = not_removed_photos;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp97_ = monitor;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp97__target = monitor_target;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp98_ = not_deleted_photos;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp95_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, GEE_TYPE_COLLECTION, GeeCollection), _tmp97_, _tmp97__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp98_, GEE_TYPE_LIST, GeeList));
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp99_ = video_global;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp100_ = not_removed_videos;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp101_ = monitor;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp101__target = monitor_target;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp102_ = not_deleted_videos;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, GEE_TYPE_COLLECTION, GeeCollection), _tmp101_, _tmp101__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp102_, GEE_TYPE_LIST, GeeList));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp103_ = not_deleted_photos;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp104_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp105_ = _tmp104_;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp106_ = not_deleted_videos;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp107_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp106_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp108_ = _tmp107_;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			num_not_deleted = _tmp105_ + _tmp108_;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp109_ = num_not_deleted;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp109_ > 0) {
#line 9136 "Dialogs.c"
				gchar* delete_failed_message = NULL;
				gint _tmp110_;
				gint _tmp111_;
				gchar* _tmp112_;
				const gchar* _tmp113_;
				const gchar* _tmp114_;
				AppWindow* _tmp115_;
				AppWindow* _tmp116_;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp110_ = num_not_deleted;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp111_ = num_not_deleted;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp112_ = g_strdup_printf (ngettext ("The photo or video cannot be deleted.", "%d photos/videos cannot be deleted.", (gulong) _tmp110_), _tmp111_);
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				delete_failed_message = _tmp112_;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp113_ = dialog_title;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp114_ = delete_failed_message;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp115_ = app_window_get_instance ();
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp116_ = _tmp115_;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				app_window_error_message_with_title (_tmp113_, _tmp114_, G_TYPE_CHECK_INSTANCE_CAST (_tmp116_, gtk_window_get_type (), GtkWindow), TRUE);
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp116_);
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (delete_failed_message);
#line 9167 "Dialogs.c"
			}
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_videos);
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_photos);
#line 9173 "Dialogs.c"
		}
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (not_deleted_message);
#line 9177 "Dialogs.c"
	}
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp117_ = progress;
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp117_ != NULL) {
#line 9183 "Dialogs.c"
		ProgressDialog* _tmp118_;
#line 1006 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp118_ = progress;
#line 1006 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress_dialog_close (_tmp118_);
#line 9189 "Dialogs.c"
	}
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp119_ = app_window_get_instance ();
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp120_ = _tmp119_;
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_normal_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp120_, TYPE_PAGE_WINDOW, PageWindow));
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp120_);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_videos);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_photos);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (progress);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (user_message);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (videos);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (photos);
#line 9219 "Dialogs.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



