/* Photo.c generated by valac 0.36.6, the Vala compiler
 * generated from Photo.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* Specifies how pixel data is fetched from the backing file on disk.  MASTER is the original*/
/* backing photo of any supported photo file format; SOURCE is either the master or the editable*/
/* file, that is, the appropriate reference file for user display; BASELINE is an appropriate*/
/* file with the proviso that it may be a suitable substitute for the master and/or the editable.*/
/* UNMODIFIED represents the photo with no edits, i.e. the head of the pipeline.*/
/**/
/* In general, callers want to use the BASELINE unless requirements are specific.*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <time.h>
#include "shotwell-graphics-processor.h"
#include <glib/gstdio.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <cairo.h>
#include <gobject/gvaluecollector.h>


#define TYPE_BACKING_FETCH_MODE (backing_fetch_mode_get_type ())

#define TYPE_PHOTO_IMPORT_PARAMS (photo_import_params_get_type ())
#define PHOTO_IMPORT_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_IMPORT_PARAMS, PhotoImportParams))
#define PHOTO_IMPORT_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_IMPORT_PARAMS, PhotoImportParamsClass))
#define IS_PHOTO_IMPORT_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_IMPORT_PARAMS))
#define IS_PHOTO_IMPORT_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_IMPORT_PARAMS))
#define PHOTO_IMPORT_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_IMPORT_PARAMS, PhotoImportParamsClass))

typedef struct _PhotoImportParams PhotoImportParams;
typedef struct _PhotoImportParamsClass PhotoImportParamsClass;
typedef struct _PhotoImportParamsPrivate PhotoImportParamsPrivate;

#define TYPE_IMPORT_ID (import_id_get_type ())
typedef struct _ImportID ImportID;

#define PHOTO_FILE_SNIFFER_TYPE_OPTIONS (photo_file_sniffer_options_get_type ())

#define TYPE_THUMBNAILS (thumbnails_get_type ())
#define THUMBNAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAILS, Thumbnails))
#define THUMBNAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAILS, ThumbnailsClass))
#define IS_THUMBNAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAILS))
#define IS_THUMBNAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAILS))
#define THUMBNAILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAILS, ThumbnailsClass))

typedef struct _Thumbnails Thumbnails;
typedef struct _ThumbnailsClass ThumbnailsClass;

#define TYPE_PHOTO_ROW (photo_row_get_type ())
#define PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_ROW, PhotoRow))
#define PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_ROW, PhotoRowClass))
#define IS_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_ROW))
#define IS_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_ROW))
#define PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_ROW, PhotoRowClass))

typedef struct _PhotoRow PhotoRow;
typedef struct _PhotoRowClass PhotoRowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _thumbnails_unref0(var) ((var == NULL) ? NULL : (var = (thumbnails_unref (var), NULL)))
#define _photo_row_unref0(var) ((var == NULL) ? NULL : (var = (photo_row_unref (var), NULL)))
typedef struct _ParamSpecPhotoImportParams ParamSpecPhotoImportParams;

#define TYPE_PHOTO_TRANSFORMATION_STATE (photo_transformation_state_get_type ())
#define PHOTO_TRANSFORMATION_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationState))
#define PHOTO_TRANSFORMATION_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationStateClass))
#define IS_PHOTO_TRANSFORMATION_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_TRANSFORMATION_STATE))
#define IS_PHOTO_TRANSFORMATION_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_TRANSFORMATION_STATE))
#define PHOTO_TRANSFORMATION_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationStateClass))

typedef struct _PhotoTransformationState PhotoTransformationState;
typedef struct _PhotoTransformationStateClass PhotoTransformationStateClass;
typedef struct _PhotoTransformationStatePrivate PhotoTransformationStatePrivate;
enum  {
	PHOTO_TRANSFORMATION_STATE_BROKEN_SIGNAL,
	PHOTO_TRANSFORMATION_STATE_LAST_SIGNAL
};
static guint photo_transformation_state_signals[PHOTO_TRANSFORMATION_STATE_LAST_SIGNAL] = {0};

#define TYPE_RATING (rating_get_type ())

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;
typedef struct _DataObjectPrivate DataObjectPrivate;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;
typedef struct _DataSourcePrivate DataSourcePrivate;

#define TYPE_SOURCE_HOLDING_TANK (source_holding_tank_get_type ())
#define SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank))
#define SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTankClass))
#define IS_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_HOLDING_TANK))
#define IS_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_HOLDING_TANK))
#define SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTankClass))

typedef struct _SourceHoldingTank SourceHoldingTank;
typedef struct _SourceHoldingTankClass SourceHoldingTankClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_SOURCE_SNAPSHOT (source_snapshot_get_type ())
#define SOURCE_SNAPSHOT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_SNAPSHOT, SourceSnapshot))
#define SOURCE_SNAPSHOT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_SNAPSHOT, SourceSnapshotClass))
#define IS_SOURCE_SNAPSHOT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_SNAPSHOT))
#define IS_SOURCE_SNAPSHOT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_SNAPSHOT))
#define SOURCE_SNAPSHOT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_SNAPSHOT, SourceSnapshotClass))

typedef struct _SourceSnapshot SourceSnapshot;
typedef struct _SourceSnapshotClass SourceSnapshotClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;
typedef struct _ThumbnailSourcePrivate ThumbnailSourcePrivate;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_INDEXABLE (indexable_get_type ())
#define INDEXABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDEXABLE, Indexable))
#define IS_INDEXABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDEXABLE))
#define INDEXABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_INDEXABLE, IndexableIface))

typedef struct _Indexable Indexable;
typedef struct _IndexableIface IndexableIface;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;
typedef struct _MediaSourcePrivate MediaSourcePrivate;

#define TYPE_EVENT_ID (event_id_get_type ())
typedef struct _EventID EventID;

#define TYPE_BACKING_FILE_STATE (backing_file_state_get_type ())
#define BACKING_FILE_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKING_FILE_STATE, BackingFileState))
#define BACKING_FILE_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKING_FILE_STATE, BackingFileStateClass))
#define IS_BACKING_FILE_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKING_FILE_STATE))
#define IS_BACKING_FILE_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKING_FILE_STATE))
#define BACKING_FILE_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKING_FILE_STATE, BackingFileStateClass))

typedef struct _BackingFileState BackingFileState;
typedef struct _BackingFileStateClass BackingFileStateClass;

#define PHOTO_TYPE_EXCEPTION (photo_exception_get_type ())

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;

#define TYPE_SCALING (scaling_get_type ())

#define TYPE_SCALE_CONSTRAINT (scale_constraint_get_type ())
typedef struct _Scaling Scaling;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;
typedef struct _PhotoSourcePrivate PhotoSourcePrivate;

#define TYPE_MEDIA_METADATA (media_metadata_get_type ())
#define MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_METADATA, MediaMetadata))
#define MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_METADATA, MediaMetadataClass))
#define IS_MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_METADATA))
#define IS_MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_METADATA))
#define MEDIA_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_METADATA, MediaMetadataClass))

typedef struct _MediaMetadata MediaMetadata;
typedef struct _MediaMetadataClass MediaMetadataClass;

#define TYPE_PHOTO_METADATA (photo_metadata_get_type ())
#define PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_METADATA, PhotoMetadata))
#define PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_METADATA, PhotoMetadataClass))
#define IS_PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_METADATA))
#define IS_PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_METADATA))
#define PHOTO_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_METADATA, PhotoMetadataClass))

typedef struct _PhotoMetadata PhotoMetadata;
typedef struct _PhotoMetadataClass PhotoMetadataClass;

#define TYPE_DATEABLE (dateable_get_type ())
#define DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATEABLE, Dateable))
#define IS_DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATEABLE))
#define DATEABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_DATEABLE, DateableIface))

typedef struct _Dateable Dateable;
typedef struct _DateableIface DateableIface;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;
typedef struct _PhotoPrivate PhotoPrivate;

#define TYPE_ROTATION (rotation_get_type ())

#define TYPE_BACKING_PHOTO_ROW (backing_photo_row_get_type ())
#define BACKING_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKING_PHOTO_ROW, BackingPhotoRow))
#define BACKING_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKING_PHOTO_ROW, BackingPhotoRowClass))
#define IS_BACKING_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKING_PHOTO_ROW))
#define IS_BACKING_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKING_PHOTO_ROW))
#define BACKING_PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKING_PHOTO_ROW, BackingPhotoRowClass))

typedef struct _BackingPhotoRow BackingPhotoRow;
typedef struct _BackingPhotoRowClass BackingPhotoRowClass;

#define PHOTO_TYPE_BACKING_READERS (photo_backing_readers_get_type ())
#define PHOTO_BACKING_READERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_BACKING_READERS, PhotoBackingReaders))
#define PHOTO_BACKING_READERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_BACKING_READERS, PhotoBackingReadersClass))
#define PHOTO_IS_BACKING_READERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_BACKING_READERS))
#define PHOTO_IS_BACKING_READERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_BACKING_READERS))
#define PHOTO_BACKING_READERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_BACKING_READERS, PhotoBackingReadersClass))

typedef struct _PhotoBackingReaders PhotoBackingReaders;
typedef struct _PhotoBackingReadersClass PhotoBackingReadersClass;

#define TYPE_ONE_SHOT_SCHEDULER (one_shot_scheduler_get_type ())
#define ONE_SHOT_SCHEDULER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ONE_SHOT_SCHEDULER, OneShotScheduler))
#define ONE_SHOT_SCHEDULER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ONE_SHOT_SCHEDULER, OneShotSchedulerClass))
#define IS_ONE_SHOT_SCHEDULER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ONE_SHOT_SCHEDULER))
#define IS_ONE_SHOT_SCHEDULER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ONE_SHOT_SCHEDULER))
#define ONE_SHOT_SCHEDULER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ONE_SHOT_SCHEDULER, OneShotSchedulerClass))

typedef struct _OneShotScheduler OneShotScheduler;
typedef struct _OneShotSchedulerClass OneShotSchedulerClass;

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())

#define PHOTO_TYPE_CACHED_PIXBUF (photo_cached_pixbuf_get_type ())
#define PHOTO_CACHED_PIXBUF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_CACHED_PIXBUF, PhotoCachedPixbuf))
#define PHOTO_CACHED_PIXBUF_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_CACHED_PIXBUF, PhotoCachedPixbufClass))
#define PHOTO_IS_CACHED_PIXBUF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_CACHED_PIXBUF))
#define PHOTO_IS_CACHED_PIXBUF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_CACHED_PIXBUF))
#define PHOTO_CACHED_PIXBUF_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_CACHED_PIXBUF, PhotoCachedPixbufClass))

typedef struct _PhotoCachedPixbuf PhotoCachedPixbuf;
typedef struct _PhotoCachedPixbufClass PhotoCachedPixbufClass;
#define _backing_photo_row_unref0(var) ((var == NULL) ? NULL : (var = (backing_photo_row_unref (var), NULL)))
#define _photo_backing_readers_unref0(var) ((var == NULL) ? NULL : (var = (photo_backing_readers_unref (var), NULL)))
#define _pixel_transformer_unref0(var) ((var == NULL) ? NULL : (var = (pixel_transformer_unref (var), NULL)))
#define _pixel_transformation_bundle_unref0(var) ((var == NULL) ? NULL : (var = (pixel_transformation_bundle_unref (var), NULL)))
#define _one_shot_scheduler_unref0(var) ((var == NULL) ? NULL : (var = (one_shot_scheduler_unref (var), NULL)))
typedef struct _PhotoRowPrivate PhotoRowPrivate;

#define TYPE_PHOTO_ID (photo_id_get_type ())
typedef struct _PhotoID PhotoID;

#define TYPE_ORIENTATION (orientation_get_type ())

#define TYPE_BACKING_PHOTO_ID (backing_photo_id_get_type ())
typedef struct _BackingPhotoID BackingPhotoID;
typedef struct _BackingPhotoRowPrivate BackingPhotoRowPrivate;

#define TYPE_PHOTO_FILE_ADAPTER (photo_file_adapter_get_type ())
#define PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter))
#define PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))
#define IS_PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_ADAPTER))
#define IS_PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_ADAPTER))
#define PHOTO_FILE_ADAPTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))

typedef struct _PhotoFileAdapter PhotoFileAdapter;
typedef struct _PhotoFileAdapterClass PhotoFileAdapterClass;

#define TYPE_PHOTO_FILE_READER (photo_file_reader_get_type ())
#define PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReader))
#define PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))
#define IS_PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_READER))
#define IS_PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_READER))
#define PHOTO_FILE_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))

typedef struct _PhotoFileReader PhotoFileReader;
typedef struct _PhotoFileReaderClass PhotoFileReaderClass;
typedef struct _PhotoBackingReadersPrivate PhotoBackingReadersPrivate;
#define _photo_file_adapter_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_adapter_unref (var), NULL)))

#define TYPE_DATABASE_TABLE (database_table_get_type ())
#define DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_TABLE, DatabaseTable))
#define DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_TABLE, DatabaseTableClass))
#define IS_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_TABLE))
#define IS_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_TABLE))
#define DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_TABLE, DatabaseTableClass))

typedef struct _DatabaseTable DatabaseTable;
typedef struct _DatabaseTableClass DatabaseTableClass;

#define TYPE_PHOTO_TABLE (photo_table_get_type ())
#define PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_TABLE, PhotoTable))
#define PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_TABLE, PhotoTableClass))
#define IS_PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_TABLE))
#define IS_PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_TABLE))
#define PHOTO_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_TABLE, PhotoTableClass))

typedef struct _PhotoTable PhotoTable;
typedef struct _PhotoTableClass PhotoTableClass;
#define _database_table_unref0(var) ((var == NULL) ? NULL : (var = (database_table_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_BACKING_PHOTO_TABLE (backing_photo_table_get_type ())
#define BACKING_PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKING_PHOTO_TABLE, BackingPhotoTable))
#define BACKING_PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKING_PHOTO_TABLE, BackingPhotoTableClass))
#define IS_BACKING_PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKING_PHOTO_TABLE))
#define IS_BACKING_PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKING_PHOTO_TABLE))
#define BACKING_PHOTO_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKING_PHOTO_TABLE, BackingPhotoTableClass))

typedef struct _BackingPhotoTable BackingPhotoTable;
typedef struct _BackingPhotoTableClass BackingPhotoTableClass;

#define TYPE_PHOTO_PREVIEW (photo_preview_get_type ())
#define PHOTO_PREVIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_PREVIEW, PhotoPreview))
#define PHOTO_PREVIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_PREVIEW, PhotoPreviewClass))
#define IS_PHOTO_PREVIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_PREVIEW))
#define IS_PHOTO_PREVIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_PREVIEW))
#define PHOTO_PREVIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_PREVIEW, PhotoPreviewClass))

typedef struct _PhotoPreview PhotoPreview;
typedef struct _PhotoPreviewClass PhotoPreviewClass;
#define _photo_preview_unref0(var) ((var == NULL) ? NULL : (var = (photo_preview_unref (var), NULL)))
#define _media_metadata_unref0(var) ((var == NULL) ? NULL : (var = (media_metadata_unref (var), NULL)))
#define _alteration_unref0(var) ((var == NULL) ? NULL : (var = (alteration_unref (var), NULL)))

#define TYPE_PHOTO_FILE_INTERROGATOR (photo_file_interrogator_get_type ())
#define PHOTO_FILE_INTERROGATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_INTERROGATOR, PhotoFileInterrogator))
#define PHOTO_FILE_INTERROGATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_INTERROGATOR, PhotoFileInterrogatorClass))
#define IS_PHOTO_FILE_INTERROGATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_INTERROGATOR))
#define IS_PHOTO_FILE_INTERROGATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_INTERROGATOR))
#define PHOTO_FILE_INTERROGATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_INTERROGATOR, PhotoFileInterrogatorClass))

typedef struct _PhotoFileInterrogator PhotoFileInterrogator;
typedef struct _PhotoFileInterrogatorClass PhotoFileInterrogatorClass;
#define _photo_file_interrogator_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_interrogator_unref (var), NULL)))

#define TYPE_DETECTED_PHOTO_INFORMATION (detected_photo_information_get_type ())
#define DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformation))
#define DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))
#define IS_DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DETECTED_PHOTO_INFORMATION))
#define IS_DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DETECTED_PHOTO_INFORMATION))
#define DETECTED_PHOTO_INFORMATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))

typedef struct _DetectedPhotoInformation DetectedPhotoInformation;
typedef struct _DetectedPhotoInformationClass DetectedPhotoInformationClass;
#define _detected_photo_information_unref0(var) ((var == NULL) ? NULL : (var = (detected_photo_information_unref (var), NULL)))
typedef struct _DetectedPhotoInformationPrivate DetectedPhotoInformationPrivate;

#define TYPE_PHOTO_FILE_WRITER (photo_file_writer_get_type ())
#define PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriter))
#define PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))
#define IS_PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_WRITER))
#define IS_PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_WRITER))
#define PHOTO_FILE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))

typedef struct _PhotoFileWriter PhotoFileWriter;
typedef struct _PhotoFileWriterClass PhotoFileWriterClass;

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())

#define TYPE_PHOTO_FILE_METADATA_WRITER (photo_file_metadata_writer_get_type ())
#define PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter))
#define PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))
#define IS_PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_METADATA_WRITER))
#define IS_PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_METADATA_WRITER))
#define PHOTO_FILE_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))

typedef struct _PhotoFileMetadataWriter PhotoFileMetadataWriter;
typedef struct _PhotoFileMetadataWriterClass PhotoFileMetadataWriterClass;
#define _g_bytes_unref0(var) ((var == NULL) ? NULL : (var = (g_bytes_unref (var), NULL)))

#define TYPE_EXPORT_FORMAT_PARAMETERS (export_format_parameters_get_type ())

#define TYPE_EXPORT_FORMAT_MODE (export_format_mode_get_type ())
typedef struct _ExportFormatParameters ExportFormatParameters;

#define TYPE_IMPORT_RESULT (import_result_get_type ())

#define TYPE_METADATA_DATE_TIME (metadata_date_time_get_type ())
#define METADATA_DATE_TIME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_METADATA_DATE_TIME, MetadataDateTime))
#define METADATA_DATE_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_METADATA_DATE_TIME, MetadataDateTimeClass))
#define IS_METADATA_DATE_TIME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_METADATA_DATE_TIME))
#define IS_METADATA_DATE_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_METADATA_DATE_TIME))
#define METADATA_DATE_TIME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_METADATA_DATE_TIME, MetadataDateTimeClass))

typedef struct _MetadataDateTime MetadataDateTime;
typedef struct _MetadataDateTimeClass MetadataDateTimeClass;
#define _metadata_date_time_unref0(var) ((var == NULL) ? NULL : (var = (metadata_date_time_unref (var), NULL)))

#define PHOTO_FILE_READER_TYPE_ROLE (photo_file_reader_role_get_type ())

#define PHOTO_TYPE_REIMPORT_MASTER_STATE (photo_reimport_master_state_get_type ())
#define PHOTO_REIMPORT_MASTER_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_REIMPORT_MASTER_STATE, PhotoReimportMasterState))
#define PHOTO_REIMPORT_MASTER_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_REIMPORT_MASTER_STATE, PhotoReimportMasterStateClass))
#define PHOTO_IS_REIMPORT_MASTER_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_REIMPORT_MASTER_STATE))
#define PHOTO_IS_REIMPORT_MASTER_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_REIMPORT_MASTER_STATE))
#define PHOTO_REIMPORT_MASTER_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_REIMPORT_MASTER_STATE, PhotoReimportMasterStateClass))

typedef struct _PhotoReimportMasterState PhotoReimportMasterState;
typedef struct _PhotoReimportMasterStateClass PhotoReimportMasterStateClass;
#define _photo_reimport_master_state_unref0(var) ((var == NULL) ? NULL : (var = (photo_reimport_master_state_unref (var), NULL)))

#define PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL (photo_reimport_master_state_impl_get_type ())
#define PHOTO_REIMPORT_MASTER_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, PhotoReimportMasterStateImpl))
#define PHOTO_REIMPORT_MASTER_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, PhotoReimportMasterStateImplClass))
#define PHOTO_IS_REIMPORT_MASTER_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL))
#define PHOTO_IS_REIMPORT_MASTER_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL))
#define PHOTO_REIMPORT_MASTER_STATE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, PhotoReimportMasterStateImplClass))

typedef struct _PhotoReimportMasterStateImpl PhotoReimportMasterStateImpl;
typedef struct _PhotoReimportMasterStateImplClass PhotoReimportMasterStateImplClass;
typedef struct _PhotoReimportMasterStatePrivate PhotoReimportMasterStatePrivate;
typedef struct _PhotoReimportMasterStateImplPrivate PhotoReimportMasterStateImplPrivate;

#define PHOTO_TYPE_REIMPORT_EDITABLE_STATE (photo_reimport_editable_state_get_type ())
#define PHOTO_REIMPORT_EDITABLE_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_REIMPORT_EDITABLE_STATE, PhotoReimportEditableState))
#define PHOTO_REIMPORT_EDITABLE_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_REIMPORT_EDITABLE_STATE, PhotoReimportEditableStateClass))
#define PHOTO_IS_REIMPORT_EDITABLE_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_REIMPORT_EDITABLE_STATE))
#define PHOTO_IS_REIMPORT_EDITABLE_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_REIMPORT_EDITABLE_STATE))
#define PHOTO_REIMPORT_EDITABLE_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_REIMPORT_EDITABLE_STATE, PhotoReimportEditableStateClass))

typedef struct _PhotoReimportEditableState PhotoReimportEditableState;
typedef struct _PhotoReimportEditableStateClass PhotoReimportEditableStateClass;
#define _photo_reimport_editable_state_unref0(var) ((var == NULL) ? NULL : (var = (photo_reimport_editable_state_unref (var), NULL)))

#define PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL (photo_reimport_editable_state_impl_get_type ())
#define PHOTO_REIMPORT_EDITABLE_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, PhotoReimportEditableStateImpl))
#define PHOTO_REIMPORT_EDITABLE_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, PhotoReimportEditableStateImplClass))
#define PHOTO_IS_REIMPORT_EDITABLE_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL))
#define PHOTO_IS_REIMPORT_EDITABLE_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL))
#define PHOTO_REIMPORT_EDITABLE_STATE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, PhotoReimportEditableStateImplClass))

typedef struct _PhotoReimportEditableStateImpl PhotoReimportEditableStateImpl;
typedef struct _PhotoReimportEditableStateImplClass PhotoReimportEditableStateImplClass;
typedef struct _PhotoReimportEditableStatePrivate PhotoReimportEditableStatePrivate;
typedef struct _PhotoReimportEditableStateImplPrivate PhotoReimportEditableStateImplPrivate;

#define PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE (photo_reimport_raw_development_state_get_type ())
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE, PhotoReimportRawDevelopmentState))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE, PhotoReimportRawDevelopmentStateClass))
#define PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE))
#define PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE, PhotoReimportRawDevelopmentStateClass))

typedef struct _PhotoReimportRawDevelopmentState PhotoReimportRawDevelopmentState;
typedef struct _PhotoReimportRawDevelopmentStateClass PhotoReimportRawDevelopmentStateClass;
#define _photo_reimport_raw_development_state_unref0(var) ((var == NULL) ? NULL : (var = (photo_reimport_raw_development_state_unref (var), NULL)))

#define PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL (photo_reimport_raw_development_state_impl_get_type ())
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL, PhotoReimportRawDevelopmentStateImpl))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL, PhotoReimportRawDevelopmentStateImplClass))
#define PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL))
#define PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL, PhotoReimportRawDevelopmentStateImplClass))

typedef struct _PhotoReimportRawDevelopmentStateImpl PhotoReimportRawDevelopmentStateImpl;
typedef struct _PhotoReimportRawDevelopmentStateImplClass PhotoReimportRawDevelopmentStateImplClass;

#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT (photo_reimport_raw_development_state_impl_dev_to_reimport_get_type ())
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_DEV_TO_REIMPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT, PhotoReimportRawDevelopmentStateImplDevToReimport))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_DEV_TO_REIMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT, PhotoReimportRawDevelopmentStateImplDevToReimportClass))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_IS_DEV_TO_REIMPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_IS_DEV_TO_REIMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT))
#define PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_DEV_TO_REIMPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT, PhotoReimportRawDevelopmentStateImplDevToReimportClass))

typedef struct _PhotoReimportRawDevelopmentStateImplDevToReimport PhotoReimportRawDevelopmentStateImplDevToReimport;
typedef struct _PhotoReimportRawDevelopmentStateImplDevToReimportClass PhotoReimportRawDevelopmentStateImplDevToReimportClass;
typedef struct _PhotoReimportRawDevelopmentStatePrivate PhotoReimportRawDevelopmentStatePrivate;
typedef struct _PhotoReimportRawDevelopmentStateImplPrivate PhotoReimportRawDevelopmentStateImplPrivate;
typedef struct _PhotoReimportRawDevelopmentStateImplDevToReimportPrivate PhotoReimportRawDevelopmentStateImplDevToReimportPrivate;
#define _photo_reimport_raw_development_state_impl_dev_to_reimport_unref0(var) ((var == NULL) ? NULL : (var = (photo_reimport_raw_development_state_impl_dev_to_reimport_unref (var), NULL)))

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define PHOTO_METADATA_TYPE_SET_OPTION (photo_metadata_set_option_get_type ())

#define TYPE_BOX (box_get_type ())
typedef struct _Box Box;
#define _key_value_map_unref0(var) ((var == NULL) ? NULL : (var = (key_value_map_unref (var), NULL)))
#define _pixel_transformation_unref0(var) ((var == NULL) ? NULL : (var = (pixel_transformation_unref (var), NULL)))

#define PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL (photo_photo_transformation_state_impl_get_type ())
#define PHOTO_PHOTO_TRANSFORMATION_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL, PhotoPhotoTransformationStateImpl))
#define PHOTO_PHOTO_TRANSFORMATION_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL, PhotoPhotoTransformationStateImplClass))
#define PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL))
#define PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL))
#define PHOTO_PHOTO_TRANSFORMATION_STATE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL, PhotoPhotoTransformationStateImplClass))

typedef struct _PhotoPhotoTransformationStateImpl PhotoPhotoTransformationStateImpl;
typedef struct _PhotoPhotoTransformationStateImplClass PhotoPhotoTransformationStateImplClass;

#define EDITING_TOOLS_TYPE_REDEYE_INSTANCE (editing_tools_redeye_instance_get_type ())
typedef struct _EditingToolsRedeyeInstance EditingToolsRedeyeInstance;
typedef struct _PhotoCachedPixbufPrivate PhotoCachedPixbufPrivate;
#define _photo_cached_pixbuf_unref0(var) ((var == NULL) ? NULL : (var = (photo_cached_pixbuf_unref (var), NULL)))

#define TYPE_PHOTO_FILE_FORMAT_PROPERTIES (photo_file_format_properties_get_type ())
#define PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties))
#define PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define PHOTO_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))

typedef struct _PhotoFileFormatProperties PhotoFileFormatProperties;
typedef struct _PhotoFileFormatPropertiesClass PhotoFileFormatPropertiesClass;
#define _photo_file_format_properties_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_properties_unref (var), NULL)))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _PhotoPhotoTransformationStateImplPrivate PhotoPhotoTransformationStateImplPrivate;
typedef struct _PhotoParamSpecBackingReaders PhotoParamSpecBackingReaders;
#define _g_timer_destroy0(var) ((var == NULL) ? NULL : (var = (g_timer_destroy (var), NULL)))
typedef struct _PhotoParamSpecCachedPixbuf PhotoParamSpecCachedPixbuf;
typedef struct _PhotoParamSpecReimportMasterState PhotoParamSpecReimportMasterState;
typedef struct _PhotoParamSpecReimportEditableState PhotoParamSpecReimportEditableState;
typedef struct _PhotoParamSpecReimportRawDevelopmentState PhotoParamSpecReimportRawDevelopmentState;
typedef struct _PhotoReimportRawDevelopmentStateImplParamSpecDevToReimport PhotoReimportRawDevelopmentStateImplParamSpecDevToReimport;
enum  {
	PHOTO_EDITABLE_REPLACED_SIGNAL,
	PHOTO_RAW_DEVELOPMENT_MODIFIED_SIGNAL,
	PHOTO_BASELINE_REPLACED_SIGNAL,
	PHOTO_MASTER_REIMPORTED_SIGNAL,
	PHOTO_EDITABLE_REIMPORTED_SIGNAL,
	PHOTO_BASELINE_REIMPORTED_SIGNAL,
	PHOTO_SOURCE_REIMPORTED_SIGNAL,
	PHOTO_LAST_SIGNAL
};
static guint photo_signals[PHOTO_LAST_SIGNAL] = {0};
typedef struct _DataCollectionPrivate DataCollectionPrivate;

#define TYPE_MARKER (marker_get_type ())
#define MARKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MARKER, Marker))
#define IS_MARKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MARKER))
#define MARKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MARKER, MarkerIface))

typedef struct _Marker Marker;
typedef struct _MarkerIface MarkerIface;
typedef struct _SourceCollectionPrivate SourceCollectionPrivate;

#define TYPE_SOURCE_BACKLINK (source_backlink_get_type ())
#define SOURCE_BACKLINK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_BACKLINK, SourceBacklink))
#define SOURCE_BACKLINK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_BACKLINK, SourceBacklinkClass))
#define IS_SOURCE_BACKLINK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_BACKLINK))
#define IS_SOURCE_BACKLINK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_BACKLINK))
#define SOURCE_BACKLINK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_BACKLINK, SourceBacklinkClass))

typedef struct _SourceBacklink SourceBacklink;
typedef struct _SourceBacklinkClass SourceBacklinkClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;
typedef struct _DatabaseSourceCollectionPrivate DatabaseSourceCollectionPrivate;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;
typedef struct _MediaSourceCollectionPrivate MediaSourceCollectionPrivate;

#define TYPE_DATABASE_SOURCE_HOLDING_TANK (database_source_holding_tank_get_type ())
#define DATABASE_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_HOLDING_TANK, DatabaseSourceHoldingTank))
#define DATABASE_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_HOLDING_TANK, DatabaseSourceHoldingTankClass))
#define IS_DATABASE_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_HOLDING_TANK))
#define IS_DATABASE_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_HOLDING_TANK))
#define DATABASE_SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_HOLDING_TANK, DatabaseSourceHoldingTankClass))

typedef struct _DatabaseSourceHoldingTank DatabaseSourceHoldingTank;
typedef struct _DatabaseSourceHoldingTankClass DatabaseSourceHoldingTankClass;

#define TYPE_MEDIA_SOURCE_HOLDING_TANK (media_source_holding_tank_get_type ())
#define MEDIA_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTank))
#define MEDIA_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTankClass))
#define IS_MEDIA_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_HOLDING_TANK))
#define IS_MEDIA_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_HOLDING_TANK))
#define MEDIA_SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTankClass))

typedef struct _MediaSourceHoldingTank MediaSourceHoldingTank;
typedef struct _MediaSourceHoldingTankClass MediaSourceHoldingTankClass;

#define TYPE_WORKERS (workers_get_type ())
#define WORKERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WORKERS, Workers))
#define WORKERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WORKERS, WorkersClass))
#define IS_WORKERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WORKERS))
#define IS_WORKERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WORKERS))
#define WORKERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WORKERS, WorkersClass))

typedef struct _Workers Workers;
typedef struct _WorkersClass WorkersClass;

#define TYPE_MEDIA_MONITOR (media_monitor_get_type ())
#define MEDIA_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_MONITOR, MediaMonitor))
#define MEDIA_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_MONITOR, MediaMonitorClass))
#define IS_MEDIA_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_MONITOR))
#define IS_MEDIA_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_MONITOR))
#define MEDIA_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_MONITOR, MediaMonitorClass))

typedef struct _MediaMonitor MediaMonitor;
typedef struct _MediaMonitorClass MediaMonitorClass;

#define TYPE_TRANSACTION_CONTROLLER (transaction_controller_get_type ())
#define TRANSACTION_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRANSACTION_CONTROLLER, TransactionController))
#define TRANSACTION_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TRANSACTION_CONTROLLER, TransactionControllerClass))
#define IS_TRANSACTION_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRANSACTION_CONTROLLER))
#define IS_TRANSACTION_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TRANSACTION_CONTROLLER))
#define TRANSACTION_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TRANSACTION_CONTROLLER, TransactionControllerClass))

typedef struct _TransactionController TransactionController;
typedef struct _TransactionControllerClass TransactionControllerClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;
typedef struct _LibraryPhotoSourceCollectionPrivate LibraryPhotoSourceCollectionPrivate;

#define LIBRARY_PHOTO_SOURCE_COLLECTION_TYPE_STATE (library_photo_source_collection_state_get_type ())
#define _transaction_controller_unref0(var) ((var == NULL) ? NULL : (var = (transaction_controller_unref (var), NULL)))
#define _source_holding_tank_unref0(var) ((var == NULL) ? NULL : (var = (source_holding_tank_unref (var), NULL)))

#define TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK (library_photo_source_holding_tank_get_type ())
#define LIBRARY_PHOTO_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTank))
#define LIBRARY_PHOTO_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTankClass))
#define IS_LIBRARY_PHOTO_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK))
#define IS_LIBRARY_PHOTO_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK))
#define LIBRARY_PHOTO_SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTankClass))

typedef struct _LibraryPhotoSourceHoldingTank LibraryPhotoSourceHoldingTank;
typedef struct _LibraryPhotoSourceHoldingTankClass LibraryPhotoSourceHoldingTankClass;

#define TYPE_PHOTO_MONITOR (photo_monitor_get_type ())
#define PHOTO_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_MONITOR, PhotoMonitor))
#define PHOTO_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_MONITOR, PhotoMonitorClass))
#define IS_PHOTO_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_MONITOR))
#define IS_PHOTO_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_MONITOR))
#define PHOTO_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_MONITOR, PhotoMonitorClass))

typedef struct _PhotoMonitor PhotoMonitor;
typedef struct _PhotoMonitorClass PhotoMonitorClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;

#define TYPE_HIERARCHICAL_TAG_INDEX (hierarchical_tag_index_get_type ())
#define HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndex))
#define HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))
#define IS_HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HIERARCHICAL_TAG_INDEX))
#define IS_HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HIERARCHICAL_TAG_INDEX))
#define HIERARCHICAL_TAG_INDEX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))

typedef struct _HierarchicalTagIndex HierarchicalTagIndex;
typedef struct _HierarchicalTagIndexClass HierarchicalTagIndexClass;
#define _hierarchical_tag_index_unref0(var) ((var == NULL) ? NULL : (var = (hierarchical_tag_index_unref (var), NULL)))

#define TYPE_MEDIA_SOURCE_TRANSACTION_CONTROLLER (media_source_transaction_controller_get_type ())
#define MEDIA_SOURCE_TRANSACTION_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_TRANSACTION_CONTROLLER, MediaSourceTransactionController))
#define MEDIA_SOURCE_TRANSACTION_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_TRANSACTION_CONTROLLER, MediaSourceTransactionControllerClass))
#define IS_MEDIA_SOURCE_TRANSACTION_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_TRANSACTION_CONTROLLER))
#define IS_MEDIA_SOURCE_TRANSACTION_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_TRANSACTION_CONTROLLER))
#define MEDIA_SOURCE_TRANSACTION_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_TRANSACTION_CONTROLLER, MediaSourceTransactionControllerClass))

typedef struct _MediaSourceTransactionController MediaSourceTransactionController;
typedef struct _MediaSourceTransactionControllerClass MediaSourceTransactionControllerClass;
enum  {
	LIBRARY_PHOTO_SOURCE_COLLECTION_MASTER_REIMPORTED_SIGNAL,
	LIBRARY_PHOTO_SOURCE_COLLECTION_EDITABLE_REIMPORTED_SIGNAL,
	LIBRARY_PHOTO_SOURCE_COLLECTION_BASELINE_REIMPORTED_SIGNAL,
	LIBRARY_PHOTO_SOURCE_COLLECTION_SOURCE_REIMPORTED_SIGNAL,
	LIBRARY_PHOTO_SOURCE_COLLECTION_LAST_SIGNAL
};
static guint library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_LAST_SIGNAL] = {0};

#define TYPE_FLAGGABLE (flaggable_get_type ())
#define FLAGGABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FLAGGABLE, Flaggable))
#define IS_FLAGGABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FLAGGABLE))
#define FLAGGABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_FLAGGABLE, FlaggableIface))

typedef struct _Flaggable Flaggable;
typedef struct _FlaggableIface FlaggableIface;

#define TYPE_MONITORABLE (monitorable_get_type ())
#define MONITORABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MONITORABLE, Monitorable))
#define IS_MONITORABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MONITORABLE))
#define MONITORABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MONITORABLE, MonitorableIface))

typedef struct _Monitorable Monitorable;
typedef struct _MonitorableIface MonitorableIface;
typedef struct _LibraryPhotoPrivate LibraryPhotoPrivate;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define THUMBNAIL_CACHE_TYPE_SIZE (thumbnail_cache_size_get_type ())

#define TYPE_EVENT_SOURCE (event_source_get_type ())
#define EVENT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_SOURCE, EventSource))
#define EVENT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_SOURCE, EventSourceClass))
#define IS_EVENT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_SOURCE))
#define IS_EVENT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_SOURCE))
#define EVENT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_SOURCE, EventSourceClass))

typedef struct _EventSource EventSource;
typedef struct _EventSourceClass EventSourceClass;

#define TYPE_EVENT (event_get_type ())
#define EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT, Event))
#define EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT, EventClass))
#define IS_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT))
#define IS_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT))
#define EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT, EventClass))

typedef struct _Event Event;
typedef struct _EventClass EventClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_TAG_SOURCE_COLLECTION (tag_source_collection_get_type ())
#define TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollection))
#define TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))
#define IS_TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_SOURCE_COLLECTION))
#define IS_TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_SOURCE_COLLECTION))
#define TAG_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))

typedef struct _TagSourceCollection TagSourceCollection;
typedef struct _TagSourceCollectionClass TagSourceCollectionClass;
typedef struct _SourceHoldingTankPrivate SourceHoldingTankPrivate;
typedef struct _DatabaseSourceHoldingTankPrivate DatabaseSourceHoldingTankPrivate;
typedef struct _MediaSourceHoldingTankPrivate MediaSourceHoldingTankPrivate;
typedef struct _LibraryPhotoSourceHoldingTankPrivate LibraryPhotoSourceHoldingTankPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	BACKING_FETCH_MODE_SOURCE,
	BACKING_FETCH_MODE_BASELINE,
	BACKING_FETCH_MODE_MASTER,
	BACKING_FETCH_MODE_UNMODIFIED
} BackingFetchMode;

struct _ImportID {
	gint64 id;
};

typedef enum  {
	PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL = 0x00000000,
	PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5 = 0x00000001
} PhotoFileSnifferOptions;

struct _PhotoImportParams {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoImportParamsPrivate * priv;
	GFile* file;
	GFile* final_associated_file;
	ImportID import_id;
	PhotoFileSnifferOptions sniffer_options;
	gchar* exif_md5;
	gchar* thumbnail_md5;
	gchar* full_md5;
	Thumbnails* thumbnails;
	PhotoRow* row;
	GeeCollection* keywords;
};

struct _PhotoImportParamsClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoImportParams *self);
};

struct _ParamSpecPhotoImportParams {
	GParamSpec parent_instance;
};

struct _PhotoTransformationState {
	GObject parent_instance;
	PhotoTransformationStatePrivate * priv;
};

struct _PhotoTransformationStateClass {
	GObjectClass parent_class;
	void (*broken) (PhotoTransformationState* self);
};

struct _PhotoTransformationStatePrivate {
	gboolean is_broke;
};

typedef enum  {
	RATING_REJECTED = -1,
	RATING_UNRATED = 0,
	RATING_ONE = 1,
	RATING_TWO = 2,
	RATING_THREE = 3,
	RATING_FOUR = 4,
	RATING_FIVE = 5
} Rating;

struct _DataObject {
	GObject parent_instance;
	DataObjectPrivate * priv;
};

struct _DataObjectClass {
	GObjectClass parent_class;
	void (*notify_altered) (DataObject* self, Alteration* alteration);
	void (*notify_membership_changed) (DataObject* self, DataCollection* collection);
	void (*notify_collection_property_set) (DataObject* self, const gchar* name, GValue* old, GValue* val);
	void (*notify_collection_property_cleared) (DataObject* self, const gchar* name);
	gchar* (*get_name) (DataObject* self);
	gchar* (*to_string) (DataObject* self);
};

struct _DataSource {
	DataObject parent_instance;
	DataSourcePrivate * priv;
};

struct _DataSourceClass {
	DataObjectClass parent_class;
	void (*notify_held_in_tank) (DataSource* self, SourceHoldingTank* holding_tank);
	void (*notify_unlinking) (DataSource* self, SourceCollection* collection);
	void (*notify_unlinked) (DataSource* self);
	void (*notify_relinking) (DataSource* self, SourceCollection* collection);
	void (*notify_relinked) (DataSource* self);
	gchar* (*get_typename) (DataSource* self);
	gint64 (*get_instance_id) (DataSource* self);
	gchar* (*get_source_id) (DataSource* self);
	void (*commit_backlinks) (DataSource* self, SourceCollection* sources, const gchar* dehydrated);
	SourceSnapshot* (*save_snapshot) (DataSource* self);
	gboolean (*internal_delete_backing) (DataSource* self, GError** error);
	gboolean (*equals) (DataSource* self, DataSource* source);
	void (*destroy) (DataSource* self);
	void (*unlinked) (DataSource* self, SourceCollection* sources);
	void (*relinked) (DataSource* self, SourceCollection* sources);
	void (*destroyed) (DataSource* self);
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

struct _ThumbnailSource {
	DataSource parent_instance;
	ThumbnailSourcePrivate * priv;
};

struct _ThumbnailSourceClass {
	DataSourceClass parent_class;
	void (*notify_thumbnail_altered) (ThumbnailSource* self);
	GdkPixbuf* (*get_thumbnail) (ThumbnailSource* self, gint scale, GError** error);
	GdkPixbuf* (*create_thumbnail) (ThumbnailSource* self, gint scale, GError** error);
	gchar* (*get_representative_id) (ThumbnailSource* self);
	PhotoFileFormat (*get_preferred_thumbnail_format) (ThumbnailSource* self);
	void (*thumbnail_altered) (ThumbnailSource* self);
};

struct _IndexableIface {
	GTypeInterface parent_iface;
	const gchar* (*get_indexable_keywords) (Indexable* self);
};

struct _EventID {
	gint64 id;
};

typedef enum  {
	PHOTO_EXCEPTION_NONE = 0,
	PHOTO_EXCEPTION_ORIENTATION = 1 << 0,
	PHOTO_EXCEPTION_CROP = 1 << 1,
	PHOTO_EXCEPTION_REDEYE = 1 << 2,
	PHOTO_EXCEPTION_ADJUST = 1 << 3,
	PHOTO_EXCEPTION_STRAIGHTEN = 1 << 4,
	PHOTO_EXCEPTION_ALL = 0xFFFFFFFFLL
} PhotoException;

struct _Dimensions {
	gint width;
	gint height;
};

typedef enum  {
	SCALE_CONSTRAINT_ORIGINAL,
	SCALE_CONSTRAINT_DIMENSIONS,
	SCALE_CONSTRAINT_WIDTH,
	SCALE_CONSTRAINT_HEIGHT,
	SCALE_CONSTRAINT_FILL_VIEWPORT
} ScaleConstraint;

struct _Scaling {
	ScaleConstraint constraint;
	gint scale;
	Dimensions viewport;
	gboolean scale_up;
};

struct _MediaSource {
	ThumbnailSource parent_instance;
	MediaSourcePrivate * priv;
};

struct _MediaSourceClass {
	ThumbnailSourceClass parent_class;
	void (*notify_master_replaced) (MediaSource* self, GFile* old_file, GFile* new_file);
	gboolean (*set_event_id) (MediaSource* self, EventID* id);
	gchar* (*get_basename) (MediaSource* self);
	GFile* (*get_file) (MediaSource* self);
	GFile* (*get_master_file) (MediaSource* self);
	guint64 (*get_master_filesize) (MediaSource* self);
	guint64 (*get_filesize) (MediaSource* self);
	time_t (*get_timestamp) (MediaSource* self);
	BackingFileState** (*get_backing_files_state) (MediaSource* self, int* result_length1);
	gchar* (*get_title) (MediaSource* self);
	gchar* (*get_comment) (MediaSource* self);
	void (*set_title) (MediaSource* self, const gchar* title);
	gboolean (*set_comment) (MediaSource* self, const gchar* comment);
	Rating (*get_rating) (MediaSource* self);
	void (*set_rating) (MediaSource* self, Rating rating);
	void (*increase_rating) (MediaSource* self);
	void (*decrease_rating) (MediaSource* self);
	void (*get_dimensions) (MediaSource* self, PhotoException disallowed_steps, Dimensions* result);
	GdkPixbuf* (*get_preview_pixbuf) (MediaSource* self, Scaling* scaling, GError** error);
	gboolean (*is_trashed) (MediaSource* self);
	void (*trash) (MediaSource* self);
	void (*untrash) (MediaSource* self);
	gboolean (*is_offline) (MediaSource* self);
	void (*mark_offline) (MediaSource* self);
	void (*mark_online) (MediaSource* self);
	gchar* (*get_master_md5) (MediaSource* self);
	void (*get_event_id) (MediaSource* self, EventID* result);
	time_t (*get_exposure_time) (MediaSource* self);
	void (*get_import_id) (MediaSource* self, ImportID* result);
	void (*master_replaced) (MediaSource* self, GFile* old_file, GFile* new_file);
};

struct _PhotoSource {
	MediaSource parent_instance;
	PhotoSourcePrivate * priv;
};

struct _PhotoSourceClass {
	MediaSourceClass parent_class;
	PhotoMetadata* (*get_metadata) (PhotoSource* self);
	GdkPixbuf* (*get_pixbuf) (PhotoSource* self, Scaling* scaling, GError** error);
};

struct _DateableIface {
	GTypeInterface parent_iface;
	void (*set_exposure_time) (Dateable* self, time_t target_time);
	time_t (*get_exposure_time) (Dateable* self);
};

typedef enum  {
	ROTATION_CLOCKWISE,
	ROTATION_COUNTERCLOCKWISE,
	ROTATION_MIRROR,
	ROTATION_UPSIDE_DOWN
} Rotation;

struct _Photo {
	PhotoSource parent_instance;
	PhotoPrivate * priv;
	PhotoRow* row;
	gboolean can_rotate_now;
	BackingPhotoRow* backing_photo_row;
};

struct _PhotoClass {
	PhotoSourceClass parent_class;
	void (*notify_editable_replaced) (Photo* self, GFile* old_file, GFile* new_file);
	void (*notify_raw_development_modified) (Photo* self);
	void (*notify_baseline_replaced) (Photo* self);
	void (*notify_master_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*notify_editable_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*notify_source_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*notify_baseline_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*apply_user_metadata_for_reimport) (Photo* self, PhotoMetadata* metadata);
	void (*rotate) (Photo* self, Rotation rotation);
	gboolean (*has_user_generated_metadata) (Photo* self);
	void (*set_user_metadata_for_export) (Photo* self, PhotoMetadata* metadata);
	void (*editable_replaced) (Photo* self, GFile* old_file, GFile* new_file);
	void (*raw_development_modified) (Photo* self);
	void (*baseline_replaced) (Photo* self);
	void (*master_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*editable_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*baseline_reimported) (Photo* self, PhotoMetadata* metadata);
	void (*source_reimported) (Photo* self, PhotoMetadata* metadata);
};

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _PhotoPrivate {
	time_t cached_exposure_time;
	GRecMutex __lock_row;
	BackingPhotoRow* editable;
	PhotoBackingReaders* readers;
	GRecMutex __lock_readers;
	PixelTransformer* transformer;
	PixelTransformationBundle* adjustments;
	gchar* file_title;
	GFileMonitor* editable_monitor;
	OneShotScheduler* reimport_editable_scheduler;
	OneShotScheduler* update_editable_attributes_scheduler;
	OneShotScheduler* remove_editable_scheduler;
	GeeHashMap* developments;
	GRecMutex __lock_developments;
};

struct _PhotoID {
	gint64 id;
};

typedef enum  {
	ORIENTATION_MIN = 1,
	ORIENTATION_TOP_LEFT = 1,
	ORIENTATION_TOP_RIGHT = 2,
	ORIENTATION_BOTTOM_RIGHT = 3,
	ORIENTATION_BOTTOM_LEFT = 4,
	ORIENTATION_LEFT_TOP = 5,
	ORIENTATION_RIGHT_TOP = 6,
	ORIENTATION_RIGHT_BOTTOM = 7,
	ORIENTATION_LEFT_BOTTOM = 8,
	ORIENTATION_MAX = 8
} Orientation;

struct _BackingPhotoID {
	gint64 id;
};

struct _PhotoRow {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoRowPrivate * priv;
	PhotoID photo_id;
	BackingPhotoRow* master;
	time_t exposure_time;
	ImportID import_id;
	EventID event_id;
	Orientation orientation;
	GeeHashMap* transformations;
	gchar* md5;
	gchar* thumbnail_md5;
	gchar* exif_md5;
	time_t time_created;
	guint64 flags;
	Rating rating;
	gchar* title;
	gchar* comment;
	gchar* backlinks;
	time_t time_reimported;
	BackingPhotoID editable_id;
	gboolean metadata_dirty;
	RawDeveloper developer;
	BackingPhotoID* development_ids;
	gint development_ids_length1;
};

struct _PhotoRowClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoRow *self);
};

struct _BackingPhotoRow {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BackingPhotoRowPrivate * priv;
	BackingPhotoID id;
	time_t time_created;
	gchar* filepath;
	gint64 filesize;
	time_t timestamp;
	PhotoFileFormat file_format;
	Dimensions dim;
	Orientation original_orientation;
};

struct _BackingPhotoRowClass {
	GTypeClass parent_class;
	void (*finalize) (BackingPhotoRow *self);
};

struct _PhotoBackingReaders {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoBackingReadersPrivate * priv;
	PhotoFileReader* master;
	PhotoFileReader* developer;
	PhotoFileReader* editable;
};

struct _PhotoBackingReadersClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoBackingReaders *self);
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _DetectedPhotoInformation {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DetectedPhotoInformationPrivate * priv;
	PhotoFileFormat file_format;
	PhotoMetadata* metadata;
	gchar* md5;
	gchar* exif_md5;
	gchar* thumbnail_md5;
	gchar* format_name;
	Dimensions image_dim;
	GdkColorspace colorspace;
	gint channels;
	gint bits_per_channel;
};

struct _DetectedPhotoInformationClass {
	GTypeClass parent_class;
	void (*finalize) (DetectedPhotoInformation *self);
};

typedef enum  {
	PHOTO_FORMAT_ERROR_READ_ONLY
} PhotoFormatError;
#define PHOTO_FORMAT_ERROR photo_format_error_quark ()
typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

typedef enum  {
	EXPORT_FORMAT_MODE_UNMODIFIED,
	EXPORT_FORMAT_MODE_CURRENT,
	EXPORT_FORMAT_MODE_SPECIFIED,
	EXPORT_FORMAT_MODE_LAST
} ExportFormatMode;

struct _ExportFormatParameters {
	ExportFormatMode mode;
	PhotoFileFormat specified_format;
	JpegQuality quality;
	gboolean export_metadata;
};

typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

typedef enum  {
	PHOTO_FILE_READER_ROLE_DEFAULT,
	PHOTO_FILE_READER_ROLE_THUMBNAIL
} PhotoFileReaderRole;

struct _PhotoReimportMasterState {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoReimportMasterStatePrivate * priv;
};

struct _PhotoReimportMasterStateClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoReimportMasterState *self);
};

struct _PhotoReimportMasterStateImpl {
	PhotoReimportMasterState parent_instance;
	PhotoReimportMasterStateImplPrivate * priv;
	PhotoRow* row;
	PhotoMetadata* metadata;
	gchar** alterations;
	gint alterations_length1;
	gint _alterations_size_;
	gboolean metadata_only;
};

struct _PhotoReimportMasterStateImplClass {
	PhotoReimportMasterStateClass parent_class;
};

struct _PhotoReimportEditableState {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoReimportEditableStatePrivate * priv;
};

struct _PhotoReimportEditableStateClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoReimportEditableState *self);
};

struct _PhotoReimportEditableStateImpl {
	PhotoReimportEditableState parent_instance;
	PhotoReimportEditableStateImplPrivate * priv;
	BackingPhotoRow* backing_state;
	PhotoMetadata* metadata;
	gboolean metadata_only;
};

struct _PhotoReimportEditableStateImplClass {
	PhotoReimportEditableStateClass parent_class;
};

struct _PhotoReimportRawDevelopmentState {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoReimportRawDevelopmentStatePrivate * priv;
};

struct _PhotoReimportRawDevelopmentStateClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoReimportRawDevelopmentState *self);
};

struct _PhotoReimportRawDevelopmentStateImpl {
	PhotoReimportRawDevelopmentState parent_instance;
	PhotoReimportRawDevelopmentStateImplPrivate * priv;
	GeeCollection* list;
	gboolean metadata_only;
};

struct _PhotoReimportRawDevelopmentStateImplClass {
	PhotoReimportRawDevelopmentStateClass parent_class;
};

struct _PhotoReimportRawDevelopmentStateImplDevToReimport {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoReimportRawDevelopmentStateImplDevToReimportPrivate * priv;
	BackingPhotoRow* backing;
	PhotoMetadata* metadata;
};

struct _PhotoReimportRawDevelopmentStateImplDevToReimportClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoReimportRawDevelopmentStateImplDevToReimport *self);
};

typedef enum  {
	PHOTO_METADATA_SET_OPTION_ALL_DOMAINS,
	PHOTO_METADATA_SET_OPTION_ONLY_IF_DOMAIN_PRESENT,
	PHOTO_METADATA_SET_OPTION_AT_LEAST_DEFAULT_DOMAIN
} PhotoMetadataSetOption;

struct _Box {
	gint left;
	gint top;
	gint right;
	gint bottom;
};

struct _EditingToolsRedeyeInstance {
	GdkPoint center;
	gint radius;
};

struct _PhotoCachedPixbuf {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoCachedPixbufPrivate * priv;
	Photo* photo;
	GdkPixbuf* pixbuf;
	GTimer* last_touched;
};

struct _PhotoCachedPixbufClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoCachedPixbuf *self);
};

typedef void (*OneShotCallback) (void* user_data);
struct _PhotoPhotoTransformationStateImpl {
	PhotoTransformationState parent_instance;
	PhotoPhotoTransformationStateImplPrivate * priv;
};

struct _PhotoPhotoTransformationStateImplClass {
	PhotoTransformationStateClass parent_class;
};

struct _PhotoPhotoTransformationStateImplPrivate {
	Photo* photo;
	Orientation orientation;
	GeeHashMap* transformations;
	PixelTransformer* transformer;
	PixelTransformationBundle* adjustments;
};

struct _PhotoParamSpecBackingReaders {
	GParamSpec parent_instance;
};

struct _PhotoParamSpecCachedPixbuf {
	GParamSpec parent_instance;
};

struct _PhotoParamSpecReimportMasterState {
	GParamSpec parent_instance;
};

struct _PhotoParamSpecReimportEditableState {
	GParamSpec parent_instance;
};

struct _PhotoParamSpecReimportRawDevelopmentState {
	GParamSpec parent_instance;
};

struct _PhotoReimportRawDevelopmentStateImplParamSpecDevToReimport {
	GParamSpec parent_instance;
};

typedef gint64 (*Comparator) (void* a, void* b, void* user_data);
typedef gboolean (*ComparatorPredicate) (DataObject* object, Alteration* alteration, void* user_data);
typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);
struct _MarkerIface {
	GTypeInterface parent_iface;
	void (*mark) (Marker* self, DataObject* object);
	void (*unmark) (Marker* self, DataObject* object);
	gboolean (*toggle) (Marker* self, DataObject* object);
	void (*mark_many) (Marker* self, GeeCollection* list);
	void (*unmark_many) (Marker* self, GeeCollection* list);
	void (*mark_all) (Marker* self);
	gint (*get_count) (Marker* self);
	GeeCollection* (*get_all) (Marker* self);
};

struct _DataCollection {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DataCollectionPrivate * priv;
};

struct _DataCollectionClass {
	GTypeClass parent_class;
	void (*finalize) (DataCollection *self);
	gchar* (*to_string) (DataCollection* self);
	void (*notify_items_added) (DataCollection* self, GeeIterable* added);
	void (*notify_items_removed) (DataCollection* self, GeeIterable* removed);
	void (*notify_contents_altered) (DataCollection* self, GeeIterable* added, GeeIterable* removed);
	void (*notify_items_altered) (DataCollection* self, GeeMap* items);
	void (*notify_ordering_changed) (DataCollection* self);
	void (*notify_property_set) (DataCollection* self, const gchar* name, GValue* old, GValue* val);
	void (*notify_property_cleared) (DataCollection* self, const gchar* name);
	gboolean (*valid_type) (DataCollection* self, DataObject* object);
	void (*set_comparator) (DataCollection* self, Comparator comparator, void* comparator_target, ComparatorPredicate predicate, void* predicate_target);
	void (*reset_comparator) (DataCollection* self);
	GeeCollection* (*get_all) (DataCollection* self);
	gint (*get_count) (DataCollection* self);
	DataObject* (*get_at) (DataCollection* self, gint index);
	gint (*index_of) (DataCollection* self, DataObject* object);
	gboolean (*contains) (DataCollection* self, DataObject* object);
	gboolean (*add) (DataCollection* self, DataObject* object);
	GeeCollection* (*add_many) (DataCollection* self, GeeCollection* objects, ProgressMonitor monitor, void* monitor_target);
	void (*remove_marked) (DataCollection* self, Marker* m);
	void (*clear) (DataCollection* self);
	void (*close) (DataCollection* self);
	void (*notify_frozen) (DataCollection* self);
	void (*notify_thawed) (DataCollection* self);
	void (*items_added) (DataCollection* self, GeeIterable* added);
	void (*items_removed) (DataCollection* self, GeeIterable* removed);
	void (*contents_altered) (DataCollection* self, GeeIterable* added, GeeIterable* removed);
	void (*items_altered) (DataCollection* self, GeeMap* items);
	void (*ordering_changed) (DataCollection* self);
	void (*property_set) (DataCollection* self, const gchar* name, GValue* old, GValue* val);
	void (*property_cleared) (DataCollection* self, const gchar* name);
	void (*frozen) (DataCollection* self);
	void (*thawed) (DataCollection* self);
};

struct _SourceCollection {
	DataCollection parent_instance;
	SourceCollectionPrivate * priv;
};

struct _SourceCollectionClass {
	DataCollectionClass parent_class;
	gboolean (*holds_type_of_source) (SourceCollection* self, DataSource* source);
	void (*notify_items_unlinking) (SourceCollection* self, GeeCollection* unlinking);
	void (*notify_items_relinked) (SourceCollection* self, GeeCollection* relinked);
	void (*notify_item_destroyed) (SourceCollection* self, DataSource* source);
	void (*notify_items_destroyed) (SourceCollection* self, GeeCollection* destroyed);
	void (*notify_unlinked_destroyed) (SourceCollection* self, DataSource* unlinked);
	void (*notify_backlink_removed) (SourceCollection* self, SourceBacklink* backlink, GeeCollection* sources);
	gboolean (*has_backlink) (SourceCollection* self, SourceBacklink* backlink);
	void (*remove_backlink) (SourceCollection* self, SourceBacklink* backlink);
	void (*items_unlinking) (SourceCollection* self, GeeCollection* unlinking);
	void (*items_relinked) (SourceCollection* self, GeeCollection* relinked);
	void (*item_destroyed) (SourceCollection* self, DataSource* source);
	void (*items_destroyed) (SourceCollection* self, GeeCollection* destroyed);
	void (*unlinked_destroyed) (SourceCollection* self, DataSource* source);
	void (*backlink_removed) (SourceCollection* self, SourceBacklink* backlink, GeeCollection* sources);
};

struct _DatabaseSourceCollection {
	SourceCollection parent_instance;
	DatabaseSourceCollectionPrivate * priv;
};

struct _DatabaseSourceCollectionClass {
	SourceCollectionClass parent_class;
};

struct _MediaSourceCollection {
	DatabaseSourceCollection parent_instance;
	MediaSourceCollectionPrivate * priv;
};

struct _MediaSourceCollectionClass {
	DatabaseSourceCollectionClass parent_class;
	MediaSourceHoldingTank* (*create_trashcan) (MediaSourceCollection* self);
	MediaSourceHoldingTank* (*create_offline_bin) (MediaSourceCollection* self);
	MediaMonitor* (*create_media_monitor) (MediaSourceCollection* self, Workers* workers, GCancellable* cancellable);
	gchar* (*get_typename) (MediaSourceCollection* self);
	gboolean (*is_file_recognized) (MediaSourceCollection* self, GFile* file);
	MediaSource* (*fetch_by_numeric_id) (MediaSourceCollection* self, gint64 numeric_id);
	void (*notify_import_roll_altered) (MediaSourceCollection* self);
	void (*notify_flagged_contents_altered) (MediaSourceCollection* self);
	void (*notify_media_import_starting) (MediaSourceCollection* self, GeeCollection* media);
	void (*notify_media_import_completed) (MediaSourceCollection* self, GeeCollection* media);
	MediaSource* (*fetch_by_source_id) (MediaSourceCollection* self, const gchar* source_id);
	GeeCollection* (*get_event_source_ids) (MediaSourceCollection* self, EventID* event_id);
	void (*import_many) (MediaSourceCollection* self, GeeCollection* media);
	void (*postprocess_imported_media) (MediaSourceCollection* self, GeeCollection* media);
	void (*media_import_starting) (MediaSourceCollection* self, GeeCollection* media);
	void (*media_import_completed) (MediaSourceCollection* self, GeeCollection* media);
	void (*master_file_replaced) (MediaSourceCollection* self, MediaSource* media, GFile* old_file, GFile* new_file);
	void (*trashcan_contents_altered) (MediaSourceCollection* self, GeeCollection* added, GeeCollection* removed);
	void (*import_roll_altered) (MediaSourceCollection* self);
	void (*offline_contents_altered) (MediaSourceCollection* self, GeeCollection* added, GeeCollection* removed);
	void (*flagged_contents_altered) (MediaSourceCollection* self);
	TransactionController* (*get_transaction_controller) (MediaSourceCollection* self);
};

struct _LibraryPhotoSourceCollection {
	MediaSourceCollection parent_instance;
	LibraryPhotoSourceCollectionPrivate * priv;
};

struct _LibraryPhotoSourceCollectionClass {
	MediaSourceCollectionClass parent_class;
	void (*notify_master_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*notify_editable_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*notify_source_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*notify_baseline_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*master_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*editable_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*baseline_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
	void (*source_reimported) (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
};

struct _LibraryPhotoSourceCollectionPrivate {
	TransactionController* _transaction_controller;
	GeeHashMap* by_editable_file;
	GeeHashMap* by_raw_development_file;
	GeeMultiMap* filesize_to_photo;
	GeeHashMap* photo_to_master_filesize;
	GeeHashMap* photo_to_editable_filesize;
	GeeMultiMap* photo_to_raw_development_filesize;
};

typedef enum  {
	LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_UNKNOWN,
	LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_ONLINE,
	LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_OFFLINE,
	LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_TRASH,
	LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_EDITABLE,
	LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_DEVELOPER
} LibraryPhotoSourceCollectionState;

typedef gint64 (*GetSourceDatabaseKey) (DataSource* source, void* user_data);
typedef gboolean (*SourceHoldingTankCheckToKeep) (DataSource* source, Alteration* alteration, void* user_data);
struct _FlaggableIface {
	GTypeInterface parent_iface;
	gboolean (*is_flagged) (Flaggable* self);
	void (*mark_flagged) (Flaggable* self);
	void (*mark_unflagged) (Flaggable* self);
};

struct _MonitorableIface {
	GTypeInterface parent_iface;
	gboolean (*is_offline) (Monitorable* self);
	void (*mark_online) (Monitorable* self);
	void (*mark_offline) (Monitorable* self);
	void (*set_master_file) (Monitorable* self, GFile* file);
	void (*set_master_timestamp) (Monitorable* self, GFileInfo* info);
};

struct _LibraryPhoto {
	Photo parent_instance;
	LibraryPhotoPrivate * priv;
};

struct _LibraryPhotoClass {
	PhotoClass parent_class;
};

struct _LibraryPhotoPrivate {
	gboolean block_thumbnail_generation;
	OneShotScheduler* thumbnail_scheduler;
	GeeCollection* import_keywords;
};

typedef enum  {
	THUMBNAIL_CACHE_SIZE_LARGEST = 360,
	THUMBNAIL_CACHE_SIZE_BIG = 360,
	THUMBNAIL_CACHE_SIZE_MEDIUM = 128,
	THUMBNAIL_CACHE_SIZE_SMALLEST = 128
} ThumbnailCacheSize;

struct _SourceHoldingTank {
	GTypeInstance parent_instance;
	volatile int ref_count;
	SourceHoldingTankPrivate * priv;
};

struct _SourceHoldingTankClass {
	GTypeClass parent_class;
	void (*finalize) (SourceHoldingTank *self);
	void (*notify_contents_altered) (SourceHoldingTank* self, GeeCollection* added, GeeCollection* removed);
	void (*contents_altered) (SourceHoldingTank* self, GeeCollection* added, GeeCollection* removed);
};

struct _DatabaseSourceHoldingTank {
	SourceHoldingTank parent_instance;
	DatabaseSourceHoldingTankPrivate * priv;
};

struct _DatabaseSourceHoldingTankClass {
	SourceHoldingTankClass parent_class;
};

struct _MediaSourceHoldingTank {
	DatabaseSourceHoldingTank parent_instance;
	MediaSourceHoldingTankPrivate * priv;
};

struct _MediaSourceHoldingTankClass {
	DatabaseSourceHoldingTankClass parent_class;
};

struct _LibraryPhotoSourceHoldingTank {
	MediaSourceHoldingTank parent_instance;
	LibraryPhotoSourceHoldingTankPrivate * priv;
};

struct _LibraryPhotoSourceHoldingTankClass {
	MediaSourceHoldingTankClass parent_class;
};

struct _LibraryPhotoSourceHoldingTankPrivate {
	GeeHashMap* editable_file_map;
	GeeHashMap* development_file_map;
	GeeMultiMap* reverse_editable_file_map;
	GeeMultiMap* reverse_development_file_map;
};


static gpointer photo_import_params_parent_class = NULL;
static gpointer photo_transformation_state_parent_class = NULL;
static gpointer photo_parent_class = NULL;
static GeeLinkedList* photo_source_pixbuf_cache;
static GRecMutex __lock_photo_source_pixbuf_cache = {0};
static GeeLinkedList* photo_source_pixbuf_cache = NULL;
static guint photo_discard_source_id;
static guint photo_discard_source_id = (guint) 0;
static gboolean photo__develop_raw_photos_to_files;
static gboolean photo__develop_raw_photos_to_files = FALSE;
static gpointer photo_photo_transformation_state_impl_parent_class = NULL;
static gpointer photo_backing_readers_parent_class = NULL;
static gpointer photo_cached_pixbuf_parent_class = NULL;
static gpointer photo_reimport_master_state_parent_class = NULL;
static gpointer photo_reimport_master_state_impl_parent_class = NULL;
static gpointer photo_reimport_editable_state_parent_class = NULL;
static gpointer photo_reimport_editable_state_impl_parent_class = NULL;
static gpointer photo_reimport_raw_development_state_parent_class = NULL;
static gpointer photo_reimport_raw_development_state_impl_parent_class = NULL;
static gpointer photo_reimport_raw_development_state_impl_dev_to_reimport_parent_class = NULL;
static DateableIface * photo_dateable_parent_iface = NULL;
static gpointer library_photo_source_collection_parent_class = NULL;
static gpointer library_photo_parent_class = NULL;
extern LibraryPhotoSourceCollection* library_photo_global;
LibraryPhotoSourceCollection* library_photo_global = NULL;
extern TagSourceCollection* tag_global;
static FlaggableIface * library_photo_flaggable_parent_iface = NULL;
static MonitorableIface * library_photo_monitorable_parent_iface = NULL;
static gpointer library_photo_source_holding_tank_parent_class = NULL;

GType backing_fetch_mode_get_type (void) G_GNUC_CONST;
gpointer photo_import_params_ref (gpointer instance);
void photo_import_params_unref (gpointer instance);
GParamSpec* param_spec_photo_import_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_import_params (GValue* value, gpointer v_object);
void value_take_photo_import_params (GValue* value, gpointer v_object);
gpointer value_get_photo_import_params (const GValue* value);
GType photo_import_params_get_type (void) G_GNUC_CONST;
GType import_id_get_type (void) G_GNUC_CONST;
ImportID* import_id_dup (const ImportID* self);
void import_id_free (ImportID* self);
GType photo_file_sniffer_options_get_type (void) G_GNUC_CONST;
gpointer thumbnails_ref (gpointer instance);
void thumbnails_unref (gpointer instance);
GParamSpec* param_spec_thumbnails (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_thumbnails (GValue* value, gpointer v_object);
void value_take_thumbnails (GValue* value, gpointer v_object);
gpointer value_get_thumbnails (const GValue* value);
GType thumbnails_get_type (void) G_GNUC_CONST;
gpointer photo_row_ref (gpointer instance);
void photo_row_unref (gpointer instance);
GParamSpec* param_spec_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_row (GValue* value, gpointer v_object);
void value_take_photo_row (GValue* value, gpointer v_object);
gpointer value_get_photo_row (const GValue* value);
GType photo_row_get_type (void) G_GNUC_CONST;
enum  {
	PHOTO_IMPORT_PARAMS_DUMMY_PROPERTY
};
PhotoRow* photo_row_new (void);
PhotoRow* photo_row_construct (GType object_type);
PhotoImportParams* photo_import_params_new (GFile* file, GFile* final_associated_file, ImportID* import_id, PhotoFileSnifferOptions sniffer_options, const gchar* exif_md5, const gchar* thumbnail_md5, const gchar* full_md5, Thumbnails* thumbnails);
PhotoImportParams* photo_import_params_construct (GType object_type, GFile* file, GFile* final_associated_file, ImportID* import_id, PhotoFileSnifferOptions sniffer_options, const gchar* exif_md5, const gchar* thumbnail_md5, const gchar* full_md5, Thumbnails* thumbnails);
PhotoImportParams* photo_import_params_new_create_placeholder (GFile* file, ImportID* import_id);
PhotoImportParams* photo_import_params_construct_create_placeholder (GType object_type, GFile* file, ImportID* import_id);
static void photo_import_params_finalize (PhotoImportParams * obj);
GType photo_transformation_state_get_type (void) G_GNUC_CONST;
#define PHOTO_TRANSFORMATION_STATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationStatePrivate))
enum  {
	PHOTO_TRANSFORMATION_STATE_DUMMY_PROPERTY
};
PhotoTransformationState* photo_transformation_state_construct (GType object_type);
gboolean photo_transformation_state_is_broken (PhotoTransformationState* self);
static void photo_transformation_state_real_broken (PhotoTransformationState* self);
static void photo_transformation_state_finalize (GObject * obj);
GType rating_get_type (void) G_GNUC_CONST;
gboolean rating_can_increase (Rating self);
gboolean rating_can_decrease (Rating self);
gboolean rating_is_valid (Rating self);
Rating rating_increase (Rating self);
Rating rating_decrease (Rating self);
gint rating_serialize (Rating self);
Rating rating_unserialize (gint value);
GType data_object_get_type (void) G_GNUC_CONST;
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
gpointer source_holding_tank_ref (gpointer instance);
void source_holding_tank_unref (gpointer instance);
GParamSpec* param_spec_source_holding_tank (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_source_holding_tank (GValue* value, gpointer v_object);
void value_take_source_holding_tank (GValue* value, gpointer v_object);
gpointer value_get_source_holding_tank (const GValue* value);
GType source_holding_tank_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
gpointer source_snapshot_ref (gpointer instance);
void source_snapshot_unref (gpointer instance);
GParamSpec* param_spec_source_snapshot (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_source_snapshot (GValue* value, gpointer v_object);
void value_take_source_snapshot (GValue* value, gpointer v_object);
gpointer value_get_source_snapshot (const GValue* value);
GType source_snapshot_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType indexable_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType event_id_get_type (void) G_GNUC_CONST;
EventID* event_id_dup (const EventID* self);
void event_id_free (EventID* self);
gpointer backing_file_state_ref (gpointer instance);
void backing_file_state_unref (gpointer instance);
GParamSpec* param_spec_backing_file_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_backing_file_state (GValue* value, gpointer v_object);
void value_take_backing_file_state (GValue* value, gpointer v_object);
gpointer value_get_backing_file_state (const GValue* value);
GType backing_file_state_get_type (void) G_GNUC_CONST;
GType photo_exception_get_type (void) G_GNUC_CONST;
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
GType scaling_get_type (void) G_GNUC_CONST;
GType scale_constraint_get_type (void) G_GNUC_CONST;
Scaling* scaling_dup (const Scaling* self);
void scaling_free (Scaling* self);
GType photo_source_get_type (void) G_GNUC_CONST;
gpointer media_metadata_ref (gpointer instance);
void media_metadata_unref (gpointer instance);
GParamSpec* param_spec_media_metadata (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_metadata (GValue* value, gpointer v_object);
void value_take_media_metadata (GValue* value, gpointer v_object);
gpointer value_get_media_metadata (const GValue* value);
GType media_metadata_get_type (void) G_GNUC_CONST;
GType photo_metadata_get_type (void) G_GNUC_CONST;
GType dateable_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
GType rotation_get_type (void) G_GNUC_CONST;
gpointer backing_photo_row_ref (gpointer instance);
void backing_photo_row_unref (gpointer instance);
GParamSpec* param_spec_backing_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_backing_photo_row (GValue* value, gpointer v_object);
void value_take_backing_photo_row (GValue* value, gpointer v_object);
gpointer value_get_backing_photo_row (const GValue* value);
GType backing_photo_row_get_type (void) G_GNUC_CONST;
static gpointer photo_backing_readers_ref (gpointer instance);
static void photo_backing_readers_unref (gpointer instance);
static GParamSpec* photo_param_spec_backing_readers (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void photo_value_set_backing_readers (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void photo_value_take_backing_readers (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer photo_value_get_backing_readers (const GValue* value) G_GNUC_UNUSED;
static GType photo_backing_readers_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
gpointer one_shot_scheduler_ref (gpointer instance);
void one_shot_scheduler_unref (gpointer instance);
GParamSpec* param_spec_one_shot_scheduler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_one_shot_scheduler (GValue* value, gpointer v_object);
void value_take_one_shot_scheduler (GValue* value, gpointer v_object);
gpointer value_get_one_shot_scheduler (const GValue* value);
GType one_shot_scheduler_get_type (void) G_GNUC_CONST;
GType raw_developer_get_type (void) G_GNUC_CONST;
#define PHOTO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHOTO, PhotoPrivate))
enum  {
	PHOTO_DUMMY_PROPERTY
};
gboolean photo_exception_prohibits (PhotoException self, PhotoException exception);
gboolean photo_exception_allows (PhotoException self, PhotoException exception);
static gpointer photo_cached_pixbuf_ref (gpointer instance);
static void photo_cached_pixbuf_unref (gpointer instance);
static GParamSpec* photo_param_spec_cached_pixbuf (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void photo_value_set_cached_pixbuf (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void photo_value_take_cached_pixbuf (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer photo_value_get_cached_pixbuf (const GValue* value) G_GNUC_UNUSED;
static GType photo_cached_pixbuf_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
BackingPhotoRow* backing_photo_row_new (void);
BackingPhotoRow* backing_photo_row_construct (GType object_type);
static PhotoBackingReaders* photo_backing_readers_new (void);
static PhotoBackingReaders* photo_backing_readers_construct (GType object_type);
#define PHOTO_TYPENAME "thumb"
#define PHOTO_SCALING_FUDGE 64
#define PHOTO_SOURCE_PIXBUF_TIME_TO_LIVE_SEC 10
#define PHOTO_SOURCE_PIXBUF_MIN_LRU_COUNT 1
#define PHOTO_SOURCE_PIXBUF_MAX_LRU_COUNT 3
#define PHOTO_MIN_EMBEDDED_SIZE 1024
Photo* photo_construct (GType object_type, PhotoRow* row);
#define DATA_OBJECT_INVALID_OBJECT_ID ((gint64) -1)
PhotoSource* photo_source_construct (GType object_type, gint64 object_id);
gchar* media_source_prep_title (const gchar* title);
GType photo_id_get_type (void) G_GNUC_CONST;
PhotoID* photo_id_dup (const PhotoID* self);
void photo_id_free (PhotoID* self);
GType orientation_get_type (void) G_GNUC_CONST;
GType backing_photo_id_get_type (void) G_GNUC_CONST;
BackingPhotoID* backing_photo_id_dup (const BackingPhotoID* self);
void backing_photo_id_free (BackingPhotoID* self);
gchar* media_source_prep_comment (const gchar* comment);
gpointer photo_file_adapter_ref (gpointer instance);
void photo_file_adapter_unref (gpointer instance);
GParamSpec* param_spec_photo_file_adapter (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_file_adapter (GValue* value, gpointer v_object);
void value_take_photo_file_adapter (GValue* value, gpointer v_object);
gpointer value_get_photo_file_adapter (const GValue* value);
GType photo_file_adapter_get_type (void) G_GNUC_CONST;
GType photo_file_reader_get_type (void) G_GNUC_CONST;
PhotoFileReader* photo_file_format_create_reader (PhotoFileFormat self, const gchar* filepath);
gchar* string_sliced_at_last_char (const gchar* haystack, gunichar ch, gint start_index);
gchar* string_sliced_at (const gchar* str, gint index);
gboolean is_string_empty (const gchar* s);
#define BACKING_PHOTO_ID_INVALID ((gint64) -1)
static BackingPhotoRow* photo_get_backing_row (Photo* self, BackingPhotoID* id);
gpointer database_table_ref (gpointer instance);
void database_table_unref (gpointer instance);
GParamSpec* param_spec_database_table (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_database_table (GValue* value, gpointer v_object);
void value_take_database_table (GValue* value, gpointer v_object);
gpointer value_get_database_table (const GValue* value);
GType database_table_get_type (void) G_GNUC_CONST;
GType photo_table_get_type (void) G_GNUC_CONST;
PhotoTable* photo_table_get_instance (void);
GQuark database_error_quark (void);
void photo_table_detach_editable (PhotoTable* self, PhotoRow* row, GError** error);
static void photo_internal_remove_all_transformations (Photo* self, gboolean notify);
RawDeveloper* raw_developer_as_array (int* result_length1);
void photo_init_photo (void);
void photo_terminate_photo (void);
void photo_notify_editable_replaced (Photo* self, GFile* old_file, GFile* new_file);
static void photo_real_notify_editable_replaced (Photo* self, GFile* old_file, GFile* new_file);
void photo_notify_raw_development_modified (Photo* self);
static void photo_real_notify_raw_development_modified (Photo* self);
void photo_notify_baseline_replaced (Photo* self);
static void photo_real_notify_baseline_replaced (Photo* self);
void photo_notify_master_reimported (Photo* self, PhotoMetadata* metadata);
static void photo_real_notify_master_reimported (Photo* self, PhotoMetadata* metadata);
void photo_notify_editable_reimported (Photo* self, PhotoMetadata* metadata);
static void photo_real_notify_editable_reimported (Photo* self, PhotoMetadata* metadata);
void photo_notify_source_reimported (Photo* self, PhotoMetadata* metadata);
static void photo_real_notify_source_reimported (Photo* self, PhotoMetadata* metadata);
void photo_notify_baseline_reimported (Photo* self, PhotoMetadata* metadata);
static void photo_real_notify_baseline_reimported (Photo* self, PhotoMetadata* metadata);
static gboolean photo_real_internal_delete_backing (DataSource* base, GError** error);
GFile* photo_file_adapter_get_file (PhotoFileAdapter* self);
static void photo_detach_editable (Photo* self, gboolean delete_editable, gboolean remove_transformations, gboolean notify);
PhotoFileFormat photo_get_master_file_format (Photo* self);
static gboolean photo_delete_raw_development (Photo* self, RawDeveloper d);
gchar* data_object_to_string (DataObject* self);
gboolean data_source_internal_delete_backing (DataSource* self, GError** error);
GType backing_photo_table_get_type (void) G_GNUC_CONST;
BackingPhotoTable* backing_photo_table_get_instance (void);
BackingPhotoRow* backing_photo_table_fetch (BackingPhotoTable* self, BackingPhotoID* id, GError** error);
void backing_photo_table_remove (BackingPhotoTable* self, BackingPhotoID* backing_id, GError** error);
gboolean photo_is_raw_developer_complete (Photo* self, RawDeveloper d);
gboolean photo_is_raw_developer_available (Photo* self, RawDeveloper d);
PhotoMetadata* photo_get_master_metadata (Photo* self, GError** error);
guint photo_metadata_get_preview_count (PhotoMetadata* self);
gpointer photo_preview_ref (gpointer instance);
void photo_preview_unref (gpointer instance);
GParamSpec* param_spec_photo_preview (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_preview (GValue* value, gpointer v_object);
void value_take_photo_preview (GValue* value, gpointer v_object);
gpointer value_get_photo_preview (const GValue* value);
GType photo_preview_get_type (void) G_GNUC_CONST;
PhotoPreview* photo_metadata_get_preview (PhotoMetadata* self, guint number);
void photo_preview_get_pixel_dimensions (PhotoPreview* self, Dimensions* result);
void photo_add_backing_photo_for_development (Photo* self, RawDeveloper d, BackingPhotoRow* bpr, gboolean notify, GError** error);
void photo_import_developed_backing_photo (PhotoRow* row, RawDeveloper d, BackingPhotoRow* bpr, GError** error);
void data_object_notify_altered (DataObject* self, Alteration* alteration);
Alteration* alteration_new (const gchar* subject, const gchar* detail);
Alteration* alteration_construct (GType object_type, const gchar* subject, const gchar* detail);
#define UTIL_FILE_ATTRIBUTES "standard::*,time::*,id::file,id::filesystem,etag::value"
#define DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES UTIL_FILE_ATTRIBUTES
gpointer photo_file_interrogator_ref (gpointer instance);
void photo_file_interrogator_unref (gpointer instance);
GParamSpec* param_spec_photo_file_interrogator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_file_interrogator (GValue* value, gpointer v_object);
void value_take_photo_file_interrogator (GValue* value, gpointer v_object);
gpointer value_get_photo_file_interrogator (const GValue* value);
GType photo_file_interrogator_get_type (void) G_GNUC_CONST;
PhotoFileInterrogator* photo_file_interrogator_new (GFile* file, PhotoFileSnifferOptions options);
PhotoFileInterrogator* photo_file_interrogator_construct (GType object_type, GFile* file, PhotoFileSnifferOptions options);
void photo_file_interrogator_interrogate (PhotoFileInterrogator* self, GError** error);
gpointer detected_photo_information_ref (gpointer instance);
void detected_photo_information_unref (gpointer instance);
GParamSpec* param_spec_detected_photo_information (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_detected_photo_information (GValue* value, gpointer v_object);
void value_take_detected_photo_information (GValue* value, gpointer v_object);
gpointer value_get_detected_photo_information (const GValue* value);
GType detected_photo_information_get_type (void) G_GNUC_CONST;
DetectedPhotoInformation* photo_file_interrogator_get_detected_photo_information (PhotoFileInterrogator* self);
gboolean photo_file_interrogator_get_is_photo_corrupted (PhotoFileInterrogator* self);
Orientation photo_metadata_get_orientation (PhotoMetadata* self);
void backing_photo_table_add (BackingPhotoTable* self, BackingPhotoRow* state, GError** error);
void photo_table_update_raw_development (PhotoTable* self, PhotoRow* row, RawDeveloper rd, BackingPhotoID* backing_photo_id, GError** error);
static void photo_develop_photo (Photo* self, RawDeveloper d, gboolean notify);
BackingPhotoRow* raw_developer_create_backing_row_for_development (RawDeveloper self, const gchar* raw_filepath, const gchar* camera_development_filename, GError** error);
GdkPixbuf* photo_get_master_pixbuf (Photo* self, Scaling* scaling, gboolean rotate, GError** error);
void scaling_for_original (Scaling* result);
GType photo_file_writer_get_type (void) G_GNUC_CONST;
GQuark photo_format_error_quark (void);
PhotoFileWriter* photo_file_format_create_writer (PhotoFileFormat self, const gchar* filepath, GError** error);
GType jpeg_quality_get_type (void) G_GNUC_CONST;
void photo_file_writer_write (PhotoFileWriter* self, GdkPixbuf* pixbuf, JpegQuality quality, GError** error);
GType photo_file_metadata_writer_get_type (void) G_GNUC_CONST;
PhotoFileMetadataWriter* photo_file_format_create_metadata_writer (PhotoFileFormat self, const gchar* filepath, GError** error);
void photo_file_metadata_writer_write_metadata (PhotoFileMetadataWriter* self, PhotoMetadata* metadata, GError** error);
GBytes* photo_preview_flatten (PhotoPreview* self, GError** error);
gboolean jpeg_is_jpeg_bytes (GBytes* bytes, GError** error);
GdkPixbuf* photo_preview_get_pixbuf (PhotoPreview* self, GError** error);
void photo_set_default_raw_developer (Photo* self, RawDeveloper d);
void photo_set_raw_developer (Photo* self, RawDeveloper d, gboolean notify);
void photo_revert_to_master (Photo* self, gboolean notify);
GdkPixbuf* photo_get_prefetched_copy (Photo* self, GError** error);
gboolean photo_set_orientation (Photo* self, Orientation orientation);
void photo_discard_prefetched (Photo* self);
RawDeveloper photo_get_raw_developer (Photo* self);
gchar* raw_developer_to_string (RawDeveloper self);
void photo_table_remove_development (PhotoTable* self, PhotoRow* row, RawDeveloper rd, GError** error);
void photo_redevelop_raw (Photo* self, RawDeveloper d);
static BackingFileState** photo_real_get_backing_files_state (MediaSource* base, int* result_length1);
BackingFileState* backing_file_state_new_from_photo_row (BackingPhotoRow* photo_row, const gchar* md5);
BackingFileState* backing_file_state_construct_from_photo_row (GType object_type, BackingPhotoRow* photo_row, const gchar* md5);
static void _vala_array_add89 (BackingFileState** * array, int* length, int* size, BackingFileState* value);
gboolean photo_has_editable (Photo* self);
static void _vala_array_add90 (BackingFileState** * array, int* length, int* size, BackingFileState* value);
gboolean photo_is_developed (Photo* self);
GeeCollection* photo_get_raw_development_photo_rows (Photo* self);
static void _vala_array_add91 (BackingFileState** * array, int* length, int* size, BackingFileState* value);
static PhotoFileReader* photo_get_backing_reader (Photo* self, BackingFetchMode mode);
static PhotoFileReader* photo_get_master_reader (Photo* self);
static PhotoFileReader* photo_get_baseline_reader (Photo* self);
static PhotoFileReader* photo_get_source_reader (Photo* self);
static PhotoFileReader* photo_get_raw_developer_reader (Photo* self);
const gchar* backing_fetch_mode_to_string (BackingFetchMode self);
PhotoFileReader* photo_get_editable_reader (Photo* self);
gboolean photo_does_master_exist (Photo* self);
gboolean photo_file_adapter_file_exists (PhotoFileAdapter* self);
gboolean photo_does_editable_exist (Photo* self);
gboolean photo_is_master_baseline (Photo* self);
gboolean photo_is_master_source (Photo* self);
gboolean photo_is_editable_baseline (Photo* self);
gboolean photo_is_editable_source (Photo* self);
BackingPhotoRow* photo_get_master_photo_row (Photo* self);
BackingPhotoRow* photo_get_editable_photo_row (Photo* self);
gboolean backing_photo_id_is_valid (BackingPhotoID *self);
BackingPhotoRow* photo_get_raw_development_photo_row (Photo* self, RawDeveloper d);
PhotoFileFormat* photo_get_editable_file_format (Photo* self);
PhotoFileFormat photo_file_adapter_get_file_format (PhotoFileAdapter* self);
static PhotoFileFormat* _photo_file_format_dup (PhotoFileFormat* self);
GType export_format_parameters_get_type (void) G_GNUC_CONST;
GType export_format_mode_get_type (void) G_GNUC_CONST;
ExportFormatParameters* export_format_parameters_dup (const ExportFormatParameters* self);
void export_format_parameters_free (ExportFormatParameters* self);
PhotoFileFormat photo_get_export_format_for_parameters (Photo* self, ExportFormatParameters* params);
PhotoFileFormat photo_file_format_get_system_default_format (void);
PhotoFileFormat photo_get_best_export_file_format (Photo* self);
gchar* photo_get_export_basename_for_parameters (Photo* self, ExportFormatParameters* params);
GFile* media_source_get_master_file (MediaSource* self);
gchar* photo_get_export_basename (Photo* self, PhotoFileFormat* file_format);
GType import_result_get_type (void) G_GNUC_CONST;
ImportResult photo_prepare_for_import (PhotoImportParams* params);
gboolean photo_is_file_image (GFile* file);
gboolean photo_file_format_is_file_supported (GFile* file);
gpointer metadata_date_time_ref (gpointer instance);
void metadata_date_time_unref (gpointer instance);
GParamSpec* param_spec_metadata_date_time (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_metadata_date_time (GValue* value, gpointer v_object);
void value_take_metadata_date_time (GValue* value, gpointer v_object);
gpointer value_get_metadata_date_time (const GValue* value);
GType metadata_date_time_get_type (void) G_GNUC_CONST;
MetadataDateTime* photo_metadata_get_exposure_date_time (PhotoMetadata* self);
time_t metadata_date_time_get_timestamp (MetadataDateTime* self);
gchar* media_metadata_get_title (MediaMetadata* self);
gchar* media_metadata_get_comment (MediaMetadata* self);
GeeSet* photo_metadata_get_keywords (PhotoMetadata* self, GCompareDataFunc compare_func, void* compare_func_target, GDestroyNotify compare_func_target_destroy_notify);
Rating photo_metadata_get_rating (PhotoMetadata* self);
#define PHOTO_ID_INVALID ((gint64) -1)
void photo_id_init (PhotoID *self, gint64 id);
#define EVENT_ID_INVALID ((gint64) -1)
void event_id_init (EventID *self, gint64 id);
GType photo_file_reader_role_get_type (void) G_GNUC_CONST;
void photo_file_reader_set_role (PhotoFileReader* self, PhotoFileReaderRole role);
void thumbnail_cache_generate_for_photo (Thumbnails* thumbnails, PhotoFileReader* reader, Orientation orientation, Dimensions* original_dim, GError** error);
ImportResult import_result_convert_error (GError* err, ImportResult default_result);
void photo_create_pre_import (PhotoImportParams* params);
void dimensions_init (Dimensions *self, gint width, gint height);
BackingPhotoRow* photo_query_backing_photo_row (Photo* self, GFile* file, PhotoFileSnifferOptions options, DetectedPhotoInformation* * detected, GError** error);
gpointer photo_reimport_master_state_ref (gpointer instance);
void photo_reimport_master_state_unref (gpointer instance);
GParamSpec* photo_param_spec_reimport_master_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void photo_value_set_reimport_master_state (GValue* value, gpointer v_object);
void photo_value_take_reimport_master_state (GValue* value, gpointer v_object);
gpointer photo_value_get_reimport_master_state (const GValue* value);
GType photo_reimport_master_state_get_type (void) G_GNUC_CONST;
gboolean photo_prepare_for_reimport_master (Photo* self, PhotoReimportMasterState* * reimport_state, GError** error);
static void _vala_array_add92 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add93 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add94 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add95 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add96 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add97 (gchar** * array, int* length, int* size, gchar* value);
static PhotoReimportMasterStateImpl* photo_reimport_master_state_impl_new (PhotoRow* row, PhotoMetadata* metadata, gchar** alterations, int alterations_length1);
static PhotoReimportMasterStateImpl* photo_reimport_master_state_impl_construct (GType object_type, PhotoRow* row, PhotoMetadata* metadata, gchar** alterations, int alterations_length1);
static GType photo_reimport_master_state_impl_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
void photo_apply_user_metadata_for_reimport (Photo* self, PhotoMetadata* metadata);
static void photo_real_apply_user_metadata_for_reimport (Photo* self, PhotoMetadata* metadata);
void photo_finish_reimport_master (Photo* self, PhotoReimportMasterState* state, GError** error);
void photo_table_reimport (PhotoTable* self, PhotoRow* row, GError** error);
void backing_photo_row_copy_from (BackingPhotoRow* self, BackingPhotoRow* from);
static void _vala_array_add98 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add99 (gchar** * array, int* length, int* size, gchar* value);
Alteration* alteration_new_from_array (gchar** array, int array_length1);
Alteration* alteration_construct_from_array (GType object_type, gchar** array, int array_length1);
static gboolean photo_verify_file_for_reimport (Photo* self, GFile* file, BackingPhotoRow* * backing, DetectedPhotoInformation* * detected, GError** error);
gpointer photo_reimport_editable_state_ref (gpointer instance);
void photo_reimport_editable_state_unref (gpointer instance);
GParamSpec* photo_param_spec_reimport_editable_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void photo_value_set_reimport_editable_state (GValue* value, gpointer v_object);
void photo_value_take_reimport_editable_state (GValue* value, gpointer v_object);
gpointer photo_value_get_reimport_editable_state (const GValue* value);
GType photo_reimport_editable_state_get_type (void) G_GNUC_CONST;
gboolean photo_prepare_for_reimport_editable (Photo* self, PhotoReimportEditableState* * state, GError** error);
GFile* photo_get_editable_file (Photo* self);
static PhotoReimportEditableStateImpl* photo_reimport_editable_state_impl_new (BackingPhotoRow* backing_state, PhotoMetadata* metadata);
static PhotoReimportEditableStateImpl* photo_reimport_editable_state_impl_construct (GType object_type, BackingPhotoRow* backing_state, PhotoMetadata* metadata);
static GType photo_reimport_editable_state_impl_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
void photo_finish_reimport_editable (Photo* self, PhotoReimportEditableState* state, GError** error);
void photo_get_editable_id (Photo* self, BackingPhotoID* result);
gboolean backing_photo_id_is_invalid (BackingPhotoID *self);
void backing_photo_table_update (BackingPhotoTable* self, BackingPhotoRow* row, GError** error);
void media_source_set_title (MediaSource* self, const gchar* title);
gboolean media_source_set_comment (MediaSource* self, const gchar* comment);
void media_source_set_rating (MediaSource* self, Rating rating);
Alteration* alteration_new_from_list (const gchar* list);
Alteration* alteration_construct_from_list (GType object_type, const gchar* list);
gpointer photo_reimport_raw_development_state_ref (gpointer instance);
void photo_reimport_raw_development_state_unref (gpointer instance);
GParamSpec* photo_param_spec_reimport_raw_development_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void photo_value_set_reimport_raw_development_state (GValue* value, gpointer v_object);
void photo_value_take_reimport_raw_development_state (GValue* value, gpointer v_object);
gpointer photo_value_get_reimport_raw_development_state (const GValue* value);
GType photo_reimport_raw_development_state_get_type (void) G_GNUC_CONST;
gboolean photo_prepare_for_reimport_raw_development (Photo* self, PhotoReimportRawDevelopmentState* * state, GError** error);
GeeCollection* photo_get_raw_developer_files (Photo* self);
static GType photo_reimport_raw_development_state_impl_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static PhotoReimportRawDevelopmentStateImpl* photo_reimport_raw_development_state_impl_new (void);
static PhotoReimportRawDevelopmentStateImpl* photo_reimport_raw_development_state_impl_construct (GType object_type);
static void photo_reimport_raw_development_state_impl_add (PhotoReimportRawDevelopmentStateImpl* self, BackingPhotoRow* backing, PhotoMetadata* metadata);
static gint photo_reimport_raw_development_state_impl_get_size (PhotoReimportRawDevelopmentStateImpl* self);
void photo_finish_reimport_raw_development (Photo* self, PhotoReimportRawDevelopmentState* state, GError** error);
static gpointer photo_reimport_raw_development_state_impl_dev_to_reimport_ref (gpointer instance);
static void photo_reimport_raw_development_state_impl_dev_to_reimport_unref (gpointer instance);
static GParamSpec* photo_reimport_raw_development_state_impl_param_spec_dev_to_reimport (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void photo_reimport_raw_development_state_impl_value_set_dev_to_reimport (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void photo_reimport_raw_development_state_impl_value_take_dev_to_reimport (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer photo_reimport_raw_development_state_impl_value_get_dev_to_reimport (const GValue* value) G_GNUC_UNUSED;
GType photo_reimport_raw_development_state_impl_dev_to_reimport_get_type (void) G_GNUC_CONST;
static gchar* photo_real_get_typename (DataSource* base);
static gint64 photo_real_get_instance_id (DataSource* base);
void photo_get_photo_id (Photo* self, PhotoID* result);
static gchar* photo_real_get_source_id (DataSource* base);
gchar* data_source_get_typename (DataSource* self);
gint64 data_source_get_instance_id (DataSource* self);
void photo_set_master_timestamp (Photo* self, GFileInfo* info);
void photo_table_update_timestamp (PhotoTable* self, PhotoID* photo_id, time_t timestamp, GError** error);
void app_window_database_error (GError* err);
void photo_update_editable_modification_time (Photo* self, GFileInfo* info, GError** error);
void backing_photo_table_update_timestamp (BackingPhotoTable* self, BackingPhotoID* id, time_t timestamp, GError** error);
void photo_update_many_editable_timestamps (GeeMap* map, GError** error);
void database_table_begin_transaction (void);
void database_table_commit_transaction (GError** error);
static PhotoFileFormat photo_real_get_preferred_thumbnail_format (ThumbnailSource* base);
PhotoFileFormat photo_get_file_format (Photo* self);
gboolean photo_file_format_can_write_image (PhotoFileFormat self);
static GdkPixbuf* photo_real_create_thumbnail (ThumbnailSource* base, gint scale, GError** error);
GdkPixbuf* photo_source_get_pixbuf (PhotoSource* self, Scaling* scaling, GError** error);
void scaling_for_best_fit (gint pixels, gboolean scale_up, Scaling* result);
static gboolean photo_is_extension_found (const gchar* basename, gchar** extensions, int extensions_length1);
void disassemble_filename (const gchar* basename, gchar* * name, gchar* * ext);
gboolean photo_is_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format);
gboolean photo_table_has_duplicate (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format);
PhotoID* photo_get_duplicate_ids (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format, int* result_length1);
PhotoID* photo_table_get_duplicate_ids (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format, int* result_length1);
gint64 photo_get_photo_key (DataSource* source);
GType library_photo_get_type (void) G_GNUC_CONST;
static GFile* photo_real_get_file (MediaSource* base);
void photo_set_master_file (Photo* self, GFile* file);
void photo_table_set_filepath (PhotoTable* self, PhotoID* photo_id, const gchar* filepath, GError** error);
void media_source_notify_master_replaced (MediaSource* self, GFile* old_file, GFile* new_file);
static void _vala_array_add100 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add101 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add102 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add103 (gchar** * array, int* length, int* size, gchar* value);
void photo_set_editable_file (Photo* self, GFile* file);
void backing_photo_table_set_filepath (BackingPhotoTable* self, BackingPhotoID* id, const gchar* filepath, GError** error);
static void _vala_array_add104 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add105 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add106 (gchar** * array, int* length, int* size, gchar* value);
void photo_set_many_editable_file (GeeMap* map, GError** error);
GFile* photo_get_actual_file (Photo* self);
static GFile* photo_real_get_master_file (MediaSource* base);
GFile* photo_get_source_file (Photo* self);
gboolean photo_file_format_can_write (PhotoFileFormat self);
static time_t photo_real_get_timestamp (MediaSource* base);
static inline void photo_real_get_event_id (MediaSource* base, EventID* result);
gint64 photo_get_raw_event_id (Photo* self);
static void photo_real_get_import_id (MediaSource* base, ImportID* result);
static gchar* photo_real_get_master_md5 (MediaSource* base);
guint64 photo_get_flags (Photo* self);
static void photo_notify_flags_altered (Photo* self, Alteration* additional_alteration);
Alteration* alteration_compress (Alteration* self, Alteration* other);
guint64 photo_replace_flags (Photo* self, guint64 flags, Alteration* additional_alteration);
gboolean photo_table_replace_flags (PhotoTable* self, PhotoID* photo_id, guint64 flags);
gboolean photo_is_flag_set (Photo* self, guint64 mask);
gboolean media_source_internal_is_flag_set (guint64 flags, guint64 selector);
guint64 photo_add_flags (Photo* self, guint64 mask, Alteration* additional_alteration);
guint64 media_source_internal_add_flags (guint64 flags, guint64 selector);
guint64 photo_remove_flags (Photo* self, guint64 mask, Alteration* additional_alteration);
guint64 media_source_internal_remove_flags (guint64 flags, guint64 selector);
guint64 photo_add_remove_flags (Photo* self, guint64 add, guint64 remove, Alteration* additional_alteration);
void photo_add_remove_many_flags (GeeCollection* add, guint64 add_mask, Alteration* additional_add_alteration, GeeCollection* remove, guint64 remove_mask, Alteration* additional_remove_alteration, GError** error);
guint64 photo_toggle_flags (Photo* self, guint64 mask, Alteration* additional_alteration);
gboolean photo_is_master_metadata_dirty (Photo* self);
void photo_set_master_metadata_dirty (Photo* self, gboolean dirty, GError** error);
void photo_table_set_metadata_dirty (PhotoTable* self, PhotoID* photo_id, gboolean dirty, GError** error);
static Rating photo_real_get_rating (MediaSource* base);
static void photo_real_set_rating (MediaSource* base, Rating rating);
gboolean photo_table_set_rating (PhotoTable* self, PhotoID* photo_id, Rating rating);
static void photo_real_increase_rating (MediaSource* base);
static void photo_real_decrease_rating (MediaSource* base);
static void photo_real_commit_backlinks (DataSource* base, SourceCollection* sources, const gchar* backlinks);
void photo_table_update_backlinks (PhotoTable* self, PhotoID* photo_id, const gchar* backlinks, GError** error);
static gboolean photo_real_set_event_id (MediaSource* base, EventID* event_id);
gboolean photo_table_set_event (PhotoTable* self, PhotoID* photo_id, EventID* event_id);
static gchar* photo_real_to_string (DataObject* base);
gchar* photo_file_adapter_get_filepath (PhotoFileAdapter* self);
static gboolean photo_real_equals (DataSource* base, DataSource* source);
gboolean data_source_equals (DataSource* self, DataSource* source);
static void photo_file_exif_updated (Photo* self);
GFile* media_source_get_file (MediaSource* self);
gboolean photo_table_master_exif_updated (PhotoTable* self, PhotoID* photoID, gint64 filesize, glong timestamp, const gchar* md5, const gchar* exif_md5, const gchar* thumbnail_md5, PhotoRow* row);
static guint64 photo_real_get_filesize (MediaSource* base);
static guint64 photo_real_get_master_filesize (MediaSource* base);
guint64 photo_get_editable_filesize (Photo* self);
static time_t photo_real_get_exposure_time (Dateable* base);
static gchar* photo_real_get_basename (MediaSource* base);
static gchar* photo_real_get_title (MediaSource* base);
static gchar* photo_real_get_comment (MediaSource* base);
static void photo_real_set_title (MediaSource* base, const gchar* title);
gboolean photo_table_set_title (PhotoTable* self, PhotoID* photo_id, const gchar* new_title);
static gboolean photo_real_set_comment (MediaSource* base, const gchar* comment);
gboolean photo_table_set_comment (PhotoTable* self, PhotoID* photo_id, const gchar* new_comment);
void photo_set_import_id (Photo* self, ImportID* import_id);
void photo_table_set_import_id (PhotoTable* self, PhotoID* photo_id, ImportID* import_id, GError** error);
void photo_set_title_persistent (Photo* self, const gchar* title, GError** error);
gboolean photo_file_format_can_write_metadata (PhotoFileFormat self);
PhotoMetadata* photo_file_reader_read_metadata (PhotoFileReader* self, GError** error);
GType photo_metadata_set_option_get_type (void) G_GNUC_CONST;
void photo_metadata_set_title (PhotoMetadata* self, const gchar* title, PhotoMetadataSetOption option);
PhotoFileMetadataWriter* photo_file_reader_create_metadata_writer (PhotoFileReader* self, GError** error);
void library_monitor_blacklist_file (GFile* file, const gchar* reason);
void library_monitor_unblacklist_file (GFile* file);
void photo_set_comment_persistent (Photo* self, const gchar* comment, GError** error);
void photo_metadata_set_comment (PhotoMetadata* self, const gchar* comment, PhotoMetadataSetOption option);
static void photo_real_set_exposure_time (Dateable* base, time_t time);
gboolean photo_table_set_exposure_time (PhotoTable* self, PhotoID* photo_id, time_t time);
void photo_set_exposure_time_persistent (Photo* self, time_t time, GError** error);
void dateable_set_exposure_time (Dateable* self, time_t target_time);
void photo_metadata_set_exposure_date_time (PhotoMetadata* self, MetadataDateTime* date_time, PhotoMetadataSetOption option);
MetadataDateTime* metadata_date_time_new (time_t timestamp);
MetadataDateTime* metadata_date_time_construct (GType object_type, time_t timestamp);
static void photo_real_get_dimensions (MediaSource* base, PhotoException disallowed_steps, Dimensions* result);
void photo_get_raw_dimensions (Photo* self, Dimensions* result);
Orientation photo_get_orientation (Photo* self);
gboolean photo_get_straighten (Photo* self, gdouble* theta);
void compute_arb_rotated_size (gdouble src_width, gdouble src_height, gdouble angle, gdouble* dest_width, gdouble* dest_height);
GType box_get_type (void) G_GNUC_CONST;
Box* box_dup (const Box* self);
void box_free (Box* self);
gboolean photo_get_crop (Photo* self, Box* crop, PhotoException exceptions);
void box_get_dimensions (Box *self, Dimensions* result);
static void photo_locked_create_adjustments_from_data (Photo* self);
static KeyValueMap* photo_get_transformation (Photo* self, const gchar* name);
PixelTransformationBundle* photo_get_color_adjustments (Photo* self);
PixelTransformer* photo_get_pixel_transformer (Photo* self);
gboolean photo_has_color_adjustments (Photo* self);
static gboolean photo_has_transformation (Photo* self, const gchar* name);
PixelTransformation* photo_get_color_adjustment (Photo* self, PixelTransformationType type);
void photo_set_color_adjustments (Photo* self, PixelTransformationBundle* new_adjustments);
static gboolean photo_remove_transformation (Photo* self, const gchar* name);
static gboolean photo_set_transformation (Photo* self, KeyValueMap* trans);
static PhotoMetadata* photo_real_get_metadata (PhotoSource* base);
PhotoMetadata* photo_get_editable_metadata (Photo* self, GError** error);
gboolean photo_persist_master_metadata (Photo* self, PhotoMetadata* metadata, PhotoReimportMasterState* * state, GError** error);
void photo_finish_update_master_metadata (Photo* self, PhotoReimportMasterState* state, GError** error);
gboolean photo_persist_editable_metadata (Photo* self, PhotoMetadata* metadata, PhotoReimportEditableState* * state, GError** error);
void photo_finish_update_editable_metadata (Photo* self, PhotoReimportEditableState* state, GError** error);
gboolean photo_has_transformations (Photo* self);
gboolean photo_only_metadata_changed (Photo* self);
PhotoMetadata* photo_source_get_metadata (PhotoSource* self);
gboolean photo_has_alterations (Photo* self);
gchar* media_source_get_comment (MediaSource* self);
gchar* media_source_get_title (MediaSource* self);
PhotoTransformationState* photo_save_transformation_state (Photo* self);
static PhotoPhotoTransformationStateImpl* photo_photo_transformation_state_impl_new (Photo* photo, Orientation orientation, GeeHashMap* transformations, PixelTransformer* transformer, PixelTransformationBundle* adjustments);
static PhotoPhotoTransformationStateImpl* photo_photo_transformation_state_impl_construct (GType object_type, Photo* photo, Orientation orientation, GeeHashMap* transformations, PixelTransformer* transformer, PixelTransformationBundle* adjustments);
static GType photo_photo_transformation_state_impl_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
gboolean photo_load_transformation_state (Photo* self, PhotoTransformationState* state);
static Orientation photo_photo_transformation_state_impl_get_orientation (PhotoPhotoTransformationStateImpl* self);
static GeeHashMap* photo_photo_transformation_state_impl_get_transformations (PhotoPhotoTransformationStateImpl* self);
static PixelTransformer* photo_photo_transformation_state_impl_get_transformer (PhotoPhotoTransformationStateImpl* self);
static PixelTransformationBundle* photo_photo_transformation_state_impl_get_color_adjustments (PhotoPhotoTransformationStateImpl* self);
gboolean photo_table_set_transformation_state (PhotoTable* self, PhotoID* photo_id, Orientation orientation, GeeHashMap* transformations);
void photo_remove_all_transformations (Photo* self);
gboolean photo_table_remove_all_transformations (PhotoTable* self, PhotoID* photo_id);
gboolean photo_table_set_orientation (PhotoTable* self, PhotoID* photo_id, Orientation orientation);
Orientation photo_get_original_orientation (Photo* self);
gboolean photo_check_can_rotate (Photo* self);
void photo_rotate (Photo* self, Rotation rotation);
static void photo_real_rotate (Photo* self, Rotation rotation);
Orientation orientation_perform (Orientation self, Rotation rotation);
gboolean photo_table_set_transformation (PhotoTable* self, PhotoID* photo_id, KeyValueMap* map);
gboolean photo_table_remove_transformation (PhotoTable* self, PhotoID* photo_id, const gchar* object);
gboolean photo_has_crop (Photo* self);
gboolean photo_get_raw_crop (Photo* self, Box* crop);
void box_init (Box *self, gint left, gint top, gint right, gint bottom);
static void photo_set_raw_crop (Photo* self, Box* crop);
static gboolean photo_get_raw_straighten (Photo* self, gdouble* angle);
static void photo_set_raw_straighten (Photo* self, gdouble theta);
GType editing_tools_redeye_instance_get_type (void) G_GNUC_CONST;
EditingToolsRedeyeInstance* editing_tools_redeye_instance_dup (const EditingToolsRedeyeInstance* self);
void editing_tools_redeye_instance_free (EditingToolsRedeyeInstance* self);
static EditingToolsRedeyeInstance* photo_get_raw_redeye_instances (Photo* self, int* result_length1);
gboolean photo_has_redeye_transformations (Photo* self);
void photo_add_redeye_instance (Photo* self, EditingToolsRedeyeInstance* redeye);
static gboolean photo_calculate_pixbuf_dimensions (Photo* self, Scaling* scaling, PhotoException exceptions, Dimensions* scaled_image, Dimensions* scaled_to_viewport);
static gboolean photo_locked_calculate_pixbuf_dimensions (Photo* self, Scaling* scaling, PhotoException exceptions, Dimensions* scaled_image, Dimensions* scaled_to_viewport);
gboolean scaling_is_unscaled (Scaling *self);
void orientation_rotate_box (Orientation self, Dimensions* space, Box* box, Box* result);
void orientation_rotate_dimensions (Orientation self, Dimensions* dim, Dimensions* result);
void box_get_scaled (Box *self, Dimensions* scaled, Box* result);
void scaling_get_scaled_dimensions (Scaling *self, Dimensions* original, Dimensions* result);
gint box_get_width (Box *self);
gint box_get_height (Box *self);
void dimensions_get_scaled_similar (Dimensions *self, Dimensions* original, Dimensions* scaled, Dimensions* result);
void orientation_derotate_dimensions (Orientation self, Dimensions* dim, Dimensions* result);
gboolean dimensions_has_area (Dimensions *self);
static GdkPixbuf* photo_load_raw_pixbuf (Photo* self, Scaling* scaling, PhotoException exceptions, BackingFetchMode fetch_mode, GError** error);
GdkPixbuf* photo_file_reader_unscaled_read (PhotoFileReader* self, GError** error);
GdkPixbuf* photo_file_reader_scaled_read (PhotoFileReader* self, Dimensions* full, Dimensions* scaled, GError** error);
gboolean dimensions_approx_equals (Dimensions *self, Dimensions* dim, gint fudge);
void dimensions_for_pixbuf (GdkPixbuf* pixbuf, Dimensions* result);
static GdkPixbuf* photo_get_untransformed_pixbuf (Photo* self, Scaling* scaling, gboolean rotate, BackingFetchMode fetch_mode, GError** error);
GdkPixbuf* photo_get_unmodified_pixbuf (Photo* self, Scaling* scaling, gboolean rotate, GError** error);
GdkPixbuf* orientation_rotate_pixbuf (Orientation self, GdkPixbuf* pixbuf);
static GdkPixbuf* photo_real_get_pixbuf (PhotoSource* base, Scaling* scaling, GError** error);
GdkPixbuf* photo_get_pixbuf_with_options (Photo* self, Scaling* scaling, PhotoException exceptions, BackingFetchMode fetch_mode, GError** error);
static GdkPixbuf* photo_run_source_pixbuf_cache (Photo* locate, gboolean keep, GError** error);
static PhotoCachedPixbuf* photo_cached_pixbuf_new (Photo* photo, GdkPixbuf* pixbuf);
static PhotoCachedPixbuf* photo_cached_pixbuf_construct (GType object_type, Photo* photo, GdkPixbuf* pixbuf);
static gboolean photo_trim_source_pixbuf_cache (void);
static gboolean _photo_trim_source_pixbuf_cache_gsource_func (gpointer self);
gboolean photo_get_develop_raw_photos_to_files (void);
void media_source_get_dimensions (MediaSource* self, PhotoException disallowed_steps, Dimensions* result);
gboolean dimensions_equals (Dimensions *self, Dimensions* dim);
static GdkPixbuf* photo_do_redeye (Photo* self, GdkPixbuf* pixbuf, EditingToolsRedeyeInstance* inst);
GdkPixbuf* rotate_arb (GdkPixbuf* source_pixbuf, gdouble angle);
gboolean photo_has_user_generated_metadata (Photo* self);
static gboolean photo_real_has_user_generated_metadata (Photo* self);
void photo_set_user_metadata_for_export (Photo* self, PhotoMetadata* metadata);
static void photo_real_set_user_metadata_for_export (Photo* self, PhotoMetadata* metadata);
gpointer photo_file_format_properties_ref (gpointer instance);
void photo_file_format_properties_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_properties (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_file_format_properties (GValue* value, gpointer v_object);
void value_take_photo_file_format_properties (GValue* value, gpointer v_object);
gpointer value_get_photo_file_format_properties (const GValue* value);
GType photo_file_format_properties_get_type (void) G_GNUC_CONST;
PhotoFileFormatProperties* photo_file_format_get_properties (PhotoFileFormat self);
GFile* photo_file_format_properties_convert_file_extension (PhotoFileFormatProperties* self, GFile* file);
static gboolean photo_export_fullsized_backing (Photo* self, GFile* file, gboolean export_metadata, GError** error);
PhotoMetadata* photo_file_format_create_metadata (PhotoFileFormat self);
time_t media_source_get_exposure_time (MediaSource* self);
void photo_metadata_set_pixel_dimensions (PhotoMetadata* self, Dimensions* dim, PhotoMetadataSetOption option);
void photo_metadata_set_orientation (PhotoMetadata* self, Orientation orientation);
void photo_metadata_set_software (PhotoMetadata* self, const gchar* software, const gchar* version);
#define RESOURCES_APP_TITLE "Shotwell"
#define RESOURCES_APP_VERSION _VERSION
void photo_metadata_remove_exif_thumbnail (PhotoMetadata* self);
void photo_metadata_clear (PhotoMetadata* self);
gboolean photo_is_export_required (Photo* self, Scaling* scaling, PhotoFileFormat export_format);
void photo_export (Photo* self, GFile* dest_file, Scaling* scaling, JpegQuality quality, PhotoFileFormat export_format, gboolean direct_copy_unmodified, gboolean export_metadata, GError** error);
const gchar* photo_file_format_to_string (PhotoFileFormat self);
void photo_metadata_remove_tag (PhotoMetadata* self, const gchar* tag);
static GFile* photo_generate_new_editable_file (Photo* self, PhotoFileFormat* file_format, GError** error);
gboolean photo_file_format_properties_is_recognized_extension (PhotoFileFormatProperties* self, const gchar* ext);
gchar* photo_file_format_properties_get_default_extension (PhotoFileFormatProperties* self);
GFile* generate_unique_file (GFile* dir, const gchar* basename, gboolean* collision, GError** error);
static gboolean photo_launch_editor (GFile* file, PhotoFileFormat file_format, GError** error);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gchar* configuration_facade_get_external_raw_app (ConfigurationFacade* self);
gchar* configuration_facade_get_external_photo_app (ConfigurationFacade* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void photo_open_with_raw_external_editor (Photo* self, GError** error);
void photo_open_with_external_editor (Photo* self, GError** error);
static void photo_halt_monitoring_editable (Photo* self);
static void photo_attach_editable (Photo* self, PhotoFileFormat file_format, GFile* file, GError** error);
static void photo_start_monitoring_editable (Photo* self, GFile* file, GError** error);
static void photo_on_editable_file_changed (Photo* self, GFile* file, GFile* other_file, GFileMonitorEvent event);
static void _photo_on_editable_file_changed_g_file_monitor_changed (GFileMonitor* _sender, GFile* file, GFile* other_file, GFileMonitorEvent event_type, gpointer self);
static void photo_update_editable (Photo* self, gboolean only_attributes, PhotoFileReader* new_reader, GError** error);
static void photo_update_editable_attributes (Photo* self, GError** error);
void photo_reimport_editable (Photo* self, GError** error);
void photo_table_attach_editable (PhotoTable* self, PhotoRow* row, BackingPhotoID* editable_id, GError** error);
void backing_photo_table_update_attributes (BackingPhotoTable* self, BackingPhotoID* id, time_t timestamp, gint64 filesize, GError** error);
static void _vala_array_add107 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add108 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add109 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add110 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add111 (gchar** * array, int* length, int* size, gchar* value);
static void _vala_array_add112 (gchar** * array, int* length, int* size, gchar* value);
void backing_photo_id_init (BackingPhotoID *self, gint64 id);
const gchar* g_file_monitor_event_to_string (GFileMonitorEvent self);
static void photo_on_reimport_editable (Photo* self);
static void _photo_on_reimport_editable_one_shot_callback (gpointer self);
OneShotScheduler* one_shot_scheduler_new (const gchar* name, OneShotCallback callback, void* callback_target);
OneShotScheduler* one_shot_scheduler_construct (GType object_type, const gchar* name, OneShotCallback callback, void* callback_target);
void one_shot_scheduler_after_timeout (OneShotScheduler* self, guint msec, gboolean reschedule);
static void photo_on_update_editable_attributes (Photo* self);
static void _photo_on_update_editable_attributes_one_shot_callback (gpointer self);
static void photo_on_remove_editable (Photo* self);
static void _photo_on_remove_editable_one_shot_callback (gpointer self);
void photo_get_original_dimensions (Photo* self, Dimensions* result);
void photo_get_master_dimensions (Photo* self, Dimensions* result);
void photo_set_crop (Photo* self, Box* crop);
void orientation_derotate_box (Orientation self, Dimensions* space, Box* box, Box* result);
void photo_set_straighten (Photo* self, gdouble theta);
static GdkPixbuf* photo_red_reduce_pixel (Photo* self, GdkPixbuf* pixbuf, gint x, gint y);
void photo_unscaled_to_raw_point (Photo* self, GdkPoint* unscaled_point, GdkPoint* result);
void orientation_derotate_point (Orientation self, Dimensions* space, GdkPoint* point, GdkPoint* result);
void photo_unscaled_to_raw_rect (Photo* self, GdkRectangle* unscaled_rect, GdkRectangle* result);
PixelTransformationBundle* photo_get_enhance_transformations (Photo* self);
gboolean photo_enhance (Photo* self);
void photo_set_develop_raw_photos_to_files (gboolean value);
static void photo_real_editable_replaced (Photo* self, GFile* old_file, GFile* new_file);
static void g_cclosure_user_marshal_VOID__OBJECT_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void photo_real_raw_development_modified (Photo* self);
static void photo_real_baseline_replaced (Photo* self);
static void photo_real_master_reimported (Photo* self, PhotoMetadata* metadata);
static void g_cclosure_user_marshal_VOID__MEDIA_METADATA (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void photo_real_editable_reimported (Photo* self, PhotoMetadata* metadata);
static void photo_real_baseline_reimported (Photo* self, PhotoMetadata* metadata);
static void photo_real_source_reimported (Photo* self, PhotoMetadata* metadata);
#define PHOTO_PHOTO_TRANSFORMATION_STATE_IMPL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL, PhotoPhotoTransformationStateImplPrivate))
enum  {
	PHOTO_PHOTO_TRANSFORMATION_STATE_IMPL_DUMMY_PROPERTY
};
static void photo_photo_transformation_state_impl_on_photo_baseline_replaced (PhotoPhotoTransformationStateImpl* self);
static void _photo_photo_transformation_state_impl_on_photo_baseline_replaced_photo_baseline_replaced (Photo* _sender, gpointer self);
static GeeHashMap* photo_photo_transformation_state_impl_copy_transformations (GeeHashMap* original);
static void photo_photo_transformation_state_impl_finalize (GObject * obj);
enum  {
	PHOTO_BACKING_READERS_DUMMY_PROPERTY
};
static void photo_backing_readers_finalize (PhotoBackingReaders * obj);
enum  {
	PHOTO_CACHED_PIXBUF_DUMMY_PROPERTY
};
static void photo_cached_pixbuf_finalize (PhotoCachedPixbuf * obj);
enum  {
	PHOTO_REIMPORT_MASTER_STATE_DUMMY_PROPERTY
};
PhotoReimportMasterState* photo_reimport_master_state_construct (GType object_type);
static void photo_reimport_master_state_finalize (PhotoReimportMasterState * obj);
enum  {
	PHOTO_REIMPORT_MASTER_STATE_IMPL_DUMMY_PROPERTY
};
static gchar** _vala_array_dup24 (gchar** self, int length);
static void photo_reimport_master_state_impl_finalize (PhotoReimportMasterState * obj);
enum  {
	PHOTO_REIMPORT_EDITABLE_STATE_DUMMY_PROPERTY
};
PhotoReimportEditableState* photo_reimport_editable_state_construct (GType object_type);
static void photo_reimport_editable_state_finalize (PhotoReimportEditableState * obj);
enum  {
	PHOTO_REIMPORT_EDITABLE_STATE_IMPL_DUMMY_PROPERTY
};
static void photo_reimport_editable_state_impl_finalize (PhotoReimportEditableState * obj);
enum  {
	PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_DUMMY_PROPERTY
};
PhotoReimportRawDevelopmentState* photo_reimport_raw_development_state_construct (GType object_type);
static void photo_reimport_raw_development_state_finalize (PhotoReimportRawDevelopmentState * obj);
enum  {
	PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_DUMMY_PROPERTY
};
static PhotoReimportRawDevelopmentStateImplDevToReimport* photo_reimport_raw_development_state_impl_dev_to_reimport_new (BackingPhotoRow* backing, PhotoMetadata* metadata);
static PhotoReimportRawDevelopmentStateImplDevToReimport* photo_reimport_raw_development_state_impl_dev_to_reimport_construct (GType object_type, BackingPhotoRow* backing, PhotoMetadata* metadata);
enum  {
	PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_DEV_TO_REIMPORT_DUMMY_PROPERTY
};
static void photo_reimport_raw_development_state_impl_dev_to_reimport_finalize (PhotoReimportRawDevelopmentStateImplDevToReimport * obj);
static void photo_reimport_raw_development_state_impl_finalize (PhotoReimportRawDevelopmentState * obj);
static void photo_finalize (GObject * obj);
static void _vala_photo_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_photo_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType marker_get_type (void) G_GNUC_CONST;
gpointer source_backlink_ref (gpointer instance);
void source_backlink_unref (gpointer instance);
GParamSpec* param_spec_source_backlink (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_source_backlink (GValue* value, gpointer v_object);
void value_take_source_backlink (GValue* value, gpointer v_object);
gpointer value_get_source_backlink (const GValue* value);
GType source_backlink_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType database_source_holding_tank_get_type (void) G_GNUC_CONST;
GType media_source_holding_tank_get_type (void) G_GNUC_CONST;
gpointer workers_ref (gpointer instance);
void workers_unref (gpointer instance);
GParamSpec* param_spec_workers (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_workers (GValue* value, gpointer v_object);
void value_take_workers (GValue* value, gpointer v_object);
gpointer value_get_workers (const GValue* value);
GType workers_get_type (void) G_GNUC_CONST;
GType media_monitor_get_type (void) G_GNUC_CONST;
gpointer transaction_controller_ref (gpointer instance);
void transaction_controller_unref (gpointer instance);
GParamSpec* param_spec_transaction_controller (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_transaction_controller (GValue* value, gpointer v_object);
void value_take_transaction_controller (GValue* value, gpointer v_object);
gpointer value_get_transaction_controller (const GValue* value);
GType transaction_controller_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionPrivate))
enum  {
	LIBRARY_PHOTO_SOURCE_COLLECTION_DUMMY_PROPERTY
};
GType library_photo_source_collection_state_get_type (void) G_GNUC_CONST;
guint file_hash (GFile* file);
static guint _file_hash_gee_hash_data_func (gconstpointer v, gpointer self);
gboolean file_equal (GFile* a, GFile* b);
static gboolean _file_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
gint int64_compare (gint64* a, gint64* b);
static gint _int64_compare_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gint64* _int64_dup (gint64* self);
gboolean int64_equal (gint64* a, gint64* b);
static gboolean _int64_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
LibraryPhotoSourceCollection* library_photo_source_collection_new (void);
LibraryPhotoSourceCollection* library_photo_source_collection_construct (GType object_type);
static gint64 _photo_get_photo_key_get_source_database_key (DataSource* source, gpointer self);
MediaSourceCollection* media_source_collection_construct (GType object_type, const gchar* name, GetSourceDatabaseKey source_key_func, void* source_key_func_target);
MediaSourceHoldingTank* media_source_collection_get_trashcan (MediaSourceCollection* self);
static void library_photo_source_collection_on_trashcan_contents_altered (LibraryPhotoSourceCollection* self, GeeCollection* added, GeeCollection* removed);
static void _library_photo_source_collection_on_trashcan_contents_altered_source_holding_tank_contents_altered (SourceHoldingTank* _sender, GeeCollection* added, GeeCollection* removed, gpointer self);
MediaSourceHoldingTank* media_source_collection_get_offline_bin (MediaSourceCollection* self);
static void library_photo_source_collection_on_offline_contents_altered (LibraryPhotoSourceCollection* self, GeeCollection* added, GeeCollection* removed);
static void _library_photo_source_collection_on_offline_contents_altered_source_holding_tank_contents_altered (SourceHoldingTank* _sender, GeeCollection* added, GeeCollection* removed, gpointer self);
static MediaSourceHoldingTank* library_photo_source_collection_real_create_trashcan (MediaSourceCollection* base);
static gboolean library_photo_source_collection_check_if_trashed_photo (LibraryPhotoSourceCollection* self, DataSource* source, Alteration* alteration);
static gboolean _library_photo_source_collection_check_if_trashed_photo_source_holding_tank_check_to_keep (DataSource* source, Alteration* alteration, gpointer self);
LibraryPhotoSourceHoldingTank* library_photo_source_holding_tank_new (LibraryPhotoSourceCollection* sources, SourceHoldingTankCheckToKeep check_to_keep, void* check_to_keep_target, GetSourceDatabaseKey get_key, void* get_key_target);
LibraryPhotoSourceHoldingTank* library_photo_source_holding_tank_construct (GType object_type, LibraryPhotoSourceCollection* sources, SourceHoldingTankCheckToKeep check_to_keep, void* check_to_keep_target, GetSourceDatabaseKey get_key, void* get_key_target);
GType library_photo_source_holding_tank_get_type (void) G_GNUC_CONST;
static MediaSourceHoldingTank* library_photo_source_collection_real_create_offline_bin (MediaSourceCollection* base);
static gboolean library_photo_source_collection_check_if_offline_photo (LibraryPhotoSourceCollection* self, DataSource* source, Alteration* alteration);
static gboolean _library_photo_source_collection_check_if_offline_photo_source_holding_tank_check_to_keep (DataSource* source, Alteration* alteration, gpointer self);
static MediaMonitor* library_photo_source_collection_real_create_media_monitor (MediaSourceCollection* base, Workers* workers, GCancellable* cancellable);
PhotoMonitor* photo_monitor_new (Workers* workers, GCancellable* cancellable);
PhotoMonitor* photo_monitor_construct (GType object_type, Workers* workers, GCancellable* cancellable);
GType photo_monitor_get_type (void) G_GNUC_CONST;
static gboolean library_photo_source_collection_real_holds_type_of_source (SourceCollection* base, DataSource* source);
static gchar* library_photo_source_collection_real_get_typename (MediaSourceCollection* base);
static gboolean library_photo_source_collection_real_is_file_recognized (MediaSourceCollection* base, GFile* file);
static void library_photo_source_collection_real_notify_contents_altered (DataCollection* base, GeeIterable* added, GeeIterable* removed);
static void library_photo_source_collection_on_editable_replaced (LibraryPhotoSourceCollection* self, Photo* photo, GFile* old_file, GFile* new_file);
static void _library_photo_source_collection_on_editable_replaced_photo_editable_replaced (Photo* _sender, GFile* old_file, GFile* new_file, gpointer self);
static void library_photo_source_collection_on_raw_development_modified (LibraryPhotoSourceCollection* self, Photo* _photo);
static void _library_photo_source_collection_on_raw_development_modified_photo_raw_development_modified (Photo* _sender, gpointer self);
void data_collection_notify_contents_altered (DataCollection* self, GeeIterable* added, GeeIterable* removed);
static void library_photo_source_collection_real_items_altered (DataCollection* base, GeeMap* items);
gboolean alteration_has_detail (Alteration* self, const gchar* subject, const gchar* detail);
static void library_photo_source_collection_real_postprocess_imported_media (MediaSourceCollection* base, GeeCollection* media_sources);
GType tag_get_type (void) G_GNUC_CONST;
gpointer hierarchical_tag_index_ref (gpointer instance);
void hierarchical_tag_index_unref (gpointer instance);
GParamSpec* param_spec_hierarchical_tag_index (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_hierarchical_tag_index (GValue* value, gpointer v_object);
void value_take_hierarchical_tag_index (GValue* value, gpointer v_object);
gpointer value_get_hierarchical_tag_index (const GValue* value);
GType hierarchical_tag_index_get_type (void) G_GNUC_CONST;
HierarchicalTagIndex* hierarchical_tag_index_get_global_index (void);
gboolean photo_metadata_has_hierarchical_keywords (PhotoMetadata* self);
HierarchicalTagIndex* hierarchical_tag_utilities_process_hierarchical_import_keywords (GeeCollection* h_keywords);
GeeSet* photo_metadata_get_hierarchical_keywords (PhotoMetadata* self);
GeeCollection* library_photo_get_import_keywords (LibraryPhoto* self);
gboolean hierarchical_tag_index_is_tag_in_index (HierarchicalTagIndex* self, const gchar* tag);
gchar* tag_prep_tag_name (const gchar* name);
gchar* hierarchical_tag_index_get_path_for_name (HierarchicalTagIndex* self, const gchar* name);
Tag* tag_for_path (const gchar* name);
GeeCollection* hierarchical_tag_index_get_all_paths (HierarchicalTagIndex* self);
void library_photo_clear_import_keywords (LibraryPhoto* self);
void tag_attach_many (Tag* self, GeeCollection* sources);
void media_source_collection_postprocess_imported_media (MediaSourceCollection* self, GeeCollection* media);
void library_photo_source_collection_notify_master_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_real_notify_master_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
void library_photo_source_collection_notify_editable_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_real_notify_editable_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
void library_photo_source_collection_notify_source_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_real_notify_source_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
void library_photo_source_collection_notify_baseline_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_real_notify_baseline_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static MediaSource* library_photo_source_collection_real_fetch_by_numeric_id (MediaSourceCollection* base, gint64 numeric_id);
LibraryPhoto* library_photo_source_collection_fetch (LibraryPhotoSourceCollection* self, PhotoID* photo_id);
gboolean media_source_is_trashed (MediaSource* self);
gboolean media_source_is_offline (MediaSource* self);
static MediaSource* library_photo_source_collection_real_fetch_by_source_id (MediaSourceCollection* base, const gchar* source_id);
MediaSource* media_source_collection_fetch_by_numeric_id (MediaSourceCollection* self, gint64 numeric_id);
gint64 parse_int64 (const gchar* str, gint num_base);
static GeeCollection* library_photo_source_collection_real_get_event_source_ids (MediaSourceCollection* base, EventID* event_id);
GeeArrayList* photo_table_get_event_source_ids (PhotoTable* self, EventID* event_id);
DataSource* database_source_collection_fetch_by_key (DatabaseSourceCollection* self, gint64 key);
LibraryPhoto* library_photo_source_collection_fetch_by_editable_file (LibraryPhotoSourceCollection* self, GFile* file);
LibraryPhoto* library_photo_source_collection_fetch_by_raw_development_file (LibraryPhotoSourceCollection* self, GFile* file);
static void library_photo_source_collection_compare_backing (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, GFileInfo* info, GeeCollection* matches_master, GeeCollection* matches_editable, GeeCollection* matches_development);
gboolean backing_photo_row_matches_file_info (BackingPhotoRow* self, GFileInfo* info);
void library_photo_source_collection_fetch_by_matching_backing (LibraryPhotoSourceCollection* self, GFileInfo* info, GeeCollection* matches_master, GeeCollection* matches_editable, GeeCollection* matched_development);
GeeCollection* media_source_collection_get_offline_bin_contents (MediaSourceCollection* self);
void library_photo_source_collection_get_basename_filesize_duplicate (LibraryPhotoSourceCollection* self, const gchar* basename, gint64 filesize, PhotoID* result);
gint utf8_ci_compare (void* a, void* b);
gboolean library_photo_source_collection_has_basename_filesize_duplicate (LibraryPhotoSourceCollection* self, const gchar* basename, gint64 filesize);
gboolean photo_id_is_valid (PhotoID *self);
LibraryPhoto* library_photo_source_collection_get_trashed_by_file (LibraryPhotoSourceCollection* self, GFile* file);
MediaSource* media_source_holding_tank_fetch_by_master_file (MediaSourceHoldingTank* self, GFile* file);
LibraryPhoto* library_photo_source_holding_tank_fetch_by_backing_file (LibraryPhotoSourceHoldingTank* self, GFile* file);
LibraryPhoto* library_photo_source_collection_get_trashed_by_md5 (LibraryPhotoSourceCollection* self, const gchar* md5);
MediaSource* media_source_holding_tank_fetch_by_md5 (MediaSourceHoldingTank* self, const gchar* md5);
LibraryPhoto* library_photo_source_collection_get_offline_by_file (LibraryPhotoSourceCollection* self, GFile* file);
LibraryPhoto* library_photo_source_collection_get_offline_by_md5 (LibraryPhotoSourceCollection* self, const gchar* md5);
gint library_photo_source_collection_get_offline_count (LibraryPhotoSourceCollection* self);
gint source_holding_tank_get_count (SourceHoldingTank* self);
LibraryPhoto* library_photo_source_collection_get_state_by_file (LibraryPhotoSourceCollection* self, GFile* file, LibraryPhotoSourceCollectionState* state);
MediaSource* media_source_collection_fetch_by_master_file (MediaSourceCollection* self, GFile* file);
static gboolean library_photo_source_collection_real_has_backlink (SourceCollection* base, SourceBacklink* backlink);
gboolean source_collection_has_backlink (SourceCollection* self, SourceBacklink* backlink);
gboolean source_holding_tank_has_backlink (SourceHoldingTank* self, SourceBacklink* backlink);
static void library_photo_source_collection_real_remove_backlink (SourceCollection* base, SourceBacklink* backlink);
void source_holding_tank_remove_backlink (SourceHoldingTank* self, SourceBacklink* backlink);
void source_collection_remove_backlink (SourceCollection* self, SourceBacklink* backlink);
MediaSourceTransactionController* media_source_transaction_controller_new (MediaSourceCollection* sources);
MediaSourceTransactionController* media_source_transaction_controller_construct (GType object_type, MediaSourceCollection* sources);
GType media_source_transaction_controller_get_type (void) G_GNUC_CONST;
static void library_photo_source_collection_real_master_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void g_cclosure_user_marshal_VOID__OBJECT_MEDIA_METADATA (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void library_photo_source_collection_real_editable_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_real_baseline_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_real_source_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata);
static void library_photo_source_collection_finalize (DataCollection * obj);
GType flaggable_get_type (void) G_GNUC_CONST;
GType monitorable_get_type (void) G_GNUC_CONST;
#define LIBRARY_PHOTO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LIBRARY_PHOTO, LibraryPhotoPrivate))
enum  {
	LIBRARY_PHOTO_DUMMY_PROPERTY
};
#define LIBRARY_PHOTO_FLAG_HIDDEN ((guint64) 0x0000000000000001)
#define LIBRARY_PHOTO_FLAG_FAVORITE ((guint64) 0x0000000000000002)
#define LIBRARY_PHOTO_FLAG_TRASH ((guint64) 0x0000000000000004)
#define LIBRARY_PHOTO_FLAG_OFFLINE ((guint64) 0x0000000000000008)
#define LIBRARY_PHOTO_FLAG_FLAGGED ((guint64) 0x0000000000000010)
static LibraryPhoto* library_photo_new (PhotoRow* row);
static LibraryPhoto* library_photo_construct (GType object_type, PhotoRow* row);
static void library_photo_generate_thumbnails (LibraryPhoto* self);
static void _library_photo_generate_thumbnails_one_shot_callback (gpointer self);
void data_source_rehydrate_backlinks (DataSource* self, SourceCollection* unlinked_from, const gchar* dehydrated);
static void library_photo_upgrade_rating_flags (LibraryPhoto* self, guint64 flags);
static LibraryPhoto* library_photo_new_from_import_params (PhotoImportParams* import_params);
static LibraryPhoto* library_photo_construct_from_import_params (GType object_type, PhotoImportParams* import_params);
void library_photo_init (ProgressMonitor monitor, void* monitor_target);
GeeArrayList* photo_table_get_all (PhotoTable* self);
GeeCollection* data_collection_add_many (DataCollection* self, GeeCollection* objects, ProgressMonitor monitor, void* monitor_target);
void media_source_collection_add_many_to_trash (MediaSourceCollection* self, GeeCollection* sources);
void media_source_collection_add_many_to_offline (MediaSourceCollection* self, GeeCollection* sources);
void library_photo_terminate (void);
ImportResult library_photo_import_create (PhotoImportParams* params, LibraryPhoto* * photo);
void photo_table_add (PhotoTable* self, PhotoRow* photo_row, PhotoID* result);
gboolean photo_id_is_invalid (PhotoID *self);
void library_photo_import_failed (LibraryPhoto* photo);
void photo_table_remove (PhotoTable* self, PhotoID* photo_id, GError** error);
static void library_photo_real_notify_master_reimported (Photo* base, PhotoMetadata* metadata);
static void library_photo_real_notify_editable_reimported (Photo* base, PhotoMetadata* metadata);
static void library_photo_real_notify_source_reimported (Photo* base, PhotoMetadata* metadata);
static void library_photo_real_notify_baseline_reimported (Photo* base, PhotoMetadata* metadata);
void thumbnail_cache_import_from_source (ThumbnailSource* source, gboolean force, GError** error);
void thumbnail_source_notify_thumbnail_altered (ThumbnailSource* self);
static void library_photo_real_notify_altered (DataObject* base, Alteration* alteration);
gboolean alteration_has_subject (Alteration* self, const gchar* subject);
void one_shot_scheduler_at_priority_idle (OneShotScheduler* self, gint priority);
static GdkPixbuf* library_photo_real_get_preview_pixbuf (MediaSource* base, Scaling* scaling, GError** error);
GdkPixbuf* thumbnail_source_get_thumbnail (ThumbnailSource* self, gint scale, GError** error);
GType thumbnail_cache_size_get_type (void) G_GNUC_CONST;
GdkPixbuf* scaling_perform_on_pixbuf (Scaling *self, GdkPixbuf* pixbuf, GdkInterpType interp, gboolean scale_up);
static void library_photo_real_rotate (Photo* base, Rotation rotation);
void thumbnail_cache_rotate (ThumbnailSource* source, Rotation rotation, GError** error);
static GdkPixbuf* library_photo_real_get_thumbnail (ThumbnailSource* base, gint scale, GError** error);
GdkPixbuf* thumbnail_cache_fetch (ThumbnailSource* source, gint scale, GError** error);
static void library_photo_duplicate_backing_photo (LibraryPhoto* self, BackingPhotoRow* backing, BackingPhotoID* result, GError** error);
GFile* library_files_duplicate (GFile* src, GFileProgressCallback progress_callback, void* progress_callback_target, gboolean blacklist, GError** error);
static void library_photo_on_duplicate_progress (LibraryPhoto* self, gint64 current, gint64 total);
static void _library_photo_on_duplicate_progress_gfile_progress_callback (gint64 current_num_bytes, gint64 total_num_bytes, gpointer self);
LibraryPhoto* library_photo_duplicate (LibraryPhoto* self, GError** error);
void photo_table_duplicate (PhotoTable* self, PhotoID* photo_id, const gchar* new_filename, BackingPhotoID* editable_id, BackingPhotoID* develop_shotwell, BackingPhotoID* develop_camera_id, BackingPhotoID* develop_embedded_id, PhotoID* result);
PhotoRow* photo_table_get_row (PhotoTable* self, PhotoID* photo_id);
void thumbnail_cache_duplicate (ThumbnailSource* src_source, ThumbnailSource* dest_source);
gboolean data_collection_add (DataCollection* self, DataObject* object);
GType event_source_get_type (void) G_GNUC_CONST;
GType event_get_type (void) G_GNUC_CONST;
Event* media_source_get_event (MediaSource* self);
void event_attach (Event* self, MediaSource* source);
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType tag_source_collection_get_type (void) G_GNUC_CONST;
GeeList* tag_source_collection_fetch_for_source (TagSourceCollection* self, MediaSource* source);
void tag_attach (Tag* self, MediaSource* source);
void spin_event_loop (void);
static gboolean library_photo_real_is_trashed (MediaSource* base);
static void library_photo_real_trash (MediaSource* base);
static void library_photo_real_untrash (MediaSource* base);
static gboolean library_photo_real_is_offline (Monitorable* base);
static void library_photo_real_mark_offline (Monitorable* base);
static void library_photo_real_mark_online (Monitorable* base);
static gboolean library_photo_real_is_flagged (Flaggable* base);
static void library_photo_real_mark_flagged (Flaggable* base);
static void library_photo_real_mark_unflagged (Flaggable* base);
static gboolean library_photo_real_internal_delete_backing (DataSource* base, GError** error);
gboolean media_source_delete_original_file (MediaSource* self);
static void library_photo_real_destroy (DataSource* base);
void thumbnail_cache_remove (ThumbnailSource* source);
void data_source_destroy (DataSource* self);
gboolean library_photo_has_nontrash_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format);
void library_photo_get_nontrash_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format, PhotoID* result);
static gboolean library_photo_real_has_user_generated_metadata (Photo* base);
Rating media_source_get_rating (MediaSource* self);
gchar* data_object_get_name (DataObject* self);
static void library_photo_real_set_user_metadata_for_export (Photo* base, PhotoMetadata* metadata);
void photo_metadata_set_keywords (PhotoMetadata* self, GeeCollection* keywords, PhotoMetadataSetOption option);
void photo_metadata_set_rating (PhotoMetadata* self, Rating rating);
static void library_photo_real_apply_user_metadata_for_reimport (Photo* base, PhotoMetadata* metadata);
gchar* hierarchical_tag_utilities_make_flat_tag_safe (const gchar* in_tag);
gchar* hierarchical_tag_utilities_flat_to_hierarchical (const gchar* name);
gboolean tag_source_collection_exists (TagSourceCollection* self, const gchar* name, gboolean treat_htags_as_root);
static void library_photo_finalize (GObject * obj);
#define LIBRARY_PHOTO_SOURCE_HOLDING_TANK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTankPrivate))
enum  {
	LIBRARY_PHOTO_SOURCE_HOLDING_TANK_DUMMY_PROPERTY
};
MediaSourceHoldingTank* media_source_holding_tank_new (MediaSourceCollection* sources, SourceHoldingTankCheckToKeep check_to_keep, void* check_to_keep_target, GetSourceDatabaseKey get_key, void* get_key_target);
MediaSourceHoldingTank* media_source_holding_tank_construct (GType object_type, MediaSourceCollection* sources, SourceHoldingTankCheckToKeep check_to_keep, void* check_to_keep_target, GetSourceDatabaseKey get_key, void* get_key_target);
static void library_photo_source_holding_tank_real_notify_contents_altered (SourceHoldingTank* base, GeeCollection* added, GeeCollection* removed);
static void library_photo_source_holding_tank_on_editable_replaced (LibraryPhotoSourceHoldingTank* self, Photo* _photo, GFile* old_file, GFile* new_file);
static void _library_photo_source_holding_tank_on_editable_replaced_photo_editable_replaced (Photo* _sender, GFile* old_file, GFile* new_file, gpointer self);
static void library_photo_source_holding_tank_on_raw_development_modified (LibraryPhotoSourceHoldingTank* self, Photo* _photo);
static void _library_photo_source_holding_tank_on_raw_development_modified_photo_raw_development_modified (Photo* _sender, gpointer self);
void source_holding_tank_notify_contents_altered (SourceHoldingTank* self, GeeCollection* added, GeeCollection* removed);
static void library_photo_source_holding_tank_finalize (SourceHoldingTank * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const gchar* PHOTO_IMAGE_EXTENSIONS[69] = {"jpg", "jpeg", "jpe", "tiff", "tif", "png", "gif", "bmp", "ppm", "pgm", "pbm", "pnm", "thm", "tga", "ilbm", "pcx", "ecw", "img", "sid", "cd5", "fits", "pgf", "cgm", "svg", "odg", "eps", "pdf", "swf", "wmf", "emf", "xps", "pns", "jps", "mpo", "3fr", "arw", "srf", "sr2", "bay", "crw", "cr2", "cap", "iiq", "eip", "dcs", "dcr", "drf", "k25", "kdc", "dng", "erf", "fff", "mef", "mos", "mrw", "nef", "nrw", "orf", "ptx", "pef", "pxn", "r3d", "raf", "raw", "rw2", "rwl", "rwz", "x3f", "srw"};

GType backing_fetch_mode_get_type (void) {
	static volatile gsize backing_fetch_mode_type_id__volatile = 0;
	if (g_once_init_enter (&backing_fetch_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{BACKING_FETCH_MODE_SOURCE, "BACKING_FETCH_MODE_SOURCE", "source"}, {BACKING_FETCH_MODE_BASELINE, "BACKING_FETCH_MODE_BASELINE", "baseline"}, {BACKING_FETCH_MODE_MASTER, "BACKING_FETCH_MODE_MASTER", "master"}, {BACKING_FETCH_MODE_UNMODIFIED, "BACKING_FETCH_MODE_UNMODIFIED", "unmodified"}, {0, NULL, NULL}};
		GType backing_fetch_mode_type_id;
		backing_fetch_mode_type_id = g_enum_register_static ("BackingFetchMode", values);
		g_once_init_leave (&backing_fetch_mode_type_id__volatile, backing_fetch_mode_type_id);
	}
	return backing_fetch_mode_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
#line 41 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? g_object_ref (self) : NULL;
#line 2809 "Photo.c"
}


static gpointer _thumbnails_ref0 (gpointer self) {
#line 48 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? thumbnails_ref (self) : NULL;
#line 2816 "Photo.c"
}


PhotoImportParams* photo_import_params_construct (GType object_type, GFile* file, GFile* final_associated_file, ImportID* import_id, PhotoFileSnifferOptions sniffer_options, const gchar* exif_md5, const gchar* thumbnail_md5, const gchar* full_md5, Thumbnails* thumbnails) {
	PhotoImportParams* self = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	ImportID _tmp4_;
	PhotoFileSnifferOptions _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	Thumbnails* _tmp12_;
	Thumbnails* _tmp13_;
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((final_associated_file == NULL) || G_IS_FILE (final_associated_file), NULL);
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (import_id != NULL, NULL);
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((thumbnails == NULL) || IS_THUMBNAILS (thumbnails), NULL);
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoImportParams*) g_type_create_instance (object_type);
#line 41 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 41 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 41 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->file);
#line 41 "/home/jens/Source/shotwell/src/Photo.vala"
	self->file = _tmp1_;
#line 42 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = final_associated_file;
#line 42 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 42 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->final_associated_file);
#line 42 "/home/jens/Source/shotwell/src/Photo.vala"
	self->final_associated_file = _tmp3_;
#line 43 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = *import_id;
#line 43 "/home/jens/Source/shotwell/src/Photo.vala"
	self->import_id = _tmp4_;
#line 44 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = sniffer_options;
#line 44 "/home/jens/Source/shotwell/src/Photo.vala"
	self->sniffer_options = _tmp5_;
#line 45 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = exif_md5;
#line 45 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 45 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->exif_md5);
#line 45 "/home/jens/Source/shotwell/src/Photo.vala"
	self->exif_md5 = _tmp7_;
#line 46 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = thumbnail_md5;
#line 46 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = g_strdup (_tmp8_);
#line 46 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->thumbnail_md5);
#line 46 "/home/jens/Source/shotwell/src/Photo.vala"
	self->thumbnail_md5 = _tmp9_;
#line 47 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = full_md5;
#line 47 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 47 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->full_md5);
#line 47 "/home/jens/Source/shotwell/src/Photo.vala"
	self->full_md5 = _tmp11_;
#line 48 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = thumbnails;
#line 48 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _thumbnails_ref0 (_tmp12_);
#line 48 "/home/jens/Source/shotwell/src/Photo.vala"
	_thumbnails_unref0 (self->thumbnails);
#line 48 "/home/jens/Source/shotwell/src/Photo.vala"
	self->thumbnails = _tmp13_;
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 2904 "Photo.c"
}


PhotoImportParams* photo_import_params_new (GFile* file, GFile* final_associated_file, ImportID* import_id, PhotoFileSnifferOptions sniffer_options, const gchar* exif_md5, const gchar* thumbnail_md5, const gchar* full_md5, Thumbnails* thumbnails) {
#line 38 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_import_params_construct (TYPE_PHOTO_IMPORT_PARAMS, file, final_associated_file, import_id, sniffer_options, exif_md5, thumbnail_md5, full_md5, thumbnails);
#line 2911 "Photo.c"
}


PhotoImportParams* photo_import_params_construct_create_placeholder (GType object_type, GFile* file, ImportID* import_id) {
	PhotoImportParams* self = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	ImportID _tmp2_;
#line 52 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 52 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (import_id != NULL, NULL);
#line 52 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoImportParams*) g_type_create_instance (object_type);
#line 53 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 53 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 53 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->file);
#line 53 "/home/jens/Source/shotwell/src/Photo.vala"
	self->file = _tmp1_;
#line 54 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = *import_id;
#line 54 "/home/jens/Source/shotwell/src/Photo.vala"
	self->import_id = _tmp2_;
#line 55 "/home/jens/Source/shotwell/src/Photo.vala"
	self->sniffer_options = PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5;
#line 56 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->exif_md5);
#line 56 "/home/jens/Source/shotwell/src/Photo.vala"
	self->exif_md5 = NULL;
#line 57 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->thumbnail_md5);
#line 57 "/home/jens/Source/shotwell/src/Photo.vala"
	self->thumbnail_md5 = NULL;
#line 58 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->full_md5);
#line 58 "/home/jens/Source/shotwell/src/Photo.vala"
	self->full_md5 = NULL;
#line 59 "/home/jens/Source/shotwell/src/Photo.vala"
	_thumbnails_unref0 (self->thumbnails);
#line 59 "/home/jens/Source/shotwell/src/Photo.vala"
	self->thumbnails = NULL;
#line 52 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 2958 "Photo.c"
}


PhotoImportParams* photo_import_params_new_create_placeholder (GFile* file, ImportID* import_id) {
#line 52 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_import_params_construct_create_placeholder (TYPE_PHOTO_IMPORT_PARAMS, file, import_id);
#line 2965 "Photo.c"
}


static void value_photo_import_params_init (GValue* value) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 2972 "Photo.c"
}


static void value_photo_import_params_free_value (GValue* value) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_import_params_unref (value->data[0].v_pointer);
#line 2981 "Photo.c"
	}
}


static void value_photo_import_params_copy_value (const GValue* src_value, GValue* dest_value) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_import_params_ref (src_value->data[0].v_pointer);
#line 2991 "Photo.c"
	} else {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2995 "Photo.c"
	}
}


static gpointer value_photo_import_params_peek_pointer (const GValue* value) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 3003 "Photo.c"
}


static gchar* value_photo_import_params_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 3010 "Photo.c"
		PhotoImportParams * object;
		object = collect_values[0].v_pointer;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3017 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3021 "Photo.c"
		}
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_import_params_ref (object);
#line 3025 "Photo.c"
	} else {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 3029 "Photo.c"
	}
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 3033 "Photo.c"
}


static gchar* value_photo_import_params_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoImportParams ** object_p;
	object_p = collect_values[0].v_pointer;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 3044 "Photo.c"
	}
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 3050 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 3054 "Photo.c"
	} else {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_import_params_ref (value->data[0].v_pointer);
#line 3058 "Photo.c"
	}
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 3062 "Photo.c"
}


GParamSpec* param_spec_photo_import_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecPhotoImportParams* spec;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_PHOTO_IMPORT_PARAMS), NULL);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 3076 "Photo.c"
}


gpointer value_get_photo_import_params (const GValue* value) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PHOTO_IMPORT_PARAMS), NULL);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 3085 "Photo.c"
}


void value_set_photo_import_params (GValue* value, gpointer v_object) {
	PhotoImportParams * old;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PHOTO_IMPORT_PARAMS));
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PHOTO_IMPORT_PARAMS));
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_import_params_ref (value->data[0].v_pointer);
#line 3105 "Photo.c"
	} else {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 3109 "Photo.c"
	}
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_import_params_unref (old);
#line 3115 "Photo.c"
	}
}


void value_take_photo_import_params (GValue* value, gpointer v_object) {
	PhotoImportParams * old;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PHOTO_IMPORT_PARAMS));
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PHOTO_IMPORT_PARAMS));
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 3134 "Photo.c"
	} else {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 3138 "Photo.c"
	}
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_import_params_unref (old);
#line 3144 "Photo.c"
	}
}


static void photo_import_params_class_init (PhotoImportParamsClass * klass) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_import_params_parent_class = g_type_class_peek_parent (klass);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoImportParamsClass *) klass)->finalize = photo_import_params_finalize;
#line 3154 "Photo.c"
}


static void photo_import_params_instance_init (PhotoImportParams * self) {
	PhotoRow* _tmp0_;
#line 24 "/home/jens/Source/shotwell/src/Photo.vala"
	self->final_associated_file = NULL;
#line 35 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_row_new ();
#line 35 "/home/jens/Source/shotwell/src/Photo.vala"
	self->row = _tmp0_;
#line 36 "/home/jens/Source/shotwell/src/Photo.vala"
	self->keywords = NULL;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 3170 "Photo.c"
}


static void photo_import_params_finalize (PhotoImportParams * obj) {
	PhotoImportParams * self;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHOTO_IMPORT_PARAMS, PhotoImportParams);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 23 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->file);
#line 24 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->final_associated_file);
#line 27 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->exif_md5);
#line 28 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->thumbnail_md5);
#line 29 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->full_md5);
#line 32 "/home/jens/Source/shotwell/src/Photo.vala"
	_thumbnails_unref0 (self->thumbnails);
#line 35 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (self->row);
#line 36 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->keywords);
#line 3196 "Photo.c"
}


GType photo_import_params_get_type (void) {
	static volatile gsize photo_import_params_type_id__volatile = 0;
	if (g_once_init_enter (&photo_import_params_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_photo_import_params_init, value_photo_import_params_free_value, value_photo_import_params_copy_value, value_photo_import_params_peek_pointer, "p", value_photo_import_params_collect_value, "p", value_photo_import_params_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoImportParamsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_import_params_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoImportParams), 0, (GInstanceInitFunc) photo_import_params_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_import_params_type_id;
		photo_import_params_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoImportParams", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&photo_import_params_type_id__volatile, photo_import_params_type_id);
	}
	return photo_import_params_type_id__volatile;
}


gpointer photo_import_params_ref (gpointer instance) {
	PhotoImportParams * self;
	self = instance;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 3221 "Photo.c"
}


void photo_import_params_unref (gpointer instance) {
	PhotoImportParams * self;
	self = instance;
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_IMPORT_PARAMS_GET_CLASS (self)->finalize (self);
#line 21 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 3234 "Photo.c"
	}
}


PhotoTransformationState* photo_transformation_state_construct (GType object_type) {
	PhotoTransformationState * self = NULL;
#line 72 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoTransformationState*) g_object_new (object_type, NULL);
#line 72 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 3245 "Photo.c"
}


gboolean photo_transformation_state_is_broken (PhotoTransformationState* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 75 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_TRANSFORMATION_STATE (self), FALSE);
#line 76 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->is_broke;
#line 76 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 76 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3260 "Photo.c"
}


static void photo_transformation_state_real_broken (PhotoTransformationState* self) {
#line 69 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->is_broke = TRUE;
#line 3267 "Photo.c"
}


static void photo_transformation_state_class_init (PhotoTransformationStateClass * klass) {
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_transformation_state_parent_class = g_type_class_peek_parent (klass);
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	g_type_class_add_private (klass, sizeof (PhotoTransformationStatePrivate));
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoTransformationStateClass *) klass)->broken = photo_transformation_state_real_broken;
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (klass)->finalize = photo_transformation_state_finalize;
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_transformation_state_signals[PHOTO_TRANSFORMATION_STATE_BROKEN_SIGNAL] = g_signal_new ("broken", TYPE_PHOTO_TRANSFORMATION_STATE, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoTransformationStateClass, broken), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3282 "Photo.c"
}


static void photo_transformation_state_instance_init (PhotoTransformationState * self) {
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv = PHOTO_TRANSFORMATION_STATE_GET_PRIVATE (self);
#line 64 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->is_broke = FALSE;
#line 3291 "Photo.c"
}


static void photo_transformation_state_finalize (GObject * obj) {
	PhotoTransformationState * self;
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationState);
#line 63 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (photo_transformation_state_parent_class)->finalize (obj);
#line 3301 "Photo.c"
}


GType photo_transformation_state_get_type (void) {
	static volatile gsize photo_transformation_state_type_id__volatile = 0;
	if (g_once_init_enter (&photo_transformation_state_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoTransformationStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_transformation_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoTransformationState), 0, (GInstanceInitFunc) photo_transformation_state_instance_init, NULL };
		GType photo_transformation_state_type_id;
		photo_transformation_state_type_id = g_type_register_static (G_TYPE_OBJECT, "PhotoTransformationState", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&photo_transformation_state_type_id__volatile, photo_transformation_state_type_id);
	}
	return photo_transformation_state_type_id__volatile;
}


gboolean rating_can_increase (Rating self) {
	gboolean result = FALSE;
#line 90 "/home/jens/Source/shotwell/src/Photo.vala"
	result = self < RATING_FIVE;
#line 90 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3323 "Photo.c"
}


gboolean rating_can_decrease (Rating self) {
	gboolean result = FALSE;
#line 94 "/home/jens/Source/shotwell/src/Photo.vala"
	result = self > RATING_REJECTED;
#line 94 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3333 "Photo.c"
}


gboolean rating_is_valid (Rating self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 98 "/home/jens/Source/shotwell/src/Photo.vala"
	if (self >= RATING_REJECTED) {
#line 98 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self <= RATING_FIVE;
#line 3344 "Photo.c"
	} else {
#line 98 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = FALSE;
#line 3348 "Photo.c"
	}
#line 98 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 98 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3354 "Photo.c"
}


Rating rating_increase (Rating self) {
	Rating result = 0;
	Rating _tmp0_ = 0;
	gboolean _tmp1_;
#line 102 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = rating_can_increase (self);
#line 102 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 102 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self + 1;
#line 3368 "Photo.c"
	} else {
#line 102 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self;
#line 3372 "Photo.c"
	}
#line 102 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 102 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3378 "Photo.c"
}


Rating rating_decrease (Rating self) {
	Rating result = 0;
	Rating _tmp0_ = 0;
	gboolean _tmp1_;
#line 106 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = rating_can_decrease (self);
#line 106 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 106 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self - 1;
#line 3392 "Photo.c"
	} else {
#line 106 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self;
#line 3396 "Photo.c"
	}
#line 106 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 106 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3402 "Photo.c"
}


gint rating_serialize (Rating self) {
	gint result = 0;
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (self) {
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_REJECTED:
#line 3412 "Photo.c"
		{
#line 112 "/home/jens/Source/shotwell/src/Photo.vala"
			result = -1;
#line 112 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3418 "Photo.c"
		}
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_UNRATED:
#line 3422 "Photo.c"
		{
#line 114 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 0;
#line 114 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3428 "Photo.c"
		}
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_ONE:
#line 3432 "Photo.c"
		{
#line 116 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 1;
#line 116 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3438 "Photo.c"
		}
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_TWO:
#line 3442 "Photo.c"
		{
#line 118 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 2;
#line 118 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3448 "Photo.c"
		}
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_THREE:
#line 3452 "Photo.c"
		{
#line 120 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 3;
#line 120 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3458 "Photo.c"
		}
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_FOUR:
#line 3462 "Photo.c"
		{
#line 122 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 4;
#line 122 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3468 "Photo.c"
		}
#line 110 "/home/jens/Source/shotwell/src/Photo.vala"
		case RATING_FIVE:
#line 3472 "Photo.c"
		{
#line 124 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 5;
#line 124 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3478 "Photo.c"
		}
		default:
		{
#line 126 "/home/jens/Source/shotwell/src/Photo.vala"
			result = 0;
#line 126 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3486 "Photo.c"
		}
	}
}


Rating rating_unserialize (gint value) {
	Rating result = 0;
	gint _tmp0_;
	gint _tmp2_;
#line 131 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = value;
#line 131 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ > ((gint) RATING_FIVE)) {
#line 132 "/home/jens/Source/shotwell/src/Photo.vala"
		result = RATING_FIVE;
#line 132 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 3504 "Photo.c"
	} else {
		gint _tmp1_;
#line 133 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = value;
#line 133 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp1_ < ((gint) RATING_REJECTED)) {
#line 134 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_REJECTED;
#line 134 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3515 "Photo.c"
		}
	}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = value;
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp2_) {
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case -1:
#line 3524 "Photo.c"
		{
#line 138 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_REJECTED;
#line 138 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3530 "Photo.c"
		}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case 0:
#line 3534 "Photo.c"
		{
#line 140 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_UNRATED;
#line 140 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3540 "Photo.c"
		}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case 1:
#line 3544 "Photo.c"
		{
#line 142 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_ONE;
#line 142 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3550 "Photo.c"
		}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case 2:
#line 3554 "Photo.c"
		{
#line 144 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_TWO;
#line 144 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3560 "Photo.c"
		}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case 3:
#line 3564 "Photo.c"
		{
#line 146 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_THREE;
#line 146 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3570 "Photo.c"
		}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case 4:
#line 3574 "Photo.c"
		{
#line 148 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_FOUR;
#line 148 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3580 "Photo.c"
		}
#line 136 "/home/jens/Source/shotwell/src/Photo.vala"
		case 5:
#line 3584 "Photo.c"
		{
#line 150 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_FIVE;
#line 150 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3590 "Photo.c"
		}
		default:
		{
#line 152 "/home/jens/Source/shotwell/src/Photo.vala"
			result = RATING_UNRATED;
#line 152 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 3598 "Photo.c"
		}
	}
}


GType rating_get_type (void) {
	static volatile gsize rating_type_id__volatile = 0;
	if (g_once_init_enter (&rating_type_id__volatile)) {
		static const GEnumValue values[] = {{RATING_REJECTED, "RATING_REJECTED", "rejected"}, {RATING_UNRATED, "RATING_UNRATED", "unrated"}, {RATING_ONE, "RATING_ONE", "one"}, {RATING_TWO, "RATING_TWO", "two"}, {RATING_THREE, "RATING_THREE", "three"}, {RATING_FOUR, "RATING_FOUR", "four"}, {RATING_FIVE, "RATING_FIVE", "five"}, {0, NULL, NULL}};
		GType rating_type_id;
		rating_type_id = g_enum_register_static ("Rating", values);
		g_once_init_leave (&rating_type_id__volatile, rating_type_id);
	}
	return rating_type_id__volatile;
}


gboolean photo_exception_prohibits (PhotoException self, PhotoException exception) {
	gboolean result = FALSE;
	PhotoException _tmp0_;
#line 228 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = exception;
#line 228 "/home/jens/Source/shotwell/src/Photo.vala"
	result = (self & _tmp0_) != 0;
#line 228 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3625 "Photo.c"
}


gboolean photo_exception_allows (PhotoException self, PhotoException exception) {
	gboolean result = FALSE;
	PhotoException _tmp0_;
#line 232 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = exception;
#line 232 "/home/jens/Source/shotwell/src/Photo.vala"
	result = (self & _tmp0_) == 0;
#line 232 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 3638 "Photo.c"
}


GType photo_exception_get_type (void) {
	static volatile gsize photo_exception_type_id__volatile = 0;
	if (g_once_init_enter (&photo_exception_type_id__volatile)) {
		static const GEnumValue values[] = {{PHOTO_EXCEPTION_NONE, "PHOTO_EXCEPTION_NONE", "none"}, {PHOTO_EXCEPTION_ORIENTATION, "PHOTO_EXCEPTION_ORIENTATION", "orientation"}, {PHOTO_EXCEPTION_CROP, "PHOTO_EXCEPTION_CROP", "crop"}, {PHOTO_EXCEPTION_REDEYE, "PHOTO_EXCEPTION_REDEYE", "redeye"}, {PHOTO_EXCEPTION_ADJUST, "PHOTO_EXCEPTION_ADJUST", "adjust"}, {PHOTO_EXCEPTION_STRAIGHTEN, "PHOTO_EXCEPTION_STRAIGHTEN", "straighten"}, {PHOTO_EXCEPTION_ALL, "PHOTO_EXCEPTION_ALL", "all"}, {0, NULL, NULL}};
		GType photo_exception_type_id;
		photo_exception_type_id = g_enum_register_static ("PhotoException", values);
		g_once_init_leave (&photo_exception_type_id__volatile, photo_exception_type_id);
	}
	return photo_exception_type_id__volatile;
}


static gpointer _photo_row_ref0 (gpointer self) {
#line 400 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? photo_row_ref (self) : NULL;
#line 3657 "Photo.c"
}


static gpointer _backing_photo_row_ref0 (gpointer self) {
#line 421 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? backing_photo_row_ref (self) : NULL;
#line 3664 "Photo.c"
}


Photo* photo_construct (GType object_type, PhotoRow* row) {
	Photo * self = NULL;
	PhotoRow* _tmp0_;
	PhotoRow* _tmp1_;
	PhotoRow* _tmp2_;
	PhotoRow* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	PhotoRow* _tmp6_;
	PhotoRow* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	PhotoBackingReaders* _tmp10_;
	PhotoRow* _tmp11_;
	BackingPhotoRow* _tmp12_;
	PhotoFileFormat _tmp13_;
	PhotoRow* _tmp14_;
	BackingPhotoRow* _tmp15_;
	const gchar* _tmp16_;
	PhotoFileReader* _tmp17_;
	gchar* basename = NULL;
	PhotoRow* _tmp18_;
	BackingPhotoRow* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp25_;
	gboolean _tmp26_;
	PhotoRow* _tmp31_;
	BackingPhotoID _tmp32_;
	gint64 _tmp33_;
	PhotoRow* _tmp49_;
	BackingPhotoRow* _tmp50_;
	PhotoFileFormat _tmp51_;
	gboolean _tmp67_ = FALSE;
	PhotoRow* _tmp68_;
	BackingPhotoRow* _tmp69_;
	PhotoFileFormat _tmp70_;
	PhotoBackingReaders* _tmp85_;
	PhotoFileReader* _tmp86_;
	PhotoRow* _tmp106_;
	time_t _tmp107_;
	GError * _inner_error_ = NULL;
#line 399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_ROW (row), NULL);
#line 399 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (Photo*) photo_source_construct (object_type, DATA_OBJECT_INVALID_OBJECT_ID);
#line 400 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = row;
#line 400 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _photo_row_ref0 (_tmp0_);
#line 400 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (self->row);
#line 400 "/home/jens/Source/shotwell/src/Photo.vala"
	self->row = _tmp1_;
#line 403 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = self->row;
#line 403 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = self->row;
#line 403 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_->title;
#line 403 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = media_source_prep_title (_tmp4_);
#line 403 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp2_->title);
#line 403 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_->title = _tmp5_;
#line 404 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = self->row;
#line 404 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = self->row;
#line 404 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_->comment;
#line 404 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = media_source_prep_comment (_tmp8_);
#line 404 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp6_->comment);
#line 404 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_->comment = _tmp9_;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = self->priv->readers;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = row;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = _tmp11_->master;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_->file_format;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = row;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_->master;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = _tmp15_->filepath;
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = photo_file_format_create_reader (_tmp13_, _tmp16_);
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp10_->master);
#line 408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_->master = _tmp17_;
#line 411 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = row;
#line 411 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = _tmp18_->master;
#line 411 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = _tmp19_->filepath;
#line 411 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = string_sliced_at_last_char (_tmp20_, (gunichar) G_DIR_SEPARATOR, 0);
#line 411 "/home/jens/Source/shotwell/src/Photo.vala"
	basename = _tmp21_;
#line 412 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = basename;
#line 412 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp22_ != NULL) {
#line 3781 "Photo.c"
		const gchar* _tmp23_;
		gchar* _tmp24_;
#line 413 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = basename;
#line 413 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = string_sliced_at (_tmp23_, 1);
#line 413 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (self->priv->file_title);
#line 413 "/home/jens/Source/shotwell/src/Photo.vala"
		self->priv->file_title = _tmp24_;
#line 3792 "Photo.c"
	}
#line 415 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = self->priv->file_title;
#line 415 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = is_string_empty (_tmp25_);
#line 415 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp26_) {
#line 3800 "Photo.c"
		PhotoRow* _tmp27_;
		BackingPhotoRow* _tmp28_;
		const gchar* _tmp29_;
		gchar* _tmp30_;
#line 416 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp27_ = row;
#line 416 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = _tmp27_->master;
#line 416 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_ = _tmp28_->filepath;
#line 416 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = g_strdup (_tmp29_);
#line 416 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (self->priv->file_title);
#line 416 "/home/jens/Source/shotwell/src/Photo.vala"
		self->priv->file_title = _tmp30_;
#line 3817 "Photo.c"
	}
#line 418 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = row;
#line 418 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = _tmp31_->editable_id;
#line 418 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = _tmp32_.id;
#line 418 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp33_ != BACKING_PHOTO_ID_INVALID) {
#line 3827 "Photo.c"
		BackingPhotoRow* e = NULL;
		PhotoRow* _tmp34_;
		BackingPhotoID _tmp35_;
		BackingPhotoRow* _tmp36_;
		BackingPhotoRow* _tmp37_;
#line 419 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp34_ = row;
#line 419 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp35_ = _tmp34_->editable_id;
#line 419 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = photo_get_backing_row (self, &_tmp35_);
#line 419 "/home/jens/Source/shotwell/src/Photo.vala"
		e = _tmp36_;
#line 420 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp37_ = e;
#line 420 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp37_ != NULL) {
#line 3845 "Photo.c"
			BackingPhotoRow* _tmp38_;
			BackingPhotoRow* _tmp39_;
			PhotoBackingReaders* _tmp40_;
			BackingPhotoRow* _tmp41_;
			PhotoFileFormat _tmp42_;
			BackingPhotoRow* _tmp43_;
			const gchar* _tmp44_;
			PhotoFileReader* _tmp45_;
#line 421 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp38_ = e;
#line 421 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp39_ = _backing_photo_row_ref0 (_tmp38_);
#line 421 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (self->priv->editable);
#line 421 "/home/jens/Source/shotwell/src/Photo.vala"
			self->priv->editable = _tmp39_;
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp40_ = self->priv->readers;
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = self->priv->editable;
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = _tmp41_->file_format;
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp43_ = self->priv->editable;
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp44_ = _tmp43_->filepath;
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp45_ = photo_file_format_create_reader (_tmp42_, _tmp44_);
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (_tmp40_->editable);
#line 422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp40_->editable = _tmp45_;
#line 3878 "Photo.c"
		} else {
			{
				PhotoTable* _tmp46_;
				PhotoTable* _tmp47_;
				PhotoRow* _tmp48_;
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = photo_table_get_instance ();
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = _tmp46_;
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = self->row;
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_detach_editable (_tmp47_, _tmp48_, &_inner_error_);
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp47_);
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_inner_error_->domain == DATABASE_ERROR) {
#line 3898 "Photo.c"
						goto __catch268_database_error;
					}
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (e);
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (basename);
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 425 "/home/jens/Source/shotwell/src/Photo.vala"
					return NULL;
#line 3911 "Photo.c"
				}
			}
			goto __finally268;
			__catch268_database_error:
			{
				GError* err = NULL;
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				err = _inner_error_;
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (err);
#line 3924 "Photo.c"
			}
			__finally268:
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (e);
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (basename);
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 424 "/home/jens/Source/shotwell/src/Photo.vala"
				return NULL;
#line 3939 "Photo.c"
			}
#line 432 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_internal_remove_all_transformations (self, FALSE);
#line 3943 "Photo.c"
		}
#line 418 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (e);
#line 3947 "Photo.c"
	}
#line 436 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp49_ = row;
#line 436 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp50_ = _tmp49_->master;
#line 436 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = _tmp50_->file_format;
#line 436 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp51_ == PHOTO_FILE_FORMAT_RAW) {
#line 3957 "Photo.c"
		GeeHashMap* _tmp52_;
		gint _tmp53_;
		RawDeveloper* _tmp54_;
#line 438 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp52_ = gee_hash_map_new (TYPE_RAW_DEVELOPER, NULL, NULL, TYPE_BACKING_PHOTO_ROW, (GBoxedCopyFunc) backing_photo_row_ref, (GDestroyNotify) backing_photo_row_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 438 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (self->priv->developments);
#line 438 "/home/jens/Source/shotwell/src/Photo.vala"
		self->priv->developments = _tmp52_;
#line 439 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp54_ = raw_developer_as_array (&_tmp53_);
#line 3969 "Photo.c"
		{
			RawDeveloper* d_collection = NULL;
			gint d_collection_length1 = 0;
			gint _d_collection_size_ = 0;
			gint d_it = 0;
#line 439 "/home/jens/Source/shotwell/src/Photo.vala"
			d_collection = _tmp54_;
#line 439 "/home/jens/Source/shotwell/src/Photo.vala"
			d_collection_length1 = _tmp53_;
#line 439 "/home/jens/Source/shotwell/src/Photo.vala"
			for (d_it = 0; d_it < _tmp53_; d_it = d_it + 1) {
#line 3981 "Photo.c"
				RawDeveloper d = 0;
#line 439 "/home/jens/Source/shotwell/src/Photo.vala"
				d = d_collection[d_it];
#line 3985 "Photo.c"
				{
					BackingPhotoID id = {0};
					PhotoRow* _tmp55_;
					BackingPhotoID* _tmp56_;
					gint _tmp56__length1;
					RawDeveloper _tmp57_;
					BackingPhotoID _tmp58_;
					BackingPhotoID _tmp59_;
					gint64 _tmp60_;
#line 440 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp55_ = row;
#line 440 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp56_ = _tmp55_->development_ids;
#line 440 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp56__length1 = _tmp55_->development_ids_length1;
#line 440 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp57_ = d;
#line 440 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp58_ = _tmp56_[_tmp57_];
#line 440 "/home/jens/Source/shotwell/src/Photo.vala"
					id = _tmp58_;
#line 441 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp59_ = id;
#line 441 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp60_ = _tmp59_.id;
#line 441 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp60_ != BACKING_PHOTO_ID_INVALID) {
#line 4013 "Photo.c"
						BackingPhotoRow* bpr = NULL;
						BackingPhotoID _tmp61_;
						BackingPhotoRow* _tmp62_;
						BackingPhotoRow* _tmp63_;
#line 442 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp61_ = id;
#line 442 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp62_ = photo_get_backing_row (self, &_tmp61_);
#line 442 "/home/jens/Source/shotwell/src/Photo.vala"
						bpr = _tmp62_;
#line 443 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp63_ = bpr;
#line 443 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp63_ != NULL) {
#line 4028 "Photo.c"
							GeeHashMap* _tmp64_;
							RawDeveloper _tmp65_;
							BackingPhotoRow* _tmp66_;
#line 444 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp64_ = self->priv->developments;
#line 444 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp65_ = d;
#line 444 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp66_ = bpr;
#line 444 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp65_), _tmp66_);
#line 4040 "Photo.c"
						}
#line 441 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (bpr);
#line 4044 "Photo.c"
					}
				}
			}
#line 439 "/home/jens/Source/shotwell/src/Photo.vala"
			d_collection = (g_free (d_collection), NULL);
#line 4050 "Photo.c"
		}
	}
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp68_ = row;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp69_ = _tmp68_->master;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp70_ = _tmp69_->file_format;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp70_ == PHOTO_FILE_FORMAT_RAW) {
#line 4061 "Photo.c"
		GeeHashMap* _tmp71_;
		PhotoRow* _tmp72_;
		RawDeveloper _tmp73_;
		gboolean _tmp74_;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp71_ = self->priv->developments;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp72_ = row;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp73_ = _tmp72_->developer;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp74_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp73_));
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp67_ = _tmp74_;
#line 4076 "Photo.c"
	} else {
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp67_ = FALSE;
#line 4080 "Photo.c"
	}
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp67_) {
#line 4084 "Photo.c"
		BackingPhotoRow* r = NULL;
		GeeHashMap* _tmp75_;
		PhotoRow* _tmp76_;
		RawDeveloper _tmp77_;
		gpointer _tmp78_;
		PhotoBackingReaders* _tmp79_;
		BackingPhotoRow* _tmp80_;
		PhotoFileFormat _tmp81_;
		BackingPhotoRow* _tmp82_;
		const gchar* _tmp83_;
		PhotoFileReader* _tmp84_;
#line 451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp75_ = self->priv->developments;
#line 451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp76_ = row;
#line 451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp77_ = _tmp76_->developer;
#line 451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp78_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp77_));
#line 451 "/home/jens/Source/shotwell/src/Photo.vala"
		r = (BackingPhotoRow*) _tmp78_;
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp79_ = self->priv->readers;
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp80_ = r;
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp81_ = _tmp80_->file_format;
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp82_ = r;
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp83_ = _tmp82_->filepath;
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp84_ = photo_file_format_create_reader (_tmp81_, _tmp83_);
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp79_->developer);
#line 452 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp79_->developer = _tmp84_;
#line 450 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (r);
#line 4124 "Photo.c"
	}
#line 456 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp85_ = self->priv->readers;
#line 456 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp86_ = _tmp85_->editable;
#line 456 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp86_ != NULL) {
#line 4132 "Photo.c"
		BackingPhotoRow* _tmp87_;
		BackingPhotoRow* _tmp88_;
#line 457 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp87_ = self->priv->editable;
#line 457 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp88_ = _backing_photo_row_ref0 (_tmp87_);
#line 457 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (self->backing_photo_row);
#line 457 "/home/jens/Source/shotwell/src/Photo.vala"
		self->backing_photo_row = _tmp88_;
#line 4143 "Photo.c"
	} else {
		PhotoRow* _tmp89_;
		BackingPhotoRow* _tmp90_;
		PhotoFileFormat _tmp91_;
#line 458 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp89_ = row;
#line 458 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp90_ = _tmp89_->master;
#line 458 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp91_ = _tmp90_->file_format;
#line 458 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp91_ != PHOTO_FILE_FORMAT_RAW) {
#line 4156 "Photo.c"
			PhotoRow* _tmp92_;
			BackingPhotoRow* _tmp93_;
			BackingPhotoRow* _tmp94_;
#line 459 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp92_ = self->row;
#line 459 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp93_ = _tmp92_->master;
#line 459 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp94_ = _backing_photo_row_ref0 (_tmp93_);
#line 459 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (self->backing_photo_row);
#line 459 "/home/jens/Source/shotwell/src/Photo.vala"
			self->backing_photo_row = _tmp94_;
#line 4170 "Photo.c"
		} else {
			GeeHashMap* _tmp95_;
			PhotoRow* _tmp96_;
			RawDeveloper _tmp97_;
			gboolean _tmp98_;
#line 463 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp95_ = self->priv->developments;
#line 463 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp96_ = row;
#line 463 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp97_ = _tmp96_->developer;
#line 463 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp98_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp95_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp97_));
#line 463 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp98_) {
#line 4186 "Photo.c"
				GeeHashMap* _tmp99_;
				PhotoRow* _tmp100_;
				RawDeveloper _tmp101_;
				gpointer _tmp102_;
#line 464 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp99_ = self->priv->developments;
#line 464 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp100_ = row;
#line 464 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp101_ = _tmp100_->developer;
#line 464 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp102_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp101_));
#line 464 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (self->backing_photo_row);
#line 464 "/home/jens/Source/shotwell/src/Photo.vala"
				self->backing_photo_row = (BackingPhotoRow*) _tmp102_;
#line 4203 "Photo.c"
			} else {
				PhotoRow* _tmp103_;
				BackingPhotoRow* _tmp104_;
				BackingPhotoRow* _tmp105_;
#line 467 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp103_ = self->row;
#line 467 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp104_ = _tmp103_->master;
#line 467 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp105_ = _backing_photo_row_ref0 (_tmp104_);
#line 467 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (self->backing_photo_row);
#line 467 "/home/jens/Source/shotwell/src/Photo.vala"
				self->backing_photo_row = _tmp105_;
#line 4218 "Photo.c"
			}
		}
	}
#line 471 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp106_ = self->row;
#line 471 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp107_ = _tmp106_->exposure_time;
#line 471 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->cached_exposure_time = _tmp107_;
#line 399 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (basename);
#line 399 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 4232 "Photo.c"
}


void photo_init_photo (void) {
	GeeLinkedList* _tmp0_;
#line 475 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = gee_linked_list_new (PHOTO_TYPE_CACHED_PIXBUF, (GBoxedCopyFunc) photo_cached_pixbuf_ref, (GDestroyNotify) photo_cached_pixbuf_unref, NULL, NULL, NULL);
#line 475 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo_source_pixbuf_cache);
#line 475 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_source_pixbuf_cache = _tmp0_;
#line 4244 "Photo.c"
}


void photo_terminate_photo (void) {
	guint _tmp0_;
#line 479 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo_source_pixbuf_cache);
#line 479 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_source_pixbuf_cache = NULL;
#line 481 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_discard_source_id;
#line 481 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 4258 "Photo.c"
		guint _tmp1_;
#line 482 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = photo_discard_source_id;
#line 482 "/home/jens/Source/shotwell/src/Photo.vala"
		g_source_remove (_tmp1_);
#line 483 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_discard_source_id = (guint) 0;
#line 4266 "Photo.c"
	}
}


static void photo_real_notify_editable_replaced (Photo* self, GFile* old_file, GFile* new_file) {
	GFile* _tmp0_;
	GFile* _tmp1_;
#line 487 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((old_file == NULL) || G_IS_FILE (old_file));
#line 487 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((new_file == NULL) || G_IS_FILE (new_file));
#line 488 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = old_file;
#line 488 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = new_file;
#line 488 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_EDITABLE_REPLACED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 4284 "Photo.c"
}


void photo_notify_editable_replaced (Photo* self, GFile* old_file, GFile* new_file) {
#line 487 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 487 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_editable_replaced (self, old_file, new_file);
#line 4293 "Photo.c"
}


static void photo_real_notify_raw_development_modified (Photo* self) {
#line 492 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_RAW_DEVELOPMENT_MODIFIED_SIGNAL], 0);
#line 4300 "Photo.c"
}


void photo_notify_raw_development_modified (Photo* self) {
#line 491 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 491 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_raw_development_modified (self);
#line 4309 "Photo.c"
}


static void photo_real_notify_baseline_replaced (Photo* self) {
#line 496 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_BASELINE_REPLACED_SIGNAL], 0);
#line 4316 "Photo.c"
}


void photo_notify_baseline_replaced (Photo* self) {
#line 495 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 495 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_baseline_replaced (self);
#line 4325 "Photo.c"
}


static void photo_real_notify_master_reimported (Photo* self, PhotoMetadata* metadata) {
	PhotoMetadata* _tmp0_;
#line 499 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 500 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 500 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_MASTER_REIMPORTED_SIGNAL], 0, _tmp0_);
#line 4337 "Photo.c"
}


void photo_notify_master_reimported (Photo* self, PhotoMetadata* metadata) {
#line 499 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 499 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_master_reimported (self, metadata);
#line 4346 "Photo.c"
}


static void photo_real_notify_editable_reimported (Photo* self, PhotoMetadata* metadata) {
	PhotoMetadata* _tmp0_;
#line 503 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 504 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 504 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_EDITABLE_REIMPORTED_SIGNAL], 0, _tmp0_);
#line 4358 "Photo.c"
}


void photo_notify_editable_reimported (Photo* self, PhotoMetadata* metadata) {
#line 503 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 503 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_editable_reimported (self, metadata);
#line 4367 "Photo.c"
}


static void photo_real_notify_source_reimported (Photo* self, PhotoMetadata* metadata) {
	PhotoMetadata* _tmp0_;
#line 507 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 508 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 508 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_SOURCE_REIMPORTED_SIGNAL], 0, _tmp0_);
#line 4379 "Photo.c"
}


void photo_notify_source_reimported (Photo* self, PhotoMetadata* metadata) {
#line 507 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 507 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_source_reimported (self, metadata);
#line 4388 "Photo.c"
}


static void photo_real_notify_baseline_reimported (Photo* self, PhotoMetadata* metadata) {
	PhotoMetadata* _tmp0_;
#line 511 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 512 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 512 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, photo_signals[PHOTO_BASELINE_REIMPORTED_SIGNAL], 0, _tmp0_);
#line 4400 "Photo.c"
}


void photo_notify_baseline_reimported (Photo* self, PhotoMetadata* metadata) {
#line 511 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 511 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->notify_baseline_reimported (self, metadata);
#line 4409 "Photo.c"
}


static gboolean photo_real_internal_delete_backing (DataSource* base, GError** error) {
	Photo * self;
	gboolean result = FALSE;
	gboolean ret = FALSE;
	GFile* file = NULL;
	PhotoFileFormat _tmp8_;
	GFile* _tmp12_;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp25_ = FALSE;
	gboolean _tmp26_;
	GError * _inner_error_ = NULL;
#line 515 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 516 "/home/jens/Source/shotwell/src/Photo.vala"
	ret = TRUE;
#line 517 "/home/jens/Source/shotwell/src/Photo.vala"
	file = NULL;
#line 4430 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 4437 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
#line 519 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 519 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 519 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 4447 "Photo.c"
				PhotoBackingReaders* _tmp3_;
				PhotoFileReader* _tmp4_;
				GFile* _tmp5_;
#line 520 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 520 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->editable;
#line 520 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 520 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 520 "/home/jens/Source/shotwell/src/Photo.vala"
				file = _tmp5_;
#line 4461 "Photo.c"
			}
		}
		__finally269:
		{
			PhotoBackingReaders* _tmp6_;
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->priv->readers;
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 4471 "Photo.c"
		}
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4475 "Photo.c"
			gboolean _tmp7_ = FALSE;
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 518 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp7_;
#line 4483 "Photo.c"
		}
	}
#line 523 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_detach_editable (self, TRUE, FALSE, TRUE);
#line 525 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo_get_master_file_format (self);
#line 525 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_ == PHOTO_FILE_FORMAT_RAW) {
#line 4492 "Photo.c"
		gint _tmp9_;
		RawDeveloper* _tmp10_;
#line 526 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = raw_developer_as_array (&_tmp9_);
#line 4497 "Photo.c"
		{
			RawDeveloper* d_collection = NULL;
			gint d_collection_length1 = 0;
			gint _d_collection_size_ = 0;
			gint d_it = 0;
#line 526 "/home/jens/Source/shotwell/src/Photo.vala"
			d_collection = _tmp10_;
#line 526 "/home/jens/Source/shotwell/src/Photo.vala"
			d_collection_length1 = _tmp9_;
#line 526 "/home/jens/Source/shotwell/src/Photo.vala"
			for (d_it = 0; d_it < _tmp9_; d_it = d_it + 1) {
#line 4509 "Photo.c"
				RawDeveloper d = 0;
#line 526 "/home/jens/Source/shotwell/src/Photo.vala"
				d = d_collection[d_it];
#line 4513 "Photo.c"
				{
					RawDeveloper _tmp11_;
#line 527 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = d;
#line 527 "/home/jens/Source/shotwell/src/Photo.vala"
					photo_delete_raw_development (self, _tmp11_);
#line 4520 "Photo.c"
				}
			}
#line 526 "/home/jens/Source/shotwell/src/Photo.vala"
			d_collection = (g_free (d_collection), NULL);
#line 4525 "Photo.c"
		}
	}
#line 531 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = file;
#line 531 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_ != NULL) {
#line 4532 "Photo.c"
		{
			gboolean _tmp13_ = FALSE;
			GFile* _tmp14_;
			gboolean _tmp15_;
#line 533 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = file;
#line 533 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = g_file_trash (_tmp14_, NULL, &_inner_error_);
#line 533 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = _tmp15_;
#line 533 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4545 "Photo.c"
				goto __catch270_g_error;
			}
#line 533 "/home/jens/Source/shotwell/src/Photo.vala"
			ret = _tmp13_;
#line 4550 "Photo.c"
		}
		goto __finally270;
		__catch270_g_error:
		{
			GError* err = NULL;
			GFile* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
			GError* _tmp21_;
			const gchar* _tmp22_;
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 535 "/home/jens/Source/shotwell/src/Photo.vala"
			ret = FALSE;
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = file;
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = g_file_get_path (_tmp16_);
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = _tmp17_;
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = _tmp19_;
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = err;
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = _tmp21_->message;
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			g_message ("Photo.vala:536: Unable to move editable %s for %s to trash: %s", _tmp18_, _tmp20_, _tmp22_);
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp20_);
#line 536 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp18_);
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 4591 "Photo.c"
		}
		__finally270:
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4596 "Photo.c"
			gboolean _tmp23_ = FALSE;
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 532 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp23_;
#line 4604 "Photo.c"
		}
	}
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = DATA_SOURCE_CLASS (photo_parent_class)->internal_delete_backing (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource), TYPE_DATA_SOURCE, DataSource), &_inner_error_);
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = _tmp26_;
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4613 "Photo.c"
		gboolean _tmp27_ = FALSE;
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp27_;
#line 4621 "Photo.c"
	}
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp25_) {
#line 4625 "Photo.c"
		gboolean _tmp28_;
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = ret;
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = _tmp28_;
#line 4631 "Photo.c"
	} else {
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = FALSE;
#line 4635 "Photo.c"
	}
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp24_;
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 542 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 4643 "Photo.c"
}


static BackingPhotoRow* photo_get_backing_row (Photo* self, BackingPhotoID* id) {
	BackingPhotoRow* result = NULL;
	BackingPhotoID _tmp0_;
	gint64 _tmp1_;
	BackingPhotoRow* backing_row = NULL;
	BackingPhotoRow* _tmp13_;
	GError * _inner_error_ = NULL;
#line 547 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 547 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 548 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = *id;
#line 548 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_.id;
#line 548 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == BACKING_PHOTO_ID_INVALID) {
#line 549 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 549 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 4668 "Photo.c"
	}
#line 551 "/home/jens/Source/shotwell/src/Photo.vala"
	backing_row = NULL;
#line 4672 "Photo.c"
	{
		BackingPhotoRow* _tmp2_ = NULL;
		BackingPhotoTable* _tmp3_;
		BackingPhotoTable* _tmp4_;
		BackingPhotoID _tmp5_;
		BackingPhotoRow* _tmp6_;
		BackingPhotoRow* _tmp7_;
		BackingPhotoRow* _tmp8_;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = backing_photo_table_get_instance ();
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp3_;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = *id;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = backing_photo_table_fetch (_tmp4_, &_tmp5_, &_inner_error_);
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_database_table_unref0 (_tmp4_);
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp7_;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 4699 "Photo.c"
				goto __catch271_database_error;
			}
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing_row);
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 4710 "Photo.c"
		}
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = _tmp2_;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = NULL;
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing_row);
#line 553 "/home/jens/Source/shotwell/src/Photo.vala"
		backing_row = _tmp8_;
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (_tmp2_);
#line 4722 "Photo.c"
	}
	goto __finally271;
	__catch271_database_error:
	{
		GError* err = NULL;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GError* _tmp11_;
		const gchar* _tmp12_;
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 555 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 555 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = _tmp9_;
#line 555 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = err;
#line 555 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp11_->message;
#line 555 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:555: Unable to fetch backing state for %s: %s", _tmp10_, _tmp12_);
#line 555 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp10_);
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 4750 "Photo.c"
	}
	__finally271:
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing_row);
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 552 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 4763 "Photo.c"
	}
#line 558 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = backing_row;
#line 558 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp13_ == NULL) {
#line 4769 "Photo.c"
		{
			BackingPhotoTable* _tmp14_;
			BackingPhotoTable* _tmp15_;
			BackingPhotoID _tmp16_;
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = backing_photo_table_get_instance ();
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = _tmp14_;
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = *id;
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
			backing_photo_table_remove (_tmp15_, &_tmp16_, &_inner_error_);
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp15_);
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 4788 "Photo.c"
					goto __catch272_database_error;
				}
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing_row);
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 560 "/home/jens/Source/shotwell/src/Photo.vala"
				return NULL;
#line 4799 "Photo.c"
			}
		}
		goto __finally272;
		__catch272_database_error:
		{
			GError* err = NULL;
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 4812 "Photo.c"
		}
		__finally272:
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing_row);
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 559 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 4825 "Photo.c"
		}
#line 564 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 564 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing_row);
#line 564 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 4833 "Photo.c"
	}
#line 567 "/home/jens/Source/shotwell/src/Photo.vala"
	result = backing_row;
#line 567 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 4839 "Photo.c"
}


gboolean photo_is_raw_developer_complete (Photo* self, RawDeveloper d) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 572 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 4848 "Photo.c"
	{
		GeeHashMap* _tmp0_;
		gboolean _tmp13_ = FALSE;
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->developments;
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_developments);
#line 4856 "Photo.c"
		{
			gboolean _tmp1_ = FALSE;
			GeeHashMap* _tmp2_;
			RawDeveloper _tmp3_;
			gboolean _tmp4_;
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->developments;
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = d;
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp3_));
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp4_) {
#line 4870 "Photo.c"
				GeeHashMap* _tmp5_;
				RawDeveloper _tmp6_;
				gpointer _tmp7_;
				BackingPhotoRow* _tmp8_;
				const gchar* _tmp9_;
				gboolean _tmp10_;
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = self->priv->developments;
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = d;
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp6_));
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = (BackingPhotoRow*) _tmp7_;
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tmp8_->filepath;
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = g_file_test (_tmp9_, G_FILE_TEST_EXISTS);
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp10_;
#line 575 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp8_);
#line 4893 "Photo.c"
			} else {
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = FALSE;
#line 4897 "Photo.c"
			}
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 4901 "Photo.c"
			{
				GeeHashMap* _tmp11_;
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = self->priv->developments;
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 4908 "Photo.c"
			}
#line 574 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 4912 "Photo.c"
		}
		__finally273:
		{
			GeeHashMap* _tmp12_;
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = self->priv->developments;
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 4921 "Photo.c"
		}
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 573 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp13_;
#line 4929 "Photo.c"
	}
}


gboolean photo_is_raw_developer_available (Photo* self, RawDeveloper d) {
	gboolean result = FALSE;
	RawDeveloper _tmp7_;
	GError * _inner_error_ = NULL;
#line 580 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 4940 "Photo.c"
	{
		GeeHashMap* _tmp0_;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->developments;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_developments);
#line 4947 "Photo.c"
		{
			GeeHashMap* _tmp1_;
			RawDeveloper _tmp2_;
			gboolean _tmp3_;
#line 582 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->developments;
#line 582 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = d;
#line 582 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp2_));
#line 582 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_) {
#line 583 "/home/jens/Source/shotwell/src/Photo.vala"
				result = TRUE;
#line 4962 "Photo.c"
				{
					GeeHashMap* _tmp4_;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp4_ = self->priv->developments;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 4969 "Photo.c"
				}
#line 583 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 4973 "Photo.c"
			}
		}
		__finally274:
		{
			GeeHashMap* _tmp5_;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->priv->developments;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 4983 "Photo.c"
		}
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4987 "Photo.c"
			gboolean _tmp6_ = FALSE;
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 581 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp6_;
#line 4995 "Photo.c"
		}
	}
#line 586 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = d;
#line 586 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp7_) {
#line 586 "/home/jens/Source/shotwell/src/Photo.vala"
		case RAW_DEVELOPER_SHOTWELL:
#line 5004 "Photo.c"
		{
#line 588 "/home/jens/Source/shotwell/src/Photo.vala"
			result = TRUE;
#line 588 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 5010 "Photo.c"
		}
#line 586 "/home/jens/Source/shotwell/src/Photo.vala"
		case RAW_DEVELOPER_CAMERA:
#line 5014 "Photo.c"
		{
#line 591 "/home/jens/Source/shotwell/src/Photo.vala"
			result = FALSE;
#line 591 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 5020 "Photo.c"
		}
#line 586 "/home/jens/Source/shotwell/src/Photo.vala"
		case RAW_DEVELOPER_EMBEDDED:
#line 5024 "Photo.c"
		{
			{
				PhotoMetadata* meta = NULL;
				PhotoMetadata* _tmp8_;
				guint num_previews = 0U;
				PhotoMetadata* _tmp9_;
				guint _tmp10_;
				guint _tmp11_;
#line 595 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = photo_get_master_metadata (self, &_inner_error_);
#line 595 "/home/jens/Source/shotwell/src/Photo.vala"
				meta = _tmp8_;
#line 595 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5039 "Photo.c"
					goto __catch275_g_error;
				}
#line 596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = meta;
#line 596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = photo_metadata_get_preview_count (_tmp9_);
#line 596 "/home/jens/Source/shotwell/src/Photo.vala"
				num_previews = _tmp10_;
#line 598 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = num_previews;
#line 598 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp11_ > ((guint) 0)) {
#line 5052 "Photo.c"
					PhotoPreview* prev = NULL;
					PhotoMetadata* _tmp12_;
					guint _tmp13_;
					PhotoPreview* _tmp14_;
					PhotoPreview* _tmp15_;
					Dimensions dims = {0};
					PhotoPreview* _tmp16_;
					Dimensions _tmp17_ = {0};
					gint _tmp18_ = 0;
					Dimensions _tmp19_;
					gint _tmp20_;
					Dimensions _tmp21_;
					gint _tmp22_;
					gint preview_major_axis = 0;
					gint _tmp27_;
#line 599 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = meta;
#line 599 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = num_previews;
#line 599 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = photo_metadata_get_preview (_tmp12_, _tmp13_ - 1);
#line 599 "/home/jens/Source/shotwell/src/Photo.vala"
					prev = _tmp14_;
#line 602 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = prev;
#line 602 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp15_ == NULL) {
#line 603 "/home/jens/Source/shotwell/src/Photo.vala"
						result = FALSE;
#line 603 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 603 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 603 "/home/jens/Source/shotwell/src/Photo.vala"
						return result;
#line 5088 "Photo.c"
					}
#line 605 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = prev;
#line 605 "/home/jens/Source/shotwell/src/Photo.vala"
					photo_preview_get_pixel_dimensions (_tmp16_, &_tmp17_);
#line 605 "/home/jens/Source/shotwell/src/Photo.vala"
					dims = _tmp17_;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = dims;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp20_ = _tmp19_.width;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp21_ = dims;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp22_ = _tmp21_.height;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp20_ > _tmp22_) {
#line 5106 "Photo.c"
						Dimensions _tmp23_;
						gint _tmp24_;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp23_ = dims;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp24_ = _tmp23_.width;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp18_ = _tmp24_;
#line 5115 "Photo.c"
					} else {
						Dimensions _tmp25_;
						gint _tmp26_;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp25_ = dims;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp26_ = _tmp25_.height;
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp18_ = _tmp26_;
#line 5125 "Photo.c"
					}
#line 608 "/home/jens/Source/shotwell/src/Photo.vala"
					preview_major_axis = _tmp18_;
#line 609 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp27_ = preview_major_axis;
#line 609 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp27_ < PHOTO_MIN_EMBEDDED_SIZE) {
#line 610 "/home/jens/Source/shotwell/src/Photo.vala"
						result = FALSE;
#line 610 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 610 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 610 "/home/jens/Source/shotwell/src/Photo.vala"
						return result;
#line 5141 "Photo.c"
					}
#line 613 "/home/jens/Source/shotwell/src/Photo.vala"
					result = TRUE;
#line 613 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 613 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 613 "/home/jens/Source/shotwell/src/Photo.vala"
					return result;
#line 5151 "Photo.c"
				}
#line 617 "/home/jens/Source/shotwell/src/Photo.vala"
				result = FALSE;
#line 617 "/home/jens/Source/shotwell/src/Photo.vala"
				_media_metadata_unref0 (meta);
#line 617 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 5159 "Photo.c"
			}
			goto __finally275;
			__catch275_g_error:
			{
				GError* e = NULL;
				GError* _tmp28_;
				const gchar* _tmp29_;
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
				e = _inner_error_;
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 619 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = e;
#line 619 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = _tmp28_->message;
#line 619 "/home/jens/Source/shotwell/src/Photo.vala"
				g_debug ("Photo.vala:619: Error accessing embedded preview. Message: %s", _tmp29_);
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (e);
#line 5179 "Photo.c"
			}
			__finally275:
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5184 "Photo.c"
				gboolean _tmp30_ = FALSE;
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 594 "/home/jens/Source/shotwell/src/Photo.vala"
				return _tmp30_;
#line 5192 "Photo.c"
			}
#line 621 "/home/jens/Source/shotwell/src/Photo.vala"
			result = FALSE;
#line 621 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 5198 "Photo.c"
		}
		default:
		{
#line 624 "/home/jens/Source/shotwell/src/Photo.vala"
			g_assert_not_reached ();
#line 5204 "Photo.c"
		}
	}
}


void photo_add_backing_photo_for_development (Photo* self, RawDeveloper d, BackingPhotoRow* bpr, gboolean notify, GError** error) {
	PhotoRow* _tmp0_;
	RawDeveloper _tmp1_;
	BackingPhotoRow* _tmp2_;
	gboolean _tmp8_;
	GError * _inner_error_ = NULL;
#line 631 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 631 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (bpr));
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->row;
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = d;
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = bpr;
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_import_developed_backing_photo (_tmp0_, _tmp1_, _tmp2_, &_inner_error_);
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 632 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 5234 "Photo.c"
	}
	{
		GeeHashMap* _tmp3_;
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = self->priv->developments;
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_developments);
#line 5242 "Photo.c"
		{
			GeeHashMap* _tmp4_;
			RawDeveloper _tmp5_;
			BackingPhotoRow* _tmp6_;
#line 634 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->priv->developments;
#line 634 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = d;
#line 634 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = bpr;
#line 634 "/home/jens/Source/shotwell/src/Photo.vala"
			gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp5_), _tmp6_);
#line 5255 "Photo.c"
		}
		__finally276:
		{
			GeeHashMap* _tmp7_;
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->priv->developments;
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 5264 "Photo.c"
		}
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 633 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 5272 "Photo.c"
		}
	}
#line 637 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = notify;
#line 637 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_) {
#line 5279 "Photo.c"
		Alteration* _tmp9_;
		Alteration* _tmp10_;
#line 638 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = alteration_new ("image", "developer");
#line 638 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = _tmp9_;
#line 638 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp10_);
#line 638 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp10_);
#line 5290 "Photo.c"
	}
}


void photo_import_developed_backing_photo (PhotoRow* row, RawDeveloper d, BackingPhotoRow* bpr, GError** error) {
	GFile* file = NULL;
	BackingPhotoRow* _tmp0_;
	const gchar* _tmp1_;
	GFile* _tmp2_;
	GFileInfo* info = NULL;
	GFile* _tmp3_;
	GFileInfo* _tmp4_;
	GTimeVal timestamp = {0};
	GFileInfo* _tmp5_;
	GTimeVal _tmp6_ = {0};
	PhotoFileInterrogator* interrogator = NULL;
	GFile* _tmp7_;
	PhotoFileInterrogator* _tmp8_;
	PhotoFileInterrogator* _tmp9_;
	DetectedPhotoInformation* detected = NULL;
	PhotoFileInterrogator* _tmp10_;
	DetectedPhotoInformation* _tmp11_;
	gboolean _tmp12_ = FALSE;
	DetectedPhotoInformation* _tmp13_;
	BackingPhotoRow* _tmp16_;
	DetectedPhotoInformation* _tmp17_;
	Dimensions _tmp18_;
	BackingPhotoRow* _tmp19_;
	GFileInfo* _tmp20_;
	gint64 _tmp21_;
	BackingPhotoRow* _tmp22_;
	GTimeVal _tmp23_;
	glong _tmp24_;
	Orientation _tmp25_ = 0;
	DetectedPhotoInformation* _tmp26_;
	PhotoMetadata* _tmp27_;
	BackingPhotoRow* _tmp31_;
	BackingPhotoTable* _tmp32_;
	BackingPhotoTable* _tmp33_;
	BackingPhotoRow* _tmp34_;
	PhotoTable* _tmp35_;
	PhotoTable* _tmp36_;
	PhotoRow* _tmp37_;
	RawDeveloper _tmp38_;
	BackingPhotoRow* _tmp39_;
	BackingPhotoID _tmp40_;
	GError * _inner_error_ = NULL;
#line 641 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 641 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (bpr));
#line 643 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = bpr;
#line 643 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->filepath;
#line 643 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = g_file_new_for_path (_tmp1_);
#line 643 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp2_;
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = file;
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = g_file_query_info (_tmp3_, DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
	info = _tmp4_;
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 644 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 5364 "Photo.c"
	}
#line 646 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = info;
#line 646 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_info_get_modification_time (_tmp5_, &_tmp6_);
#line 646 "/home/jens/Source/shotwell/src/Photo.vala"
	timestamp = _tmp6_;
#line 648 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = file;
#line 648 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo_file_interrogator_new (_tmp7_, PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL);
#line 648 "/home/jens/Source/shotwell/src/Photo.vala"
	interrogator = _tmp8_;
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = interrogator;
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_interrogator_interrogate (_tmp9_, &_inner_error_);
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 650 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 5394 "Photo.c"
	}
#line 652 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = interrogator;
#line 652 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = photo_file_interrogator_get_detected_photo_information (_tmp10_);
#line 652 "/home/jens/Source/shotwell/src/Photo.vala"
	detected = _tmp11_;
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = detected;
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp13_ == NULL) {
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = TRUE;
#line 5408 "Photo.c"
	} else {
		PhotoFileInterrogator* _tmp14_;
		gboolean _tmp15_;
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = interrogator;
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = photo_file_interrogator_get_is_photo_corrupted (_tmp14_);
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp15_;
#line 5418 "Photo.c"
	}
#line 653 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_) {
#line 656 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 656 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 656 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 656 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 656 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 5432 "Photo.c"
	}
#line 659 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = bpr;
#line 659 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = detected;
#line 659 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = _tmp17_->image_dim;
#line 659 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_->dim = _tmp18_;
#line 660 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = bpr;
#line 660 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = info;
#line 660 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = g_file_info_get_size (_tmp20_);
#line 660 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_->filesize = _tmp21_;
#line 661 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = bpr;
#line 661 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = timestamp;
#line 661 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = _tmp23_.tv_sec;
#line 661 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_->timestamp = (time_t) _tmp24_;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = detected;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = _tmp26_->metadata;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp27_ != NULL) {
#line 5464 "Photo.c"
		DetectedPhotoInformation* _tmp28_;
		PhotoMetadata* _tmp29_;
		Orientation _tmp30_;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = detected;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_ = _tmp28_->metadata;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = photo_metadata_get_orientation (_tmp29_);
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp30_;
#line 5476 "Photo.c"
	} else {
#line 663 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = ORIENTATION_TOP_LEFT;
#line 5480 "Photo.c"
	}
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = bpr;
#line 662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_->original_orientation = _tmp25_;
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = backing_photo_table_get_instance ();
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = _tmp32_;
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = bpr;
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
	backing_photo_table_add (_tmp33_, _tmp34_, &_inner_error_);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp33_);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 666 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 5510 "Photo.c"
	}
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = photo_table_get_instance ();
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = _tmp35_;
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = row;
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = d;
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = bpr;
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = _tmp39_->id;
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_table_update_raw_development (_tmp36_, _tmp37_, _tmp38_, &_tmp40_, &_inner_error_);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp36_);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 667 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 5542 "Photo.c"
	}
#line 641 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 641 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_interrogator_unref0 (interrogator);
#line 641 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (info);
#line 641 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 5552 "Photo.c"
}


static void photo_develop_photo (Photo* self, RawDeveloper d, gboolean notify) {
	gboolean wrote_img_to_disk = FALSE;
	BackingPhotoRow* bps = NULL;
	RawDeveloper _tmp0_;
	GError * _inner_error_ = NULL;
#line 672 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 673 "/home/jens/Source/shotwell/src/Photo.vala"
	wrote_img_to_disk = FALSE;
#line 674 "/home/jens/Source/shotwell/src/Photo.vala"
	bps = NULL;
#line 676 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = d;
#line 676 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp0_) {
#line 676 "/home/jens/Source/shotwell/src/Photo.vala"
		case RAW_DEVELOPER_SHOTWELL:
#line 5573 "Photo.c"
		{
			{
				BackingPhotoRow* _tmp1_ = NULL;
				RawDeveloper _tmp2_;
				PhotoRow* _tmp3_;
				BackingPhotoRow* _tmp4_;
				const gchar* _tmp5_;
				BackingPhotoRow* _tmp6_;
				BackingPhotoRow* _tmp7_;
				GdkPixbuf* pix = NULL;
				GdkPixbuf* _tmp14_;
				PhotoFileWriter* writer = NULL;
				BackingPhotoRow* _tmp21_;
				const gchar* _tmp22_;
				PhotoFileWriter* _tmp23_;
				PhotoFileWriter* _tmp24_;
				GdkPixbuf* _tmp25_;
				PhotoMetadata* meta = NULL;
				PhotoMetadata* _tmp26_;
				PhotoFileMetadataWriter* mwriter = NULL;
				BackingPhotoRow* _tmp27_;
				const gchar* _tmp28_;
				PhotoFileMetadataWriter* _tmp29_;
				PhotoFileMetadataWriter* _tmp30_;
				PhotoMetadata* _tmp31_;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp2_ = d;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->master;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_->filepath;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = raw_developer_create_backing_row_for_development (_tmp2_, _tmp5_, NULL, &_inner_error_);
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp6_;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5613 "Photo.c"
					goto __catch277_g_error;
				}
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = _tmp1_;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = NULL;
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bps);
#line 680 "/home/jens/Source/shotwell/src/Photo.vala"
				bps = _tmp7_;
#line 681 "/home/jens/Source/shotwell/src/Photo.vala"
				pix = NULL;
#line 5626 "Photo.c"
				{
					PhotoBackingReaders* _tmp8_;
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp8_ = self->priv->readers;
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_lock (&self->priv->__lock_readers);
#line 5633 "Photo.c"
					{
						GdkPixbuf* _tmp9_ = NULL;
						Scaling _tmp10_ = {0};
						GdkPixbuf* _tmp11_;
						GdkPixbuf* _tmp12_;
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						scaling_for_original (&_tmp10_);
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp11_ = photo_get_master_pixbuf (self, &_tmp10_, FALSE, &_inner_error_);
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp9_ = _tmp11_;
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5647 "Photo.c"
							goto __finally278;
						}
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp12_ = _tmp9_;
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp9_ = NULL;
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (pix);
#line 687 "/home/jens/Source/shotwell/src/Photo.vala"
						pix = _tmp12_;
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_tmp9_);
#line 5660 "Photo.c"
					}
					__finally278:
					{
						PhotoBackingReaders* _tmp13_;
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp13_ = self->priv->readers;
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 5669 "Photo.c"
					}
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (pix);
#line 682 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (_tmp1_);
#line 5677 "Photo.c"
						goto __catch277_g_error;
					}
				}
#line 690 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = pix;
#line 690 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp14_ == NULL) {
#line 691 "/home/jens/Source/shotwell/src/Photo.vala"
					g_debug ("Photo.vala:691: Could not get preview pixbuf");
#line 692 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pix);
#line 692 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp1_);
#line 5691 "Photo.c"
					{
						gboolean _tmp15_;
#line 716 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp15_ = wrote_img_to_disk;
#line 716 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp15_) {
#line 5698 "Photo.c"
							{
								RawDeveloper _tmp16_;
								BackingPhotoRow* _tmp17_;
								gboolean _tmp18_;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp16_ = d;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp17_ = bps;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp18_ = notify;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_add_backing_photo_for_development (self, _tmp16_, _tmp17_, _tmp18_, &_inner_error_);
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5713 "Photo.c"
									goto __catch279_g_error;
								}
#line 721 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_notify_raw_development_modified (self);
#line 5718 "Photo.c"
							}
							goto __finally279;
							__catch279_g_error:
							{
								GError* e = NULL;
								GError* _tmp19_;
								const gchar* _tmp20_;
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
								e = _inner_error_;
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
								_inner_error_ = NULL;
#line 723 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp19_ = e;
#line 723 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp20_ = _tmp19_->message;
#line 723 "/home/jens/Source/shotwell/src/Photo.vala"
								g_debug ("Photo.vala:723: Error adding backing photo as development. Message: %s", _tmp20_);
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_error_free0 (e);
#line 5738 "Photo.c"
							}
							__finally279:
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5743 "Photo.c"
								goto __catch277_g_error;
							}
						}
					}
#line 692 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (bps);
#line 692 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 5752 "Photo.c"
				}
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = bps;
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = _tmp21_->filepath;
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = photo_file_format_create_writer (PHOTO_FILE_FORMAT_JFIF, _tmp22_, &_inner_error_);
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
				writer = _tmp23_;
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pix);
#line 696 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp1_);
#line 5768 "Photo.c"
					goto __catch277_g_error;
				}
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = writer;
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = pix;
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_file_writer_write (_tmp24_, _tmp25_, JPEG_QUALITY_HIGH, &_inner_error_);
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (writer);
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pix);
#line 697 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp1_);
#line 5785 "Photo.c"
					goto __catch277_g_error;
				}
#line 705 "/home/jens/Source/shotwell/src/Photo.vala"
				wrote_img_to_disk = TRUE;
#line 710 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = photo_get_master_metadata (self, &_inner_error_);
#line 710 "/home/jens/Source/shotwell/src/Photo.vala"
				meta = _tmp26_;
#line 710 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 710 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (writer);
#line 710 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pix);
#line 710 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp1_);
#line 5802 "Photo.c"
					goto __catch277_g_error;
				}
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = bps;
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = _tmp27_->filepath;
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = photo_file_format_create_metadata_writer (PHOTO_FILE_FORMAT_JFIF, _tmp28_, &_inner_error_);
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
				mwriter = _tmp29_;
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (writer);
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pix);
#line 711 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp1_);
#line 5823 "Photo.c"
					goto __catch277_g_error;
				}
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = mwriter;
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = meta;
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_file_metadata_writer_write_metadata (_tmp30_, _tmp31_, &_inner_error_);
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (mwriter);
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (writer);
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pix);
#line 712 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp1_);
#line 5844 "Photo.c"
					goto __catch277_g_error;
				}
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (mwriter);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_media_metadata_unref0 (meta);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (writer);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (pix);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp1_);
#line 5857 "Photo.c"
			}
			goto __finally277;
			__catch277_g_error:
			{
				GError* err = NULL;
				GError* _tmp32_;
				const gchar* _tmp33_;
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				err = _inner_error_;
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 714 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = err;
#line 714 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = _tmp32_->message;
#line 714 "/home/jens/Source/shotwell/src/Photo.vala"
				g_debug ("Photo.vala:714: Error developing photo: %s", _tmp33_);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (err);
#line 5877 "Photo.c"
			}
			__finally277:
			{
				gboolean _tmp34_;
#line 716 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = wrote_img_to_disk;
#line 716 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp34_) {
#line 5886 "Photo.c"
					{
						RawDeveloper _tmp35_;
						BackingPhotoRow* _tmp36_;
						gboolean _tmp37_;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp35_ = d;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp36_ = bps;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp37_ = notify;
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
						photo_add_backing_photo_for_development (self, _tmp35_, _tmp36_, _tmp37_, &_inner_error_);
#line 719 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5901 "Photo.c"
							goto __catch280_g_error;
						}
#line 721 "/home/jens/Source/shotwell/src/Photo.vala"
						photo_notify_raw_development_modified (self);
#line 5906 "Photo.c"
					}
					goto __finally280;
					__catch280_g_error:
					{
						GError* e = NULL;
						GError* _tmp38_;
						const gchar* _tmp39_;
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						e = _inner_error_;
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						_inner_error_ = NULL;
#line 723 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp38_ = e;
#line 723 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp39_ = _tmp38_->message;
#line 723 "/home/jens/Source/shotwell/src/Photo.vala"
						g_debug ("Photo.vala:723: Error adding backing photo as development. Message: %s", _tmp39_);
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_error_free0 (e);
#line 5926 "Photo.c"
					}
					__finally280:
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (bps);
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						g_clear_error (&_inner_error_);
#line 717 "/home/jens/Source/shotwell/src/Photo.vala"
						return;
#line 5939 "Photo.c"
					}
				}
			}
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bps);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 678 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 5953 "Photo.c"
			}
#line 729 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 5957 "Photo.c"
		}
#line 676 "/home/jens/Source/shotwell/src/Photo.vala"
		case RAW_DEVELOPER_CAMERA:
#line 5961 "Photo.c"
		{
#line 733 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 5965 "Photo.c"
		}
#line 676 "/home/jens/Source/shotwell/src/Photo.vala"
		case RAW_DEVELOPER_EMBEDDED:
#line 5969 "Photo.c"
		{
			{
				PhotoMetadata* meta = NULL;
				PhotoMetadata* _tmp40_;
				guint c = 0U;
				PhotoMetadata* _tmp41_;
				guint _tmp42_;
				guint _tmp43_;
				PhotoPreview* prev = NULL;
				PhotoMetadata* _tmp50_;
				guint _tmp51_;
				PhotoPreview* _tmp52_;
				PhotoPreview* _tmp53_;
				GBytes* pix = NULL;
				PhotoPreview* _tmp60_;
				GBytes* _tmp61_;
				GBytes* _tmp62_;
				BackingPhotoRow* _tmp69_ = NULL;
				RawDeveloper _tmp70_;
				PhotoRow* _tmp71_;
				BackingPhotoRow* _tmp72_;
				const gchar* _tmp73_;
				BackingPhotoRow* _tmp74_;
				BackingPhotoRow* _tmp75_;
				gboolean _tmp76_ = FALSE;
				GBytes* _tmp77_;
				gboolean _tmp78_;
				PhotoFileMetadataWriter* mwriter = NULL;
				BackingPhotoRow* _tmp100_;
				const gchar* _tmp101_;
				PhotoFileMetadataWriter* _tmp102_;
				PhotoFileMetadataWriter* _tmp103_;
				PhotoMetadata* _tmp104_;
#line 738 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = photo_get_master_metadata (self, &_inner_error_);
#line 738 "/home/jens/Source/shotwell/src/Photo.vala"
				meta = _tmp40_;
#line 738 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6009 "Photo.c"
					goto __catch281_g_error;
				}
#line 739 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp41_ = meta;
#line 739 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp42_ = photo_metadata_get_preview_count (_tmp41_);
#line 739 "/home/jens/Source/shotwell/src/Photo.vala"
				c = _tmp42_;
#line 740 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = c;
#line 740 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp43_ <= ((guint) 0)) {
#line 741 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6024 "Photo.c"
					{
						gboolean _tmp44_;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp44_ = wrote_img_to_disk;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp44_) {
#line 6031 "Photo.c"
							{
								RawDeveloper _tmp45_;
								BackingPhotoRow* _tmp46_;
								gboolean _tmp47_;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp45_ = d;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp46_ = bps;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp47_ = notify;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_add_backing_photo_for_development (self, _tmp45_, _tmp46_, _tmp47_, &_inner_error_);
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6046 "Photo.c"
									goto __catch282_g_error;
								}
#line 791 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_notify_raw_development_modified (self);
#line 6051 "Photo.c"
							}
							goto __finally282;
							__catch282_g_error:
							{
								GError* e = NULL;
								GError* _tmp48_;
								const gchar* _tmp49_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								e = _inner_error_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								_inner_error_ = NULL;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp48_ = e;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp49_ = _tmp48_->message;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								g_debug ("Photo.vala:793: Error adding backing photo as development. Message: %s", _tmp49_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_error_free0 (e);
#line 6071 "Photo.c"
							}
							__finally282:
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6076 "Photo.c"
								goto __catch281_g_error;
							}
						}
					}
#line 741 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (bps);
#line 741 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 6085 "Photo.c"
				}
#line 742 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp50_ = meta;
#line 742 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp51_ = c;
#line 742 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp52_ = photo_metadata_get_preview (_tmp50_, _tmp51_ - 1);
#line 742 "/home/jens/Source/shotwell/src/Photo.vala"
				prev = _tmp52_;
#line 743 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp53_ = prev;
#line 743 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp53_ == NULL) {
#line 744 "/home/jens/Source/shotwell/src/Photo.vala"
					g_debug ("Photo.vala:744: Could not get preview from metadata");
#line 745 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 745 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6105 "Photo.c"
					{
						gboolean _tmp54_;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp54_ = wrote_img_to_disk;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp54_) {
#line 6112 "Photo.c"
							{
								RawDeveloper _tmp55_;
								BackingPhotoRow* _tmp56_;
								gboolean _tmp57_;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp55_ = d;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp56_ = bps;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp57_ = notify;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_add_backing_photo_for_development (self, _tmp55_, _tmp56_, _tmp57_, &_inner_error_);
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6127 "Photo.c"
									goto __catch283_g_error;
								}
#line 791 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_notify_raw_development_modified (self);
#line 6132 "Photo.c"
							}
							goto __finally283;
							__catch283_g_error:
							{
								GError* e = NULL;
								GError* _tmp58_;
								const gchar* _tmp59_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								e = _inner_error_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								_inner_error_ = NULL;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp58_ = e;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp59_ = _tmp58_->message;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								g_debug ("Photo.vala:793: Error adding backing photo as development. Message: %s", _tmp59_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_error_free0 (e);
#line 6152 "Photo.c"
							}
							__finally283:
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6157 "Photo.c"
								goto __catch281_g_error;
							}
						}
					}
#line 745 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (bps);
#line 745 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 6166 "Photo.c"
				}
#line 748 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp60_ = prev;
#line 748 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp61_ = photo_preview_flatten (_tmp60_, &_inner_error_);
#line 748 "/home/jens/Source/shotwell/src/Photo.vala"
				pix = _tmp61_;
#line 748 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 748 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 748 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6180 "Photo.c"
					goto __catch281_g_error;
				}
#line 749 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp62_ = pix;
#line 749 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp62_ == NULL) {
#line 750 "/home/jens/Source/shotwell/src/Photo.vala"
					g_debug ("Photo.vala:750: Could not get preview pixbuf");
#line 751 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_bytes_unref0 (pix);
#line 751 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 751 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6195 "Photo.c"
					{
						gboolean _tmp63_;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp63_ = wrote_img_to_disk;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp63_) {
#line 6202 "Photo.c"
							{
								RawDeveloper _tmp64_;
								BackingPhotoRow* _tmp65_;
								gboolean _tmp66_;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp64_ = d;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp65_ = bps;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp66_ = notify;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_add_backing_photo_for_development (self, _tmp64_, _tmp65_, _tmp66_, &_inner_error_);
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6217 "Photo.c"
									goto __catch284_g_error;
								}
#line 791 "/home/jens/Source/shotwell/src/Photo.vala"
								photo_notify_raw_development_modified (self);
#line 6222 "Photo.c"
							}
							goto __finally284;
							__catch284_g_error:
							{
								GError* e = NULL;
								GError* _tmp67_;
								const gchar* _tmp68_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								e = _inner_error_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								_inner_error_ = NULL;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp67_ = e;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp68_ = _tmp67_->message;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
								g_debug ("Photo.vala:793: Error adding backing photo as development. Message: %s", _tmp68_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_error_free0 (e);
#line 6242 "Photo.c"
							}
							__finally284:
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6247 "Photo.c"
								goto __catch281_g_error;
							}
						}
					}
#line 751 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (bps);
#line 751 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 6256 "Photo.c"
				}
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp70_ = d;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp71_ = self->row;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp72_ = _tmp71_->master;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp73_ = _tmp72_->filepath;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp74_ = raw_developer_create_backing_row_for_development (_tmp70_, _tmp73_, NULL, &_inner_error_);
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp69_ = _tmp74_;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_bytes_unref0 (pix);
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6278 "Photo.c"
					goto __catch281_g_error;
				}
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp75_ = _tmp69_;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp69_ = NULL;
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bps);
#line 755 "/home/jens/Source/shotwell/src/Photo.vala"
				bps = _tmp75_;
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp77_ = pix;
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp78_ = jpeg_is_jpeg_bytes (_tmp77_, &_inner_error_);
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp76_ = _tmp78_;
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp69_);
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_bytes_unref0 (pix);
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6305 "Photo.c"
					goto __catch281_g_error;
				}
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp76_) {
#line 6310 "Photo.c"
					GFile* outfile = NULL;
					BackingPhotoRow* _tmp79_;
					const gchar* _tmp80_;
					GFile* _tmp81_;
					GFile* _tmp82_;
					GBytes* _tmp83_;
					gsize _tmp84_;
					guint8* _tmp85_;
#line 760 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp79_ = bps;
#line 760 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp80_ = _tmp79_->filepath;
#line 760 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp81_ = g_file_new_for_path (_tmp80_);
#line 760 "/home/jens/Source/shotwell/src/Photo.vala"
					outfile = _tmp81_;
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp82_ = outfile;
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp83_ = pix;
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp85_ = g_bytes_get_data (_tmp83_, &_tmp84_);
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
					g_file_replace_contents (_tmp82_, _tmp85_, (gsize) _tmp84_, NULL, FALSE, G_FILE_CREATE_NONE, NULL, NULL, &_inner_error_);
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (outfile);
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (_tmp69_);
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_bytes_unref0 (pix);
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 761 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 6347 "Photo.c"
						goto __catch281_g_error;
					}
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (outfile);
#line 6352 "Photo.c"
				} else {
					GdkPixbuf* pixbuf = NULL;
					PhotoPreview* _tmp86_;
					GdkPixbuf* _tmp87_;
					GdkPixbuf* _tmp88_;
					PhotoFileWriter* writer = NULL;
					BackingPhotoRow* _tmp95_;
					const gchar* _tmp96_;
					PhotoFileWriter* _tmp97_;
					PhotoFileWriter* _tmp98_;
					GdkPixbuf* _tmp99_;
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp86_ = prev;
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp87_ = photo_preview_get_pixbuf (_tmp86_, &_inner_error_);
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
					pixbuf = _tmp87_;
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (_tmp69_);
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_bytes_unref0 (pix);
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 764 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 6380 "Photo.c"
						goto __catch281_g_error;
					}
#line 765 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp88_ = pixbuf;
#line 765 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp88_ == NULL) {
#line 766 "/home/jens/Source/shotwell/src/Photo.vala"
						g_debug ("Photo.vala:766: Could not get preview pixbuf");
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (pixbuf);
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (_tmp69_);
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_bytes_unref0 (pix);
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 6399 "Photo.c"
						{
							gboolean _tmp89_;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp89_ = wrote_img_to_disk;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
							if (_tmp89_) {
#line 6406 "Photo.c"
								{
									RawDeveloper _tmp90_;
									BackingPhotoRow* _tmp91_;
									gboolean _tmp92_;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp90_ = d;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp91_ = bps;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp92_ = notify;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
									photo_add_backing_photo_for_development (self, _tmp90_, _tmp91_, _tmp92_, &_inner_error_);
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
									if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6421 "Photo.c"
										goto __catch285_g_error;
									}
#line 791 "/home/jens/Source/shotwell/src/Photo.vala"
									photo_notify_raw_development_modified (self);
#line 6426 "Photo.c"
								}
								goto __finally285;
								__catch285_g_error:
								{
									GError* e = NULL;
									GError* _tmp93_;
									const gchar* _tmp94_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
									e = _inner_error_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
									_inner_error_ = NULL;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp93_ = e;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp94_ = _tmp93_->message;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
									g_debug ("Photo.vala:793: Error adding backing photo as development. Message: %s", _tmp94_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
									_g_error_free0 (e);
#line 6446 "Photo.c"
								}
								__finally285:
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6451 "Photo.c"
									goto __catch281_g_error;
								}
							}
						}
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (bps);
#line 767 "/home/jens/Source/shotwell/src/Photo.vala"
						return;
#line 6460 "Photo.c"
					}
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp95_ = bps;
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp96_ = _tmp95_->filepath;
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp97_ = photo_file_format_create_writer (PHOTO_FILE_FORMAT_JFIF, _tmp96_, &_inner_error_);
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
					writer = _tmp97_;
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (pixbuf);
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (_tmp69_);
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_bytes_unref0 (pix);
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 770 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 6482 "Photo.c"
						goto __catch281_g_error;
					}
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp98_ = writer;
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp99_ = pixbuf;
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
					photo_file_writer_write (_tmp98_, _tmp99_, JPEG_QUALITY_HIGH, &_inner_error_);
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_file_adapter_unref0 (writer);
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (pixbuf);
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (_tmp69_);
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_bytes_unref0 (pix);
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_preview_unref0 (prev);
#line 771 "/home/jens/Source/shotwell/src/Photo.vala"
						_media_metadata_unref0 (meta);
#line 6505 "Photo.c"
						goto __catch281_g_error;
					}
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (writer);
#line 759 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pixbuf);
#line 6512 "Photo.c"
				}
#line 777 "/home/jens/Source/shotwell/src/Photo.vala"
				wrote_img_to_disk = TRUE;
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp100_ = bps;
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp101_ = _tmp100_->filepath;
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp102_ = photo_file_format_create_metadata_writer (PHOTO_FILE_FORMAT_JFIF, _tmp101_, &_inner_error_);
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
				mwriter = _tmp102_;
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp69_);
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_bytes_unref0 (pix);
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 780 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6534 "Photo.c"
					goto __catch281_g_error;
				}
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp103_ = mwriter;
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp104_ = meta;
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_file_metadata_writer_write_metadata (_tmp103_, _tmp104_, &_inner_error_);
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (mwriter);
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp69_);
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_bytes_unref0 (pix);
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_preview_unref0 (prev);
#line 781 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (meta);
#line 6555 "Photo.c"
					goto __catch281_g_error;
				}
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (mwriter);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp69_);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_bytes_unref0 (pix);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_preview_unref0 (prev);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_media_metadata_unref0 (meta);
#line 6568 "Photo.c"
			}
			goto __finally281;
			__catch281_g_error:
			{
				GError* e = NULL;
				GError* _tmp105_;
				const gchar* _tmp106_;
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				e = _inner_error_;
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 783 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp105_ = e;
#line 783 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp106_ = _tmp105_->message;
#line 783 "/home/jens/Source/shotwell/src/Photo.vala"
				g_debug ("Photo.vala:783: Error accessing embedded preview. Message: %s", _tmp106_);
#line 784 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (e);
#line 6588 "Photo.c"
				{
					gboolean _tmp107_;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp107_ = wrote_img_to_disk;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp107_) {
#line 6595 "Photo.c"
						{
							RawDeveloper _tmp108_;
							BackingPhotoRow* _tmp109_;
							gboolean _tmp110_;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp108_ = d;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp109_ = bps;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp110_ = notify;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
							photo_add_backing_photo_for_development (self, _tmp108_, _tmp109_, _tmp110_, &_inner_error_);
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6610 "Photo.c"
								goto __catch286_g_error;
							}
#line 791 "/home/jens/Source/shotwell/src/Photo.vala"
							photo_notify_raw_development_modified (self);
#line 6615 "Photo.c"
						}
						goto __finally286;
						__catch286_g_error:
						{
							GError* e = NULL;
							GError* _tmp111_;
							const gchar* _tmp112_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							e = _inner_error_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							_inner_error_ = NULL;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp111_ = e;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp112_ = _tmp111_->message;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
							g_debug ("Photo.vala:793: Error adding backing photo as development. Message: %s", _tmp112_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_error_free0 (e);
#line 6635 "Photo.c"
						}
						__finally286:
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
							_backing_photo_row_unref0 (bps);
#line 6642 "Photo.c"
						}
					}
				}
#line 784 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bps);
#line 784 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 6650 "Photo.c"
			}
			__finally281:
			{
				gboolean _tmp113_;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp113_ = wrote_img_to_disk;
#line 786 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp113_) {
#line 6659 "Photo.c"
					{
						RawDeveloper _tmp114_;
						BackingPhotoRow* _tmp115_;
						gboolean _tmp116_;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp114_ = d;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp115_ = bps;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp116_ = notify;
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
						photo_add_backing_photo_for_development (self, _tmp114_, _tmp115_, _tmp116_, &_inner_error_);
#line 789 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6674 "Photo.c"
							goto __catch287_g_error;
						}
#line 791 "/home/jens/Source/shotwell/src/Photo.vala"
						photo_notify_raw_development_modified (self);
#line 6679 "Photo.c"
					}
					goto __finally287;
					__catch287_g_error:
					{
						GError* e = NULL;
						GError* _tmp117_;
						const gchar* _tmp118_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						e = _inner_error_;
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						_inner_error_ = NULL;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp117_ = e;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp118_ = _tmp117_->message;
#line 793 "/home/jens/Source/shotwell/src/Photo.vala"
						g_debug ("Photo.vala:793: Error adding backing photo as development. Message: %s", _tmp118_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_error_free0 (e);
#line 6699 "Photo.c"
					}
					__finally287:
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						_backing_photo_row_unref0 (bps);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						g_clear_error (&_inner_error_);
#line 787 "/home/jens/Source/shotwell/src/Photo.vala"
						return;
#line 6712 "Photo.c"
					}
				}
			}
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bps);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 736 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 6726 "Photo.c"
			}
#line 798 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 6730 "Photo.c"
		}
		default:
		{
#line 801 "/home/jens/Source/shotwell/src/Photo.vala"
			g_assert_not_reached ();
#line 6736 "Photo.c"
		}
	}
#line 672 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (bps);
#line 6741 "Photo.c"
}


void photo_set_default_raw_developer (Photo* self, RawDeveloper d) {
	GError * _inner_error_ = NULL;
#line 806 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 6749 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 6756 "Photo.c"
		{
			PhotoRow* _tmp1_;
			RawDeveloper _tmp2_;
#line 808 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 808 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = d;
#line 808 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_->developer = _tmp2_;
#line 6766 "Photo.c"
		}
		__finally288:
		{
			PhotoRow* _tmp3_;
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 6775 "Photo.c"
		}
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 807 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 6785 "Photo.c"
		}
	}
}


void photo_set_raw_developer (Photo* self, RawDeveloper d, gboolean notify) {
	PhotoFileFormat _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_;
	gboolean _tmp51_;
	GError * _inner_error_ = NULL;
#line 813 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 814 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_master_file_format (self);
#line 814 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != PHOTO_FILE_FORMAT_RAW) {
#line 815 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 6807 "Photo.c"
	}
#line 820 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_is_raw_developer_available (self, RAW_DEVELOPER_CAMERA);
#line 820 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 6813 "Photo.c"
		RawDeveloper _tmp3_;
#line 820 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = d;
#line 820 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp3_ == RAW_DEVELOPER_EMBEDDED;
#line 6819 "Photo.c"
	} else {
#line 820 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = FALSE;
#line 6823 "Photo.c"
	}
#line 820 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 821 "/home/jens/Source/shotwell/src/Photo.vala"
		d = RAW_DEVELOPER_CAMERA;
#line 6829 "Photo.c"
	}
#line 825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_is_raw_developer_available (self, RAW_DEVELOPER_EMBEDDED);
#line 825 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp5_) {
#line 6835 "Photo.c"
		RawDeveloper _tmp6_;
#line 825 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = d;
#line 825 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp6_ != RAW_DEVELOPER_CAMERA;
#line 6841 "Photo.c"
	} else {
#line 825 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = FALSE;
#line 6845 "Photo.c"
	}
#line 825 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp4_) {
#line 826 "/home/jens/Source/shotwell/src/Photo.vala"
		d = RAW_DEVELOPER_SHOTWELL;
#line 6851 "Photo.c"
	}
	{
		GeeHashMap* _tmp7_;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = self->priv->developments;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_developments);
#line 6859 "Photo.c"
		{
			RawDeveloper stale_raw_developer = 0;
			PhotoRow* _tmp8_;
			RawDeveloper _tmp9_;
			RawDeveloper _tmp10_;
			gboolean _tmp11_;
			GeeHashMap* _tmp14_;
			RawDeveloper _tmp15_;
			gboolean _tmp16_;
			PhotoRow* _tmp18_;
			RawDeveloper _tmp19_;
			GeeHashMap* _tmp20_;
			RawDeveloper _tmp21_;
			gpointer _tmp22_;
			PhotoBackingReaders* _tmp23_;
			BackingPhotoRow* _tmp24_;
			PhotoFileFormat _tmp25_;
			BackingPhotoRow* _tmp26_;
			const gchar* _tmp27_;
			PhotoFileReader* _tmp28_;
			BackingPhotoRow* _tmp33_;
			Orientation _tmp34_;
			gboolean _tmp44_ = FALSE;
			RawDeveloper _tmp45_;
#line 829 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = self->row;
#line 829 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_->developer;
#line 829 "/home/jens/Source/shotwell/src/Photo.vala"
			stale_raw_developer = _tmp9_;
#line 832 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = d;
#line 832 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = photo_is_raw_developer_complete (self, _tmp10_);
#line 832 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp11_) {
#line 6896 "Photo.c"
				RawDeveloper _tmp12_;
				gboolean _tmp13_;
#line 833 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = d;
#line 833 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = notify;
#line 833 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_develop_photo (self, _tmp12_, _tmp13_);
#line 6905 "Photo.c"
			}
#line 835 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = self->priv->developments;
#line 835 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = d;
#line 835 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp15_));
#line 835 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp16_) {
#line 6915 "Photo.c"
				{
					GeeHashMap* _tmp17_;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = self->priv->developments;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 6922 "Photo.c"
				}
#line 836 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 6926 "Photo.c"
			}
#line 839 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_revert_to_master (self, FALSE);
#line 842 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = self->row;
#line 842 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = d;
#line 842 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_->developer = _tmp19_;
#line 843 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = self->priv->developments;
#line 843 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = d;
#line 843 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp21_));
#line 843 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (self->backing_photo_row);
#line 843 "/home/jens/Source/shotwell/src/Photo.vala"
			self->backing_photo_row = (BackingPhotoRow*) _tmp22_;
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_ = self->priv->readers;
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = self->backing_photo_row;
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp25_ = _tmp24_->file_format;
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = self->backing_photo_row;
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = _tmp26_->filepath;
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp28_ = photo_file_format_create_reader (_tmp25_, _tmp27_);
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (_tmp23_->developer);
#line 844 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_->developer = _tmp28_;
#line 6962 "Photo.c"
			{
				GdkPixbuf* _tmp29_;
				GdkPixbuf* _tmp30_;
#line 847 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = photo_get_prefetched_copy (self, &_inner_error_);
#line 847 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = _tmp29_;
#line 847 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp30_);
#line 847 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6974 "Photo.c"
					goto __catch290_g_error;
				}
			}
			goto __finally290;
			__catch290_g_error:
			{
				GError* e = NULL;
#line 846 "/home/jens/Source/shotwell/src/Photo.vala"
				e = _inner_error_;
#line 846 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 850 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (e);
#line 6988 "Photo.c"
				{
					GeeHashMap* _tmp31_;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31_ = self->priv->developments;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 6995 "Photo.c"
				}
#line 850 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 6999 "Photo.c"
			}
			__finally290:
#line 846 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7004 "Photo.c"
				{
					GeeHashMap* _tmp32_;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp32_ = self->priv->developments;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7011 "Photo.c"
				}
#line 846 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 846 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 846 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 7019 "Photo.c"
			}
#line 853 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp33_ = self->backing_photo_row;
#line 853 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp34_ = _tmp33_->original_orientation;
#line 853 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_set_orientation (self, _tmp34_);
#line 7027 "Photo.c"
			{
				PhotoTable* _tmp35_;
				PhotoTable* _tmp36_;
				PhotoRow* _tmp37_;
				RawDeveloper _tmp38_;
				BackingPhotoRow* _tmp39_;
				BackingPhotoID _tmp40_;
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = photo_table_get_instance ();
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = _tmp35_;
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = self->row;
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = d;
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = self->backing_photo_row;
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = _tmp39_->id;
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_update_raw_development (_tmp36_, _tmp37_, _tmp38_, &_tmp40_, &_inner_error_);
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp36_);
#line 856 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7053 "Photo.c"
					goto __catch291_g_error;
				}
			}
			goto __finally291;
			__catch291_g_error:
			{
				GError* e = NULL;
				GError* _tmp41_;
				const gchar* _tmp42_;
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
				e = _inner_error_;
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 858 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp41_ = e;
#line 858 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp42_ = _tmp41_->message;
#line 858 "/home/jens/Source/shotwell/src/Photo.vala"
				g_warning ("Photo.vala:858: Error updating database: %s", _tmp42_);
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (e);
#line 7075 "Photo.c"
			}
			__finally291:
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7080 "Photo.c"
				{
					GeeHashMap* _tmp43_;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp43_ = self->priv->developments;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7087 "Photo.c"
				}
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 855 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 7095 "Photo.c"
			}
#line 865 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp45_ = stale_raw_developer;
#line 865 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp45_ != RAW_DEVELOPER_CAMERA) {
#line 7101 "Photo.c"
				RawDeveloper _tmp46_;
				PhotoRow* _tmp47_;
				RawDeveloper _tmp48_;
#line 866 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = stale_raw_developer;
#line 866 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = self->row;
#line 866 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = _tmp47_->developer;
#line 866 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = _tmp46_ != _tmp48_;
#line 7113 "Photo.c"
			} else {
#line 865 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = FALSE;
#line 7117 "Photo.c"
			}
#line 865 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp44_) {
#line 7121 "Photo.c"
				RawDeveloper _tmp49_;
#line 869 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp49_ = stale_raw_developer;
#line 869 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_delete_raw_development (self, _tmp49_);
#line 7127 "Photo.c"
			}
		}
		__finally289:
		{
			GeeHashMap* _tmp50_;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp50_ = self->priv->developments;
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7137 "Photo.c"
		}
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 828 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 7147 "Photo.c"
		}
	}
#line 876 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = notify;
#line 876 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp51_) {
#line 7154 "Photo.c"
		Alteration* _tmp52_;
		Alteration* _tmp53_;
#line 877 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp52_ = alteration_new ("image", "developer");
#line 877 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp53_ = _tmp52_;
#line 877 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp53_);
#line 877 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp53_);
#line 7165 "Photo.c"
	}
#line 878 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_discard_prefetched (self);
#line 7169 "Photo.c"
}


RawDeveloper photo_get_raw_developer (Photo* self) {
	RawDeveloper result = 0;
	PhotoRow* _tmp0_;
	RawDeveloper _tmp1_;
#line 881 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 882 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->row;
#line 882 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->developer;
#line 882 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 882 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 7187 "Photo.c"
}


static gboolean photo_delete_raw_development (Photo* self, RawDeveloper d) {
	gboolean result = FALSE;
	gboolean ret = FALSE;
	GError * _inner_error_ = NULL;
#line 887 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 888 "/home/jens/Source/shotwell/src/Photo.vala"
	ret = FALSE;
#line 7199 "Photo.c"
	{
		GeeHashMap* _tmp0_;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->developments;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_developments);
#line 7206 "Photo.c"
		{
			GeeHashMap* _tmp1_;
			RawDeveloper _tmp2_;
			gboolean _tmp3_;
			gchar* _tmp5_;
			gchar* _tmp6_;
			RawDeveloper _tmp7_;
			gchar* _tmp8_;
			gchar* _tmp9_;
			BackingPhotoRow* bpr = NULL;
			GeeHashMap* _tmp10_;
			RawDeveloper _tmp11_;
			gpointer _tmp12_;
			BackingPhotoRow* _tmp13_;
			const gchar* _tmp14_;
			GeeHashMap* _tmp39_;
			RawDeveloper _tmp40_;
			gboolean _tmp41_;
#line 891 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->developments;
#line 891 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = d;
#line 891 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp2_));
#line 891 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp3_) {
#line 892 "/home/jens/Source/shotwell/src/Photo.vala"
				result = FALSE;
#line 7235 "Photo.c"
				{
					GeeHashMap* _tmp4_;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp4_ = self->priv->developments;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7242 "Photo.c"
				}
#line 892 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 7246 "Photo.c"
			}
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_;
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = d;
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = raw_developer_to_string (_tmp7_);
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_;
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			g_debug ("Photo.vala:896: Delete raw development: %s %s", _tmp6_, _tmp9_);
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp9_);
#line 896 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp6_);
#line 897 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = self->priv->developments;
#line 897 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = d;
#line 897 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp11_));
#line 897 "/home/jens/Source/shotwell/src/Photo.vala"
			bpr = (BackingPhotoRow*) _tmp12_;
#line 898 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = bpr;
#line 898 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = _tmp13_->filepath;
#line 898 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp14_ != NULL) {
#line 7278 "Photo.c"
				GFile* f = NULL;
				BackingPhotoRow* _tmp15_;
				const gchar* _tmp16_;
				GFile* _tmp17_;
#line 899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = bpr;
#line 899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = _tmp15_->filepath;
#line 899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = g_file_new_for_path (_tmp16_);
#line 899 "/home/jens/Source/shotwell/src/Photo.vala"
				f = _tmp17_;
#line 7291 "Photo.c"
				{
					RawDeveloper _tmp18_;
#line 901 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = d;
#line 901 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp18_ == RAW_DEVELOPER_CAMERA) {
#line 7298 "Photo.c"
						GFile* _tmp19_;
#line 902 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp19_ = f;
#line 902 "/home/jens/Source/shotwell/src/Photo.vala"
						g_file_trash (_tmp19_, NULL, &_inner_error_);
#line 902 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7306 "Photo.c"
							goto __catch293_g_error;
						}
					} else {
						GFile* _tmp20_;
#line 904 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp20_ = f;
#line 904 "/home/jens/Source/shotwell/src/Photo.vala"
						g_file_delete (_tmp20_, NULL, &_inner_error_);
#line 904 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7317 "Photo.c"
							goto __catch293_g_error;
						}
					}
				}
				goto __finally293;
				__catch293_g_error:
				{
					GError* e = NULL;
					BackingPhotoRow* _tmp21_;
					const gchar* _tmp22_;
					GError* _tmp23_;
					const gchar* _tmp24_;
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					e = _inner_error_;
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					_inner_error_ = NULL;
#line 906 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp21_ = bpr;
#line 906 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp22_ = _tmp21_->filepath;
#line 906 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp23_ = e;
#line 906 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp24_ = _tmp23_->message;
#line 906 "/home/jens/Source/shotwell/src/Photo.vala"
					g_warning ("Photo.vala:906: Unable to delete RAW development: %s error: %s", _tmp22_, _tmp24_);
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_error_free0 (e);
#line 7346 "Photo.c"
				}
				__finally293:
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7351 "Photo.c"
					gboolean _tmp26_ = FALSE;
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (f);
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (bpr);
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (f);
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (bpr);
#line 7361 "Photo.c"
					{
						GeeHashMap* _tmp25_;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp25_ = self->priv->developments;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7368 "Photo.c"
					}
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 900 "/home/jens/Source/shotwell/src/Photo.vala"
					return _tmp26_;
#line 7376 "Photo.c"
				}
#line 898 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (f);
#line 7380 "Photo.c"
			}
			{
				PhotoTable* _tmp27_;
				PhotoTable* _tmp28_;
				PhotoRow* _tmp29_;
				RawDeveloper _tmp30_;
				BackingPhotoTable* _tmp31_;
				BackingPhotoTable* _tmp32_;
				BackingPhotoRow* _tmp33_;
				BackingPhotoID _tmp34_;
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = photo_table_get_instance ();
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = _tmp27_;
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = self->row;
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = d;
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_remove_development (_tmp28_, _tmp29_, _tmp30_, &_inner_error_);
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp28_);
#line 912 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7405 "Photo.c"
					goto __catch294_g_error;
				}
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = backing_photo_table_get_instance ();
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = _tmp31_;
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = bpr;
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = _tmp33_->id;
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				backing_photo_table_remove (_tmp32_, &_tmp34_, &_inner_error_);
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp32_);
#line 913 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7422 "Photo.c"
					goto __catch294_g_error;
				}
			}
			goto __finally294;
			__catch294_g_error:
			{
				GError* e = NULL;
				GError* _tmp35_;
				const gchar* _tmp36_;
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				e = _inner_error_;
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 915 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = e;
#line 915 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = _tmp35_->message;
#line 915 "/home/jens/Source/shotwell/src/Photo.vala"
				g_warning ("Photo.vala:915: Database error while deleting RAW development: %s", _tmp36_);
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (e);
#line 7444 "Photo.c"
			}
			__finally294:
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7449 "Photo.c"
				gboolean _tmp38_ = FALSE;
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bpr);
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (bpr);
#line 7455 "Photo.c"
				{
					GeeHashMap* _tmp37_;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp37_ = self->priv->developments;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7462 "Photo.c"
				}
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 911 "/home/jens/Source/shotwell/src/Photo.vala"
				return _tmp38_;
#line 7470 "Photo.c"
			}
#line 918 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp39_ = self->priv->developments;
#line 918 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp40_ = d;
#line 918 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp40_), NULL);
#line 918 "/home/jens/Source/shotwell/src/Photo.vala"
			ret = _tmp41_;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (bpr);
#line 7482 "Photo.c"
		}
		__finally292:
		{
			GeeHashMap* _tmp42_;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = self->priv->developments;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7491 "Photo.c"
		}
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7495 "Photo.c"
			gboolean _tmp43_ = FALSE;
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 890 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp43_;
#line 7503 "Photo.c"
		}
	}
#line 921 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_notify_raw_development_modified (self);
#line 922 "/home/jens/Source/shotwell/src/Photo.vala"
	result = ret;
#line 922 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 7512 "Photo.c"
}


void photo_redevelop_raw (Photo* self, RawDeveloper d) {
	GError * _inner_error_ = NULL;
#line 926 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 7520 "Photo.c"
	{
		GeeHashMap* _tmp0_;
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->developments;
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_developments);
#line 7527 "Photo.c"
		{
			RawDeveloper _tmp1_;
			RawDeveloper dev = 0;
			RawDeveloper _tmp2_;
			RawDeveloper _tmp3_;
			RawDeveloper _tmp4_;
#line 928 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = d;
#line 928 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_delete_raw_development (self, _tmp1_);
#line 929 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = d;
#line 929 "/home/jens/Source/shotwell/src/Photo.vala"
			dev = _tmp2_;
#line 930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = dev;
#line 930 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_ == RAW_DEVELOPER_CAMERA) {
#line 931 "/home/jens/Source/shotwell/src/Photo.vala"
				dev = RAW_DEVELOPER_EMBEDDED;
#line 7548 "Photo.c"
			}
#line 933 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = dev;
#line 933 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_set_raw_developer (self, _tmp4_, TRUE);
#line 7554 "Photo.c"
		}
		__finally295:
		{
			GeeHashMap* _tmp5_;
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->priv->developments;
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_developments);
#line 7563 "Photo.c"
		}
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 927 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 7573 "Photo.c"
		}
	}
}


static void _vala_array_add89 (BackingFileState** * array, int* length, int* size, BackingFileState* value) {
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (BackingFileState*, *array, (*size) + 1);
#line 7586 "Photo.c"
	}
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 7592 "Photo.c"
}


static void _vala_array_add90 (BackingFileState** * array, int* length, int* size, BackingFileState* value) {
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (BackingFileState*, *array, (*size) + 1);
#line 7603 "Photo.c"
	}
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 7609 "Photo.c"
}


static void _vala_array_add91 (BackingFileState** * array, int* length, int* size, BackingFileState* value) {
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (BackingFileState*, *array, (*size) + 1);
#line 7620 "Photo.c"
	}
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 7626 "Photo.c"
}


static BackingFileState** photo_real_get_backing_files_state (MediaSource* base, int* result_length1) {
	Photo * self;
	BackingFileState** result = NULL;
	BackingFileState** backing = NULL;
	BackingFileState** _tmp0_;
	gint backing_length1;
	gint _backing_size_;
	BackingFileState** _tmp27_;
	gint _tmp27__length1;
	GError * _inner_error_ = NULL;
#line 937 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 938 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = g_new0 (BackingFileState*, 0 + 1);
#line 938 "/home/jens/Source/shotwell/src/Photo.vala"
	backing = _tmp0_;
#line 938 "/home/jens/Source/shotwell/src/Photo.vala"
	backing_length1 = 0;
#line 938 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_size_ = backing_length1;
#line 7650 "Photo.c"
	{
		PhotoRow* _tmp1_;
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = self->row;
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 7657 "Photo.c"
		{
			BackingFileState** _tmp2_;
			gint _tmp2__length1;
			PhotoRow* _tmp3_;
			BackingPhotoRow* _tmp4_;
			PhotoRow* _tmp5_;
			const gchar* _tmp6_;
			BackingFileState* _tmp7_;
			gboolean _tmp8_;
			gboolean _tmp12_;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = backing;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2__length1 = backing_length1;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = _tmp3_->master;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_->md5;
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = backing_file_state_new_from_photo_row (_tmp4_, _tmp6_);
#line 940 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add89 (&backing, &backing_length1, &_backing_size_, _tmp7_);
#line 941 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = photo_has_editable (self);
#line 941 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp8_) {
#line 7688 "Photo.c"
				BackingFileState** _tmp9_;
				gint _tmp9__length1;
				BackingPhotoRow* _tmp10_;
				BackingFileState* _tmp11_;
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = backing;
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9__length1 = backing_length1;
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = self->priv->editable;
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = backing_file_state_new_from_photo_row (_tmp10_, NULL);
#line 942 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_array_add90 (&backing, &backing_length1, &_backing_size_, _tmp11_);
#line 7703 "Photo.c"
			}
#line 944 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo_is_developed (self);
#line 944 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp12_) {
#line 7709 "Photo.c"
				GeeCollection* dev_rows = NULL;
				GeeCollection* _tmp13_;
				GeeCollection* _tmp14_;
#line 945 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = photo_get_raw_development_photo_rows (self);
#line 945 "/home/jens/Source/shotwell/src/Photo.vala"
				dev_rows = _tmp13_;
#line 946 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = dev_rows;
#line 946 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp14_ != NULL) {
#line 7721 "Photo.c"
					{
						GeeIterator* _r_it = NULL;
						GeeCollection* _tmp15_;
						GeeIterator* _tmp16_;
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp15_ = dev_rows;
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp16_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_ITERABLE, GeeIterable));
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
						_r_it = _tmp16_;
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 7734 "Photo.c"
							GeeIterator* _tmp17_;
							gboolean _tmp18_;
							BackingPhotoRow* r = NULL;
							GeeIterator* _tmp19_;
							gpointer _tmp20_;
							BackingPhotoRow* _tmp21_;
							const gchar* _tmp22_;
							BackingFileState** _tmp23_;
							gint _tmp23__length1;
							BackingPhotoRow* _tmp24_;
							BackingFileState* _tmp25_;
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp17_ = _r_it;
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp18_ = gee_iterator_next (_tmp17_);
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp18_) {
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 7754 "Photo.c"
							}
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp19_ = _r_it;
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp20_ = gee_iterator_get (_tmp19_);
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							r = (BackingPhotoRow*) _tmp20_;
#line 948 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp21_ = r;
#line 948 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp22_ = _tmp21_->filepath;
#line 948 "/home/jens/Source/shotwell/src/Photo.vala"
							g_debug ("Photo.vala:948: adding: %s", _tmp22_);
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp23_ = backing;
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp23__length1 = backing_length1;
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp24_ = r;
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp25_ = backing_file_state_new_from_photo_row (_tmp24_, NULL);
#line 949 "/home/jens/Source/shotwell/src/Photo.vala"
							_vala_array_add91 (&backing, &backing_length1, &_backing_size_, _tmp25_);
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
							_backing_photo_row_unref0 (r);
#line 7780 "Photo.c"
						}
#line 947 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_r_it);
#line 7784 "Photo.c"
					}
				}
#line 944 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (dev_rows);
#line 7789 "Photo.c"
			}
		}
		__finally296:
		{
			PhotoRow* _tmp26_;
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = self->row;
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 7799 "Photo.c"
		}
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
			backing = (_vala_array_free (backing, backing_length1, (GDestroyNotify) backing_file_state_unref), NULL);
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 939 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 7811 "Photo.c"
		}
	}
#line 955 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = backing;
#line 955 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27__length1 = backing_length1;
#line 955 "/home/jens/Source/shotwell/src/Photo.vala"
	if (result_length1) {
#line 955 "/home/jens/Source/shotwell/src/Photo.vala"
		*result_length1 = _tmp27__length1;
#line 7822 "Photo.c"
	}
#line 955 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp27_;
#line 955 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 7828 "Photo.c"
}


static PhotoFileReader* photo_get_backing_reader (Photo* self, BackingFetchMode mode) {
	PhotoFileReader* result = NULL;
	BackingFetchMode _tmp0_;
#line 958 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 959 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = mode;
#line 959 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp0_) {
#line 959 "/home/jens/Source/shotwell/src/Photo.vala"
		case BACKING_FETCH_MODE_MASTER:
#line 7843 "Photo.c"
		{
			PhotoFileReader* _tmp1_;
#line 961 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_get_master_reader (self);
#line 961 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 961 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 7852 "Photo.c"
		}
#line 959 "/home/jens/Source/shotwell/src/Photo.vala"
		case BACKING_FETCH_MODE_BASELINE:
#line 7856 "Photo.c"
		{
			PhotoFileReader* _tmp2_;
#line 964 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = photo_get_baseline_reader (self);
#line 964 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 964 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 7865 "Photo.c"
		}
#line 959 "/home/jens/Source/shotwell/src/Photo.vala"
		case BACKING_FETCH_MODE_SOURCE:
#line 7869 "Photo.c"
		{
			PhotoFileReader* _tmp3_;
#line 967 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = photo_get_source_reader (self);
#line 967 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 967 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 7878 "Photo.c"
		}
#line 959 "/home/jens/Source/shotwell/src/Photo.vala"
		case BACKING_FETCH_MODE_UNMODIFIED:
#line 7882 "Photo.c"
		{
			PhotoFileFormat _tmp4_;
#line 970 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = photo_get_master_file_format (self);
#line 970 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp4_ == PHOTO_FILE_FORMAT_RAW) {
#line 7889 "Photo.c"
				PhotoFileReader* _tmp5_;
#line 971 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = photo_get_raw_developer_reader (self);
#line 971 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp5_;
#line 971 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 7897 "Photo.c"
			} else {
				PhotoFileReader* _tmp6_;
#line 973 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = photo_get_master_reader (self);
#line 973 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp6_;
#line 973 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 7906 "Photo.c"
			}
		}
		default:
		{
			BackingFetchMode _tmp7_;
			GEnumValue* _tmp8_;
#line 976 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = mode;
#line 976 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = g_enum_get_value (g_type_class_ref (TYPE_BACKING_FETCH_MODE), _tmp7_);
#line 976 "/home/jens/Source/shotwell/src/Photo.vala"
			g_error ("Photo.vala:976: Unknown backing fetch mode %s", (_tmp8_ != NULL) ? _tmp8_->value_name : NULL);
#line 7919 "Photo.c"
		}
	}
}


static gpointer _photo_file_adapter_ref0 (gpointer self) {
#line 982 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? photo_file_adapter_ref (self) : NULL;
#line 7928 "Photo.c"
}


static PhotoFileReader* photo_get_master_reader (Photo* self) {
	PhotoFileReader* result = NULL;
	GError * _inner_error_ = NULL;
#line 980 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 7937 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 7944 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			PhotoFileReader* _tmp3_;
#line 982 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 982 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->master;
#line 982 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _photo_file_adapter_ref0 (_tmp2_);
#line 982 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 7957 "Photo.c"
			{
				PhotoBackingReaders* _tmp4_;
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->priv->readers;
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 7964 "Photo.c"
			}
#line 982 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 7968 "Photo.c"
		}
		__finally297:
		{
			PhotoBackingReaders* _tmp5_;
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->priv->readers;
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 7977 "Photo.c"
		}
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 981 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 7985 "Photo.c"
	}
}


PhotoFileReader* photo_get_editable_reader (Photo* self) {
	PhotoFileReader* result = NULL;
	GError * _inner_error_ = NULL;
#line 986 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 7995 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8002 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			PhotoFileReader* _tmp3_;
#line 988 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 988 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 988 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _photo_file_adapter_ref0 (_tmp2_);
#line 988 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 8015 "Photo.c"
			{
				PhotoBackingReaders* _tmp4_;
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->priv->readers;
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8022 "Photo.c"
			}
#line 988 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8026 "Photo.c"
		}
		__finally298:
		{
			PhotoBackingReaders* _tmp5_;
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->priv->readers;
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8035 "Photo.c"
		}
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 987 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8043 "Photo.c"
	}
}


static PhotoFileReader* photo_get_baseline_reader (Photo* self) {
	PhotoFileReader* result = NULL;
	GError * _inner_error_ = NULL;
#line 993 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8053 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8060 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			PhotoBackingReaders* _tmp7_;
			PhotoFileReader* _tmp8_;
			PhotoBackingReaders* _tmp13_;
			PhotoFileReader* _tmp14_;
			PhotoFileReader* _tmp15_;
#line 995 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 995 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 995 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 8075 "Photo.c"
				PhotoBackingReaders* _tmp3_;
				PhotoFileReader* _tmp4_;
				PhotoFileReader* _tmp5_;
#line 996 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 996 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->editable;
#line 996 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _photo_file_adapter_ref0 (_tmp4_);
#line 996 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp5_;
#line 8087 "Photo.c"
				{
					PhotoBackingReaders* _tmp6_;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp6_ = self->priv->readers;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8094 "Photo.c"
				}
#line 996 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 8098 "Photo.c"
			}
#line 998 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->priv->readers;
#line 998 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp7_->developer;
#line 998 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp8_ != NULL) {
#line 8106 "Photo.c"
				PhotoBackingReaders* _tmp9_;
				PhotoFileReader* _tmp10_;
				PhotoFileReader* _tmp11_;
#line 999 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = self->priv->readers;
#line 999 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tmp9_->developer;
#line 999 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _photo_file_adapter_ref0 (_tmp10_);
#line 999 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp11_;
#line 8118 "Photo.c"
				{
					PhotoBackingReaders* _tmp12_;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = self->priv->readers;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8125 "Photo.c"
				}
#line 999 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 8129 "Photo.c"
			}
#line 1001 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = self->priv->readers;
#line 1001 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = _tmp13_->master;
#line 1001 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = _photo_file_adapter_ref0 (_tmp14_);
#line 1001 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp15_;
#line 8139 "Photo.c"
			{
				PhotoBackingReaders* _tmp16_;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = self->priv->readers;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8146 "Photo.c"
			}
#line 1001 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8150 "Photo.c"
		}
		__finally299:
		{
			PhotoBackingReaders* _tmp17_;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = self->priv->readers;
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8159 "Photo.c"
		}
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 994 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8167 "Photo.c"
	}
}


static PhotoFileReader* photo_get_source_reader (Photo* self) {
	PhotoFileReader* result = NULL;
	GError * _inner_error_ = NULL;
#line 1006 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8177 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8184 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			PhotoBackingReaders* _tmp7_;
			PhotoFileReader* _tmp8_;
			PhotoBackingReaders* _tmp13_;
			PhotoFileReader* _tmp14_;
			PhotoFileReader* _tmp15_;
#line 1008 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1008 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 1008 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 8199 "Photo.c"
				PhotoBackingReaders* _tmp3_;
				PhotoFileReader* _tmp4_;
				PhotoFileReader* _tmp5_;
#line 1009 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 1009 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->editable;
#line 1009 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _photo_file_adapter_ref0 (_tmp4_);
#line 1009 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp5_;
#line 8211 "Photo.c"
				{
					PhotoBackingReaders* _tmp6_;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp6_ = self->priv->readers;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8218 "Photo.c"
				}
#line 1009 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 8222 "Photo.c"
			}
#line 1011 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->priv->readers;
#line 1011 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp7_->developer;
#line 1011 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp8_ != NULL) {
#line 8230 "Photo.c"
				PhotoBackingReaders* _tmp9_;
				PhotoFileReader* _tmp10_;
				PhotoFileReader* _tmp11_;
#line 1012 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = self->priv->readers;
#line 1012 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tmp9_->developer;
#line 1012 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _photo_file_adapter_ref0 (_tmp10_);
#line 1012 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp11_;
#line 8242 "Photo.c"
				{
					PhotoBackingReaders* _tmp12_;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = self->priv->readers;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8249 "Photo.c"
				}
#line 1012 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 8253 "Photo.c"
			}
#line 1014 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = self->priv->readers;
#line 1014 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = _tmp13_->master;
#line 1014 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = _photo_file_adapter_ref0 (_tmp14_);
#line 1014 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp15_;
#line 8263 "Photo.c"
			{
				PhotoBackingReaders* _tmp16_;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = self->priv->readers;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8270 "Photo.c"
			}
#line 1014 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8274 "Photo.c"
		}
		__finally300:
		{
			PhotoBackingReaders* _tmp17_;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = self->priv->readers;
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8283 "Photo.c"
		}
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1007 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8291 "Photo.c"
	}
}


static PhotoFileReader* photo_get_raw_developer_reader (Photo* self) {
	PhotoFileReader* result = NULL;
	GError * _inner_error_ = NULL;
#line 1019 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8301 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8308 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			PhotoFileReader* _tmp3_;
#line 1021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->developer;
#line 1021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _photo_file_adapter_ref0 (_tmp2_);
#line 1021 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 8321 "Photo.c"
			{
				PhotoBackingReaders* _tmp4_;
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->priv->readers;
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8328 "Photo.c"
			}
#line 1021 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8332 "Photo.c"
		}
		__finally301:
		{
			PhotoBackingReaders* _tmp5_;
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->priv->readers;
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8341 "Photo.c"
		}
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1020 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8349 "Photo.c"
	}
}


gboolean photo_is_developed (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 1025 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 8359 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
		gboolean _tmp5_ = FALSE;
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8367 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
#line 1027 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1027 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->developer;
#line 1027 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_ != NULL;
#line 8377 "Photo.c"
			{
				PhotoBackingReaders* _tmp3_;
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8384 "Photo.c"
			}
#line 1027 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8388 "Photo.c"
		}
		__finally302:
		{
			PhotoBackingReaders* _tmp4_;
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->priv->readers;
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8397 "Photo.c"
		}
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1026 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 8405 "Photo.c"
	}
}


gboolean photo_has_editable (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 1031 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 8415 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
		gboolean _tmp5_ = FALSE;
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8423 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
#line 1033 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1033 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 1033 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_ != NULL;
#line 8433 "Photo.c"
			{
				PhotoBackingReaders* _tmp3_;
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8440 "Photo.c"
			}
#line 1033 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8444 "Photo.c"
		}
		__finally303:
		{
			PhotoBackingReaders* _tmp4_;
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->priv->readers;
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8453 "Photo.c"
		}
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1032 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 8461 "Photo.c"
	}
}


gboolean photo_does_master_exist (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 1037 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 8471 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
		gboolean _tmp6_ = FALSE;
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8479 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			gboolean _tmp3_;
#line 1039 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1039 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->master;
#line 1039 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = photo_file_adapter_file_exists (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1039 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 8492 "Photo.c"
			{
				PhotoBackingReaders* _tmp4_;
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->priv->readers;
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8499 "Photo.c"
			}
#line 1039 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8503 "Photo.c"
		}
		__finally304:
		{
			PhotoBackingReaders* _tmp5_;
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->priv->readers;
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8512 "Photo.c"
		}
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1038 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp6_;
#line 8520 "Photo.c"
	}
}


gboolean photo_does_editable_exist (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 1044 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 8530 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
		gboolean _tmp9_ = FALSE;
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8538 "Photo.c"
		{
			gboolean _tmp1_ = FALSE;
			PhotoBackingReaders* _tmp2_;
			PhotoFileReader* _tmp3_;
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->readers;
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _tmp2_->editable;
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_ != NULL) {
#line 8549 "Photo.c"
				PhotoBackingReaders* _tmp4_;
				PhotoFileReader* _tmp5_;
				gboolean _tmp6_;
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->priv->readers;
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_->editable;
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = photo_file_adapter_file_exists (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp6_;
#line 8561 "Photo.c"
			} else {
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = FALSE;
#line 8565 "Photo.c"
			}
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 8569 "Photo.c"
			{
				PhotoBackingReaders* _tmp7_;
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = self->priv->readers;
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8576 "Photo.c"
			}
#line 1046 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8580 "Photo.c"
		}
		__finally305:
		{
			PhotoBackingReaders* _tmp8_;
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = self->priv->readers;
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8589 "Photo.c"
		}
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1045 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp9_;
#line 8597 "Photo.c"
	}
}


gboolean photo_is_master_baseline (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 1050 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 8607 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
		gboolean _tmp5_ = FALSE;
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8615 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
#line 1052 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1052 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 1052 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_ == NULL;
#line 8625 "Photo.c"
			{
				PhotoBackingReaders* _tmp3_;
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8632 "Photo.c"
			}
#line 1052 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8636 "Photo.c"
		}
		__finally306:
		{
			PhotoBackingReaders* _tmp4_;
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->priv->readers;
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8645 "Photo.c"
		}
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1051 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 8653 "Photo.c"
	}
}


gboolean photo_is_master_source (Photo* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 1056 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 1057 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_has_editable (self);
#line 1057 "/home/jens/Source/shotwell/src/Photo.vala"
	result = !_tmp0_;
#line 1057 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 8669 "Photo.c"
}


gboolean photo_is_editable_baseline (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 1060 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 8678 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
		gboolean _tmp5_ = FALSE;
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 8686 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
#line 1062 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1062 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 1062 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_ != NULL;
#line 8696 "Photo.c"
			{
				PhotoBackingReaders* _tmp3_;
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8703 "Photo.c"
			}
#line 1062 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8707 "Photo.c"
		}
		__finally307:
		{
			PhotoBackingReaders* _tmp4_;
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->priv->readers;
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 8716 "Photo.c"
		}
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1061 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 8724 "Photo.c"
	}
}


gboolean photo_is_editable_source (Photo* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 1066 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 1067 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_has_editable (self);
#line 1067 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 1067 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 8740 "Photo.c"
}


BackingPhotoRow* photo_get_master_photo_row (Photo* self) {
	BackingPhotoRow* result = NULL;
	GError * _inner_error_ = NULL;
#line 1070 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8749 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 8756 "Photo.c"
		{
			PhotoRow* _tmp1_;
			BackingPhotoRow* _tmp2_;
			BackingPhotoRow* _tmp3_;
#line 1072 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 1072 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->master;
#line 1072 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _backing_photo_row_ref0 (_tmp2_);
#line 1072 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 8769 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8776 "Photo.c"
			}
#line 1072 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8780 "Photo.c"
		}
		__finally308:
		{
			PhotoRow* _tmp5_;
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8789 "Photo.c"
		}
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1071 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8797 "Photo.c"
	}
}


BackingPhotoRow* photo_get_editable_photo_row (Photo* self) {
	BackingPhotoRow* result = NULL;
	GError * _inner_error_ = NULL;
#line 1076 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8807 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 8814 "Photo.c"
		{
			PhotoRow* _tmp1_;
			gboolean _tmp2_;
#line 1079 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 1079 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = backing_photo_id_is_valid (&_tmp1_->editable_id);
#line 1079 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_) {
#line 8824 "Photo.c"
				BackingPhotoRow* _tmp3_;
				BackingPhotoRow* _tmp4_;
#line 1080 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->editable;
#line 1080 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _backing_photo_row_ref0 (_tmp3_);
#line 1080 "/home/jens/Source/shotwell/src/Photo.vala"
				result = _tmp4_;
#line 8833 "Photo.c"
				{
					PhotoRow* _tmp5_;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp5_ = self->row;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8840 "Photo.c"
				}
#line 1080 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 8844 "Photo.c"
			} else {
#line 1082 "/home/jens/Source/shotwell/src/Photo.vala"
				result = NULL;
#line 8848 "Photo.c"
				{
					PhotoRow* _tmp6_;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp6_ = self->row;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8855 "Photo.c"
				}
#line 1082 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 8859 "Photo.c"
			}
		}
		__finally309:
		{
			PhotoRow* _tmp7_;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->row;
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8869 "Photo.c"
		}
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1077 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8877 "Photo.c"
	}
}


GeeCollection* photo_get_raw_development_photo_rows (Photo* self) {
	GeeCollection* result = NULL;
	GError * _inner_error_ = NULL;
#line 1086 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8887 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 8894 "Photo.c"
		{
			GeeCollection* _tmp1_ = NULL;
			GeeHashMap* _tmp2_;
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->developments;
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 8902 "Photo.c"
				GeeHashMap* _tmp3_;
				GeeCollection* _tmp4_;
				GeeCollection* _tmp5_;
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->developments;
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_abstract_map_get_values (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_;
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp1_);
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp5_;
#line 8916 "Photo.c"
			} else {
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp1_);
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = NULL;
#line 8922 "Photo.c"
			}
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 8926 "Photo.c"
			{
				PhotoRow* _tmp6_;
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->row;
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8933 "Photo.c"
			}
#line 1088 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 8937 "Photo.c"
		}
		__finally310:
		{
			PhotoRow* _tmp7_;
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->row;
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 8946 "Photo.c"
		}
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1087 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 8954 "Photo.c"
	}
}


BackingPhotoRow* photo_get_raw_development_photo_row (Photo* self, RawDeveloper d) {
	BackingPhotoRow* result = NULL;
	GError * _inner_error_ = NULL;
#line 1092 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 8964 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 8971 "Photo.c"
		{
			BackingPhotoRow* _tmp1_ = NULL;
			GeeHashMap* _tmp2_;
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->developments;
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 8979 "Photo.c"
				GeeHashMap* _tmp3_;
				RawDeveloper _tmp4_;
				gpointer _tmp5_;
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->developments;
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = d;
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp4_));
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp1_);
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = (BackingPhotoRow*) _tmp5_;
#line 8993 "Photo.c"
			} else {
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp1_);
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = NULL;
#line 8999 "Photo.c"
			}
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 9003 "Photo.c"
			{
				PhotoRow* _tmp6_;
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->row;
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 9010 "Photo.c"
			}
#line 1094 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 9014 "Photo.c"
		}
		__finally311:
		{
			PhotoRow* _tmp7_;
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->row;
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 9023 "Photo.c"
		}
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1093 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 9031 "Photo.c"
	}
}


static PhotoFileFormat* _photo_file_format_dup (PhotoFileFormat* self) {
	PhotoFileFormat* dup;
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	dup = g_new0 (PhotoFileFormat, 1);
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	memcpy (dup, self, sizeof (PhotoFileFormat));
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	return dup;
#line 9044 "Photo.c"
}


static gpointer __photo_file_format_dup0 (gpointer self) {
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? _photo_file_format_dup (self) : NULL;
#line 9051 "Photo.c"
}


PhotoFileFormat* photo_get_editable_file_format (Photo* self) {
	PhotoFileFormat* result = NULL;
	PhotoFileReader* reader = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	PhotoFileReader* _tmp2_;
	PhotoFileFormat _tmp3_;
	PhotoFileFormat* _tmp4_;
#line 1098 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1099 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_editable_reader (self);
#line 1099 "/home/jens/Source/shotwell/src/Photo.vala"
	reader = _tmp0_;
#line 1100 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = reader;
#line 1100 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 1101 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 1101 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (reader);
#line 1101 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9079 "Photo.c"
	}
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = reader;
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = __photo_file_format_dup0 (&_tmp3_);
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (reader);
#line 1104 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 9093 "Photo.c"
}


PhotoFileFormat photo_get_export_format_for_parameters (Photo* self, ExportFormatParameters* params) {
	PhotoFileFormat result = 0;
	PhotoFileFormat _result_ = 0;
	PhotoFileFormat _tmp0_;
	ExportFormatParameters _tmp1_;
	ExportFormatMode _tmp2_;
#line 1107 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 1107 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (params != NULL, 0);
#line 1108 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_file_format_get_system_default_format ();
#line 1108 "/home/jens/Source/shotwell/src/Photo.vala"
	_result_ = _tmp0_;
#line 1110 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = *params;
#line 1110 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_.mode;
#line 1110 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp2_) {
#line 1110 "/home/jens/Source/shotwell/src/Photo.vala"
		case EXPORT_FORMAT_MODE_UNMODIFIED:
#line 9119 "Photo.c"
		{
			PhotoFileFormat _tmp3_;
#line 1112 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = photo_get_master_file_format (self);
#line 1112 "/home/jens/Source/shotwell/src/Photo.vala"
			_result_ = _tmp3_;
#line 1113 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 9128 "Photo.c"
		}
#line 1110 "/home/jens/Source/shotwell/src/Photo.vala"
		case EXPORT_FORMAT_MODE_CURRENT:
#line 9132 "Photo.c"
		{
			PhotoFileFormat _tmp4_;
#line 1116 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = photo_get_best_export_file_format (self);
#line 1116 "/home/jens/Source/shotwell/src/Photo.vala"
			_result_ = _tmp4_;
#line 1117 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 9141 "Photo.c"
		}
#line 1110 "/home/jens/Source/shotwell/src/Photo.vala"
		case EXPORT_FORMAT_MODE_SPECIFIED:
#line 9145 "Photo.c"
		{
			ExportFormatParameters _tmp5_;
			PhotoFileFormat _tmp6_;
#line 1120 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = *params;
#line 1120 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_.specified_format;
#line 1120 "/home/jens/Source/shotwell/src/Photo.vala"
			_result_ = _tmp6_;
#line 1121 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 9157 "Photo.c"
		}
		default:
		{
#line 1124 "/home/jens/Source/shotwell/src/Photo.vala"
			g_error ("Photo.vala:1124: get_export_format_for_parameters: unsupported export " \
"format mode");
#line 9163 "Photo.c"
		}
	}
#line 1127 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _result_;
#line 1127 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 9170 "Photo.c"
}


gchar* photo_get_export_basename_for_parameters (Photo* self, ExportFormatParameters* params) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	ExportFormatParameters _tmp0_;
	ExportFormatMode _tmp1_;
	const gchar* _tmp8_;
#line 1130 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1130 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (params != NULL, NULL);
#line 1131 "/home/jens/Source/shotwell/src/Photo.vala"
	_result_ = NULL;
#line 1133 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = *params;
#line 1133 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_.mode;
#line 1133 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp1_) {
#line 1133 "/home/jens/Source/shotwell/src/Photo.vala"
		case EXPORT_FORMAT_MODE_UNMODIFIED:
#line 9194 "Photo.c"
		{
			GFile* _tmp2_;
			GFile* _tmp3_;
			gchar* _tmp4_;
#line 1135 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 1135 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _tmp2_;
#line 1135 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = g_file_get_basename (_tmp3_);
#line 1135 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_result_);
#line 1135 "/home/jens/Source/shotwell/src/Photo.vala"
			_result_ = _tmp4_;
#line 1135 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp3_);
#line 1136 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 9213 "Photo.c"
		}
#line 1133 "/home/jens/Source/shotwell/src/Photo.vala"
		case EXPORT_FORMAT_MODE_CURRENT:
#line 1133 "/home/jens/Source/shotwell/src/Photo.vala"
		case EXPORT_FORMAT_MODE_SPECIFIED:
#line 9219 "Photo.c"
		{
			ExportFormatParameters _tmp5_;
			PhotoFileFormat _tmp6_;
			gchar* _tmp7_;
#line 1140 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = *params;
#line 1140 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = photo_get_export_format_for_parameters (self, &_tmp5_);
#line 1140 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = photo_get_export_basename (self, &_tmp6_);
#line 1140 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp7_;
#line 1140 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_result_);
#line 1140 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 9236 "Photo.c"
		}
		default:
		{
#line 1143 "/home/jens/Source/shotwell/src/Photo.vala"
			g_error ("Photo.vala:1143: get_export_basename_for_parameters: unsupported expor" \
"t format mode");
#line 9242 "Photo.c"
		}
	}
#line 1146 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _result_;
#line 1146 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp8_ != NULL, "result != null");
#line 1147 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _result_;
#line 1147 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 9253 "Photo.c"
}


ImportResult photo_prepare_for_import (PhotoImportParams* params) {
	ImportResult result = 0;
	GFile* file = NULL;
	PhotoImportParams* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFileInfo* info = NULL;
	GFileInfo* _tmp7_;
	GFileType _tmp8_;
	GFile* _tmp9_;
	gboolean _tmp10_;
	GFile* _tmp14_;
	gboolean _tmp15_;
	GTimeVal timestamp = {0};
	GFileInfo* _tmp19_;
	GTimeVal _tmp20_ = {0};
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_ = FALSE;
	PhotoImportParams* _tmp23_;
	const gchar* _tmp24_;
	PhotoFileInterrogator* interrogator = NULL;
	GFile* _tmp32_;
	PhotoImportParams* _tmp33_;
	PhotoFileSnifferOptions _tmp34_;
	PhotoFileInterrogator* _tmp35_;
	PhotoFileInterrogator* _tmp42_;
	gboolean _tmp43_;
	DetectedPhotoInformation* detected = NULL;
	PhotoFileInterrogator* _tmp44_;
	DetectedPhotoInformation* _tmp45_;
	gboolean _tmp46_ = FALSE;
	DetectedPhotoInformation* _tmp47_;
	PhotoImportParams* _tmp50_;
	PhotoFileSnifferOptions _tmp51_;
	Orientation orientation = 0;
	time_t exposure_time = 0;
	gchar* title = NULL;
	gchar* _tmp64_;
	gchar* comment = NULL;
	gchar* _tmp65_;
	Rating rating = 0;
	DetectedPhotoInformation* _tmp66_;
	PhotoMetadata* _tmp67_;
	gboolean _tmp90_ = FALSE;
	gboolean _tmp91_ = FALSE;
	DetectedPhotoInformation* _tmp92_;
	GdkColorspace _tmp93_;
	PhotoImportParams* _tmp101_;
	PhotoRow* _tmp102_;
	PhotoImportParams* _tmp103_;
	PhotoRow* _tmp104_;
	BackingPhotoRow* _tmp105_;
	GFile* _tmp106_;
	gchar* _tmp107_;
	PhotoImportParams* _tmp108_;
	PhotoRow* _tmp109_;
	BackingPhotoRow* _tmp110_;
	DetectedPhotoInformation* _tmp111_;
	Dimensions _tmp112_;
	PhotoImportParams* _tmp113_;
	PhotoRow* _tmp114_;
	BackingPhotoRow* _tmp115_;
	GFileInfo* _tmp116_;
	gint64 _tmp117_;
	PhotoImportParams* _tmp118_;
	PhotoRow* _tmp119_;
	BackingPhotoRow* _tmp120_;
	GTimeVal _tmp121_;
	glong _tmp122_;
	PhotoImportParams* _tmp123_;
	PhotoRow* _tmp124_;
	time_t _tmp125_;
	PhotoImportParams* _tmp126_;
	PhotoRow* _tmp127_;
	Orientation _tmp128_;
	PhotoImportParams* _tmp129_;
	PhotoRow* _tmp130_;
	BackingPhotoRow* _tmp131_;
	Orientation _tmp132_;
	PhotoImportParams* _tmp133_;
	PhotoRow* _tmp134_;
	PhotoImportParams* _tmp135_;
	ImportID _tmp136_;
	PhotoImportParams* _tmp137_;
	PhotoRow* _tmp138_;
	PhotoImportParams* _tmp139_;
	PhotoRow* _tmp140_;
	PhotoImportParams* _tmp141_;
	PhotoRow* _tmp142_;
	DetectedPhotoInformation* _tmp143_;
	const gchar* _tmp144_;
	gchar* _tmp145_;
	PhotoImportParams* _tmp146_;
	PhotoRow* _tmp147_;
	DetectedPhotoInformation* _tmp148_;
	const gchar* _tmp149_;
	gchar* _tmp150_;
	PhotoImportParams* _tmp151_;
	PhotoRow* _tmp152_;
	DetectedPhotoInformation* _tmp153_;
	const gchar* _tmp154_;
	gchar* _tmp155_;
	PhotoImportParams* _tmp156_;
	PhotoRow* _tmp157_;
	PhotoImportParams* _tmp158_;
	PhotoRow* _tmp159_;
	PhotoImportParams* _tmp160_;
	PhotoRow* _tmp161_;
	BackingPhotoRow* _tmp162_;
	DetectedPhotoInformation* _tmp163_;
	PhotoFileFormat _tmp164_;
	PhotoImportParams* _tmp165_;
	PhotoRow* _tmp166_;
	const gchar* _tmp167_;
	gchar* _tmp168_;
	PhotoImportParams* _tmp169_;
	PhotoRow* _tmp170_;
	const gchar* _tmp171_;
	gchar* _tmp172_;
	PhotoImportParams* _tmp173_;
	PhotoRow* _tmp174_;
	Rating _tmp175_;
	PhotoImportParams* _tmp176_;
	Thumbnails* _tmp177_;
	GError * _inner_error_ = NULL;
#line 1162 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_PARAMS (params), 0);
#line 1166 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = params;
#line 1166 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->file;
#line 1166 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1166 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp2_;
#line 1168 "/home/jens/Source/shotwell/src/Photo.vala"
	info = NULL;
#line 9394 "Photo.c"
	{
		GFileInfo* _tmp3_ = NULL;
		GFile* _tmp4_;
		GFileInfo* _tmp5_;
		GFileInfo* _tmp6_;
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = file;
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = g_file_query_info (_tmp4_, DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp5_;
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9408 "Photo.c"
			goto __catch312_g_error;
		}
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp3_;
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = NULL;
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1170 "/home/jens/Source/shotwell/src/Photo.vala"
		info = _tmp6_;
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 9421 "Photo.c"
	}
	goto __finally312;
	__catch312_g_error:
	{
		GError* err = NULL;
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1173 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_FILE_ERROR;
#line 1173 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 1173 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1173 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1173 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9441 "Photo.c"
	}
	__finally312:
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1169 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 9456 "Photo.c"
	}
#line 1176 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = info;
#line 1176 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = g_file_info_get_file_type (_tmp7_);
#line 1176 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_ != G_FILE_TYPE_REGULAR) {
#line 1177 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_NOT_A_FILE;
#line 1177 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1177 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1177 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9472 "Photo.c"
	}
#line 1179 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = file;
#line 1179 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = photo_is_file_image (_tmp9_);
#line 1179 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp10_) {
#line 9480 "Photo.c"
		GFile* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
#line 1180 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = file;
#line 1180 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = g_file_get_path (_tmp11_);
#line 1180 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _tmp12_;
#line 1180 "/home/jens/Source/shotwell/src/Photo.vala"
		g_message ("Photo.vala:1180: Not importing %s: Not an image file", _tmp13_);
#line 1180 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp13_);
#line 1182 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_NOT_AN_IMAGE;
#line 1182 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1182 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1182 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9502 "Photo.c"
	}
#line 1185 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = file;
#line 1185 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = photo_file_format_is_file_supported (_tmp14_);
#line 1185 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp15_) {
#line 9510 "Photo.c"
		GFile* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
#line 1186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = file;
#line 1186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = g_file_get_path (_tmp16_);
#line 1186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = _tmp17_;
#line 1186 "/home/jens/Source/shotwell/src/Photo.vala"
		g_message ("Photo.vala:1186: Not importing %s: Unsupported extension", _tmp18_);
#line 1186 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp18_);
#line 1188 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_UNSUPPORTED_FORMAT;
#line 1188 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1188 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1188 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9532 "Photo.c"
	}
#line 1191 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = info;
#line 1191 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_info_get_modification_time (_tmp19_, &_tmp20_);
#line 1191 "/home/jens/Source/shotwell/src/Photo.vala"
	timestamp = _tmp20_;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = params;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = _tmp23_->exif_md5;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp24_ != NULL) {
#line 9546 "Photo.c"
		PhotoImportParams* _tmp25_;
		const gchar* _tmp26_;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = params;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp26_ = _tmp25_->thumbnail_md5;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = _tmp26_ != NULL;
#line 9555 "Photo.c"
	} else {
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = FALSE;
#line 9559 "Photo.c"
	}
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp22_) {
#line 9563 "Photo.c"
		PhotoImportParams* _tmp27_;
		const gchar* _tmp28_;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp27_ = params;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = _tmp27_->full_md5;
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp28_ != NULL;
#line 9572 "Photo.c"
	} else {
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = FALSE;
#line 9576 "Photo.c"
	}
#line 1194 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp21_) {
#line 9580 "Photo.c"
		PhotoImportParams* _tmp29_;
		PhotoImportParams* _tmp30_;
		PhotoFileSnifferOptions _tmp31_;
#line 1195 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_ = params;
#line 1195 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = params;
#line 1195 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = _tmp30_->sniffer_options;
#line 1195 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_->sniffer_options = _tmp31_ | PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5;
#line 9592 "Photo.c"
	}
#line 1198 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = file;
#line 1198 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = params;
#line 1198 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = _tmp33_->sniffer_options;
#line 1198 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = photo_file_interrogator_new (_tmp32_, _tmp34_);
#line 1198 "/home/jens/Source/shotwell/src/Photo.vala"
	interrogator = _tmp35_;
#line 9604 "Photo.c"
	{
		PhotoFileInterrogator* _tmp36_;
#line 1200 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = interrogator;
#line 1200 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_interrogator_interrogate (_tmp36_, &_inner_error_);
#line 1200 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9613 "Photo.c"
			goto __catch313_g_error;
		}
	}
	goto __finally313;
	__catch313_g_error:
	{
		GError* err = NULL;
		GFile* _tmp37_;
		gchar* _tmp38_;
		gchar* _tmp39_;
		GError* _tmp40_;
		const gchar* _tmp41_;
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp37_ = file;
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp38_ = g_file_get_path (_tmp37_);
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = _tmp38_;
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = err;
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = _tmp40_->message;
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:1202: Unable to interrogate photo file %s: %s", _tmp39_, _tmp41_);
#line 1202 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp39_);
#line 1204 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_DECODE_ERROR;
#line 1204 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 1204 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1204 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1204 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1204 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9656 "Photo.c"
	}
	__finally313:
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1199 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 9673 "Photo.c"
	}
#line 1207 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = interrogator;
#line 1207 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp43_ = photo_file_interrogator_get_is_photo_corrupted (_tmp42_);
#line 1207 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp43_) {
#line 1208 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_NOT_AN_IMAGE;
#line 1208 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1208 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1208 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1208 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9691 "Photo.c"
	}
#line 1211 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = interrogator;
#line 1211 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = photo_file_interrogator_get_detected_photo_information (_tmp44_);
#line 1211 "/home/jens/Source/shotwell/src/Photo.vala"
	detected = _tmp45_;
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = detected;
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp47_ == NULL) {
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = TRUE;
#line 9705 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp48_;
		PhotoFileFormat _tmp49_;
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = detected;
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = _tmp48_->file_format;
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = _tmp49_ == PHOTO_FILE_FORMAT_UNKNOWN;
#line 9715 "Photo.c"
	}
#line 1212 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp46_) {
#line 1213 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_UNSUPPORTED_FORMAT;
#line 1213 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1213 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1213 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1213 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1213 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9731 "Photo.c"
	}
#line 1216 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp50_ = params;
#line 1216 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = _tmp50_->sniffer_options;
#line 1216 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp51_ & PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5) != 0) {
#line 9739 "Photo.c"
		DetectedPhotoInformation* _tmp52_;
		PhotoImportParams* _tmp53_;
		const gchar* _tmp54_;
		gchar* _tmp55_;
		DetectedPhotoInformation* _tmp56_;
		PhotoImportParams* _tmp57_;
		const gchar* _tmp58_;
		gchar* _tmp59_;
		DetectedPhotoInformation* _tmp60_;
		PhotoImportParams* _tmp61_;
		const gchar* _tmp62_;
		gchar* _tmp63_;
#line 1217 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp52_ = detected;
#line 1217 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp53_ = params;
#line 1217 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp54_ = _tmp53_->exif_md5;
#line 1217 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp55_ = g_strdup (_tmp54_);
#line 1217 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp52_->exif_md5);
#line 1217 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp52_->exif_md5 = _tmp55_;
#line 1218 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp56_ = detected;
#line 1218 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57_ = params;
#line 1218 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp58_ = _tmp57_->thumbnail_md5;
#line 1218 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp59_ = g_strdup (_tmp58_);
#line 1218 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp56_->thumbnail_md5);
#line 1218 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp56_->thumbnail_md5 = _tmp59_;
#line 1219 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp60_ = detected;
#line 1219 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp61_ = params;
#line 1219 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp62_ = _tmp61_->full_md5;
#line 1219 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp63_ = g_strdup (_tmp62_);
#line 1219 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp60_->md5);
#line 1219 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp60_->md5 = _tmp63_;
#line 9788 "Photo.c"
	}
#line 1222 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation = ORIENTATION_TOP_LEFT;
#line 1223 "/home/jens/Source/shotwell/src/Photo.vala"
	exposure_time = (time_t) 0;
#line 1224 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp64_ = g_strdup ("");
#line 1224 "/home/jens/Source/shotwell/src/Photo.vala"
	title = _tmp64_;
#line 1225 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp65_ = g_strdup ("");
#line 1225 "/home/jens/Source/shotwell/src/Photo.vala"
	comment = _tmp65_;
#line 1226 "/home/jens/Source/shotwell/src/Photo.vala"
	rating = RATING_UNRATED;
#line 1233 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp66_ = detected;
#line 1233 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp67_ = _tmp66_->metadata;
#line 1233 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp67_ != NULL) {
#line 9810 "Photo.c"
		MetadataDateTime* date_time = NULL;
		DetectedPhotoInformation* _tmp68_;
		PhotoMetadata* _tmp69_;
		MetadataDateTime* _tmp70_;
		MetadataDateTime* _tmp71_;
		DetectedPhotoInformation* _tmp74_;
		PhotoMetadata* _tmp75_;
		Orientation _tmp76_;
		DetectedPhotoInformation* _tmp77_;
		PhotoMetadata* _tmp78_;
		gchar* _tmp79_;
		DetectedPhotoInformation* _tmp80_;
		PhotoMetadata* _tmp81_;
		gchar* _tmp82_;
		PhotoImportParams* _tmp83_;
		DetectedPhotoInformation* _tmp84_;
		PhotoMetadata* _tmp85_;
		GeeSet* _tmp86_;
		DetectedPhotoInformation* _tmp87_;
		PhotoMetadata* _tmp88_;
		Rating _tmp89_;
#line 1234 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp68_ = detected;
#line 1234 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp69_ = _tmp68_->metadata;
#line 1234 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp70_ = photo_metadata_get_exposure_date_time (_tmp69_);
#line 1234 "/home/jens/Source/shotwell/src/Photo.vala"
		date_time = _tmp70_;
#line 1235 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp71_ = date_time;
#line 1235 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp71_ != NULL) {
#line 9844 "Photo.c"
			MetadataDateTime* _tmp72_;
			time_t _tmp73_;
#line 1236 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp72_ = date_time;
#line 1236 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp73_ = metadata_date_time_get_timestamp (_tmp72_);
#line 1236 "/home/jens/Source/shotwell/src/Photo.vala"
			exposure_time = _tmp73_;
#line 9853 "Photo.c"
		}
#line 1238 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp74_ = detected;
#line 1238 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp75_ = _tmp74_->metadata;
#line 1238 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp76_ = photo_metadata_get_orientation (_tmp75_);
#line 1238 "/home/jens/Source/shotwell/src/Photo.vala"
		orientation = _tmp76_;
#line 1239 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp77_ = detected;
#line 1239 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp78_ = _tmp77_->metadata;
#line 1239 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp79_ = media_metadata_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1239 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (title);
#line 1239 "/home/jens/Source/shotwell/src/Photo.vala"
		title = _tmp79_;
#line 1240 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp80_ = detected;
#line 1240 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp81_ = _tmp80_->metadata;
#line 1240 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp82_ = media_metadata_get_comment (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1240 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (comment);
#line 1240 "/home/jens/Source/shotwell/src/Photo.vala"
		comment = _tmp82_;
#line 1241 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp83_ = params;
#line 1241 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp84_ = detected;
#line 1241 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp85_ = _tmp84_->metadata;
#line 1241 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp86_ = photo_metadata_get_keywords (_tmp85_, NULL, NULL, NULL);
#line 1241 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp83_->keywords);
#line 1241 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp83_->keywords = G_TYPE_CHECK_INSTANCE_CAST (_tmp86_, GEE_TYPE_COLLECTION, GeeCollection);
#line 1242 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp87_ = detected;
#line 1242 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp88_ = _tmp87_->metadata;
#line 1242 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp89_ = photo_metadata_get_rating (_tmp88_);
#line 1242 "/home/jens/Source/shotwell/src/Photo.vala"
		rating = _tmp89_;
#line 1233 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 9905 "Photo.c"
	}
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp92_ = detected;
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp93_ = _tmp92_->colorspace;
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp93_ != GDK_COLORSPACE_RGB) {
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp91_ = TRUE;
#line 9915 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp94_;
		gint _tmp95_;
#line 1247 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp94_ = detected;
#line 1247 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp95_ = _tmp94_->channels;
#line 1247 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp91_ = _tmp95_ < 3;
#line 9925 "Photo.c"
	}
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp91_) {
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp90_ = TRUE;
#line 9931 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp96_;
		gint _tmp97_;
#line 1248 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp96_ = detected;
#line 1248 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp97_ = _tmp96_->bits_per_channel;
#line 1248 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp90_ = _tmp97_ != 8;
#line 9941 "Photo.c"
	}
#line 1246 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp90_) {
#line 9945 "Photo.c"
		GFile* _tmp98_;
		gchar* _tmp99_;
		gchar* _tmp100_;
#line 1249 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp98_ = file;
#line 1249 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp99_ = g_file_get_path (_tmp98_);
#line 1249 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp100_ = _tmp99_;
#line 1249 "/home/jens/Source/shotwell/src/Photo.vala"
		g_message ("Photo.vala:1249: Not importing %s: Unsupported color format", _tmp100_);
#line 1249 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp100_);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_UNSUPPORTED_FORMAT;
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (comment);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (title);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1251 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 9975 "Photo.c"
	}
#line 1257 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp101_ = params;
#line 1257 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp102_ = _tmp101_->row;
#line 1257 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id_init (&_tmp102_->photo_id, PHOTO_ID_INVALID);
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp103_ = params;
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp104_ = _tmp103_->row;
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp105_ = _tmp104_->master;
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp106_ = file;
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp107_ = g_file_get_path (_tmp106_);
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp105_->filepath);
#line 1258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp105_->filepath = _tmp107_;
#line 1259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp108_ = params;
#line 1259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp109_ = _tmp108_->row;
#line 1259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp110_ = _tmp109_->master;
#line 1259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp111_ = detected;
#line 1259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp112_ = _tmp111_->image_dim;
#line 1259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp110_->dim = _tmp112_;
#line 1260 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp113_ = params;
#line 1260 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp114_ = _tmp113_->row;
#line 1260 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp115_ = _tmp114_->master;
#line 1260 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp116_ = info;
#line 1260 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp117_ = g_file_info_get_size (_tmp116_);
#line 1260 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp115_->filesize = _tmp117_;
#line 1261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp118_ = params;
#line 1261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp119_ = _tmp118_->row;
#line 1261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp120_ = _tmp119_->master;
#line 1261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp121_ = timestamp;
#line 1261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp122_ = _tmp121_.tv_sec;
#line 1261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp120_->timestamp = (time_t) _tmp122_;
#line 1262 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp123_ = params;
#line 1262 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp124_ = _tmp123_->row;
#line 1262 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp125_ = exposure_time;
#line 1262 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp124_->exposure_time = _tmp125_;
#line 1263 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp126_ = params;
#line 1263 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp127_ = _tmp126_->row;
#line 1263 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp128_ = orientation;
#line 1263 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp127_->orientation = _tmp128_;
#line 1264 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp129_ = params;
#line 1264 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp130_ = _tmp129_->row;
#line 1264 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp131_ = _tmp130_->master;
#line 1264 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp132_ = orientation;
#line 1264 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp131_->original_orientation = _tmp132_;
#line 1265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp133_ = params;
#line 1265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp134_ = _tmp133_->row;
#line 1265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp135_ = params;
#line 1265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp136_ = _tmp135_->import_id;
#line 1265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp134_->import_id = _tmp136_;
#line 1266 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp137_ = params;
#line 1266 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp138_ = _tmp137_->row;
#line 1266 "/home/jens/Source/shotwell/src/Photo.vala"
	event_id_init (&_tmp138_->event_id, EVENT_ID_INVALID);
#line 1267 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp139_ = params;
#line 1267 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp140_ = _tmp139_->row;
#line 1267 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp140_->transformations);
#line 1267 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp140_->transformations = NULL;
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp141_ = params;
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp142_ = _tmp141_->row;
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp143_ = detected;
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp144_ = _tmp143_->md5;
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp145_ = g_strdup (_tmp144_);
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp142_->md5);
#line 1268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp142_->md5 = _tmp145_;
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp146_ = params;
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp147_ = _tmp146_->row;
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp148_ = detected;
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp149_ = _tmp148_->thumbnail_md5;
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp150_ = g_strdup (_tmp149_);
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp147_->thumbnail_md5);
#line 1269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp147_->thumbnail_md5 = _tmp150_;
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp151_ = params;
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp152_ = _tmp151_->row;
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp153_ = detected;
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp154_ = _tmp153_->exif_md5;
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp155_ = g_strdup (_tmp154_);
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp152_->exif_md5);
#line 1270 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp152_->exif_md5 = _tmp155_;
#line 1271 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp156_ = params;
#line 1271 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp157_ = _tmp156_->row;
#line 1271 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp157_->time_created = (time_t) 0;
#line 1272 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp158_ = params;
#line 1272 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp159_ = _tmp158_->row;
#line 1272 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp159_->flags = (guint64) 0;
#line 1273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp160_ = params;
#line 1273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp161_ = _tmp160_->row;
#line 1273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp162_ = _tmp161_->master;
#line 1273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp163_ = detected;
#line 1273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp164_ = _tmp163_->file_format;
#line 1273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp162_->file_format = _tmp164_;
#line 1274 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp165_ = params;
#line 1274 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp166_ = _tmp165_->row;
#line 1274 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp167_ = title;
#line 1274 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp168_ = g_strdup (_tmp167_);
#line 1274 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp166_->title);
#line 1274 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp166_->title = _tmp168_;
#line 1275 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp169_ = params;
#line 1275 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp170_ = _tmp169_->row;
#line 1275 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp171_ = comment;
#line 1275 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp172_ = g_strdup (_tmp171_);
#line 1275 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp170_->comment);
#line 1275 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp170_->comment = _tmp172_;
#line 1276 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp173_ = params;
#line 1276 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp174_ = _tmp173_->row;
#line 1276 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp175_ = rating;
#line 1276 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp174_->rating = _tmp175_;
#line 1278 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp176_ = params;
#line 1278 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp177_ = _tmp176_->thumbnails;
#line 1278 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp177_ != NULL) {
#line 10187 "Photo.c"
		PhotoFileReader* reader = NULL;
		PhotoImportParams* _tmp178_;
		PhotoRow* _tmp179_;
		BackingPhotoRow* _tmp180_;
		PhotoFileFormat _tmp181_;
		PhotoImportParams* _tmp182_;
		PhotoRow* _tmp183_;
		BackingPhotoRow* _tmp184_;
		const gchar* _tmp185_;
		PhotoFileReader* _tmp186_;
		PhotoFileReader* _tmp187_;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp178_ = params;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp179_ = _tmp178_->row;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp180_ = _tmp179_->master;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp181_ = _tmp180_->file_format;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp182_ = params;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp183_ = _tmp182_->row;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp184_ = _tmp183_->master;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp185_ = _tmp184_->filepath;
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp186_ = photo_file_format_create_reader (_tmp181_, _tmp185_);
#line 1279 "/home/jens/Source/shotwell/src/Photo.vala"
		reader = _tmp186_;
#line 1281 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp187_ = reader;
#line 1281 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_reader_set_role (_tmp187_, PHOTO_FILE_READER_ROLE_THUMBNAIL);
#line 10223 "Photo.c"
		{
			PhotoImportParams* _tmp188_;
			Thumbnails* _tmp189_;
			PhotoFileReader* _tmp190_;
			PhotoImportParams* _tmp191_;
			PhotoRow* _tmp192_;
			Orientation _tmp193_;
			PhotoImportParams* _tmp194_;
			PhotoRow* _tmp195_;
			BackingPhotoRow* _tmp196_;
			Dimensions _tmp197_;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp188_ = params;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp189_ = _tmp188_->thumbnails;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp190_ = reader;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp191_ = params;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp192_ = _tmp191_->row;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp193_ = _tmp192_->orientation;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp194_ = params;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp195_ = _tmp194_->row;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp196_ = _tmp195_->master;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp197_ = _tmp196_->dim;
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			thumbnail_cache_generate_for_photo (_tmp189_, _tmp190_, _tmp193_, &_tmp197_, &_inner_error_);
#line 1283 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10259 "Photo.c"
				goto __catch314_g_error;
			}
		}
		goto __finally314;
		__catch314_g_error:
		{
			GError* err = NULL;
			GError* _tmp198_;
			ImportResult _tmp199_;
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp198_ = err;
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp199_ = import_result_convert_error (_tmp198_, IMPORT_RESULT_FILE_ERROR);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp199_;
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (reader);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (comment);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (title);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_interrogator_unref0 (interrogator);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 1286 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 10297 "Photo.c"
		}
		__finally314:
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (reader);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (comment);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (title);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_interrogator_unref0 (interrogator);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 1282 "/home/jens/Source/shotwell/src/Photo.vala"
			return 0;
#line 10322 "Photo.c"
		}
#line 1278 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (reader);
#line 10326 "Photo.c"
	}
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	result = IMPORT_RESULT_SUCCESS;
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (comment);
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (title);
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_interrogator_unref0 (interrogator);
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (info);
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 1293 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 10344 "Photo.c"
}


void photo_create_pre_import (PhotoImportParams* params) {
	GFile* file = NULL;
	PhotoImportParams* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	PhotoImportParams* _tmp3_;
	PhotoRow* _tmp4_;
	PhotoImportParams* _tmp5_;
	PhotoRow* _tmp6_;
	BackingPhotoRow* _tmp7_;
	gchar* _tmp8_;
	PhotoImportParams* _tmp9_;
	PhotoRow* _tmp10_;
	BackingPhotoRow* _tmp11_;
	PhotoImportParams* _tmp12_;
	PhotoRow* _tmp13_;
	BackingPhotoRow* _tmp14_;
	PhotoImportParams* _tmp15_;
	PhotoRow* _tmp16_;
	BackingPhotoRow* _tmp17_;
	PhotoImportParams* _tmp18_;
	PhotoRow* _tmp19_;
	PhotoImportParams* _tmp20_;
	PhotoRow* _tmp21_;
	PhotoImportParams* _tmp22_;
	PhotoRow* _tmp23_;
	BackingPhotoRow* _tmp24_;
	PhotoImportParams* _tmp25_;
	PhotoRow* _tmp26_;
	PhotoImportParams* _tmp27_;
	ImportID _tmp28_;
	PhotoImportParams* _tmp29_;
	PhotoRow* _tmp30_;
	PhotoImportParams* _tmp31_;
	PhotoRow* _tmp32_;
	PhotoImportParams* _tmp33_;
	PhotoRow* _tmp34_;
	PhotoImportParams* _tmp35_;
	PhotoRow* _tmp36_;
	PhotoImportParams* _tmp37_;
	PhotoRow* _tmp38_;
	PhotoImportParams* _tmp39_;
	PhotoRow* _tmp40_;
	PhotoImportParams* _tmp41_;
	PhotoRow* _tmp42_;
	PhotoImportParams* _tmp43_;
	PhotoRow* _tmp44_;
	BackingPhotoRow* _tmp45_;
	PhotoImportParams* _tmp46_;
	PhotoRow* _tmp47_;
	PhotoImportParams* _tmp48_;
	PhotoRow* _tmp49_;
	PhotoImportParams* _tmp50_;
	PhotoRow* _tmp51_;
	PhotoFileInterrogator* interrogator = NULL;
	PhotoImportParams* _tmp52_;
	GFile* _tmp53_;
	PhotoImportParams* _tmp54_;
	PhotoFileSnifferOptions _tmp55_;
	PhotoFileInterrogator* _tmp56_;
	GError * _inner_error_ = NULL;
#line 1296 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO_IMPORT_PARAMS (params));
#line 1297 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = params;
#line 1297 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->file;
#line 1297 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1297 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp2_;
#line 1298 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = params;
#line 1298 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_->row;
#line 1298 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id_init (&_tmp4_->photo_id, PHOTO_ID_INVALID);
#line 1299 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = params;
#line 1299 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _tmp5_->row;
#line 1299 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = _tmp6_->master;
#line 1299 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = g_file_get_path (file);
#line 1299 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp7_->filepath);
#line 1299 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_->filepath = _tmp8_;
#line 1300 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = params;
#line 1300 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = _tmp9_->row;
#line 1300 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp10_->master;
#line 1300 "/home/jens/Source/shotwell/src/Photo.vala"
	dimensions_init (&_tmp11_->dim, 0, 0);
#line 1301 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = params;
#line 1301 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_->row;
#line 1301 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = _tmp13_->master;
#line 1301 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_->filesize = (gint64) 0;
#line 1302 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = params;
#line 1302 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = _tmp15_->row;
#line 1302 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = _tmp16_->master;
#line 1302 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_->timestamp = (time_t) 0;
#line 1303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = params;
#line 1303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = _tmp18_->row;
#line 1303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_->exposure_time = (time_t) 0;
#line 1304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = params;
#line 1304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = _tmp20_->row;
#line 1304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_->orientation = ORIENTATION_TOP_LEFT;
#line 1305 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = params;
#line 1305 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = _tmp22_->row;
#line 1305 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = _tmp23_->master;
#line 1305 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_->original_orientation = ORIENTATION_TOP_LEFT;
#line 1306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = params;
#line 1306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = _tmp25_->row;
#line 1306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = params;
#line 1306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = _tmp27_->import_id;
#line 1306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_->import_id = _tmp28_;
#line 1307 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = params;
#line 1307 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = _tmp29_->row;
#line 1307 "/home/jens/Source/shotwell/src/Photo.vala"
	event_id_init (&_tmp30_->event_id, EVENT_ID_INVALID);
#line 1308 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = params;
#line 1308 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = _tmp31_->row;
#line 1308 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp32_->transformations);
#line 1308 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_->transformations = NULL;
#line 1309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = params;
#line 1309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = _tmp33_->row;
#line 1309 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp34_->md5);
#line 1309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_->md5 = NULL;
#line 1310 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = params;
#line 1310 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = _tmp35_->row;
#line 1310 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp36_->thumbnail_md5);
#line 1310 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_->thumbnail_md5 = NULL;
#line 1311 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = params;
#line 1311 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = _tmp37_->row;
#line 1311 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp38_->exif_md5);
#line 1311 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_->exif_md5 = NULL;
#line 1312 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = params;
#line 1312 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = _tmp39_->row;
#line 1312 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_->time_created = (time_t) 0;
#line 1313 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = params;
#line 1313 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = _tmp41_->row;
#line 1313 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_->flags = (guint64) 0;
#line 1314 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp43_ = params;
#line 1314 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = _tmp43_->row;
#line 1314 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = _tmp44_->master;
#line 1314 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_->file_format = PHOTO_FILE_FORMAT_JFIF;
#line 1315 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp46_ = params;
#line 1315 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = _tmp46_->row;
#line 1315 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp47_->title);
#line 1315 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_->title = NULL;
#line 1316 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp48_ = params;
#line 1316 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp49_ = _tmp48_->row;
#line 1316 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp49_->comment);
#line 1316 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp49_->comment = NULL;
#line 1317 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp50_ = params;
#line 1317 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = _tmp50_->row;
#line 1317 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_->rating = RATING_UNRATED;
#line 1319 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp52_ = params;
#line 1319 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp53_ = _tmp52_->file;
#line 1319 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp54_ = params;
#line 1319 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp55_ = _tmp54_->sniffer_options;
#line 1319 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp56_ = photo_file_interrogator_new (_tmp53_, _tmp55_);
#line 1319 "/home/jens/Source/shotwell/src/Photo.vala"
	interrogator = _tmp56_;
#line 10583 "Photo.c"
	{
		DetectedPhotoInformation* detected = NULL;
		DetectedPhotoInformation* _tmp57_;
		gboolean _tmp58_ = FALSE;
		gboolean _tmp59_ = FALSE;
		DetectedPhotoInformation* _tmp60_;
#line 1321 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_interrogator_interrogate (interrogator, &_inner_error_);
#line 1321 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10594 "Photo.c"
			goto __catch315_g_error;
		}
#line 1322 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57_ = photo_file_interrogator_get_detected_photo_information (interrogator);
#line 1322 "/home/jens/Source/shotwell/src/Photo.vala"
		detected = _tmp57_;
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp60_ = detected;
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp60_ != NULL) {
#line 10605 "Photo.c"
			gboolean _tmp61_;
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp61_ = photo_file_interrogator_get_is_photo_corrupted (interrogator);
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp59_ = !_tmp61_;
#line 10611 "Photo.c"
		} else {
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp59_ = FALSE;
#line 10615 "Photo.c"
		}
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp59_) {
#line 10619 "Photo.c"
			DetectedPhotoInformation* _tmp62_;
			PhotoFileFormat _tmp63_;
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp62_ = detected;
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp63_ = _tmp62_->file_format;
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp58_ = _tmp63_ != PHOTO_FILE_FORMAT_UNKNOWN;
#line 10628 "Photo.c"
		} else {
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp58_ = FALSE;
#line 10632 "Photo.c"
		}
#line 1323 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp58_) {
#line 10636 "Photo.c"
			PhotoImportParams* _tmp64_;
			PhotoRow* _tmp65_;
			BackingPhotoRow* _tmp66_;
			DetectedPhotoInformation* _tmp67_;
			PhotoFileFormat _tmp68_;
#line 1324 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp64_ = params;
#line 1324 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp65_ = _tmp64_->row;
#line 1324 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp66_ = _tmp65_->master;
#line 1324 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp67_ = detected;
#line 1324 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp68_ = _tmp67_->file_format;
#line 1324 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp66_->file_format = _tmp68_;
#line 10654 "Photo.c"
		}
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 10658 "Photo.c"
	}
	goto __finally315;
	__catch315_g_error:
	{
		GError* err = NULL;
		gchar* _tmp69_;
		gchar* _tmp70_;
		GError* _tmp71_;
		const gchar* _tmp72_;
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1326 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp69_ = g_file_get_path (file);
#line 1326 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp70_ = _tmp69_;
#line 1326 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp71_ = err;
#line 1326 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp72_ = _tmp71_->message;
#line 1326 "/home/jens/Source/shotwell/src/Photo.vala"
		g_debug ("Photo.vala:1326: Unable to interrogate photo file %s: %s", _tmp70_, _tmp72_);
#line 1326 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp70_);
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 10686 "Photo.c"
	}
	__finally315:
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1320 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 10701 "Photo.c"
	}
#line 1296 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_interrogator_unref0 (interrogator);
#line 1296 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 10707 "Photo.c"
}


BackingPhotoRow* photo_query_backing_photo_row (Photo* self, GFile* file, PhotoFileSnifferOptions options, DetectedPhotoInformation* * detected, GError** error) {
	DetectedPhotoInformation* _vala_detected = NULL;
	BackingPhotoRow* result = NULL;
	BackingPhotoRow* backing = NULL;
	BackingPhotoRow* _tmp0_;
	GFileInfo* info = NULL;
	PhotoFileInterrogator* interrogator = NULL;
	GFile* _tmp10_;
	PhotoFileSnifferOptions _tmp11_;
	PhotoFileInterrogator* _tmp12_;
	PhotoFileInterrogator* _tmp13_;
	PhotoFileInterrogator* _tmp14_;
	DetectedPhotoInformation* _tmp15_;
	gboolean _tmp16_ = FALSE;
	DetectedPhotoInformation* _tmp17_;
	GTimeVal modification_time = {0};
	GFileInfo* _tmp22_;
	GTimeVal _tmp23_ = {0};
	BackingPhotoRow* _tmp24_;
	GFile* _tmp25_;
	gchar* _tmp26_;
	BackingPhotoRow* _tmp27_;
	GTimeVal _tmp28_;
	glong _tmp29_;
	BackingPhotoRow* _tmp30_;
	GFileInfo* _tmp31_;
	gint64 _tmp32_;
	BackingPhotoRow* _tmp33_;
	DetectedPhotoInformation* _tmp34_;
	PhotoFileFormat _tmp35_;
	BackingPhotoRow* _tmp36_;
	DetectedPhotoInformation* _tmp37_;
	Dimensions _tmp38_;
	Orientation _tmp39_ = 0;
	DetectedPhotoInformation* _tmp40_;
	PhotoMetadata* _tmp41_;
	BackingPhotoRow* _tmp45_;
	GError * _inner_error_ = NULL;
#line 1330 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1330 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 1332 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (_vala_detected);
#line 1332 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_detected = NULL;
#line 1334 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backing_photo_row_new ();
#line 1334 "/home/jens/Source/shotwell/src/Photo.vala"
	backing = _tmp0_;
#line 1336 "/home/jens/Source/shotwell/src/Photo.vala"
	info = NULL;
#line 10763 "Photo.c"
	{
		GFileInfo* _tmp1_ = NULL;
		GFile* _tmp2_;
		GFileInfo* _tmp3_;
		GFileInfo* _tmp4_;
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = file;
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = g_file_query_info (_tmp2_, DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp3_;
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10777 "Photo.c"
			goto __catch316_g_error;
		}
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp1_;
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = NULL;
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1338 "/home/jens/Source/shotwell/src/Photo.vala"
		info = _tmp4_;
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp1_);
#line 10790 "Photo.c"
	}
	goto __finally316;
	__catch316_g_error:
	{
		GError* err = NULL;
		GFile* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		GError* _tmp8_;
		const gchar* _tmp9_;
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = file;
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = g_file_get_path (_tmp5_);
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = err;
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = _tmp8_->message;
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("Photo.vala:1341: Unable to read file information for %s: %s", _tmp7_, _tmp9_);
#line 1341 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp7_);
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
		if (detected) {
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
			*detected = _vala_detected;
#line 10831 "Photo.c"
		} else {
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (_vala_detected);
#line 10835 "Photo.c"
		}
#line 1343 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 10839 "Photo.c"
	}
	__finally316:
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1337 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 10852 "Photo.c"
	}
#line 1347 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = file;
#line 1347 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = options;
#line 1347 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = photo_file_interrogator_new (_tmp10_, _tmp11_);
#line 1347 "/home/jens/Source/shotwell/src/Photo.vala"
	interrogator = _tmp12_;
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = interrogator;
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_interrogator_interrogate (_tmp13_, &_inner_error_);
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1348 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 10878 "Photo.c"
	}
#line 1349 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = interrogator;
#line 1349 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = photo_file_interrogator_get_detected_photo_information (_tmp14_);
#line 1349 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (_vala_detected);
#line 1349 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_detected = _tmp15_;
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = _vala_detected;
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp17_ == NULL) {
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = TRUE;
#line 10894 "Photo.c"
	} else {
		PhotoFileInterrogator* _tmp18_;
		gboolean _tmp19_;
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = interrogator;
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = photo_file_interrogator_get_is_photo_corrupted (_tmp18_);
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = _tmp19_;
#line 10904 "Photo.c"
	}
#line 1350 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp16_) {
#line 10908 "Photo.c"
		gchar* _tmp20_;
		gchar* _tmp21_;
#line 1351 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 1351 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp20_;
#line 1351 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("Photo.vala:1351: Photo update: %s no longer a recognized image", _tmp21_);
#line 1351 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp21_);
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
		if (detected) {
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
			*detected = _vala_detected;
#line 10931 "Photo.c"
		} else {
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (_vala_detected);
#line 10935 "Photo.c"
		}
#line 1353 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 10939 "Photo.c"
	}
#line 1356 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = info;
#line 1356 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_info_get_modification_time (_tmp22_, &_tmp23_);
#line 1356 "/home/jens/Source/shotwell/src/Photo.vala"
	modification_time = _tmp23_;
#line 1358 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = backing;
#line 1358 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = file;
#line 1358 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = g_file_get_path (_tmp25_);
#line 1358 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp24_->filepath);
#line 1358 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_->filepath = _tmp26_;
#line 1359 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = backing;
#line 1359 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = modification_time;
#line 1359 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = _tmp28_.tv_sec;
#line 1359 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_->timestamp = (time_t) _tmp29_;
#line 1360 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = backing;
#line 1360 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = info;
#line 1360 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = g_file_info_get_size (_tmp31_);
#line 1360 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_->filesize = _tmp32_;
#line 1361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = backing;
#line 1361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = _vala_detected;
#line 1361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = _tmp34_->file_format;
#line 1361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_->file_format = _tmp35_;
#line 1362 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = backing;
#line 1362 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = _vala_detected;
#line 1362 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = _tmp37_->image_dim;
#line 1362 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_->dim = _tmp38_;
#line 1363 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = _vala_detected;
#line 1363 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = _tmp40_->metadata;
#line 1363 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp41_ != NULL) {
#line 10995 "Photo.c"
		DetectedPhotoInformation* _tmp42_;
		PhotoMetadata* _tmp43_;
		Orientation _tmp44_;
#line 1364 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = _vala_detected;
#line 1364 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = _tmp42_->metadata;
#line 1364 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp44_ = photo_metadata_get_orientation (_tmp43_);
#line 1364 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = _tmp44_;
#line 11007 "Photo.c"
	} else {
#line 1364 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = ORIENTATION_TOP_LEFT;
#line 11011 "Photo.c"
	}
#line 1363 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = backing;
#line 1363 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_->original_orientation = _tmp39_;
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
	result = backing;
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_interrogator_unref0 (interrogator);
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (info);
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
	if (detected) {
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
		*detected = _vala_detected;
#line 11027 "Photo.c"
	} else {
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (_vala_detected);
#line 11031 "Photo.c"
	}
#line 1366 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 11035 "Photo.c"
}


static void _vala_array_add92 (gchar** * array, int* length, int* size, gchar* value) {
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11046 "Photo.c"
	}
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11052 "Photo.c"
}


static void _vala_array_add93 (gchar** * array, int* length, int* size, gchar* value) {
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11063 "Photo.c"
	}
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11069 "Photo.c"
}


static void _vala_array_add94 (gchar** * array, int* length, int* size, gchar* value) {
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11080 "Photo.c"
	}
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11086 "Photo.c"
}


static void _vala_array_add95 (gchar** * array, int* length, int* size, gchar* value) {
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11097 "Photo.c"
	}
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11103 "Photo.c"
}


static void _vala_array_add96 (gchar** * array, int* length, int* size, gchar* value) {
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11114 "Photo.c"
	}
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11120 "Photo.c"
}


static void _vala_array_add97 (gchar** * array, int* length, int* size, gchar* value) {
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11131 "Photo.c"
	}
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11137 "Photo.c"
}


static gpointer _media_metadata_ref0 (gpointer self) {
#line 1491 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? media_metadata_ref (self) : NULL;
#line 11144 "Photo.c"
}


gboolean photo_prepare_for_reimport_master (Photo* self, PhotoReimportMasterState* * reimport_state, GError** error) {
	PhotoReimportMasterState* _vala_reimport_state = NULL;
	gboolean result = FALSE;
	GFile* file = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	DetectedPhotoInformation* detected = NULL;
	BackingPhotoRow* backing = NULL;
	GFile* _tmp4_;
	DetectedPhotoInformation* _tmp5_ = NULL;
	BackingPhotoRow* _tmp6_;
	BackingPhotoRow* _tmp8_;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	DetectedPhotoInformation* _tmp14_;
	GdkColorspace _tmp15_;
	PhotoRow* updated_row = NULL;
	PhotoRow* _tmp23_;
	gchar** list = NULL;
	gchar** _tmp29_;
	gint list_length1;
	gint _list_size_;
	PhotoRow* _tmp30_;
	const gchar* _tmp31_;
	DetectedPhotoInformation* _tmp32_;
	const gchar* _tmp33_;
	PhotoRow* _tmp36_;
	BackingPhotoRow* _tmp37_;
	Orientation _tmp38_;
	BackingPhotoRow* _tmp39_;
	Orientation _tmp40_;
	DetectedPhotoInformation* _tmp47_;
	PhotoMetadata* _tmp48_;
	PhotoRow* _tmp85_;
	BackingPhotoRow* _tmp86_;
	BackingPhotoRow* _tmp87_;
	PhotoRow* _tmp88_;
	DetectedPhotoInformation* _tmp89_;
	const gchar* _tmp90_;
	gchar* _tmp91_;
	PhotoRow* _tmp92_;
	DetectedPhotoInformation* _tmp93_;
	const gchar* _tmp94_;
	gchar* _tmp95_;
	PhotoRow* _tmp96_;
	DetectedPhotoInformation* _tmp97_;
	const gchar* _tmp98_;
	gchar* _tmp99_;
	PhotoMetadata* metadata = NULL;
	DetectedPhotoInformation* _tmp100_;
	PhotoMetadata* _tmp101_;
	PhotoRow* _tmp124_;
	PhotoMetadata* _tmp125_;
	gchar** _tmp126_;
	gint _tmp126__length1;
	PhotoReimportMasterStateImpl* _tmp127_;
	GError * _inner_error_ = NULL;
#line 1430 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 1431 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_master_state_unref0 (_vala_reimport_state);
#line 1431 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_reimport_state = NULL;
#line 1433 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_master_reader (self);
#line 1433 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1433 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1433 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 1433 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp1_);
#line 1433 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp3_;
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = file;
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_query_backing_photo_row (self, _tmp4_, PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL, &_tmp5_, &_inner_error_);
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
	detected = _tmp5_;
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
	backing = _tmp6_;
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11237 "Photo.c"
		gboolean _tmp7_ = FALSE;
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1436 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp7_;
#line 11247 "Photo.c"
	}
#line 1438 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = backing;
#line 1438 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_ == NULL) {
#line 11253 "Photo.c"
		GFile* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 1439 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = file;
#line 1439 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = g_file_get_path (_tmp9_);
#line 1439 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = _tmp10_;
#line 1439 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:1439: Unable to retrieve photo state from %s for reimport", _tmp11_);
#line 1439 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp11_);
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
		if (reimport_state) {
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
			*reimport_state = _vala_reimport_state;
#line 11279 "Photo.c"
		} else {
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_master_state_unref0 (_vala_reimport_state);
#line 11283 "Photo.c"
		}
#line 1440 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 11287 "Photo.c"
	}
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = detected;
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_->colorspace;
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp15_ != GDK_COLORSPACE_RGB) {
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = TRUE;
#line 11297 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp16_;
		gint _tmp17_;
#line 1445 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = detected;
#line 1445 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = _tmp16_->channels;
#line 1445 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _tmp17_ < 3;
#line 11307 "Photo.c"
	}
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp13_) {
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = TRUE;
#line 11313 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp18_;
		gint _tmp19_;
#line 1446 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = detected;
#line 1446 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = _tmp18_->bits_per_channel;
#line 1446 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp19_ != 8;
#line 11323 "Photo.c"
	}
#line 1444 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_) {
#line 11327 "Photo.c"
		GFile* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 1447 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = file;
#line 1447 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = g_file_get_path (_tmp20_);
#line 1447 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = _tmp21_;
#line 1447 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:1447: Not re-importing %s: Unsupported color format", _tmp22_);
#line 1447 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp22_);
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
		if (reimport_state) {
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
			*reimport_state = _vala_reimport_state;
#line 11353 "Photo.c"
		} else {
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_master_state_unref0 (_vala_reimport_state);
#line 11357 "Photo.c"
		}
#line 1449 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 11361 "Photo.c"
	}
#line 1453 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = photo_row_new ();
#line 1453 "/home/jens/Source/shotwell/src/Photo.vala"
	updated_row = _tmp23_;
#line 11367 "Photo.c"
	{
		PhotoRow* _tmp24_;
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = self->row;
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 11374 "Photo.c"
		{
			PhotoRow* _tmp25_;
			PhotoRow* _tmp26_;
#line 1455 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp25_ = self->row;
#line 1455 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = _photo_row_ref0 (_tmp25_);
#line 1455 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_row_unref0 (updated_row);
#line 1455 "/home/jens/Source/shotwell/src/Photo.vala"
			updated_row = _tmp26_;
#line 11386 "Photo.c"
		}
		__finally317:
		{
			PhotoRow* _tmp27_;
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = self->row;
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 11395 "Photo.c"
		}
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11399 "Photo.c"
			gboolean _tmp28_ = FALSE;
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_row_unref0 (updated_row);
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing);
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 1454 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp28_;
#line 11413 "Photo.c"
		}
	}
#line 1459 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = g_new0 (gchar*, 0 + 1);
#line 1459 "/home/jens/Source/shotwell/src/Photo.vala"
	list = _tmp29_;
#line 1459 "/home/jens/Source/shotwell/src/Photo.vala"
	list_length1 = 0;
#line 1459 "/home/jens/Source/shotwell/src/Photo.vala"
	_list_size_ = list_length1;
#line 1461 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = updated_row;
#line 1461 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = _tmp30_->md5;
#line 1461 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = detected;
#line 1461 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = _tmp32_->md5;
#line 1461 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_strcmp0 (_tmp31_, _tmp33_) != 0) {
#line 11434 "Photo.c"
		gchar** _tmp34_;
		gint _tmp34__length1;
		gchar* _tmp35_;
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp34_ = list;
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp34__length1 = list_length1;
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp35_ = g_strdup ("metadata:md5");
#line 1462 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add92 (&list, &list_length1, &_list_size_, _tmp35_);
#line 11446 "Photo.c"
	}
#line 1464 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = updated_row;
#line 1464 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = _tmp36_->master;
#line 1464 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = _tmp37_->original_orientation;
#line 1464 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = backing;
#line 1464 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = _tmp39_->original_orientation;
#line 1464 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp38_ != _tmp40_) {
#line 11460 "Photo.c"
		gchar** _tmp41_;
		gint _tmp41__length1;
		gchar* _tmp42_;
		PhotoRow* _tmp43_;
		BackingPhotoRow* _tmp44_;
		BackingPhotoRow* _tmp45_;
		Orientation _tmp46_;
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = list;
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41__length1 = list_length1;
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = g_strdup ("image:orientation");
#line 1465 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add93 (&list, &list_length1, &_list_size_, _tmp42_);
#line 1466 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = updated_row;
#line 1466 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp44_ = _tmp43_->master;
#line 1466 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = backing;
#line 1466 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = _tmp45_->original_orientation;
#line 1466 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp44_->original_orientation = _tmp46_;
#line 11486 "Photo.c"
	}
#line 1469 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = detected;
#line 1469 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp48_ = _tmp47_->metadata;
#line 1469 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp48_ != NULL) {
#line 11494 "Photo.c"
		MetadataDateTime* date_time = NULL;
		DetectedPhotoInformation* _tmp49_;
		PhotoMetadata* _tmp50_;
		MetadataDateTime* _tmp51_;
		gboolean _tmp52_ = FALSE;
		MetadataDateTime* _tmp53_;
		PhotoRow* _tmp60_;
		const gchar* _tmp61_;
		DetectedPhotoInformation* _tmp62_;
		PhotoMetadata* _tmp63_;
		gchar* _tmp64_;
		gchar* _tmp65_;
		gboolean _tmp66_;
		PhotoRow* _tmp69_;
		const gchar* _tmp70_;
		DetectedPhotoInformation* _tmp71_;
		PhotoMetadata* _tmp72_;
		gchar* _tmp73_;
		gchar* _tmp74_;
		gboolean _tmp75_;
		PhotoRow* _tmp78_;
		Rating _tmp79_;
		DetectedPhotoInformation* _tmp80_;
		PhotoMetadata* _tmp81_;
		Rating _tmp82_;
#line 1470 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = detected;
#line 1470 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp50_ = _tmp49_->metadata;
#line 1470 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp51_ = photo_metadata_get_exposure_date_time (_tmp50_);
#line 1470 "/home/jens/Source/shotwell/src/Photo.vala"
		date_time = _tmp51_;
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp53_ = date_time;
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp53_ != NULL) {
#line 11532 "Photo.c"
			PhotoRow* _tmp54_;
			time_t _tmp55_;
			MetadataDateTime* _tmp56_;
			time_t _tmp57_;
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp54_ = updated_row;
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp55_ = _tmp54_->exposure_time;
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp56_ = date_time;
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp57_ = metadata_date_time_get_timestamp (_tmp56_);
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp52_ = _tmp55_ != _tmp57_;
#line 11547 "Photo.c"
		} else {
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp52_ = FALSE;
#line 11551 "Photo.c"
		}
#line 1471 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp52_) {
#line 11555 "Photo.c"
			gchar** _tmp58_;
			gint _tmp58__length1;
			gchar* _tmp59_;
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp58_ = list;
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp58__length1 = list_length1;
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp59_ = g_strdup ("metadata:exposure-time");
#line 1472 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add94 (&list, &list_length1, &_list_size_, _tmp59_);
#line 11567 "Photo.c"
		}
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp60_ = updated_row;
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp61_ = _tmp60_->title;
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp62_ = detected;
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp63_ = _tmp62_->metadata;
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp64_ = media_metadata_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp65_ = _tmp64_;
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp66_ = g_strcmp0 (_tmp61_, _tmp65_) != 0;
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp65_);
#line 1474 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp66_) {
#line 11587 "Photo.c"
			gchar** _tmp67_;
			gint _tmp67__length1;
			gchar* _tmp68_;
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp67_ = list;
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp67__length1 = list_length1;
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp68_ = g_strdup ("metadata:name");
#line 1475 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add95 (&list, &list_length1, &_list_size_, _tmp68_);
#line 11599 "Photo.c"
		}
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp69_ = updated_row;
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp70_ = _tmp69_->comment;
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp71_ = detected;
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp72_ = _tmp71_->metadata;
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp73_ = media_metadata_get_comment (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp74_ = _tmp73_;
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp75_ = g_strcmp0 (_tmp70_, _tmp74_) != 0;
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp74_);
#line 1477 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp75_) {
#line 11619 "Photo.c"
			gchar** _tmp76_;
			gint _tmp76__length1;
			gchar* _tmp77_;
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp76_ = list;
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp76__length1 = list_length1;
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp77_ = g_strdup ("metadata:comment");
#line 1478 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add96 (&list, &list_length1, &_list_size_, _tmp77_);
#line 11631 "Photo.c"
		}
#line 1480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp78_ = updated_row;
#line 1480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp79_ = _tmp78_->rating;
#line 1480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp80_ = detected;
#line 1480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp81_ = _tmp80_->metadata;
#line 1480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp82_ = photo_metadata_get_rating (_tmp81_);
#line 1480 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp79_ != _tmp82_) {
#line 11645 "Photo.c"
			gchar** _tmp83_;
			gint _tmp83__length1;
			gchar* _tmp84_;
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp83_ = list;
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp83__length1 = list_length1;
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp84_ = g_strdup ("metadata:rating");
#line 1481 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add97 (&list, &list_length1, &_list_size_, _tmp84_);
#line 11657 "Photo.c"
		}
#line 1469 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 11661 "Photo.c"
	}
#line 1484 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp85_ = updated_row;
#line 1484 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp86_ = backing;
#line 1484 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp87_ = _backing_photo_row_ref0 (_tmp86_);
#line 1484 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp85_->master);
#line 1484 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp85_->master = _tmp87_;
#line 1485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp88_ = updated_row;
#line 1485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp89_ = detected;
#line 1485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp90_ = _tmp89_->md5;
#line 1485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp91_ = g_strdup (_tmp90_);
#line 1485 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp88_->md5);
#line 1485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp88_->md5 = _tmp91_;
#line 1486 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp92_ = updated_row;
#line 1486 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp93_ = detected;
#line 1486 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp94_ = _tmp93_->exif_md5;
#line 1486 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp95_ = g_strdup (_tmp94_);
#line 1486 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp92_->exif_md5);
#line 1486 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp92_->exif_md5 = _tmp95_;
#line 1487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp96_ = updated_row;
#line 1487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp97_ = detected;
#line 1487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp98_ = _tmp97_->thumbnail_md5;
#line 1487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp99_ = g_strdup (_tmp98_);
#line 1487 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp96_->thumbnail_md5);
#line 1487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp96_->thumbnail_md5 = _tmp99_;
#line 1489 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = NULL;
#line 1490 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp100_ = detected;
#line 1490 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp101_ = _tmp100_->metadata;
#line 1490 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp101_ != NULL) {
#line 11717 "Photo.c"
		DetectedPhotoInformation* _tmp102_;
		PhotoMetadata* _tmp103_;
		PhotoMetadata* _tmp104_;
		MetadataDateTime* date_time = NULL;
		DetectedPhotoInformation* _tmp105_;
		PhotoMetadata* _tmp106_;
		MetadataDateTime* _tmp107_;
		MetadataDateTime* _tmp108_;
		PhotoRow* _tmp112_;
		DetectedPhotoInformation* _tmp113_;
		PhotoMetadata* _tmp114_;
		gchar* _tmp115_;
		PhotoRow* _tmp116_;
		DetectedPhotoInformation* _tmp117_;
		PhotoMetadata* _tmp118_;
		gchar* _tmp119_;
		PhotoRow* _tmp120_;
		DetectedPhotoInformation* _tmp121_;
		PhotoMetadata* _tmp122_;
		Rating _tmp123_;
#line 1491 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp102_ = detected;
#line 1491 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp103_ = _tmp102_->metadata;
#line 1491 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp104_ = _media_metadata_ref0 (_tmp103_);
#line 1491 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 1491 "/home/jens/Source/shotwell/src/Photo.vala"
		metadata = _tmp104_;
#line 1493 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp105_ = detected;
#line 1493 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp106_ = _tmp105_->metadata;
#line 1493 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp107_ = photo_metadata_get_exposure_date_time (_tmp106_);
#line 1493 "/home/jens/Source/shotwell/src/Photo.vala"
		date_time = _tmp107_;
#line 1494 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp108_ = date_time;
#line 1494 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp108_ != NULL) {
#line 11760 "Photo.c"
			PhotoRow* _tmp109_;
			MetadataDateTime* _tmp110_;
			time_t _tmp111_;
#line 1495 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp109_ = updated_row;
#line 1495 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp110_ = date_time;
#line 1495 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp111_ = metadata_date_time_get_timestamp (_tmp110_);
#line 1495 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp109_->exposure_time = _tmp111_;
#line 11772 "Photo.c"
		}
#line 1497 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp112_ = updated_row;
#line 1497 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp113_ = detected;
#line 1497 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp114_ = _tmp113_->metadata;
#line 1497 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp115_ = media_metadata_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1497 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp112_->title);
#line 1497 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp112_->title = _tmp115_;
#line 1498 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp116_ = updated_row;
#line 1498 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp117_ = detected;
#line 1498 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp118_ = _tmp117_->metadata;
#line 1498 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp119_ = media_metadata_get_comment (G_TYPE_CHECK_INSTANCE_CAST (_tmp118_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1498 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp116_->comment);
#line 1498 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp116_->comment = _tmp119_;
#line 1499 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp120_ = updated_row;
#line 1499 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp121_ = detected;
#line 1499 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp122_ = _tmp121_->metadata;
#line 1499 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp123_ = photo_metadata_get_rating (_tmp122_);
#line 1499 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp120_->rating = _tmp123_;
#line 1490 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 11810 "Photo.c"
	}
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp124_ = updated_row;
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp125_ = metadata;
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp126_ = list;
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp126__length1 = list_length1;
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp127_ = photo_reimport_master_state_impl_new (_tmp124_, _tmp125_, _tmp126_, _tmp126__length1);
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_master_state_unref0 (_vala_reimport_state);
#line 1502 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_reimport_state = G_TYPE_CHECK_INSTANCE_CAST (_tmp127_, PHOTO_TYPE_REIMPORT_MASTER_STATE, PhotoReimportMasterState);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	list = (_vala_array_free (list, list_length1, (GDestroyNotify) g_free), NULL);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (updated_row);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (backing);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	if (reimport_state) {
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
		*reimport_state = _vala_reimport_state;
#line 11844 "Photo.c"
	} else {
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_reimport_master_state_unref0 (_vala_reimport_state);
#line 11848 "Photo.c"
	}
#line 1504 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 11852 "Photo.c"
}


static void photo_real_apply_user_metadata_for_reimport (Photo* self, PhotoMetadata* metadata) {
#line 1507 "/home/jens/Source/shotwell/src/Photo.vala"
	g_critical ("Type `%s' does not implement abstract method `photo_apply_user_metadata_for_reimport'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 1507 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 11861 "Photo.c"
}


void photo_apply_user_metadata_for_reimport (Photo* self, PhotoMetadata* metadata) {
#line 1507 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1507 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->apply_user_metadata_for_reimport (self, metadata);
#line 11870 "Photo.c"
}


static gpointer _photo_reimport_master_state_ref0 (gpointer self) {
#line 1511 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? photo_reimport_master_state_ref (self) : NULL;
#line 11877 "Photo.c"
}


static void _vala_array_add98 (gchar** * array, int* length, int* size, gchar* value) {
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11888 "Photo.c"
	}
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11894 "Photo.c"
}


static void _vala_array_add99 (gchar** * array, int* length, int* size, gchar* value) {
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 11905 "Photo.c"
	}
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 11911 "Photo.c"
}


void photo_finish_reimport_master (Photo* self, PhotoReimportMasterState* state, GError** error) {
	PhotoReimportMasterStateImpl* reimport_state = NULL;
	PhotoReimportMasterState* _tmp0_;
	PhotoReimportMasterStateImpl* _tmp1_;
	PhotoTable* _tmp2_;
	PhotoTable* _tmp3_;
	PhotoRow* _tmp4_;
	PhotoMetadata* _tmp20_;
	gboolean _tmp22_;
	gchar** _tmp28_;
	gint _tmp28__length1;
	PhotoMetadata* _tmp32_;
	gboolean _tmp33_;
	gboolean _tmp35_;
	GError * _inner_error_ = NULL;
#line 1510 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1510 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_REIMPORT_MASTER_STATE (state));
#line 1511 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = state;
#line 1511 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _photo_reimport_master_state_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, PhotoReimportMasterStateImpl));
#line 1511 "/home/jens/Source/shotwell/src/Photo.vala"
	reimport_state = _tmp1_;
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_table_get_instance ();
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = reimport_state->row;
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_table_reimport (_tmp3_, _tmp4_, &_inner_error_);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp3_);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_master_state_unref0 (reimport_state);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 11960 "Photo.c"
		} else {
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_master_state_unref0 (reimport_state);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 1513 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 11970 "Photo.c"
		}
	}
	{
		PhotoRow* _tmp5_;
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = self->row;
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 11979 "Photo.c"
		{
			BackingPhotoRow* original_master = NULL;
			PhotoRow* _tmp6_;
			BackingPhotoRow* _tmp7_;
			BackingPhotoRow* _tmp8_;
			PhotoRow* _tmp9_;
			PhotoRow* _tmp10_;
			PhotoRow* _tmp11_;
			BackingPhotoRow* _tmp12_;
			BackingPhotoRow* _tmp13_;
			PhotoRow* _tmp14_;
			BackingPhotoRow* _tmp15_;
			PhotoRow* _tmp16_;
			BackingPhotoRow* _tmp17_;
			gboolean _tmp18_;
#line 1517 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->row;
#line 1517 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _tmp6_->master;
#line 1517 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _backing_photo_row_ref0 (_tmp7_);
#line 1517 "/home/jens/Source/shotwell/src/Photo.vala"
			original_master = _tmp8_;
#line 1518 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = reimport_state->row;
#line 1518 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = _photo_row_ref0 (_tmp9_);
#line 1518 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_row_unref0 (self->row);
#line 1518 "/home/jens/Source/shotwell/src/Photo.vala"
			self->row = _tmp10_;
#line 1519 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = self->row;
#line 1519 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = original_master;
#line 1519 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = _backing_photo_row_ref0 (_tmp12_);
#line 1519 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (_tmp11_->master);
#line 1519 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_->master = _tmp13_;
#line 1520 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = self->row;
#line 1520 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = _tmp14_->master;
#line 1520 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = reimport_state->row;
#line 1520 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = _tmp16_->master;
#line 1520 "/home/jens/Source/shotwell/src/Photo.vala"
			backing_photo_row_copy_from (_tmp15_, _tmp17_);
#line 1521 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = reimport_state->metadata_only;
#line 1521 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp18_) {
#line 1522 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_internal_remove_all_transformations (self, FALSE);
#line 12037 "Photo.c"
			}
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (original_master);
#line 12041 "Photo.c"
		}
		__finally318:
		{
			PhotoRow* _tmp19_;
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = self->row;
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 12050 "Photo.c"
		}
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_reimport_master_state_unref0 (reimport_state);
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 12062 "Photo.c"
			} else {
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_reimport_master_state_unref0 (reimport_state);
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 1515 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 12072 "Photo.c"
			}
		}
	}
#line 1525 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = reimport_state->metadata;
#line 1525 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp20_ != NULL) {
#line 12080 "Photo.c"
		PhotoMetadata* _tmp21_;
#line 1526 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = reimport_state->metadata;
#line 1526 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_apply_user_metadata_for_reimport (self, _tmp21_);
#line 12086 "Photo.c"
	}
#line 1528 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = reimport_state->metadata_only;
#line 1528 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp22_) {
#line 12092 "Photo.c"
		gchar** _tmp23_;
		gint _tmp23__length1;
		gchar* _tmp24_;
		gboolean _tmp25_;
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = reimport_state->alterations;
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23__length1 = reimport_state->alterations_length1;
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = g_strdup ("image:master");
#line 1529 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add98 (&reimport_state->alterations, &reimport_state->alterations_length1, &reimport_state->_alterations_size_, _tmp24_);
#line 1530 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = photo_is_master_baseline (self);
#line 1530 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp25_) {
#line 12109 "Photo.c"
			gchar** _tmp26_;
			gint _tmp26__length1;
			gchar* _tmp27_;
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = reimport_state->alterations;
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26__length1 = reimport_state->alterations_length1;
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = g_strdup ("image:baseline");
#line 1531 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add99 (&reimport_state->alterations, &reimport_state->alterations_length1, &reimport_state->_alterations_size_, _tmp27_);
#line 12121 "Photo.c"
		}
	}
#line 1534 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = reimport_state->alterations;
#line 1534 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28__length1 = reimport_state->alterations_length1;
#line 1534 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp28__length1 > 0) {
#line 12130 "Photo.c"
		gchar** _tmp29_;
		gint _tmp29__length1;
		Alteration* _tmp30_;
		Alteration* _tmp31_;
#line 1535 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_ = reimport_state->alterations;
#line 1535 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29__length1 = reimport_state->alterations_length1;
#line 1535 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = alteration_new_from_array (_tmp29_, _tmp29__length1);
#line 1535 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = _tmp30_;
#line 1535 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp31_);
#line 1535 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp31_);
#line 12147 "Photo.c"
	}
#line 1537 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = reimport_state->metadata;
#line 1537 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_notify_master_reimported (self, _tmp32_);
#line 1539 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = photo_is_master_baseline (self);
#line 1539 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp33_) {
#line 12157 "Photo.c"
		PhotoMetadata* _tmp34_;
#line 1540 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp34_ = reimport_state->metadata;
#line 1540 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_baseline_reimported (self, _tmp34_);
#line 12163 "Photo.c"
	}
#line 1542 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = photo_is_master_source (self);
#line 1542 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp35_) {
#line 12169 "Photo.c"
		PhotoMetadata* _tmp36_;
#line 1543 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = reimport_state->metadata;
#line 1543 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_source_reimported (self, _tmp36_);
#line 12175 "Photo.c"
	}
#line 1510 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_master_state_unref0 (reimport_state);
#line 12179 "Photo.c"
}


static gboolean photo_verify_file_for_reimport (Photo* self, GFile* file, BackingPhotoRow* * backing, DetectedPhotoInformation* * detected, GError** error) {
	BackingPhotoRow* _vala_backing = NULL;
	DetectedPhotoInformation* _vala_detected = NULL;
	gboolean result = FALSE;
	BackingPhotoRow* _tmp0_ = NULL;
	GFile* _tmp1_;
	DetectedPhotoInformation* _tmp2_ = NULL;
	BackingPhotoRow* _tmp3_;
	BackingPhotoRow* _tmp5_;
	BackingPhotoRow* _tmp6_;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	DetectedPhotoInformation* _tmp9_;
	GdkColorspace _tmp10_;
	GError * _inner_error_ = NULL;
#line 1547 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 1547 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_query_backing_photo_row (self, _tmp1_, PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5, &_tmp2_, &_inner_error_);
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (_vala_detected);
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_detected = _tmp2_;
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp3_;
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12214 "Photo.c"
		gboolean _tmp4_ = FALSE;
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp4_;
#line 12220 "Photo.c"
	}
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp0_;
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_vala_backing);
#line 1549 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_backing = _tmp5_;
#line 1551 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _vala_backing;
#line 1551 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_ == NULL) {
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (_tmp0_);
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
		if (backing) {
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
			*backing = _vala_backing;
#line 12242 "Photo.c"
		} else {
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (_vala_backing);
#line 12246 "Photo.c"
		}
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
		if (detected) {
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
			*detected = _vala_detected;
#line 12252 "Photo.c"
		} else {
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (_vala_detected);
#line 12256 "Photo.c"
		}
#line 1552 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 12260 "Photo.c"
	}
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _vala_detected;
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = _tmp9_->colorspace;
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp10_ != GDK_COLORSPACE_RGB) {
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = TRUE;
#line 12270 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp11_;
		gint _tmp12_;
#line 1557 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = _vala_detected;
#line 1557 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp11_->channels;
#line 1557 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = _tmp12_ < 3;
#line 12280 "Photo.c"
	}
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_) {
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = TRUE;
#line 12286 "Photo.c"
	} else {
		DetectedPhotoInformation* _tmp13_;
		gint _tmp14_;
#line 1558 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _vala_detected;
#line 1558 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = _tmp13_->bits_per_channel;
#line 1558 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp14_ != 8;
#line 12296 "Photo.c"
	}
#line 1556 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp7_) {
#line 12300 "Photo.c"
		GFile* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
#line 1559 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = file;
#line 1559 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = g_file_get_path (_tmp15_);
#line 1559 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = _tmp16_;
#line 1559 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:1559: Not re-importing %s: Unsupported color format", _tmp17_);
#line 1559 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp17_);
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (_tmp0_);
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
		if (backing) {
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
			*backing = _vala_backing;
#line 12322 "Photo.c"
		} else {
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (_vala_backing);
#line 12326 "Photo.c"
		}
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
		if (detected) {
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
			*detected = _vala_detected;
#line 12332 "Photo.c"
		} else {
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (_vala_detected);
#line 12336 "Photo.c"
		}
#line 1561 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 12340 "Photo.c"
	}
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp0_);
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
	if (backing) {
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
		*backing = _vala_backing;
#line 12350 "Photo.c"
	} else {
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (_vala_backing);
#line 12354 "Photo.c"
	}
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
	if (detected) {
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
		*detected = _vala_detected;
#line 12360 "Photo.c"
	} else {
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (_vala_detected);
#line 12364 "Photo.c"
	}
#line 1564 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 12368 "Photo.c"
}


gboolean photo_prepare_for_reimport_editable (Photo* self, PhotoReimportEditableState* * state, GError** error) {
	PhotoReimportEditableState* _vala_state = NULL;
	gboolean result = FALSE;
	GFile* file = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	DetectedPhotoInformation* detected = NULL;
	BackingPhotoRow* backing = NULL;
	gboolean _tmp2_ = FALSE;
	GFile* _tmp3_;
	BackingPhotoRow* _tmp4_ = NULL;
	DetectedPhotoInformation* _tmp5_ = NULL;
	gboolean _tmp6_;
	BackingPhotoRow* _tmp8_;
	DetectedPhotoInformation* _tmp9_;
	PhotoMetadata* _tmp10_;
	PhotoReimportEditableStateImpl* _tmp11_;
	GError * _inner_error_ = NULL;
#line 1568 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 1569 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_editable_state_unref0 (_vala_state);
#line 1569 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = NULL;
#line 1571 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_editable_file (self);
#line 1571 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp0_;
#line 1572 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 1572 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 1573 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1573 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1573 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 1573 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 12412 "Photo.c"
		} else {
#line 1573 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_editable_state_unref0 (_vala_state);
#line 12416 "Photo.c"
		}
#line 1573 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 12420 "Photo.c"
	}
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = file;
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_verify_file_for_reimport (self, _tmp3_, &_tmp4_, &_tmp5_, &_inner_error_);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (backing);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	backing = _tmp4_;
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	detected = _tmp5_;
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp6_;
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12438 "Photo.c"
		gboolean _tmp7_ = FALSE;
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp7_;
#line 12450 "Photo.c"
	}
#line 1577 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp2_) {
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (backing);
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 12466 "Photo.c"
		} else {
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_editable_state_unref0 (_vala_state);
#line 12470 "Photo.c"
		}
#line 1578 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 12474 "Photo.c"
	}
#line 1580 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = backing;
#line 1580 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = detected;
#line 1580 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = _tmp9_->metadata;
#line 1580 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = photo_reimport_editable_state_impl_new (_tmp8_, _tmp10_);
#line 1580 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_editable_state_unref0 (_vala_state);
#line 1580 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, PHOTO_TYPE_REIMPORT_EDITABLE_STATE, PhotoReimportEditableState);
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (backing);
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
	if (state) {
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
		*state = _vala_state;
#line 12500 "Photo.c"
	} else {
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_reimport_editable_state_unref0 (_vala_state);
#line 12504 "Photo.c"
	}
#line 1582 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 12508 "Photo.c"
}


static gpointer _photo_reimport_editable_state_ref0 (gpointer self) {
#line 1591 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? photo_reimport_editable_state_ref (self) : NULL;
#line 12515 "Photo.c"
}


void photo_finish_reimport_editable (Photo* self, PhotoReimportEditableState* state, GError** error) {
	BackingPhotoID editable_id = {0};
	BackingPhotoID _tmp0_ = {0};
	gboolean _tmp1_;
	PhotoReimportEditableStateImpl* reimport_state = NULL;
	PhotoReimportEditableState* _tmp2_;
	PhotoReimportEditableStateImpl* _tmp3_;
	PhotoReimportEditableStateImpl* _tmp4_;
	gboolean _tmp5_;
	PhotoReimportEditableStateImpl* _tmp21_;
	PhotoMetadata* _tmp22_;
	gchar* list = NULL;
	gchar* _tmp36_;
	PhotoReimportEditableStateImpl* _tmp37_;
	gboolean _tmp38_;
	const gchar* _tmp41_;
	Alteration* _tmp42_;
	Alteration* _tmp43_;
	PhotoReimportEditableStateImpl* _tmp44_;
	PhotoMetadata* _tmp45_;
	gboolean _tmp46_;
	gboolean _tmp49_;
	GError * _inner_error_ = NULL;
#line 1586 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1586 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_REIMPORT_EDITABLE_STATE (state));
#line 1587 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_editable_id (self, &_tmp0_);
#line 1587 "/home/jens/Source/shotwell/src/Photo.vala"
	editable_id = _tmp0_;
#line 1588 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = backing_photo_id_is_invalid (&editable_id);
#line 1588 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 1589 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 12556 "Photo.c"
	}
#line 1591 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = state;
#line 1591 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _photo_reimport_editable_state_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, PhotoReimportEditableStateImpl));
#line 1591 "/home/jens/Source/shotwell/src/Photo.vala"
	reimport_state = _tmp3_;
#line 1593 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = reimport_state;
#line 1593 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_->metadata_only;
#line 1593 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp5_) {
#line 12570 "Photo.c"
		BackingPhotoTable* _tmp6_;
		BackingPhotoTable* _tmp7_;
		PhotoReimportEditableStateImpl* _tmp8_;
		BackingPhotoRow* _tmp9_;
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = backing_photo_table_get_instance ();
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = reimport_state;
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = _tmp8_->backing_state;
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		backing_photo_table_update (_tmp7_, _tmp9_, &_inner_error_);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		_database_table_unref0 (_tmp7_);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_reimport_editable_state_unref0 (reimport_state);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 12597 "Photo.c"
			} else {
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_reimport_editable_state_unref0 (reimport_state);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 1594 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 12607 "Photo.c"
			}
		}
		{
			PhotoRow* _tmp10_;
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = self->row;
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 12616 "Photo.c"
			{
				PhotoReimportEditableStateImpl* _tmp11_;
				BackingPhotoRow* _tmp12_;
				BackingPhotoRow* _tmp13_;
				PhotoReimportEditableStateImpl* _tmp14_;
				BackingPhotoRow* _tmp15_;
				Orientation _tmp16_;
#line 1597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = reimport_state;
#line 1597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tmp11_->backing_state;
#line 1597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _backing_photo_row_ref0 (_tmp12_);
#line 1597 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (self->priv->editable);
#line 1597 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->editable = _tmp13_;
#line 1598 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = reimport_state;
#line 1598 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = _tmp14_->backing_state;
#line 1598 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = _tmp15_->original_orientation;
#line 1598 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_set_orientation (self, _tmp16_);
#line 1599 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_internal_remove_all_transformations (self, FALSE);
#line 12644 "Photo.c"
			}
			__finally319:
			{
				PhotoRow* _tmp17_;
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = self->row;
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 12653 "Photo.c"
			}
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					g_propagate_error (error, _inner_error_);
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_reimport_editable_state_unref0 (reimport_state);
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 12665 "Photo.c"
				} else {
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_reimport_editable_state_unref0 (reimport_state);
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 1596 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 12675 "Photo.c"
				}
			}
		}
	} else {
		PhotoReimportEditableStateImpl* _tmp18_;
		BackingPhotoRow* _tmp19_;
		Orientation _tmp20_;
#line 1602 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = reimport_state;
#line 1602 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = _tmp18_->backing_state;
#line 1602 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = _tmp19_->original_orientation;
#line 1602 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_set_orientation (self, _tmp20_);
#line 12691 "Photo.c"
	}
#line 1605 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = reimport_state;
#line 1605 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = _tmp21_->metadata;
#line 1605 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp22_ != NULL) {
#line 12699 "Photo.c"
		PhotoReimportEditableStateImpl* _tmp23_;
		PhotoMetadata* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		PhotoReimportEditableStateImpl* _tmp27_;
		PhotoMetadata* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		PhotoReimportEditableStateImpl* _tmp31_;
		PhotoMetadata* _tmp32_;
		Rating _tmp33_;
		PhotoReimportEditableStateImpl* _tmp34_;
		PhotoMetadata* _tmp35_;
#line 1606 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = reimport_state;
#line 1606 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = _tmp23_->metadata;
#line 1606 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = media_metadata_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1606 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp26_ = _tmp25_;
#line 1606 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp26_);
#line 1606 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp26_);
#line 1607 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp27_ = reimport_state;
#line 1607 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = _tmp27_->metadata;
#line 1607 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_ = media_metadata_get_comment (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 1607 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = _tmp29_;
#line 1607 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp30_);
#line 1607 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp30_);
#line 1608 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = reimport_state;
#line 1608 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp32_ = _tmp31_->metadata;
#line 1608 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp33_ = photo_metadata_get_rating (_tmp32_);
#line 1608 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp33_);
#line 1609 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp34_ = reimport_state;
#line 1609 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp35_ = _tmp34_->metadata;
#line 1609 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_apply_user_metadata_for_reimport (self, _tmp35_);
#line 12751 "Photo.c"
	}
#line 1612 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = g_strdup ("metadata:name,image:orientation,metadata:rating,metadata:exposure-time");
#line 1612 "/home/jens/Source/shotwell/src/Photo.vala"
	list = _tmp36_;
#line 1613 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = reimport_state;
#line 1613 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = _tmp37_->metadata_only;
#line 1613 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp38_) {
#line 12763 "Photo.c"
		const gchar* _tmp39_;
		gchar* _tmp40_;
#line 1614 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = list;
#line 1614 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = g_strconcat (_tmp39_, "image:editable,image:baseline", NULL);
#line 1614 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (list);
#line 1614 "/home/jens/Source/shotwell/src/Photo.vala"
		list = _tmp40_;
#line 12774 "Photo.c"
	}
#line 1616 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = list;
#line 1616 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = alteration_new_from_list (_tmp41_);
#line 1616 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp43_ = _tmp42_;
#line 1616 "/home/jens/Source/shotwell/src/Photo.vala"
	data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp43_);
#line 1616 "/home/jens/Source/shotwell/src/Photo.vala"
	_alteration_unref0 (_tmp43_);
#line 1618 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = reimport_state;
#line 1618 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = _tmp44_->metadata;
#line 1618 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_notify_editable_reimported (self, _tmp45_);
#line 1620 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp46_ = photo_is_editable_baseline (self);
#line 1620 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp46_) {
#line 12796 "Photo.c"
		PhotoReimportEditableStateImpl* _tmp47_;
		PhotoMetadata* _tmp48_;
#line 1621 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = reimport_state;
#line 1621 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = _tmp47_->metadata;
#line 1621 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_baseline_reimported (self, _tmp48_);
#line 12805 "Photo.c"
	}
#line 1623 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp49_ = photo_is_editable_source (self);
#line 1623 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp49_) {
#line 12811 "Photo.c"
		PhotoReimportEditableStateImpl* _tmp50_;
		PhotoMetadata* _tmp51_;
#line 1624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp50_ = reimport_state;
#line 1624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp51_ = _tmp50_->metadata;
#line 1624 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_source_reimported (self, _tmp51_);
#line 12820 "Photo.c"
	}
#line 1586 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (list);
#line 1586 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_editable_state_unref0 (reimport_state);
#line 12826 "Photo.c"
}


static gpointer _photo_reimport_raw_development_state_ref0 (gpointer self) {
#line 1646 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? photo_reimport_raw_development_state_ref (self) : NULL;
#line 12833 "Photo.c"
}


gboolean photo_prepare_for_reimport_raw_development (Photo* self, PhotoReimportRawDevelopmentState* * state, GError** error) {
	PhotoReimportRawDevelopmentState* _vala_state = NULL;
	gboolean result = FALSE;
	GeeCollection* files = NULL;
	GeeCollection* _tmp0_;
	GeeCollection* _tmp1_;
	PhotoReimportRawDevelopmentStateImpl* reimport_state = NULL;
	PhotoReimportRawDevelopmentStateImpl* _tmp2_;
	PhotoReimportRawDevelopmentStateImpl* _tmp19_;
	PhotoReimportRawDevelopmentState* _tmp20_;
	PhotoReimportRawDevelopmentStateImpl* _tmp21_;
	gint _tmp22_;
	GError * _inner_error_ = NULL;
#line 1628 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 1629 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_raw_development_state_unref0 (_vala_state);
#line 1629 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = NULL;
#line 1631 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_raw_developer_files (self);
#line 1631 "/home/jens/Source/shotwell/src/Photo.vala"
	files = _tmp0_;
#line 1632 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = files;
#line 1632 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 1633 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1633 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (files);
#line 1633 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 1633 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 12872 "Photo.c"
		} else {
#line 1633 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_raw_development_state_unref0 (_vala_state);
#line 12876 "Photo.c"
		}
#line 1633 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 12880 "Photo.c"
	}
#line 1635 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_reimport_raw_development_state_impl_new ();
#line 1635 "/home/jens/Source/shotwell/src/Photo.vala"
	reimport_state = _tmp2_;
#line 12886 "Photo.c"
	{
		GeeIterator* _file_it = NULL;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = files;
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
		_file_it = _tmp4_;
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 12899 "Photo.c"
			GeeIterator* _tmp5_;
			gboolean _tmp6_;
			GFile* file = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			DetectedPhotoInformation* detected = NULL;
			BackingPhotoRow* backing = NULL;
			gboolean _tmp9_ = FALSE;
			GFile* _tmp10_;
			BackingPhotoRow* _tmp11_ = NULL;
			DetectedPhotoInformation* _tmp12_ = NULL;
			gboolean _tmp13_;
			PhotoReimportRawDevelopmentStateImpl* _tmp15_;
			BackingPhotoRow* _tmp16_;
			DetectedPhotoInformation* _tmp17_;
			PhotoMetadata* _tmp18_;
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _file_it;
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = gee_iterator_next (_tmp5_);
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp6_) {
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 12924 "Photo.c"
			}
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _file_it;
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = gee_iterator_get (_tmp7_);
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			file = (GFile*) _tmp8_;
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = file;
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = photo_verify_file_for_reimport (self, _tmp10_, &_tmp11_, &_tmp12_, &_inner_error_);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			backing = _tmp11_;
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			detected = _tmp12_;
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp13_;
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12948 "Photo.c"
				gboolean _tmp14_ = FALSE;
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_file_it);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (files);
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
				return _tmp14_;
#line 12966 "Photo.c"
			}
#line 1640 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp9_) {
#line 1641 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing);
#line 1641 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 1641 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 1641 "/home/jens/Source/shotwell/src/Photo.vala"
				continue;
#line 12978 "Photo.c"
			}
#line 1643 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = reimport_state;
#line 1643 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = backing;
#line 1643 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = detected;
#line 1643 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = _tmp17_->metadata;
#line 1643 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_reimport_raw_development_state_impl_add (_tmp15_, _tmp16_, _tmp18_);
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing);
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 12996 "Photo.c"
		}
#line 1637 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_file_it);
#line 13000 "Photo.c"
	}
#line 1646 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = reimport_state;
#line 1646 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = _photo_reimport_raw_development_state_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE, PhotoReimportRawDevelopmentState));
#line 1646 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_raw_development_state_unref0 (_vala_state);
#line 1646 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = _tmp20_;
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = reimport_state;
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = photo_reimport_raw_development_state_impl_get_size (_tmp21_);
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp22_ > 0;
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (files);
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	if (state) {
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
		*state = _vala_state;
#line 13024 "Photo.c"
	} else {
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_reimport_raw_development_state_unref0 (_vala_state);
#line 13028 "Photo.c"
	}
#line 1647 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 13032 "Photo.c"
}


void photo_finish_reimport_raw_development (Photo* self, PhotoReimportRawDevelopmentState* state, GError** error) {
	PhotoFileFormat _tmp0_;
	PhotoReimportRawDevelopmentStateImpl* reimport_state = NULL;
	PhotoReimportRawDevelopmentState* _tmp1_;
	PhotoReimportRawDevelopmentStateImpl* _tmp2_;
	gchar* list = NULL;
	gchar* _tmp32_;
	PhotoReimportRawDevelopmentStateImpl* _tmp33_;
	gboolean _tmp34_;
	const gchar* _tmp37_;
	Alteration* _tmp38_;
	Alteration* _tmp39_;
	GError * _inner_error_ = NULL;
#line 1651 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1651 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE (state));
#line 1652 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_master_file_format (self);
#line 1652 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != PHOTO_FILE_FORMAT_RAW) {
#line 1653 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 13059 "Photo.c"
	}
#line 1655 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = state;
#line 1655 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _photo_reimport_raw_development_state_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL, PhotoReimportRawDevelopmentStateImpl));
#line 1655 "/home/jens/Source/shotwell/src/Photo.vala"
	reimport_state = _tmp2_;
#line 13067 "Photo.c"
	{
		GeeIterator* _dev_it = NULL;
		PhotoReimportRawDevelopmentStateImpl* _tmp3_;
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = reimport_state;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp3_->list;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
		_dev_it = _tmp5_;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 13083 "Photo.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			PhotoReimportRawDevelopmentStateImplDevToReimport* dev = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			PhotoReimportRawDevelopmentStateImpl* _tmp10_;
			gboolean _tmp11_;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _dev_it;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp7_) {
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 13099 "Photo.c"
			}
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _dev_it;
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			dev = (PhotoReimportRawDevelopmentStateImplDevToReimport*) _tmp9_;
#line 1658 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = reimport_state;
#line 1658 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = _tmp10_->metadata_only;
#line 1658 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp11_) {
#line 13113 "Photo.c"
				BackingPhotoTable* _tmp12_;
				BackingPhotoTable* _tmp13_;
				PhotoReimportRawDevelopmentStateImplDevToReimport* _tmp14_;
				BackingPhotoRow* _tmp15_;
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = backing_photo_table_get_instance ();
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _tmp12_;
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = dev;
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = _tmp14_->backing;
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				backing_photo_table_update (_tmp13_, _tmp15_, &_inner_error_);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp13_);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_inner_error_->domain == DATABASE_ERROR) {
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						g_propagate_error (error, _inner_error_);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_reimport_raw_development_state_impl_dev_to_reimport_unref0 (dev);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_dev_it);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						return;
#line 13144 "Photo.c"
					} else {
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_reimport_raw_development_state_impl_dev_to_reimport_unref0 (dev);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_dev_it);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						g_clear_error (&_inner_error_);
#line 1659 "/home/jens/Source/shotwell/src/Photo.vala"
						return;
#line 13158 "Photo.c"
					}
				}
				{
					PhotoRow* _tmp16_;
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = self->row;
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_lock (&self->priv->__lock_row);
#line 13167 "Photo.c"
					{
						gint _tmp17_;
						RawDeveloper* _tmp18_;
#line 1663 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp18_ = raw_developer_as_array (&_tmp17_);
#line 13173 "Photo.c"
						{
							RawDeveloper* d_collection = NULL;
							gint d_collection_length1 = 0;
							gint _d_collection_size_ = 0;
							gint d_it = 0;
#line 1663 "/home/jens/Source/shotwell/src/Photo.vala"
							d_collection = _tmp18_;
#line 1663 "/home/jens/Source/shotwell/src/Photo.vala"
							d_collection_length1 = _tmp17_;
#line 1663 "/home/jens/Source/shotwell/src/Photo.vala"
							for (d_it = 0; d_it < _tmp17_; d_it = d_it + 1) {
#line 13185 "Photo.c"
								RawDeveloper d = 0;
#line 1663 "/home/jens/Source/shotwell/src/Photo.vala"
								d = d_collection[d_it];
#line 13189 "Photo.c"
								{
									BackingPhotoID id = {0};
									PhotoRow* _tmp19_;
									BackingPhotoID* _tmp20_;
									gint _tmp20__length1;
									RawDeveloper _tmp21_;
									BackingPhotoID _tmp22_;
									BackingPhotoID _tmp23_;
									gint64 _tmp24_;
#line 1664 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp19_ = self->row;
#line 1664 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp20_ = _tmp19_->development_ids;
#line 1664 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp20__length1 = _tmp19_->development_ids_length1;
#line 1664 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp21_ = d;
#line 1664 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp22_ = _tmp20_[_tmp21_];
#line 1664 "/home/jens/Source/shotwell/src/Photo.vala"
									id = _tmp22_;
#line 1665 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp23_ = id;
#line 1665 "/home/jens/Source/shotwell/src/Photo.vala"
									_tmp24_ = _tmp23_.id;
#line 1665 "/home/jens/Source/shotwell/src/Photo.vala"
									if (_tmp24_ != BACKING_PHOTO_ID_INVALID) {
#line 13217 "Photo.c"
										BackingPhotoRow* bpr = NULL;
										BackingPhotoID _tmp25_;
										BackingPhotoRow* _tmp26_;
										BackingPhotoRow* _tmp27_;
#line 1666 "/home/jens/Source/shotwell/src/Photo.vala"
										_tmp25_ = id;
#line 1666 "/home/jens/Source/shotwell/src/Photo.vala"
										_tmp26_ = photo_get_backing_row (self, &_tmp25_);
#line 1666 "/home/jens/Source/shotwell/src/Photo.vala"
										bpr = _tmp26_;
#line 1667 "/home/jens/Source/shotwell/src/Photo.vala"
										_tmp27_ = bpr;
#line 1667 "/home/jens/Source/shotwell/src/Photo.vala"
										if (_tmp27_ != NULL) {
#line 13232 "Photo.c"
											GeeHashMap* _tmp28_;
											RawDeveloper _tmp29_;
											BackingPhotoRow* _tmp30_;
#line 1668 "/home/jens/Source/shotwell/src/Photo.vala"
											_tmp28_ = self->priv->developments;
#line 1668 "/home/jens/Source/shotwell/src/Photo.vala"
											_tmp29_ = d;
#line 1668 "/home/jens/Source/shotwell/src/Photo.vala"
											_tmp30_ = bpr;
#line 1668 "/home/jens/Source/shotwell/src/Photo.vala"
											gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), (gpointer) ((gintptr) _tmp29_), _tmp30_);
#line 13244 "Photo.c"
										}
#line 1665 "/home/jens/Source/shotwell/src/Photo.vala"
										_backing_photo_row_unref0 (bpr);
#line 13248 "Photo.c"
									}
								}
							}
#line 1663 "/home/jens/Source/shotwell/src/Photo.vala"
							d_collection = (g_free (d_collection), NULL);
#line 13254 "Photo.c"
						}
					}
					__finally320:
					{
						PhotoRow* _tmp31_;
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp31_ = self->row;
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_row);
#line 13264 "Photo.c"
					}
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_inner_error_->domain == DATABASE_ERROR) {
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							g_propagate_error (error, _inner_error_);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							_photo_reimport_raw_development_state_impl_dev_to_reimport_unref0 (dev);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_dev_it);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							return;
#line 13280 "Photo.c"
						} else {
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							_photo_reimport_raw_development_state_impl_dev_to_reimport_unref0 (dev);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_dev_it);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							g_clear_error (&_inner_error_);
#line 1661 "/home/jens/Source/shotwell/src/Photo.vala"
							return;
#line 13294 "Photo.c"
						}
					}
				}
			}
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_raw_development_state_impl_dev_to_reimport_unref0 (dev);
#line 13301 "Photo.c"
		}
#line 1657 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_dev_it);
#line 13305 "Photo.c"
	}
#line 1675 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = g_strdup ("metadata:name,image:orientation,metadata:rating,metadata:exposure-time");
#line 1675 "/home/jens/Source/shotwell/src/Photo.vala"
	list = _tmp32_;
#line 1676 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = reimport_state;
#line 1676 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = _tmp33_->metadata_only;
#line 1676 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp34_) {
#line 13317 "Photo.c"
		const gchar* _tmp35_;
		gchar* _tmp36_;
#line 1677 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp35_ = list;
#line 1677 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = g_strconcat (_tmp35_, "image:editable,image:baseline", NULL);
#line 1677 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (list);
#line 1677 "/home/jens/Source/shotwell/src/Photo.vala"
		list = _tmp36_;
#line 13328 "Photo.c"
	}
#line 1679 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = list;
#line 1679 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = alteration_new_from_list (_tmp37_);
#line 1679 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = _tmp38_;
#line 1679 "/home/jens/Source/shotwell/src/Photo.vala"
	data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp39_);
#line 1679 "/home/jens/Source/shotwell/src/Photo.vala"
	_alteration_unref0 (_tmp39_);
#line 1681 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_notify_raw_development_modified (self);
#line 1651 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (list);
#line 1651 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_raw_development_state_unref0 (reimport_state);
#line 13346 "Photo.c"
}


static gchar* photo_real_get_typename (DataSource* base) {
	Photo * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 1684 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1685 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = g_strdup (PHOTO_TYPENAME);
#line 1685 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 1685 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 13362 "Photo.c"
}


static gint64 photo_real_get_instance_id (DataSource* base) {
	Photo * self;
	gint64 result = 0LL;
	PhotoID _tmp0_ = {0};
	gint64 _tmp1_;
#line 1688 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1689 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_photo_id (self, &_tmp0_);
#line 1689 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_.id;
#line 1689 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 1689 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 13381 "Photo.c"
}


static gchar* photo_real_get_source_id (DataSource* base) {
	Photo * self;
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gint64 _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 1692 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = data_source_get_typename (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_SOURCE, DataSource));
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = data_source_get_instance_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_SOURCE, DataSource));
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = g_strdup_printf ("%s%016" G_GINT64_MODIFIER "x", _tmp1_, _tmp2_);
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp1_);
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 1696 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 13411 "Photo.c"
}


void photo_set_master_timestamp (Photo* self, GFileInfo* info) {
	GTimeVal modification = {0};
	GFileInfo* _tmp0_;
	GTimeVal _tmp1_ = {0};
	gboolean _tmp21_;
	GError * _inner_error_ = NULL;
#line 1700 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1700 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE_INFO (info));
#line 1701 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = info;
#line 1701 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_info_get_modification_time (_tmp0_, &_tmp1_);
#line 1701 "/home/jens/Source/shotwell/src/Photo.vala"
	modification = _tmp1_;
#line 13431 "Photo.c"
	{
		{
			PhotoRow* _tmp2_;
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->row;
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 13439 "Photo.c"
			{
				PhotoRow* _tmp3_;
				BackingPhotoRow* _tmp4_;
				time_t _tmp5_;
				GTimeVal _tmp6_;
				glong _tmp7_;
				PhotoTable* _tmp9_;
				PhotoTable* _tmp10_;
				PhotoRow* _tmp11_;
				PhotoID _tmp12_;
				GTimeVal _tmp13_;
				glong _tmp14_;
				PhotoRow* _tmp15_;
				BackingPhotoRow* _tmp16_;
				GTimeVal _tmp17_;
				glong _tmp18_;
#line 1705 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 1705 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->master;
#line 1705 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_->timestamp;
#line 1705 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = modification;
#line 1705 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = _tmp6_.tv_sec;
#line 1705 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp5_ == ((time_t) _tmp7_)) {
#line 13468 "Photo.c"
					{
						PhotoRow* _tmp8_;
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp8_ = self->row;
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_row);
#line 13475 "Photo.c"
					}
#line 1706 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 13479 "Photo.c"
				}
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = photo_table_get_instance ();
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tmp9_;
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = self->row;
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tmp11_->photo_id;
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = modification;
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = _tmp13_.tv_sec;
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_update_timestamp (_tmp10_, &_tmp12_, (time_t) _tmp14_, &_inner_error_);
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp10_);
#line 1708 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 13499 "Photo.c"
					goto __finally322;
				}
#line 1709 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = self->row;
#line 1709 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = _tmp15_->master;
#line 1709 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = modification;
#line 1709 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = _tmp17_.tv_sec;
#line 1709 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_->timestamp = (time_t) _tmp18_;
#line 13512 "Photo.c"
			}
			__finally322:
			{
				PhotoRow* _tmp19_;
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = self->row;
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 13521 "Photo.c"
			}
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 13527 "Photo.c"
					goto __catch321_database_error;
				}
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 1704 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 13536 "Photo.c"
			}
		}
	}
	goto __finally321;
	__catch321_database_error:
	{
		GError* err = NULL;
		GError* _tmp20_;
#line 1703 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1703 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1712 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = err;
#line 1712 "/home/jens/Source/shotwell/src/Photo.vala"
		app_window_database_error (_tmp20_);
#line 1714 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 1714 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 13557 "Photo.c"
	}
	__finally321:
#line 1703 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1703 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1703 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1703 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 13568 "Photo.c"
	}
#line 1717 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = photo_is_master_baseline (self);
#line 1717 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp21_) {
#line 13574 "Photo.c"
		Alteration* _tmp22_;
		Alteration* _tmp23_;
#line 1718 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = alteration_new_from_list ("metadata:master-timestamp,metadata:baseline-timestamp");
#line 1718 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = _tmp22_;
#line 1718 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp23_);
#line 1718 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp23_);
#line 13585 "Photo.c"
	} else {
		Alteration* _tmp24_;
		Alteration* _tmp25_;
#line 1720 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = alteration_new ("metadata", "master-timestamp");
#line 1720 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp24_;
#line 1720 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp25_);
#line 1720 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp25_);
#line 13597 "Photo.c"
	}
}


void photo_update_editable_modification_time (Photo* self, GFileInfo* info, GError** error) {
	GTimeVal modification = {0};
	GFileInfo* _tmp0_;
	GTimeVal _tmp1_ = {0};
	gboolean altered = FALSE;
	gboolean _tmp20_;
	GError * _inner_error_ = NULL;
#line 1724 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1724 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE_INFO (info));
#line 1725 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = info;
#line 1725 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_info_get_modification_time (_tmp0_, &_tmp1_);
#line 1725 "/home/jens/Source/shotwell/src/Photo.vala"
	modification = _tmp1_;
#line 1727 "/home/jens/Source/shotwell/src/Photo.vala"
	altered = FALSE;
#line 13621 "Photo.c"
	{
		PhotoRow* _tmp2_;
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->row;
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 13628 "Photo.c"
		{
			gboolean _tmp3_ = FALSE;
			PhotoRow* _tmp4_;
			gboolean _tmp5_;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = backing_photo_id_is_valid (&_tmp4_->editable_id);
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp5_) {
#line 13639 "Photo.c"
				BackingPhotoRow* _tmp6_;
				time_t _tmp7_;
				GTimeVal _tmp8_;
				glong _tmp9_;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->priv->editable;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = _tmp6_->timestamp;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = modification;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tmp8_.tv_sec;
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = _tmp7_ != ((time_t) _tmp9_);
#line 13654 "Photo.c"
			} else {
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = FALSE;
#line 13658 "Photo.c"
			}
#line 1729 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_) {
#line 13662 "Photo.c"
				BackingPhotoTable* _tmp10_;
				BackingPhotoTable* _tmp11_;
				PhotoRow* _tmp12_;
				BackingPhotoID _tmp13_;
				GTimeVal _tmp14_;
				glong _tmp15_;
				BackingPhotoRow* _tmp16_;
				GTimeVal _tmp17_;
				glong _tmp18_;
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = backing_photo_table_get_instance ();
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _tmp10_;
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = self->row;
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _tmp12_->editable_id;
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = modification;
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = _tmp14_.tv_sec;
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				backing_photo_table_update_timestamp (_tmp11_, &_tmp13_, (time_t) _tmp15_, &_inner_error_);
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp11_);
#line 1730 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 13690 "Photo.c"
					goto __finally323;
				}
#line 1732 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = self->priv->editable;
#line 1732 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = modification;
#line 1732 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = _tmp17_.tv_sec;
#line 1732 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_->timestamp = (time_t) _tmp18_;
#line 1733 "/home/jens/Source/shotwell/src/Photo.vala"
				altered = TRUE;
#line 13703 "Photo.c"
			}
		}
		__finally323:
		{
			PhotoRow* _tmp19_;
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = self->row;
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 13713 "Photo.c"
		}
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 13723 "Photo.c"
			} else {
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 1728 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 13731 "Photo.c"
			}
		}
	}
#line 1737 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = altered;
#line 1737 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp20_) {
#line 13739 "Photo.c"
		Alteration* _tmp21_;
		Alteration* _tmp22_;
#line 1738 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = alteration_new_from_list ("metadata:editable-timestamp,metadata:baseline-timestamp");
#line 1738 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = _tmp21_;
#line 1738 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp22_);
#line 1738 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp22_);
#line 13750 "Photo.c"
	}
}


void photo_update_many_editable_timestamps (GeeMap* map, GError** error) {
	GError * _inner_error_ = NULL;
#line 1742 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_MAP (map));
#line 1744 "/home/jens/Source/shotwell/src/Photo.vala"
	database_table_begin_transaction ();
#line 13761 "Photo.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = map;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = gee_map_get_keys (_tmp0_);
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp1_;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_it = _tmp5_;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 13788 "Photo.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			Photo* photo = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			Photo* _tmp10_;
			GeeMap* _tmp11_;
			Photo* _tmp12_;
			gpointer _tmp13_;
			GFileInfo* _tmp14_;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _photo_it;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp7_) {
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 13807 "Photo.c"
			}
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _photo_it;
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			photo = (Photo*) _tmp9_;
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = photo;
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = map;
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo;
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = gee_map_get (_tmp11_, _tmp12_);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = (GFileInfo*) _tmp13_;
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_update_editable_modification_time (_tmp10_, _tmp14_, &_inner_error_);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp14_);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					g_propagate_error (error, _inner_error_);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (photo);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_photo_it);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 13841 "Photo.c"
				} else {
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (photo);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_photo_it);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 1746 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 13853 "Photo.c"
				}
			}
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (photo);
#line 13858 "Photo.c"
		}
#line 1745 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_photo_it);
#line 13862 "Photo.c"
	}
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
	database_table_commit_transaction (&_inner_error_);
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 13874 "Photo.c"
		} else {
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 1747 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 13882 "Photo.c"
		}
	}
}


static PhotoFileFormat photo_real_get_preferred_thumbnail_format (ThumbnailSource* base) {
	Photo * self;
	PhotoFileFormat result = 0;
	PhotoFileFormat _tmp0_ = 0;
	PhotoFileFormat _tmp1_;
	gboolean _tmp2_;
#line 1750 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_file_format (self);
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_format_can_write_image (_tmp1_);
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 13902 "Photo.c"
		PhotoFileFormat _tmp3_;
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_get_file_format (self);
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp3_;
#line 13908 "Photo.c"
	} else {
		PhotoFileFormat _tmp4_;
#line 1752 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = photo_file_format_get_system_default_format ();
#line 1752 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp4_;
#line 13915 "Photo.c"
	}
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 1751 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 13921 "Photo.c"
}


static GdkPixbuf* photo_real_create_thumbnail (ThumbnailSource* base, gint scale, GError** error) {
	Photo * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	gint _tmp1_;
	Scaling _tmp2_ = {0};
	GdkPixbuf* _tmp3_;
	GdkPixbuf* _tmp4_;
	GError * _inner_error_ = NULL;
#line 1755 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = scale;
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	scaling_for_best_fit (_tmp1_, TRUE, &_tmp2_);
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_source_get_pixbuf (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource), &_tmp2_, &_inner_error_);
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp3_;
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 13950 "Photo.c"
	}
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp0_;
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp0_);
#line 1756 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 13962 "Photo.c"
}


gboolean photo_is_file_image (GFile* file) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_;
	gboolean _tmp2_;
#line 1759 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 1763 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 1763 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_format_is_file_supported (_tmp1_);
#line 1763 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = TRUE;
#line 13981 "Photo.c"
	} else {
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gboolean _tmp6_;
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = file;
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = g_file_get_basename (_tmp3_);
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = photo_is_extension_found (_tmp5_, PHOTO_IMAGE_EXTENSIONS, G_N_ELEMENTS (PHOTO_IMAGE_EXTENSIONS));
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp6_;
#line 1764 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp5_);
#line 13999 "Photo.c"
	}
#line 1763 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 1763 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 14005 "Photo.c"
}


static gboolean photo_is_extension_found (const gchar* basename, gchar** extensions, int extensions_length1) {
	gboolean result = FALSE;
	gchar* name = NULL;
	gchar* ext = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar** _tmp6_;
	gint _tmp6__length1;
#line 1767 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (basename != NULL, FALSE);
#line 1769 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = basename;
#line 1769 "/home/jens/Source/shotwell/src/Photo.vala"
	disassemble_filename (_tmp0_, &_tmp1_, &_tmp2_);
#line 1769 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (name);
#line 1769 "/home/jens/Source/shotwell/src/Photo.vala"
	name = _tmp1_;
#line 1769 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (ext);
#line 1769 "/home/jens/Source/shotwell/src/Photo.vala"
	ext = _tmp2_;
#line 1770 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = ext;
#line 1770 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp3_ == NULL) {
#line 1771 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 1771 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (ext);
#line 1771 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (name);
#line 1771 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 14047 "Photo.c"
	}
#line 1774 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = ext;
#line 1774 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = g_utf8_strdown (_tmp4_, (gssize) -1);
#line 1774 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (ext);
#line 1774 "/home/jens/Source/shotwell/src/Photo.vala"
	ext = _tmp5_;
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = extensions;
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6__length1 = extensions_length1;
#line 14061 "Photo.c"
	{
		gchar** extension_collection = NULL;
		gint extension_collection_length1 = 0;
		gint _extension_collection_size_ = 0;
		gint extension_it = 0;
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
		extension_collection = _tmp6_;
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
		extension_collection_length1 = _tmp6__length1;
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
		for (extension_it = 0; extension_it < _tmp6__length1; extension_it = extension_it + 1) {
#line 14073 "Photo.c"
			gchar* _tmp7_;
			gchar* extension = NULL;
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = g_strdup (extension_collection[extension_it]);
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
			extension = _tmp7_;
#line 14080 "Photo.c"
			{
				const gchar* _tmp8_;
				const gchar* _tmp9_;
#line 1778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = ext;
#line 1778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = extension;
#line 1778 "/home/jens/Source/shotwell/src/Photo.vala"
				if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 1779 "/home/jens/Source/shotwell/src/Photo.vala"
					result = TRUE;
#line 1779 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (extension);
#line 1779 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (ext);
#line 1779 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (name);
#line 1779 "/home/jens/Source/shotwell/src/Photo.vala"
					return result;
#line 14100 "Photo.c"
				}
#line 1777 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (extension);
#line 14104 "Photo.c"
			}
		}
	}
#line 1782 "/home/jens/Source/shotwell/src/Photo.vala"
	result = FALSE;
#line 1782 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (ext);
#line 1782 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (name);
#line 1782 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 14116 "Photo.c"
}


gboolean photo_is_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format) {
	gboolean result = FALSE;
	PhotoTable* _tmp0_;
	PhotoTable* _tmp1_;
	GFile* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	PhotoFileFormat _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
#line 1788 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((file == NULL) || G_IS_FILE (file), FALSE);
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_table_get_instance ();
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = file;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = thumbnail_md5;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = full_md5;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = file_format;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_table_has_duplicate (_tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = _tmp6_;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp1_);
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp7_;
#line 1791 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 14154 "Photo.c"
}


PhotoID* photo_get_duplicate_ids (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format, int* result_length1) {
	PhotoID* result = NULL;
	PhotoTable* _tmp0_;
	PhotoTable* _tmp1_;
	GFile* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	PhotoFileFormat _tmp5_;
	gint _tmp6_;
	PhotoID* _tmp7_;
	PhotoID* _tmp8_;
	gint _tmp8__length1;
	PhotoID* _tmp9_;
	gint _tmp9__length1;
#line 1797 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((file == NULL) || G_IS_FILE (file), NULL);
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_table_get_instance ();
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = file;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = thumbnail_md5;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = full_md5;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = file_format;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = photo_table_get_duplicate_ids (_tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_, &_tmp6_);
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8__length1 = _tmp6_;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp1_);
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _tmp8_;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9__length1 = _tmp8__length1;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	if (result_length1) {
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
		*result_length1 = _tmp9__length1;
#line 14202 "Photo.c"
	}
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp9_;
#line 1800 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 14208 "Photo.c"
}


gint64 photo_get_photo_key (DataSource* source) {
	gint64 result = 0LL;
	DataSource* _tmp0_;
	PhotoID _tmp1_ = {0};
	gint64 _tmp2_;
#line 1807 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), 0LL);
#line 1808 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = source;
#line 1808 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_photo_id (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_LIBRARY_PHOTO, LibraryPhoto), TYPE_PHOTO, Photo), &_tmp1_);
#line 1808 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_.id;
#line 1808 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp2_;
#line 1808 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 14229 "Photo.c"
}


static GFile* photo_real_get_file (MediaSource* base) {
	Photo * self;
	GFile* result = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
#line 1826 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_source_reader (self);
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp1_);
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 1827 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 14256 "Photo.c"
}


static void _vala_array_add100 (gchar** * array, int* length, int* size, gchar* value) {
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14267 "Photo.c"
	}
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14273 "Photo.c"
}


static void _vala_array_add101 (gchar** * array, int* length, int* size, gchar* value) {
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14284 "Photo.c"
	}
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14290 "Photo.c"
}


static void _vala_array_add102 (gchar** * array, int* length, int* size, gchar* value) {
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14301 "Photo.c"
	}
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14307 "Photo.c"
}


static void _vala_array_add103 (gchar** * array, int* length, int* size, gchar* value) {
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14318 "Photo.c"
	}
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14324 "Photo.c"
}


void photo_set_master_file (Photo* self, GFile* file) {
	gchar* filepath = NULL;
	GFile* _tmp0_;
	gchar* _tmp1_;
	gboolean altered = FALSE;
	gboolean is_baseline = FALSE;
	gboolean is_source = FALSE;
	gboolean name_changed = FALSE;
	GFile* old_file = NULL;
	gboolean _tmp41_;
	GError * _inner_error_ = NULL;
#line 1832 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1832 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 1833 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 1833 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = g_file_get_path (_tmp0_);
#line 1833 "/home/jens/Source/shotwell/src/Photo.vala"
	filepath = _tmp1_;
#line 1835 "/home/jens/Source/shotwell/src/Photo.vala"
	altered = FALSE;
#line 1836 "/home/jens/Source/shotwell/src/Photo.vala"
	is_baseline = FALSE;
#line 1837 "/home/jens/Source/shotwell/src/Photo.vala"
	is_source = FALSE;
#line 1838 "/home/jens/Source/shotwell/src/Photo.vala"
	name_changed = FALSE;
#line 1839 "/home/jens/Source/shotwell/src/Photo.vala"
	old_file = NULL;
#line 14359 "Photo.c"
	{
		{
			PhotoRow* _tmp2_;
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->row;
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 14367 "Photo.c"
			{
				{
					PhotoBackingReaders* _tmp3_;
#line 1842 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp3_ = self->priv->readers;
#line 1842 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_lock (&self->priv->__lock_readers);
#line 14375 "Photo.c"
					{
						PhotoBackingReaders* _tmp4_;
						PhotoFileReader* _tmp5_;
						GFile* _tmp6_;
						GFile* _tmp7_;
						GFile* _tmp8_;
						gboolean _tmp9_;
#line 1843 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp4_ = self->priv->readers;
#line 1843 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp5_ = _tmp4_->master;
#line 1843 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp6_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1843 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (old_file);
#line 1843 "/home/jens/Source/shotwell/src/Photo.vala"
						old_file = _tmp6_;
#line 1844 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp7_ = file;
#line 1844 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp8_ = old_file;
#line 1844 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp9_ = g_file_equal (_tmp7_, _tmp8_);
#line 1844 "/home/jens/Source/shotwell/src/Photo.vala"
						if (!_tmp9_) {
#line 14401 "Photo.c"
							PhotoTable* _tmp10_;
							PhotoTable* _tmp11_;
							PhotoID _tmp12_ = {0};
							const gchar* _tmp13_;
							PhotoRow* _tmp14_;
							BackingPhotoRow* _tmp15_;
							const gchar* _tmp16_;
							gchar* _tmp17_;
							GFile* _tmp18_;
							gchar* _tmp19_;
							PhotoBackingReaders* _tmp20_;
							PhotoRow* _tmp21_;
							BackingPhotoRow* _tmp22_;
							PhotoFileFormat _tmp23_;
							const gchar* _tmp24_;
							PhotoFileReader* _tmp25_;
							gboolean _tmp26_;
							gboolean _tmp27_;
							gboolean _tmp28_ = FALSE;
							PhotoRow* _tmp29_;
							const gchar* _tmp30_;
							gboolean _tmp31_;
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp10_ = photo_table_get_instance ();
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp11_ = _tmp10_;
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							photo_get_photo_id (self, &_tmp12_);
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp13_ = filepath;
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							photo_table_set_filepath (_tmp11_, &_tmp12_, _tmp13_, &_inner_error_);
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							_database_table_unref0 (_tmp11_);
#line 1845 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 14438 "Photo.c"
								goto __finally326;
							}
#line 1847 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp14_ = self->row;
#line 1847 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp15_ = _tmp14_->master;
#line 1847 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp16_ = filepath;
#line 1847 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp17_ = g_strdup (_tmp16_);
#line 1847 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (_tmp15_->filepath);
#line 1847 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp15_->filepath = _tmp17_;
#line 1848 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp18_ = file;
#line 1848 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp19_ = g_file_get_basename (_tmp18_);
#line 1848 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (self->priv->file_title);
#line 1848 "/home/jens/Source/shotwell/src/Photo.vala"
							self->priv->file_title = _tmp19_;
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp20_ = self->priv->readers;
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp21_ = self->row;
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp22_ = _tmp21_->master;
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp23_ = _tmp22_->file_format;
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp24_ = filepath;
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp25_ = photo_file_format_create_reader (_tmp23_, _tmp24_);
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_photo_file_adapter_unref0 (_tmp20_->master);
#line 1849 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp20_->master = _tmp25_;
#line 1851 "/home/jens/Source/shotwell/src/Photo.vala"
							altered = TRUE;
#line 1852 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp26_ = photo_is_master_baseline (self);
#line 1852 "/home/jens/Source/shotwell/src/Photo.vala"
							is_baseline = _tmp26_;
#line 1853 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp27_ = photo_is_master_source (self);
#line 1853 "/home/jens/Source/shotwell/src/Photo.vala"
							is_source = _tmp27_;
#line 1854 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp29_ = self->row;
#line 1854 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp30_ = _tmp29_->title;
#line 1854 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp31_ = is_string_empty (_tmp30_);
#line 1854 "/home/jens/Source/shotwell/src/Photo.vala"
							if (_tmp31_) {
#line 14495 "Photo.c"
								GFile* _tmp32_;
								gchar* _tmp33_;
								gchar* _tmp34_;
								GFile* _tmp35_;
								gchar* _tmp36_;
								gchar* _tmp37_;
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp32_ = old_file;
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp33_ = g_file_get_basename (_tmp32_);
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp34_ = _tmp33_;
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp35_ = file;
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp36_ = g_file_get_basename (_tmp35_);
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp37_ = _tmp36_;
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp28_ = g_strcmp0 (_tmp34_, _tmp37_) != 0;
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_free0 (_tmp37_);
#line 1855 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_free0 (_tmp34_);
#line 14520 "Photo.c"
							} else {
#line 1854 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp28_ = FALSE;
#line 14524 "Photo.c"
							}
#line 1854 "/home/jens/Source/shotwell/src/Photo.vala"
							name_changed = _tmp28_;
#line 14528 "Photo.c"
						}
					}
					__finally326:
					{
						PhotoBackingReaders* _tmp38_;
#line 1842 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp38_ = self->priv->readers;
#line 1842 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 14538 "Photo.c"
					}
#line 1842 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 14542 "Photo.c"
						goto __finally325;
					}
				}
			}
			__finally325:
			{
				PhotoRow* _tmp39_;
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = self->row;
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 14554 "Photo.c"
			}
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 14560 "Photo.c"
					goto __catch324_database_error;
				}
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (old_file);
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (filepath);
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 1841 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 14573 "Photo.c"
			}
		}
	}
	goto __finally324;
	__catch324_database_error:
	{
		GError* err = NULL;
		GError* _tmp40_;
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1860 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = err;
#line 1860 "/home/jens/Source/shotwell/src/Photo.vala"
		app_window_database_error (_tmp40_);
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 14592 "Photo.c"
	}
	__finally324:
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (old_file);
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (filepath);
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1840 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 14607 "Photo.c"
	}
#line 1863 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = altered;
#line 1863 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp41_) {
#line 14613 "Photo.c"
		GFile* _tmp42_;
		GFile* _tmp43_;
		gboolean _tmp44_;
		gchar** alteration_list = NULL;
		gchar** _tmp45_;
		gint alteration_list_length1;
		gint _alteration_list_size_;
		gchar** _tmp46_;
		gint _tmp46__length1;
		gchar* _tmp47_;
		gboolean _tmp48_;
		gboolean _tmp51_;
		gboolean _tmp54_;
		gchar** _tmp57_;
		gint _tmp57__length1;
		Alteration* _tmp58_;
		Alteration* _tmp59_;
#line 1864 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = old_file;
#line 1864 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = file;
#line 1864 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_notify_master_replaced (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp42_, _tmp43_);
#line 1866 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp44_ = is_baseline;
#line 1866 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp44_) {
#line 1867 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_notify_baseline_replaced (self);
#line 14643 "Photo.c"
		}
#line 1869 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = g_new0 (gchar*, 0 + 1);
#line 1869 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration_list = _tmp45_;
#line 1869 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration_list_length1 = 0;
#line 1869 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_list_size_ = alteration_list_length1;
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = alteration_list;
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46__length1 = alteration_list_length1;
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = g_strdup ("backing:master");
#line 1870 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add100 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp47_);
#line 1874 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = name_changed;
#line 1874 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp48_) {
#line 14665 "Photo.c"
			gchar** _tmp49_;
			gint _tmp49__length1;
			gchar* _tmp50_;
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp49_ = alteration_list;
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp49__length1 = alteration_list_length1;
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp50_ = g_strdup ("metadata:name");
#line 1875 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add101 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp50_);
#line 14677 "Photo.c"
		}
#line 1877 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp51_ = is_source;
#line 1877 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp51_) {
#line 14683 "Photo.c"
			gchar** _tmp52_;
			gint _tmp52__length1;
			gchar* _tmp53_;
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp52_ = alteration_list;
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp52__length1 = alteration_list_length1;
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp53_ = g_strdup ("backing:source");
#line 1878 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add102 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp53_);
#line 14695 "Photo.c"
		}
#line 1880 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp54_ = is_baseline;
#line 1880 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp54_) {
#line 14701 "Photo.c"
			gchar** _tmp55_;
			gint _tmp55__length1;
			gchar* _tmp56_;
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp55_ = alteration_list;
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp55__length1 = alteration_list_length1;
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp56_ = g_strdup ("backing:baseline");
#line 1881 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add103 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp56_);
#line 14713 "Photo.c"
		}
#line 1883 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57_ = alteration_list;
#line 1883 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57__length1 = alteration_list_length1;
#line 1883 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp58_ = alteration_new_from_array (_tmp57_, _tmp57__length1);
#line 1883 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp59_ = _tmp58_;
#line 1883 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp59_);
#line 1883 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp59_);
#line 1863 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration_list = (_vala_array_free (alteration_list, alteration_list_length1, (GDestroyNotify) g_free), NULL);
#line 14729 "Photo.c"
	}
#line 1832 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (old_file);
#line 1832 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (filepath);
#line 14735 "Photo.c"
}


static void _vala_array_add104 (gchar** * array, int* length, int* size, gchar* value) {
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14746 "Photo.c"
	}
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14752 "Photo.c"
}


static void _vala_array_add105 (gchar** * array, int* length, int* size, gchar* value) {
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14763 "Photo.c"
	}
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14769 "Photo.c"
}


static void _vala_array_add106 (gchar** * array, int* length, int* size, gchar* value) {
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 14780 "Photo.c"
	}
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 14786 "Photo.c"
}


void photo_set_editable_file (Photo* self, GFile* file) {
	gchar* filepath = NULL;
	GFile* _tmp0_;
	gchar* _tmp1_;
	gboolean altered = FALSE;
	gboolean is_baseline = FALSE;
	gboolean is_source = FALSE;
	GFile* old_file = NULL;
	gboolean _tmp34_;
	GError * _inner_error_ = NULL;
#line 1889 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 1889 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 1890 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 1890 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = g_file_get_path (_tmp0_);
#line 1890 "/home/jens/Source/shotwell/src/Photo.vala"
	filepath = _tmp1_;
#line 1892 "/home/jens/Source/shotwell/src/Photo.vala"
	altered = FALSE;
#line 1893 "/home/jens/Source/shotwell/src/Photo.vala"
	is_baseline = FALSE;
#line 1894 "/home/jens/Source/shotwell/src/Photo.vala"
	is_source = FALSE;
#line 1895 "/home/jens/Source/shotwell/src/Photo.vala"
	old_file = NULL;
#line 14818 "Photo.c"
	{
		{
			PhotoRow* _tmp2_;
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->row;
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 14826 "Photo.c"
			{
				{
					PhotoBackingReaders* _tmp3_;
#line 1898 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp3_ = self->priv->readers;
#line 1898 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_lock (&self->priv->__lock_readers);
#line 14834 "Photo.c"
					{
						GFile* _tmp4_ = NULL;
						PhotoBackingReaders* _tmp5_;
						PhotoFileReader* _tmp6_;
						GFile* _tmp10_;
						gboolean _tmp11_ = FALSE;
						GFile* _tmp12_;
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp5_ = self->priv->readers;
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp6_ = _tmp5_->editable;
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp6_ != NULL) {
#line 14848 "Photo.c"
							PhotoBackingReaders* _tmp7_;
							PhotoFileReader* _tmp8_;
							GFile* _tmp9_;
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp7_ = self->priv->readers;
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp8_ = _tmp7_->editable;
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp9_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp4_);
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp4_ = _tmp9_;
#line 14862 "Photo.c"
						} else {
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp4_);
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp4_ = NULL;
#line 14868 "Photo.c"
						}
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp10_ = _g_object_ref0 (_tmp4_);
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (old_file);
#line 1899 "/home/jens/Source/shotwell/src/Photo.vala"
						old_file = _tmp10_;
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp12_ = old_file;
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp12_ != NULL) {
#line 14880 "Photo.c"
							GFile* _tmp13_;
							GFile* _tmp14_;
							gboolean _tmp15_;
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp13_ = old_file;
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp14_ = file;
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp15_ = g_file_equal (_tmp13_, _tmp14_);
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp11_ = !_tmp15_;
#line 14892 "Photo.c"
						} else {
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp11_ = FALSE;
#line 14896 "Photo.c"
						}
#line 1900 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp11_) {
#line 14900 "Photo.c"
							BackingPhotoTable* _tmp16_;
							BackingPhotoTable* _tmp17_;
							PhotoRow* _tmp18_;
							BackingPhotoID _tmp19_;
							const gchar* _tmp20_;
							BackingPhotoRow* _tmp21_;
							const gchar* _tmp22_;
							gchar* _tmp23_;
							PhotoBackingReaders* _tmp24_;
							BackingPhotoRow* _tmp25_;
							PhotoFileFormat _tmp26_;
							const gchar* _tmp27_;
							PhotoFileReader* _tmp28_;
							gboolean _tmp29_;
							gboolean _tmp30_;
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp16_ = backing_photo_table_get_instance ();
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp17_ = _tmp16_;
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp18_ = self->row;
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp19_ = _tmp18_->editable_id;
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp20_ = filepath;
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							backing_photo_table_set_filepath (_tmp17_, &_tmp19_, _tmp20_, &_inner_error_);
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							_database_table_unref0 (_tmp17_);
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
							if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1901 "/home/jens/Source/shotwell/src/Photo.vala"
								_g_object_unref0 (_tmp4_);
#line 14934 "Photo.c"
								goto __finally329;
							}
#line 1903 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp21_ = self->priv->editable;
#line 1903 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp22_ = filepath;
#line 1903 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp23_ = g_strdup (_tmp22_);
#line 1903 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (_tmp21_->filepath);
#line 1903 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp21_->filepath = _tmp23_;
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp24_ = self->priv->readers;
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp25_ = self->priv->editable;
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp26_ = _tmp25_->file_format;
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp27_ = filepath;
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp28_ = photo_file_format_create_reader (_tmp26_, _tmp27_);
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_photo_file_adapter_unref0 (_tmp24_->editable);
#line 1904 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp24_->editable = _tmp28_;
#line 1906 "/home/jens/Source/shotwell/src/Photo.vala"
							altered = TRUE;
#line 1907 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp29_ = photo_is_editable_baseline (self);
#line 1907 "/home/jens/Source/shotwell/src/Photo.vala"
							is_baseline = _tmp29_;
#line 1908 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp30_ = photo_is_editable_source (self);
#line 1908 "/home/jens/Source/shotwell/src/Photo.vala"
							is_source = _tmp30_;
#line 14971 "Photo.c"
						}
#line 1898 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_tmp4_);
#line 14975 "Photo.c"
					}
					__finally329:
					{
						PhotoBackingReaders* _tmp31_;
#line 1898 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp31_ = self->priv->readers;
#line 1898 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 14984 "Photo.c"
					}
#line 1898 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 14988 "Photo.c"
						goto __finally328;
					}
				}
			}
			__finally328:
			{
				PhotoRow* _tmp32_;
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = self->row;
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15000 "Photo.c"
			}
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 15006 "Photo.c"
					goto __catch327_database_error;
				}
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (old_file);
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (filepath);
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 1897 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 15019 "Photo.c"
			}
		}
	}
	goto __finally327;
	__catch327_database_error:
	{
		GError* err = NULL;
		GError* _tmp33_;
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 1913 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp33_ = err;
#line 1913 "/home/jens/Source/shotwell/src/Photo.vala"
		app_window_database_error (_tmp33_);
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 15038 "Photo.c"
	}
	__finally327:
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (old_file);
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (filepath);
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1896 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 15053 "Photo.c"
	}
#line 1916 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = altered;
#line 1916 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp34_) {
#line 15059 "Photo.c"
		GFile* _tmp35_;
		GFile* _tmp36_;
		gboolean _tmp37_;
		gchar** alteration_list = NULL;
		gchar** _tmp38_;
		gint alteration_list_length1;
		gint _alteration_list_size_;
		gchar** _tmp39_;
		gint _tmp39__length1;
		gchar* _tmp40_;
		gboolean _tmp41_;
		gboolean _tmp44_;
		gchar** _tmp47_;
		gint _tmp47__length1;
		Alteration* _tmp48_;
		Alteration* _tmp49_;
#line 1917 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp35_ = old_file;
#line 1917 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = file;
#line 1917 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_editable_replaced (self, _tmp35_, _tmp36_);
#line 1919 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp37_ = is_baseline;
#line 1919 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp37_) {
#line 1920 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_notify_baseline_replaced (self);
#line 15088 "Photo.c"
		}
#line 1922 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp38_ = g_new0 (gchar*, 0 + 1);
#line 1922 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration_list = _tmp38_;
#line 1922 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration_list_length1 = 0;
#line 1922 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_list_size_ = alteration_list_length1;
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = alteration_list;
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39__length1 = alteration_list_length1;
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = g_strdup ("backing:editable");
#line 1923 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add104 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp40_);
#line 1925 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = is_baseline;
#line 1925 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp41_) {
#line 15110 "Photo.c"
			gchar** _tmp42_;
			gint _tmp42__length1;
			gchar* _tmp43_;
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = alteration_list;
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42__length1 = alteration_list_length1;
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp43_ = g_strdup ("backing:baseline");
#line 1926 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add105 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp43_);
#line 15122 "Photo.c"
		}
#line 1928 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp44_ = is_source;
#line 1928 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp44_) {
#line 15128 "Photo.c"
			gchar** _tmp45_;
			gint _tmp45__length1;
			gchar* _tmp46_;
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp45_ = alteration_list;
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp45__length1 = alteration_list_length1;
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp46_ = g_strdup ("backing:source");
#line 1929 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add106 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp46_);
#line 15140 "Photo.c"
		}
#line 1931 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = alteration_list;
#line 1931 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47__length1 = alteration_list_length1;
#line 1931 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = alteration_new_from_array (_tmp47_, _tmp47__length1);
#line 1931 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = _tmp48_;
#line 1931 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp49_);
#line 1931 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp49_);
#line 1916 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration_list = (_vala_array_free (alteration_list, alteration_list_length1, (GDestroyNotify) g_free), NULL);
#line 15156 "Photo.c"
	}
#line 1889 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (old_file);
#line 1889 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (filepath);
#line 15162 "Photo.c"
}


void photo_set_many_editable_file (GeeMap* map, GError** error) {
	GeeMapIterator* map_iter = NULL;
	GeeMap* _tmp0_;
	GeeMapIterator* _tmp1_;
	GError * _inner_error_ = NULL;
#line 1936 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_MAP (map));
#line 1937 "/home/jens/Source/shotwell/src/Photo.vala"
	database_table_begin_transaction ();
#line 1939 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = map;
#line 1939 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = gee_map_map_iterator (_tmp0_);
#line 1939 "/home/jens/Source/shotwell/src/Photo.vala"
	map_iter = _tmp1_;
#line 1940 "/home/jens/Source/shotwell/src/Photo.vala"
	while (TRUE) {
#line 15183 "Photo.c"
		GeeMapIterator* _tmp2_;
		gboolean _tmp3_;
		GeeMapIterator* _tmp4_;
		gpointer _tmp5_;
		Photo* _tmp6_;
		GeeMapIterator* _tmp7_;
		gpointer _tmp8_;
		GFile* _tmp9_;
#line 1940 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = map_iter;
#line 1940 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = gee_map_iterator_next (_tmp2_);
#line 1940 "/home/jens/Source/shotwell/src/Photo.vala"
		if (!_tmp3_) {
#line 1940 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 15200 "Photo.c"
		}
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = map_iter;
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = gee_map_iterator_get_key (_tmp4_);
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = (Photo*) _tmp5_;
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = map_iter;
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = gee_map_iterator_get_value (_tmp7_);
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = (GFile*) _tmp8_;
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_set_editable_file (_tmp6_, _tmp9_);
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp9_);
#line 1941 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp6_);
#line 15220 "Photo.c"
	}
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
	database_table_commit_transaction (&_inner_error_);
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (map_iter);
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 15234 "Photo.c"
		} else {
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (map_iter);
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 1943 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 15244 "Photo.c"
		}
	}
#line 1936 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (map_iter);
#line 15249 "Photo.c"
}


GFile* photo_get_actual_file (Photo* self) {
	GFile* result = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
#line 1948 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_baseline_reader (self);
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp1_);
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 1949 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15275 "Photo.c"
}


static GFile* photo_real_get_master_file (MediaSource* base) {
	Photo * self;
	GFile* result = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
#line 1952 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_master_reader (self);
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp1_);
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 1953 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15302 "Photo.c"
}


GFile* photo_get_editable_file (Photo* self) {
	GFile* result = NULL;
	PhotoFileReader* reader = NULL;
	PhotoFileReader* _tmp0_;
	GFile* _tmp1_ = NULL;
	PhotoFileReader* _tmp2_;
#line 1956 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1957 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_editable_reader (self);
#line 1957 "/home/jens/Source/shotwell/src/Photo.vala"
	reader = _tmp0_;
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = reader;
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ != NULL) {
#line 15322 "Photo.c"
		PhotoFileReader* _tmp3_;
		GFile* _tmp4_;
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = reader;
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp1_);
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp4_;
#line 15333 "Photo.c"
	} else {
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp1_);
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = NULL;
#line 15339 "Photo.c"
	}
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (reader);
#line 1959 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15347 "Photo.c"
}


GeeCollection* photo_get_raw_developer_files (Photo* self) {
	GeeCollection* result = NULL;
	PhotoFileFormat _tmp0_;
	GeeArrayList* ret = NULL;
	GeeArrayList* _tmp1_;
	GError * _inner_error_ = NULL;
#line 1962 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1963 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_master_file_format (self);
#line 1963 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != PHOTO_FILE_FORMAT_RAW) {
#line 1964 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 1964 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 15367 "Photo.c"
	}
#line 1966 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = gee_array_list_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 1966 "/home/jens/Source/shotwell/src/Photo.vala"
	ret = _tmp1_;
#line 15373 "Photo.c"
	{
		PhotoRow* _tmp2_;
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->row;
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15380 "Photo.c"
		{
			{
				GeeIterator* _row_it = NULL;
				GeeHashMap* _tmp3_;
				GeeCollection* _tmp4_;
				GeeCollection* _tmp5_;
				GeeCollection* _tmp6_;
				GeeIterator* _tmp7_;
				GeeIterator* _tmp8_;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->developments;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_abstract_map_get_values (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = _tmp5_;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _tmp7_;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp6_);
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_row_it = _tmp8_;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				while (TRUE) {
#line 15408 "Photo.c"
					GeeIterator* _tmp9_;
					gboolean _tmp10_;
					BackingPhotoRow* row = NULL;
					GeeIterator* _tmp11_;
					gpointer _tmp12_;
					GeeArrayList* _tmp13_;
					BackingPhotoRow* _tmp14_;
					const gchar* _tmp15_;
					GFile* _tmp16_;
					GFile* _tmp17_;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp9_ = _row_it;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp10_ = gee_iterator_next (_tmp9_);
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					if (!_tmp10_) {
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
						break;
#line 15427 "Photo.c"
					}
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = _row_it;
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = gee_iterator_get (_tmp11_);
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					row = (BackingPhotoRow*) _tmp12_;
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = ret;
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = row;
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = _tmp14_->filepath;
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = g_file_new_for_path (_tmp15_);
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = _tmp16_;
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp17_);
#line 1969 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp17_);
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (row);
#line 15451 "Photo.c"
				}
#line 1968 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_row_it);
#line 15455 "Photo.c"
			}
		}
		__finally330:
		{
			PhotoRow* _tmp18_;
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = self->row;
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15465 "Photo.c"
		}
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (ret);
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 1967 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 15477 "Photo.c"
		}
	}
#line 1972 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (ret, GEE_TYPE_COLLECTION, GeeCollection);
#line 1972 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15484 "Photo.c"
}


GFile* photo_get_source_file (Photo* self) {
	GFile* result = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
#line 1975 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_source_reader (self);
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp1_);
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 1976 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15510 "Photo.c"
}


PhotoFileFormat photo_get_file_format (Photo* self) {
	PhotoFileFormat result = 0;
	GError * _inner_error_ = NULL;
#line 1979 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 15519 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15526 "Photo.c"
		{
			BackingPhotoRow* _tmp1_;
			PhotoFileFormat _tmp2_;
#line 1981 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->backing_photo_row;
#line 1981 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->file_format;
#line 1981 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 15536 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15543 "Photo.c"
			}
#line 1981 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 15547 "Photo.c"
		}
		__finally331:
		{
			PhotoRow* _tmp4_;
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15556 "Photo.c"
		}
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1980 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 15564 "Photo.c"
	}
}


PhotoFileFormat photo_get_best_export_file_format (Photo* self) {
	PhotoFileFormat result = 0;
	PhotoFileFormat file_format = 0;
	PhotoFileFormat _tmp0_;
	PhotoFileFormat _tmp1_;
	gboolean _tmp2_;
#line 1985 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 1986 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_file_format (self);
#line 1986 "/home/jens/Source/shotwell/src/Photo.vala"
	file_format = _tmp0_;
#line 1987 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file_format;
#line 1987 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_format_can_write (_tmp1_);
#line 1987 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp2_) {
#line 15587 "Photo.c"
		PhotoFileFormat _tmp3_;
#line 1988 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_file_format_get_system_default_format ();
#line 1988 "/home/jens/Source/shotwell/src/Photo.vala"
		file_format = _tmp3_;
#line 15593 "Photo.c"
	}
#line 1990 "/home/jens/Source/shotwell/src/Photo.vala"
	result = file_format;
#line 1990 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15599 "Photo.c"
}


PhotoFileFormat photo_get_master_file_format (Photo* self) {
	PhotoFileFormat result = 0;
	GError * _inner_error_ = NULL;
#line 1993 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 15608 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15615 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			PhotoFileFormat _tmp3_;
#line 1995 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 1995 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->master;
#line 1995 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 1995 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 15628 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15635 "Photo.c"
			}
#line 1995 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 15639 "Photo.c"
		}
		__finally332:
		{
			PhotoRow* _tmp5_;
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15648 "Photo.c"
		}
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 1994 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 15656 "Photo.c"
	}
}


static time_t photo_real_get_timestamp (MediaSource* base) {
	Photo * self;
	time_t result = 0;
	GError * _inner_error_ = NULL;
#line 1999 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 15667 "Photo.c"
	{
		PhotoRow* _tmp0_;
		time_t _tmp5_ = 0;
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15675 "Photo.c"
		{
			BackingPhotoRow* _tmp1_;
			time_t _tmp2_;
#line 2001 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->backing_photo_row;
#line 2001 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->timestamp;
#line 2001 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 15685 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15692 "Photo.c"
			}
#line 2001 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 15696 "Photo.c"
		}
		__finally333:
		{
			PhotoRow* _tmp4_;
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15705 "Photo.c"
		}
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2000 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 15713 "Photo.c"
	}
}


void photo_get_photo_id (Photo* self, PhotoID* result) {
	GError * _inner_error_ = NULL;
#line 2005 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 15722 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15729 "Photo.c"
		{
			PhotoRow* _tmp1_;
			PhotoID _tmp2_;
#line 2007 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2007 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->photo_id;
#line 2007 "/home/jens/Source/shotwell/src/Photo.vala"
			*result = _tmp2_;
#line 15739 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15746 "Photo.c"
			}
#line 2007 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 15750 "Photo.c"
		}
		__finally334:
		{
			PhotoRow* _tmp4_;
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15759 "Photo.c"
		}
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2006 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 15767 "Photo.c"
	}
}


static inline void photo_real_get_event_id (MediaSource* base, EventID* result) {
	Photo * self;
	PhotoRow* _tmp0_;
	EventID _tmp1_;
#line 2012 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2013 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->row;
#line 2013 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->event_id;
#line 2013 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = _tmp1_;
#line 2013 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 15786 "Photo.c"
}


inline gint64 photo_get_raw_event_id (Photo* self) {
	gint64 result = 0LL;
	PhotoRow* _tmp0_;
	EventID _tmp1_;
	gint64 _tmp2_;
#line 2017 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0LL);
#line 2018 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->row;
#line 2018 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->event_id;
#line 2018 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_.id;
#line 2018 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp2_;
#line 2018 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 15807 "Photo.c"
}


static void photo_real_get_import_id (MediaSource* base, ImportID* result) {
	Photo * self;
	GError * _inner_error_ = NULL;
#line 2021 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 15816 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15823 "Photo.c"
		{
			PhotoRow* _tmp1_;
			ImportID _tmp2_;
#line 2023 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2023 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->import_id;
#line 2023 "/home/jens/Source/shotwell/src/Photo.vala"
			*result = _tmp2_;
#line 15833 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15840 "Photo.c"
			}
#line 2023 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 15844 "Photo.c"
		}
		__finally335:
		{
			PhotoRow* _tmp4_;
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15853 "Photo.c"
		}
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2022 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 15861 "Photo.c"
	}
}


void photo_get_editable_id (Photo* self, BackingPhotoID* result) {
	GError * _inner_error_ = NULL;
#line 2027 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 15870 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15877 "Photo.c"
		{
			PhotoRow* _tmp1_;
			BackingPhotoID _tmp2_;
#line 2029 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2029 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable_id;
#line 2029 "/home/jens/Source/shotwell/src/Photo.vala"
			*result = _tmp2_;
#line 15887 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15894 "Photo.c"
			}
#line 2029 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 15898 "Photo.c"
		}
		__finally336:
		{
			PhotoRow* _tmp4_;
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15907 "Photo.c"
		}
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2028 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 15915 "Photo.c"
	}
}


static gchar* photo_real_get_master_md5 (MediaSource* base) {
	Photo * self;
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 2033 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 15926 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15933 "Photo.c"
		{
			PhotoRow* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
#line 2035 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2035 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->md5;
#line 2035 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = g_strdup (_tmp2_);
#line 2035 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 15946 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15953 "Photo.c"
			}
#line 2035 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 15957 "Photo.c"
		}
		__finally337:
		{
			PhotoRow* _tmp5_;
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 15966 "Photo.c"
		}
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2034 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 15974 "Photo.c"
	}
}


guint64 photo_get_flags (Photo* self) {
	guint64 result = 0ULL;
	GError * _inner_error_ = NULL;
#line 2041 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 15984 "Photo.c"
	{
		PhotoRow* _tmp0_;
		guint64 _tmp5_ = 0ULL;
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 15992 "Photo.c"
		{
			PhotoRow* _tmp1_;
			guint64 _tmp2_;
#line 2043 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2043 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->flags;
#line 2043 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 16002 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16009 "Photo.c"
			}
#line 2043 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 16013 "Photo.c"
		}
		__finally338:
		{
			PhotoRow* _tmp4_;
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16022 "Photo.c"
		}
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2042 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 16030 "Photo.c"
	}
}


static void photo_notify_flags_altered (Photo* self, Alteration* additional_alteration) {
	Alteration* alteration = NULL;
	Alteration* _tmp0_;
	Alteration* _tmp1_;
	Alteration* _tmp5_;
#line 2047 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2047 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((additional_alteration == NULL) || IS_ALTERATION (additional_alteration));
#line 2048 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = alteration_new ("metadata", "flags");
#line 2048 "/home/jens/Source/shotwell/src/Photo.vala"
	alteration = _tmp0_;
#line 2049 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = additional_alteration;
#line 2049 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ != NULL) {
#line 16052 "Photo.c"
		Alteration* _tmp2_;
		Alteration* _tmp3_;
		Alteration* _tmp4_;
#line 2050 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = alteration;
#line 2050 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = additional_alteration;
#line 2050 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = alteration_compress (_tmp2_, _tmp3_);
#line 2050 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (alteration);
#line 2050 "/home/jens/Source/shotwell/src/Photo.vala"
		alteration = _tmp4_;
#line 16066 "Photo.c"
	}
#line 2052 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = alteration;
#line 2052 "/home/jens/Source/shotwell/src/Photo.vala"
	data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp5_);
#line 2047 "/home/jens/Source/shotwell/src/Photo.vala"
	_alteration_unref0 (alteration);
#line 16074 "Photo.c"
}


guint64 photo_replace_flags (Photo* self, guint64 flags, Alteration* additional_alteration) {
	guint64 result = 0ULL;
	gboolean committed = FALSE;
	gboolean _tmp11_;
	guint64 _tmp13_;
	GError * _inner_error_ = NULL;
#line 2055 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 2055 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((additional_alteration == NULL) || IS_ALTERATION (additional_alteration), 0ULL);
#line 16088 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16095 "Photo.c"
		{
			PhotoTable* _tmp1_;
			PhotoTable* _tmp2_;
			PhotoID _tmp3_ = {0};
			guint64 _tmp4_;
			gboolean _tmp5_;
			gboolean _tmp6_;
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_table_get_instance ();
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_;
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_get_photo_id (self, &_tmp3_);
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = flags;
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = photo_table_replace_flags (_tmp2_, &_tmp3_, _tmp4_);
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp5_;
#line 2058 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp2_);
#line 2059 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = committed;
#line 2059 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp6_) {
#line 16121 "Photo.c"
				PhotoRow* _tmp7_;
				guint64 _tmp8_;
#line 2060 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = self->row;
#line 2060 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = flags;
#line 2060 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_->flags = _tmp8_;
#line 16130 "Photo.c"
			}
		}
		__finally339:
		{
			PhotoRow* _tmp9_;
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16140 "Photo.c"
		}
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16144 "Photo.c"
			guint64 _tmp10_ = 0ULL;
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2057 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp10_;
#line 16152 "Photo.c"
		}
	}
#line 2063 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = committed;
#line 2063 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_) {
#line 16159 "Photo.c"
		Alteration* _tmp12_;
#line 2064 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = additional_alteration;
#line 2064 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_flags_altered (self, _tmp12_);
#line 16165 "Photo.c"
	}
#line 2066 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = flags;
#line 2066 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp13_;
#line 2066 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 16173 "Photo.c"
}


gboolean photo_is_flag_set (Photo* self, guint64 mask) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2069 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 16182 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp7_ = FALSE;
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16190 "Photo.c"
		{
			PhotoRow* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			gboolean _tmp4_;
#line 2071 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2071 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->flags;
#line 2071 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = mask;
#line 2071 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = media_source_internal_is_flag_set (_tmp2_, _tmp3_);
#line 2071 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp4_;
#line 16206 "Photo.c"
			{
				PhotoRow* _tmp5_;
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = self->row;
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16213 "Photo.c"
			}
#line 2071 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 16217 "Photo.c"
		}
		__finally340:
		{
			PhotoRow* _tmp6_;
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->row;
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16226 "Photo.c"
		}
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2070 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp7_;
#line 16234 "Photo.c"
	}
}


guint64 photo_add_flags (Photo* self, guint64 mask, Alteration* additional_alteration) {
	guint64 result = 0ULL;
	guint64 flags = 0ULL;
	gboolean committed = FALSE;
	gboolean _tmp18_;
	GError * _inner_error_ = NULL;
#line 2075 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 2075 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((additional_alteration == NULL) || IS_ALTERATION (additional_alteration), 0ULL);
#line 2076 "/home/jens/Source/shotwell/src/Photo.vala"
	flags = (guint64) 0;
#line 2078 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 16253 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16260 "Photo.c"
		{
			PhotoRow* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			guint64 _tmp4_;
			PhotoRow* _tmp5_;
			guint64 _tmp6_;
			guint64 _tmp7_;
#line 2080 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2080 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->flags;
#line 2080 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = mask;
#line 2080 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = media_source_internal_add_flags (_tmp2_, _tmp3_);
#line 2080 "/home/jens/Source/shotwell/src/Photo.vala"
			flags = _tmp4_;
#line 2081 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2081 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_->flags;
#line 2081 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = flags;
#line 2081 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp6_ != _tmp7_) {
#line 16287 "Photo.c"
				PhotoTable* _tmp8_;
				PhotoTable* _tmp9_;
				PhotoID _tmp10_ = {0};
				guint64 _tmp11_;
				gboolean _tmp12_;
				gboolean _tmp13_;
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = photo_table_get_instance ();
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tmp8_;
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (self, &_tmp10_);
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = flags;
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = photo_table_replace_flags (_tmp9_, &_tmp10_, _tmp11_);
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = _tmp12_;
#line 2082 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp9_);
#line 2083 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = committed;
#line 2083 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp13_) {
#line 16312 "Photo.c"
					PhotoRow* _tmp14_;
					guint64 _tmp15_;
#line 2084 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = self->row;
#line 2084 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = flags;
#line 2084 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_->flags = _tmp15_;
#line 16321 "Photo.c"
				}
			}
		}
		__finally341:
		{
			PhotoRow* _tmp16_;
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = self->row;
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16332 "Photo.c"
		}
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16336 "Photo.c"
			guint64 _tmp17_ = 0ULL;
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2079 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp17_;
#line 16344 "Photo.c"
		}
	}
#line 2088 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = committed;
#line 2088 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp18_) {
#line 16351 "Photo.c"
		Alteration* _tmp19_;
#line 2089 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = additional_alteration;
#line 2089 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_flags_altered (self, _tmp19_);
#line 16357 "Photo.c"
	}
#line 2091 "/home/jens/Source/shotwell/src/Photo.vala"
	result = flags;
#line 2091 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 16363 "Photo.c"
}


guint64 photo_remove_flags (Photo* self, guint64 mask, Alteration* additional_alteration) {
	guint64 result = 0ULL;
	guint64 flags = 0ULL;
	gboolean committed = FALSE;
	gboolean _tmp18_;
	GError * _inner_error_ = NULL;
#line 2094 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 2094 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((additional_alteration == NULL) || IS_ALTERATION (additional_alteration), 0ULL);
#line 2095 "/home/jens/Source/shotwell/src/Photo.vala"
	flags = (guint64) 0;
#line 2097 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 16381 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16388 "Photo.c"
		{
			PhotoRow* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			guint64 _tmp4_;
			PhotoRow* _tmp5_;
			guint64 _tmp6_;
			guint64 _tmp7_;
#line 2099 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2099 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->flags;
#line 2099 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = mask;
#line 2099 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = media_source_internal_remove_flags (_tmp2_, _tmp3_);
#line 2099 "/home/jens/Source/shotwell/src/Photo.vala"
			flags = _tmp4_;
#line 2100 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2100 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_->flags;
#line 2100 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = flags;
#line 2100 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp6_ != _tmp7_) {
#line 16415 "Photo.c"
				PhotoTable* _tmp8_;
				PhotoTable* _tmp9_;
				PhotoID _tmp10_ = {0};
				guint64 _tmp11_;
				gboolean _tmp12_;
				gboolean _tmp13_;
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = photo_table_get_instance ();
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tmp8_;
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (self, &_tmp10_);
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = flags;
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = photo_table_replace_flags (_tmp9_, &_tmp10_, _tmp11_);
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = _tmp12_;
#line 2101 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp9_);
#line 2102 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = committed;
#line 2102 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp13_) {
#line 16440 "Photo.c"
					PhotoRow* _tmp14_;
					guint64 _tmp15_;
#line 2103 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = self->row;
#line 2103 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = flags;
#line 2103 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_->flags = _tmp15_;
#line 16449 "Photo.c"
				}
			}
		}
		__finally342:
		{
			PhotoRow* _tmp16_;
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = self->row;
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16460 "Photo.c"
		}
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16464 "Photo.c"
			guint64 _tmp17_ = 0ULL;
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2098 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp17_;
#line 16472 "Photo.c"
		}
	}
#line 2107 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = committed;
#line 2107 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp18_) {
#line 16479 "Photo.c"
		Alteration* _tmp19_;
#line 2108 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = additional_alteration;
#line 2108 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_flags_altered (self, _tmp19_);
#line 16485 "Photo.c"
	}
#line 2110 "/home/jens/Source/shotwell/src/Photo.vala"
	result = flags;
#line 2110 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 16491 "Photo.c"
}


guint64 photo_add_remove_flags (Photo* self, guint64 add, guint64 remove, Alteration* additional_alteration) {
	guint64 result = 0ULL;
	guint64 flags = 0ULL;
	gboolean committed = FALSE;
	gboolean _tmp18_;
	GError * _inner_error_ = NULL;
#line 2113 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 2113 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((additional_alteration == NULL) || IS_ALTERATION (additional_alteration), 0ULL);
#line 2114 "/home/jens/Source/shotwell/src/Photo.vala"
	flags = (guint64) 0;
#line 2116 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 16509 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16516 "Photo.c"
		{
			PhotoRow* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			guint64 _tmp4_;
			PhotoRow* _tmp5_;
			guint64 _tmp6_;
			guint64 _tmp7_;
#line 2118 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2118 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->flags;
#line 2118 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = add;
#line 2118 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = remove;
#line 2118 "/home/jens/Source/shotwell/src/Photo.vala"
			flags = (_tmp2_ | _tmp3_) & (~_tmp4_);
#line 2119 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2119 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_->flags;
#line 2119 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = flags;
#line 2119 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp6_ != _tmp7_) {
#line 16543 "Photo.c"
				PhotoTable* _tmp8_;
				PhotoTable* _tmp9_;
				PhotoID _tmp10_ = {0};
				guint64 _tmp11_;
				gboolean _tmp12_;
				gboolean _tmp13_;
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = photo_table_get_instance ();
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tmp8_;
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (self, &_tmp10_);
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = flags;
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = photo_table_replace_flags (_tmp9_, &_tmp10_, _tmp11_);
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = _tmp12_;
#line 2120 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp9_);
#line 2121 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = committed;
#line 2121 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp13_) {
#line 16568 "Photo.c"
					PhotoRow* _tmp14_;
					guint64 _tmp15_;
#line 2122 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = self->row;
#line 2122 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = flags;
#line 2122 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_->flags = _tmp15_;
#line 16577 "Photo.c"
				}
			}
		}
		__finally343:
		{
			PhotoRow* _tmp16_;
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = self->row;
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16588 "Photo.c"
		}
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16592 "Photo.c"
			guint64 _tmp17_ = 0ULL;
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2117 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp17_;
#line 16600 "Photo.c"
		}
	}
#line 2126 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = committed;
#line 2126 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp18_) {
#line 16607 "Photo.c"
		Alteration* _tmp19_;
#line 2127 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = additional_alteration;
#line 2127 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_flags_altered (self, _tmp19_);
#line 16613 "Photo.c"
	}
#line 2129 "/home/jens/Source/shotwell/src/Photo.vala"
	result = flags;
#line 2129 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 16619 "Photo.c"
}


void photo_add_remove_many_flags (GeeCollection* add, guint64 add_mask, Alteration* additional_add_alteration, GeeCollection* remove, guint64 remove_mask, Alteration* additional_remove_alteration, GError** error) {
	GeeCollection* _tmp0_;
	GeeCollection* _tmp10_;
	GError * _inner_error_ = NULL;
#line 2132 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((add == NULL) || GEE_IS_COLLECTION (add));
#line 2132 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((additional_add_alteration == NULL) || IS_ALTERATION (additional_add_alteration));
#line 2132 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((remove == NULL) || GEE_IS_COLLECTION (remove));
#line 2132 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((additional_remove_alteration == NULL) || IS_ALTERATION (additional_remove_alteration));
#line 2135 "/home/jens/Source/shotwell/src/Photo.vala"
	database_table_begin_transaction ();
#line 2137 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = add;
#line 2137 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != NULL) {
#line 16641 "Photo.c"
		{
			GeeIterator* _photo_it = NULL;
			GeeCollection* _tmp1_;
			GeeIterator* _tmp2_;
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = add;
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_it = _tmp2_;
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 16654 "Photo.c"
				GeeIterator* _tmp3_;
				gboolean _tmp4_;
				Photo* photo = NULL;
				GeeIterator* _tmp5_;
				gpointer _tmp6_;
				Photo* _tmp7_;
				guint64 _tmp8_;
				Alteration* _tmp9_;
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = _photo_it;
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_iterator_next (_tmp3_);
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp4_) {
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 16671 "Photo.c"
				}
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _photo_it;
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = gee_iterator_get (_tmp5_);
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = (Photo*) _tmp6_;
#line 2139 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = photo;
#line 2139 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = add_mask;
#line 2139 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = additional_add_alteration;
#line 2139 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_add_flags (_tmp7_, _tmp8_, _tmp9_);
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 16689 "Photo.c"
			}
#line 2138 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_photo_it);
#line 16693 "Photo.c"
		}
	}
#line 2142 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = remove;
#line 2142 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp10_ != NULL) {
#line 16700 "Photo.c"
		{
			GeeIterator* _photo_it = NULL;
			GeeCollection* _tmp11_;
			GeeIterator* _tmp12_;
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = remove;
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_it = _tmp12_;
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 16713 "Photo.c"
				GeeIterator* _tmp13_;
				gboolean _tmp14_;
				Photo* photo = NULL;
				GeeIterator* _tmp15_;
				gpointer _tmp16_;
				Photo* _tmp17_;
				guint64 _tmp18_;
				Alteration* _tmp19_;
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _photo_it;
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = gee_iterator_next (_tmp13_);
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp14_) {
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 16730 "Photo.c"
				}
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = _photo_it;
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = gee_iterator_get (_tmp15_);
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = (Photo*) _tmp16_;
#line 2144 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = photo;
#line 2144 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = remove_mask;
#line 2144 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = additional_remove_alteration;
#line 2144 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_remove_flags (_tmp17_, _tmp18_, _tmp19_);
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 16748 "Photo.c"
			}
#line 2143 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_photo_it);
#line 16752 "Photo.c"
		}
	}
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
	database_table_commit_transaction (&_inner_error_);
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 16765 "Photo.c"
		} else {
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2147 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 16773 "Photo.c"
		}
	}
}


guint64 photo_toggle_flags (Photo* self, guint64 mask, Alteration* additional_alteration) {
	guint64 result = 0ULL;
	guint64 flags = 0ULL;
	gboolean committed = FALSE;
	gboolean _tmp17_;
	GError * _inner_error_ = NULL;
#line 2150 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 2150 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((additional_alteration == NULL) || IS_ALTERATION (additional_alteration), 0ULL);
#line 2151 "/home/jens/Source/shotwell/src/Photo.vala"
	flags = (guint64) 0;
#line 2153 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 16793 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16800 "Photo.c"
		{
			PhotoRow* _tmp1_;
			guint64 _tmp2_;
			guint64 _tmp3_;
			PhotoRow* _tmp4_;
			guint64 _tmp5_;
			guint64 _tmp6_;
#line 2155 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2155 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->flags;
#line 2155 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = mask;
#line 2155 "/home/jens/Source/shotwell/src/Photo.vala"
			flags = _tmp2_ ^ _tmp3_;
#line 2156 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2156 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _tmp4_->flags;
#line 2156 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = flags;
#line 2156 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp5_ != _tmp6_) {
#line 16824 "Photo.c"
				PhotoTable* _tmp7_;
				PhotoTable* _tmp8_;
				PhotoID _tmp9_ = {0};
				guint64 _tmp10_;
				gboolean _tmp11_;
				gboolean _tmp12_;
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = photo_table_get_instance ();
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _tmp7_;
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (self, &_tmp9_);
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = flags;
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = photo_table_replace_flags (_tmp8_, &_tmp9_, _tmp10_);
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = _tmp11_;
#line 2157 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp8_);
#line 2158 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = committed;
#line 2158 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp12_) {
#line 16849 "Photo.c"
					PhotoRow* _tmp13_;
					guint64 _tmp14_;
#line 2159 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = self->row;
#line 2159 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = flags;
#line 2159 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_->flags = _tmp14_;
#line 16858 "Photo.c"
				}
			}
		}
		__finally344:
		{
			PhotoRow* _tmp15_;
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = self->row;
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16869 "Photo.c"
		}
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16873 "Photo.c"
			guint64 _tmp16_ = 0ULL;
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2154 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp16_;
#line 16881 "Photo.c"
		}
	}
#line 2163 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = committed;
#line 2163 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp17_) {
#line 16888 "Photo.c"
		Alteration* _tmp18_;
#line 2164 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = additional_alteration;
#line 2164 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_flags_altered (self, _tmp18_);
#line 16894 "Photo.c"
	}
#line 2166 "/home/jens/Source/shotwell/src/Photo.vala"
	result = flags;
#line 2166 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 16900 "Photo.c"
}


gboolean photo_is_master_metadata_dirty (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2169 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 16909 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp5_ = FALSE;
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16917 "Photo.c"
		{
			PhotoRow* _tmp1_;
			gboolean _tmp2_;
#line 2171 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2171 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->metadata_dirty;
#line 2171 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 16927 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16934 "Photo.c"
			}
#line 2171 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 16938 "Photo.c"
		}
		__finally345:
		{
			PhotoRow* _tmp4_;
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 16947 "Photo.c"
		}
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2170 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 16955 "Photo.c"
	}
}


void photo_set_master_metadata_dirty (Photo* self, gboolean dirty, GError** error) {
	gboolean committed = FALSE;
	gboolean _tmp11_;
	GError * _inner_error_ = NULL;
#line 2175 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2176 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 16968 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 16975 "Photo.c"
		{
			PhotoRow* _tmp1_;
			gboolean _tmp2_;
			gboolean _tmp3_;
#line 2178 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2178 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->metadata_dirty;
#line 2178 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = dirty;
#line 2178 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != _tmp3_) {
#line 16988 "Photo.c"
				PhotoTable* _tmp4_;
				PhotoTable* _tmp5_;
				PhotoID _tmp6_ = {0};
				gboolean _tmp7_;
				PhotoRow* _tmp8_;
				gboolean _tmp9_;
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = photo_table_get_instance ();
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_;
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (self, &_tmp6_);
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = dirty;
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_set_metadata_dirty (_tmp5_, &_tmp6_, _tmp7_, &_inner_error_);
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp5_);
#line 2179 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17009 "Photo.c"
					goto __finally346;
				}
#line 2180 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = self->row;
#line 2180 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = dirty;
#line 2180 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_->metadata_dirty = _tmp9_;
#line 2181 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = TRUE;
#line 17020 "Photo.c"
			}
		}
		__finally346:
		{
			PhotoRow* _tmp10_;
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = self->row;
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17030 "Photo.c"
		}
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 17040 "Photo.c"
			} else {
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 2177 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 17048 "Photo.c"
			}
		}
	}
#line 2185 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = committed;
#line 2185 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_) {
#line 17056 "Photo.c"
		Alteration* _tmp12_;
		Alteration* _tmp13_;
#line 2186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = alteration_new ("metadata", "master-dirty");
#line 2186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _tmp12_;
#line 2186 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp13_);
#line 2186 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp13_);
#line 17067 "Photo.c"
	}
}


static Rating photo_real_get_rating (MediaSource* base) {
	Photo * self;
	Rating result = 0;
	GError * _inner_error_ = NULL;
#line 2189 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 17078 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 17085 "Photo.c"
		{
			PhotoRow* _tmp1_;
			Rating _tmp2_;
#line 2191 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2191 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->rating;
#line 2191 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 17095 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17102 "Photo.c"
			}
#line 2191 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 17106 "Photo.c"
		}
		__finally347:
		{
			PhotoRow* _tmp4_;
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17115 "Photo.c"
		}
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2190 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 17123 "Photo.c"
	}
}


static void photo_real_set_rating (MediaSource* base, Rating rating) {
	Photo * self;
	gboolean committed = FALSE;
	gboolean _tmp16_;
	GError * _inner_error_ = NULL;
#line 2195 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2196 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 17137 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 17144 "Photo.c"
		{
			gboolean _tmp1_ = FALSE;
			Rating _tmp2_;
			PhotoRow* _tmp3_;
			Rating _tmp4_;
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = rating;
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = _tmp3_->rating;
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != _tmp4_) {
#line 17158 "Photo.c"
				Rating _tmp5_;
				gboolean _tmp6_;
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = rating;
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = rating_is_valid (_tmp5_);
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp6_;
#line 17167 "Photo.c"
			} else {
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = FALSE;
#line 17171 "Photo.c"
			}
#line 2199 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp1_) {
#line 17175 "Photo.c"
				PhotoTable* _tmp7_;
				PhotoTable* _tmp8_;
				PhotoID _tmp9_ = {0};
				Rating _tmp10_;
				gboolean _tmp11_;
				gboolean _tmp12_;
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = photo_table_get_instance ();
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _tmp7_;
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (self, &_tmp9_);
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = rating;
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = photo_table_set_rating (_tmp8_, &_tmp9_, _tmp10_);
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = _tmp11_;
#line 2200 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp8_);
#line 2201 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = committed;
#line 2201 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp12_) {
#line 17200 "Photo.c"
					PhotoRow* _tmp13_;
					Rating _tmp14_;
#line 2202 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = self->row;
#line 2202 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = rating;
#line 2202 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_->rating = _tmp14_;
#line 17209 "Photo.c"
				}
			}
		}
		__finally348:
		{
			PhotoRow* _tmp15_;
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = self->row;
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17220 "Photo.c"
		}
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2198 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 17230 "Photo.c"
		}
	}
#line 2206 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = committed;
#line 2206 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp16_) {
#line 17237 "Photo.c"
		Alteration* _tmp17_;
		Alteration* _tmp18_;
#line 2207 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = alteration_new ("metadata", "rating");
#line 2207 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = _tmp17_;
#line 2207 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp18_);
#line 2207 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp18_);
#line 17248 "Photo.c"
	}
}


static void photo_real_increase_rating (MediaSource* base) {
	Photo * self;
	GError * _inner_error_ = NULL;
#line 2210 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 17258 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 17265 "Photo.c"
		{
			PhotoRow* _tmp1_;
			Rating _tmp2_;
			Rating _tmp3_;
#line 2212 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2212 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->rating;
#line 2212 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = rating_increase (_tmp2_);
#line 2212 "/home/jens/Source/shotwell/src/Photo.vala"
			media_source_set_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp3_);
#line 17278 "Photo.c"
		}
		__finally349:
		{
			PhotoRow* _tmp4_;
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17287 "Photo.c"
		}
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2211 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 17297 "Photo.c"
		}
	}
}


static void photo_real_decrease_rating (MediaSource* base) {
	Photo * self;
	GError * _inner_error_ = NULL;
#line 2216 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 17308 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 17315 "Photo.c"
		{
			PhotoRow* _tmp1_;
			Rating _tmp2_;
			Rating _tmp3_;
#line 2218 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2218 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->rating;
#line 2218 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = rating_decrease (_tmp2_);
#line 2218 "/home/jens/Source/shotwell/src/Photo.vala"
			media_source_set_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp3_);
#line 17328 "Photo.c"
		}
		__finally350:
		{
			PhotoRow* _tmp4_;
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17337 "Photo.c"
		}
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2217 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 17347 "Photo.c"
		}
	}
}


static void photo_real_commit_backlinks (DataSource* base, SourceCollection* sources, const gchar* backlinks) {
	Photo * self;
	GError * _inner_error_ = NULL;
#line 2222 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2222 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((sources == NULL) || IS_SOURCE_COLLECTION (sources));
#line 17360 "Photo.c"
	{
		PhotoTable* _tmp0_;
		PhotoTable* _tmp1_;
		PhotoID _tmp2_ = {0};
		const gchar* _tmp3_;
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = photo_table_get_instance ();
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp0_;
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_get_photo_id (self, &_tmp2_);
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = backlinks;
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_table_update_backlinks (_tmp1_, &_tmp2_, _tmp3_, &_inner_error_);
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		_database_table_unref0 (_tmp1_);
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 17382 "Photo.c"
				goto __catch351_database_error;
			}
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2227 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 17391 "Photo.c"
		}
		{
			PhotoRow* _tmp4_;
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 17399 "Photo.c"
			{
				PhotoRow* _tmp5_;
				const gchar* _tmp6_;
				gchar* _tmp7_;
#line 2229 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = self->row;
#line 2229 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = backlinks;
#line 2229 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = g_strdup (_tmp6_);
#line 2229 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp5_->backlinks);
#line 2229 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_->backlinks = _tmp7_;
#line 17414 "Photo.c"
			}
			__finally352:
			{
				PhotoRow* _tmp8_;
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = self->row;
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17423 "Photo.c"
			}
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 17429 "Photo.c"
					goto __catch351_database_error;
				}
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 2228 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 17438 "Photo.c"
			}
		}
	}
	goto __finally351;
	__catch351_database_error:
	{
		GError* err = NULL;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GError* _tmp11_;
		const gchar* _tmp12_;
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 2232 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 2232 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = _tmp9_;
#line 2232 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = err;
#line 2232 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp11_->message;
#line 2232 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2232: Unable to update link state for %s: %s", _tmp10_, _tmp12_);
#line 2232 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp10_);
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 17468 "Photo.c"
	}
	__finally351:
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2226 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 17479 "Photo.c"
	}
}


static gboolean photo_real_set_event_id (MediaSource* base, EventID* event_id) {
	Photo * self;
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2240 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2240 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (event_id != NULL, FALSE);
#line 17492 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp13_ = FALSE;
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 17500 "Photo.c"
		{
			gboolean committed = FALSE;
			PhotoTable* _tmp1_;
			PhotoTable* _tmp2_;
			PhotoRow* _tmp3_;
			PhotoID _tmp4_;
			EventID _tmp5_;
			gboolean _tmp6_;
			gboolean _tmp7_;
			gboolean _tmp8_;
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_table_get_instance ();
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_;
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = _tmp3_->photo_id;
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = *event_id;
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = photo_table_set_event (_tmp2_, &_tmp4_, &_tmp5_);
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _tmp6_;
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp2_);
#line 2242 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp7_;
#line 2244 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = committed;
#line 2244 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp8_) {
#line 17533 "Photo.c"
				PhotoRow* _tmp9_;
				EventID _tmp10_;
#line 2245 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = self->row;
#line 2245 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = *event_id;
#line 2245 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_->event_id = _tmp10_;
#line 17542 "Photo.c"
			}
#line 2247 "/home/jens/Source/shotwell/src/Photo.vala"
			result = committed;
#line 17546 "Photo.c"
			{
				PhotoRow* _tmp11_;
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = self->row;
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17553 "Photo.c"
			}
#line 2247 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 17557 "Photo.c"
		}
		__finally353:
		{
			PhotoRow* _tmp12_;
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = self->row;
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 17566 "Photo.c"
		}
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2241 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp13_;
#line 17574 "Photo.c"
	}
}


static gchar* photo_real_to_string (DataObject* base) {
	Photo * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gboolean _tmp1_;
	PhotoID _tmp10_ = {0};
	gint64 _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	PhotoFileReader* _tmp14_;
	PhotoFileReader* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
#line 2251 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_is_master_baseline (self);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp1_) {
#line 17600 "Photo.c"
		GFile* _tmp2_;
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = photo_get_actual_file (self);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = g_file_get_path (_tmp3_);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = g_strconcat (" (", _tmp5_, NULL);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = g_strconcat (_tmp7_, ")", NULL);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp8_;
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp7_);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp5_);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 17632 "Photo.c"
	} else {
		gchar* _tmp9_;
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = g_strdup ("");
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 2253 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp9_;
#line 17641 "Photo.c"
	}
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_photo_id (self, &_tmp10_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp10_.id;
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = g_strdup_printf ("%" G_GINT64_FORMAT, _tmp11_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_;
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = photo_get_master_reader (self);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_;
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = _tmp16_;
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = g_strdup_printf ("[%s] %s%s", _tmp13_, _tmp17_, _tmp0_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = _tmp18_;
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp17_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp15_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp13_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp19_;
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp0_);
#line 2252 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 17675 "Photo.c"
}


static gboolean photo_real_equals (DataSource* base, DataSource* source) {
	Photo * self;
	gboolean result = FALSE;
	Photo* photo = NULL;
	DataSource* _tmp0_;
	Photo* _tmp1_;
	Photo* _tmp2_;
	DataSource* _tmp14_;
	gboolean _tmp15_;
#line 2256 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2256 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((source == NULL) || IS_DATA_SOURCE (source), FALSE);
#line 2258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = source;
#line 2258 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_PHOTO) ? ((Photo*) _tmp0_) : NULL);
#line 2258 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp1_;
#line 2259 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo;
#line 2259 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ != NULL) {
#line 17702 "Photo.c"
		PhotoID photo_id = {0};
		PhotoID _tmp3_ = {0};
		PhotoID other_photo_id = {0};
		Photo* _tmp4_;
		PhotoID _tmp5_ = {0};
		gboolean _tmp6_ = FALSE;
		Photo* _tmp7_;
#line 2260 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_get_photo_id (self, &_tmp3_);
#line 2260 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_id = _tmp3_;
#line 2261 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = photo;
#line 2261 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_get_photo_id (_tmp4_, &_tmp5_);
#line 2261 "/home/jens/Source/shotwell/src/Photo.vala"
		other_photo_id = _tmp5_;
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = photo;
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
		if (self != _tmp7_) {
#line 17724 "Photo.c"
			PhotoID _tmp8_;
			gint64 _tmp9_;
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = photo_id;
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_.id;
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp9_ != PHOTO_ID_INVALID;
#line 17733 "Photo.c"
		} else {
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = FALSE;
#line 17737 "Photo.c"
		}
#line 2263 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp6_) {
#line 17741 "Photo.c"
			PhotoID _tmp10_;
			gint64 _tmp11_;
			PhotoID _tmp12_;
			gint64 _tmp13_;
#line 2264 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = photo_id;
#line 2264 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = _tmp10_.id;
#line 2264 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = other_photo_id;
#line 2264 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = _tmp12_.id;
#line 2264 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_assert (_tmp11_ != _tmp13_, "photo_id.id != other_photo_id.id");
#line 17756 "Photo.c"
		}
	}
#line 2268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = source;
#line 2268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = DATA_SOURCE_CLASS (photo_parent_class)->equals (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource), TYPE_DATA_SOURCE, DataSource), _tmp14_);
#line 2268 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp15_;
#line 2268 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 2268 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 17769 "Photo.c"
}


static void photo_file_exif_updated (Photo* self) {
	GFile* file = NULL;
	GFile* _tmp0_;
	GFileInfo* info = NULL;
	GTimeVal timestamp = {0};
	GFileInfo* _tmp7_;
	GTimeVal _tmp8_ = {0};
	PhotoFileInterrogator* interrogator = NULL;
	PhotoFileInterrogator* _tmp9_;
	DetectedPhotoInformation* detected = NULL;
	DetectedPhotoInformation* _tmp14_;
	gboolean _tmp15_ = FALSE;
	DetectedPhotoInformation* _tmp16_;
	gboolean success = FALSE;
	gboolean _tmp37_;
	GError * _inner_error_ = NULL;
#line 2272 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_get_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 2273 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp0_;
#line 2275 "/home/jens/Source/shotwell/src/Photo.vala"
	info = NULL;
#line 17797 "Photo.c"
	{
		GFileInfo* _tmp1_ = NULL;
		GFileInfo* _tmp2_;
		GFileInfo* _tmp3_;
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = g_file_query_info (file, DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &_inner_error_);
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp2_;
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17808 "Photo.c"
			goto __catch354_g_error;
		}
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp1_;
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = NULL;
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 2277 "/home/jens/Source/shotwell/src/Photo.vala"
		info = _tmp3_;
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp1_);
#line 17821 "Photo.c"
	}
	goto __finally354;
	__catch354_g_error:
	{
		GError* err = NULL;
		gchar* _tmp4_;
		gchar* _tmp5_;
		const gchar* _tmp6_;
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 2280 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 2280 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 2280 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = err->message;
#line 2280 "/home/jens/Source/shotwell/src/Photo.vala"
		g_error ("Photo.vala:2280: Unable to read file information for %s: %s", _tmp5_, _tmp6_);
#line 2280 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp5_);
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 17846 "Photo.c"
	}
	__finally354:
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2276 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 17861 "Photo.c"
	}
#line 2283 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = info;
#line 2283 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_info_get_modification_time (_tmp7_, &_tmp8_);
#line 2283 "/home/jens/Source/shotwell/src/Photo.vala"
	timestamp = _tmp8_;
#line 2286 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = photo_file_interrogator_new (file, PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL);
#line 2286 "/home/jens/Source/shotwell/src/Photo.vala"
	interrogator = _tmp9_;
#line 17873 "Photo.c"
	{
#line 2288 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_interrogator_interrogate (interrogator, &_inner_error_);
#line 2288 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17879 "Photo.c"
			goto __catch355_g_error;
		}
	}
	goto __finally355;
	__catch355_g_error:
	{
		GError* err = NULL;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GError* _tmp12_;
		const gchar* _tmp13_;
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 2290 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = g_file_get_path (file);
#line 2290 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = _tmp10_;
#line 2290 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = err;
#line 2290 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _tmp12_->message;
#line 2290 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2290: Unable to interrogate photo file %s: %s", _tmp11_, _tmp13_);
#line 2290 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp11_);
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 17909 "Photo.c"
	}
	__finally355:
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2287 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 17926 "Photo.c"
	}
#line 2293 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = photo_file_interrogator_get_detected_photo_information (interrogator);
#line 2293 "/home/jens/Source/shotwell/src/Photo.vala"
	detected = _tmp14_;
#line 2294 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = detected;
#line 2294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp16_ == NULL) {
#line 2294 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = TRUE;
#line 17938 "Photo.c"
	} else {
		gboolean _tmp17_;
#line 2294 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = photo_file_interrogator_get_is_photo_corrupted (interrogator);
#line 2294 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = _tmp17_;
#line 17945 "Photo.c"
	}
#line 2294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp15_) {
#line 17949 "Photo.c"
		gchar* _tmp18_;
		gchar* _tmp19_;
#line 2295 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 2295 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = _tmp18_;
#line 2295 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("Photo.vala:2295: file_exif_updated: %s no longer an image", _tmp19_);
#line 2295 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp19_);
#line 2297 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 2297 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_interrogator_unref0 (interrogator);
#line 2297 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 2297 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 2297 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 17970 "Photo.c"
	}
	{
		PhotoRow* _tmp20_;
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = self->row;
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 17978 "Photo.c"
		{
			PhotoTable* _tmp21_;
			PhotoTable* _tmp22_;
			PhotoID _tmp23_ = {0};
			GFileInfo* _tmp24_;
			gint64 _tmp25_;
			GTimeVal _tmp26_;
			glong _tmp27_;
			DetectedPhotoInformation* _tmp28_;
			const gchar* _tmp29_;
			DetectedPhotoInformation* _tmp30_;
			const gchar* _tmp31_;
			DetectedPhotoInformation* _tmp32_;
			const gchar* _tmp33_;
			PhotoRow* _tmp34_;
			gboolean _tmp35_;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = photo_table_get_instance ();
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = _tmp21_;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_get_photo_id (self, &_tmp23_);
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = info;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp25_ = g_file_info_get_size (_tmp24_);
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = timestamp;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = _tmp26_.tv_sec;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp28_ = detected;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp29_ = _tmp28_->md5;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp30_ = detected;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp31_ = _tmp30_->exif_md5;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp32_ = detected;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp33_ = _tmp32_->thumbnail_md5;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp34_ = self->row;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp35_ = photo_table_master_exif_updated (_tmp22_, &_tmp23_, _tmp25_, _tmp27_, _tmp29_, _tmp31_, _tmp33_, _tmp34_);
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			success = _tmp35_;
#line 2302 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp22_);
#line 18029 "Photo.c"
		}
		__finally356:
		{
			PhotoRow* _tmp36_;
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp36_ = self->row;
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18038 "Photo.c"
		}
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_interrogator_unref0 (interrogator);
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2301 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 18056 "Photo.c"
		}
	}
#line 2306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = success;
#line 2306 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp37_) {
#line 18063 "Photo.c"
		Alteration* _tmp38_;
		Alteration* _tmp39_;
#line 2307 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp38_ = alteration_new_from_list ("metadata:exif,metadata:md5");
#line 2307 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = _tmp38_;
#line 2307 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp39_);
#line 2307 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp39_);
#line 18074 "Photo.c"
	}
#line 2272 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 2272 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_interrogator_unref0 (interrogator);
#line 2272 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (info);
#line 2272 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 18084 "Photo.c"
}


static guint64 photo_real_get_filesize (MediaSource* base) {
	Photo * self;
	guint64 result = 0ULL;
	GError * _inner_error_ = NULL;
#line 2312 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 18094 "Photo.c"
	{
		PhotoRow* _tmp0_;
		guint64 _tmp5_ = 0ULL;
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18102 "Photo.c"
		{
			BackingPhotoRow* _tmp1_;
			gint64 _tmp2_;
#line 2314 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->backing_photo_row;
#line 2314 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->filesize;
#line 2314 "/home/jens/Source/shotwell/src/Photo.vala"
			result = (guint64) _tmp2_;
#line 18112 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18119 "Photo.c"
			}
#line 2314 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 18123 "Photo.c"
		}
		__finally357:
		{
			PhotoRow* _tmp4_;
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18132 "Photo.c"
		}
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2313 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 18140 "Photo.c"
	}
}


static guint64 photo_real_get_master_filesize (MediaSource* base) {
	Photo * self;
	guint64 result = 0ULL;
	GError * _inner_error_ = NULL;
#line 2318 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 18151 "Photo.c"
	{
		PhotoRow* _tmp0_;
		guint64 _tmp6_ = 0ULL;
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18159 "Photo.c"
		{
			PhotoRow* _tmp1_;
			BackingPhotoRow* _tmp2_;
			gint64 _tmp3_;
#line 2320 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2320 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->master;
#line 2320 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _tmp2_->filesize;
#line 2320 "/home/jens/Source/shotwell/src/Photo.vala"
			result = (guint64) _tmp3_;
#line 18172 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18179 "Photo.c"
			}
#line 2320 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 18183 "Photo.c"
		}
		__finally358:
		{
			PhotoRow* _tmp5_;
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18192 "Photo.c"
		}
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2319 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp6_;
#line 18200 "Photo.c"
	}
}


guint64 photo_get_editable_filesize (Photo* self) {
	guint64 result = 0ULL;
	GError * _inner_error_ = NULL;
#line 2324 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0ULL);
#line 18210 "Photo.c"
	{
		PhotoRow* _tmp0_;
		guint64 _tmp5_ = 0ULL;
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18218 "Photo.c"
		{
			BackingPhotoRow* _tmp1_;
			gint64 _tmp2_;
#line 2326 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->editable;
#line 2326 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->filesize;
#line 2326 "/home/jens/Source/shotwell/src/Photo.vala"
			result = (guint64) _tmp2_;
#line 18228 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18235 "Photo.c"
			}
#line 2326 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 18239 "Photo.c"
		}
		__finally359:
		{
			PhotoRow* _tmp4_;
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18248 "Photo.c"
		}
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2325 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp5_;
#line 18256 "Photo.c"
	}
}


static time_t photo_real_get_exposure_time (Dateable* base) {
	Photo * self;
	time_t result = 0;
	time_t _tmp0_;
#line 2330 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2331 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->cached_exposure_time;
#line 2331 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 2331 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 18273 "Photo.c"
}


static gchar* photo_real_get_basename (MediaSource* base) {
	Photo * self;
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 2334 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 18283 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18290 "Photo.c"
		{
			const gchar* _tmp1_;
			gchar* _tmp2_;
#line 2336 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->file_title;
#line 2336 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = g_strdup (_tmp1_);
#line 2336 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 18300 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18307 "Photo.c"
			}
#line 2336 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 18311 "Photo.c"
		}
		__finally360:
		{
			PhotoRow* _tmp4_;
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18320 "Photo.c"
		}
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2335 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 18328 "Photo.c"
	}
}


static gchar* photo_real_get_title (MediaSource* base) {
	Photo * self;
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 2340 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 18339 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18346 "Photo.c"
		{
			PhotoRow* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
#line 2342 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2342 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->title;
#line 2342 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = g_strdup (_tmp2_);
#line 2342 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 18359 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18366 "Photo.c"
			}
#line 2342 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 18370 "Photo.c"
		}
		__finally361:
		{
			PhotoRow* _tmp5_;
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18379 "Photo.c"
		}
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2341 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 18387 "Photo.c"
	}
}


static gchar* photo_real_get_comment (MediaSource* base) {
	Photo * self;
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 2346 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 18398 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18405 "Photo.c"
		{
			PhotoRow* _tmp1_;
			const gchar* _tmp2_;
			gchar* _tmp3_;
#line 2348 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2348 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->comment;
#line 2348 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = g_strdup (_tmp2_);
#line 2348 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 18418 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18425 "Photo.c"
			}
#line 2348 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 18429 "Photo.c"
		}
		__finally362:
		{
			PhotoRow* _tmp5_;
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18438 "Photo.c"
		}
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2347 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 18446 "Photo.c"
	}
}


static void photo_real_set_title (MediaSource* base, const gchar* title) {
	Photo * self;
	gchar* new_title = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean committed = FALSE;
	gboolean _tmp18_;
	GError * _inner_error_ = NULL;
#line 2352 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2353 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = title;
#line 2353 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = media_source_prep_title (_tmp0_);
#line 2353 "/home/jens/Source/shotwell/src/Photo.vala"
	new_title = _tmp1_;
#line 2355 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 18469 "Photo.c"
	{
		PhotoRow* _tmp2_;
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->row;
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18476 "Photo.c"
		{
			const gchar* _tmp3_;
			PhotoRow* _tmp4_;
			const gchar* _tmp5_;
			PhotoTable* _tmp7_;
			PhotoTable* _tmp8_;
			PhotoRow* _tmp9_;
			PhotoID _tmp10_;
			const gchar* _tmp11_;
			gboolean _tmp12_;
			gboolean _tmp13_;
#line 2357 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = new_title;
#line 2357 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2357 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _tmp4_->title;
#line 2357 "/home/jens/Source/shotwell/src/Photo.vala"
			if (g_strcmp0 (_tmp3_, _tmp5_) == 0) {
#line 18496 "Photo.c"
				{
					PhotoRow* _tmp6_;
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp6_ = self->row;
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18503 "Photo.c"
				}
#line 2358 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (new_title);
#line 2358 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 18509 "Photo.c"
			}
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = photo_table_get_instance ();
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp7_;
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = _tmp9_->photo_id;
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = new_title;
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo_table_set_title (_tmp8_, &_tmp10_, _tmp11_);
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp12_;
#line 2360 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp8_);
#line 2361 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = committed;
#line 2361 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp13_) {
#line 18531 "Photo.c"
				PhotoRow* _tmp14_;
				const gchar* _tmp15_;
				gchar* _tmp16_;
#line 2362 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = self->row;
#line 2362 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = new_title;
#line 2362 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = g_strdup (_tmp15_);
#line 2362 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp14_->title);
#line 2362 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_->title = _tmp16_;
#line 18545 "Photo.c"
			}
		}
		__finally363:
		{
			PhotoRow* _tmp17_;
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = self->row;
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18555 "Photo.c"
		}
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (new_title);
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2356 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 18567 "Photo.c"
		}
	}
#line 2365 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = committed;
#line 2365 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp18_) {
#line 18574 "Photo.c"
		Alteration* _tmp19_;
		Alteration* _tmp20_;
#line 2366 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = alteration_new ("metadata", "name");
#line 2366 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = _tmp19_;
#line 2366 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp20_);
#line 2366 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp20_);
#line 18585 "Photo.c"
	}
#line 2352 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (new_title);
#line 18589 "Photo.c"
}


static gboolean photo_real_set_comment (MediaSource* base, const gchar* comment) {
	Photo * self;
	gboolean result = FALSE;
	gchar* new_comment = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean committed = FALSE;
	gboolean _tmp19_;
	GError * _inner_error_ = NULL;
#line 2369 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2370 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = comment;
#line 2370 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = media_source_prep_comment (_tmp0_);
#line 2370 "/home/jens/Source/shotwell/src/Photo.vala"
	new_comment = _tmp1_;
#line 2372 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 18612 "Photo.c"
	{
		PhotoRow* _tmp2_;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->row;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18619 "Photo.c"
		{
			const gchar* _tmp3_;
			PhotoRow* _tmp4_;
			const gchar* _tmp5_;
			PhotoTable* _tmp7_;
			PhotoTable* _tmp8_;
			PhotoRow* _tmp9_;
			PhotoID _tmp10_;
			const gchar* _tmp11_;
			gboolean _tmp12_;
			gboolean _tmp13_;
#line 2374 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = new_comment;
#line 2374 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2374 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _tmp4_->comment;
#line 2374 "/home/jens/Source/shotwell/src/Photo.vala"
			if (g_strcmp0 (_tmp3_, _tmp5_) == 0) {
#line 2375 "/home/jens/Source/shotwell/src/Photo.vala"
				result = TRUE;
#line 18641 "Photo.c"
				{
					PhotoRow* _tmp6_;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp6_ = self->row;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18648 "Photo.c"
				}
#line 2375 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (new_comment);
#line 2375 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 18654 "Photo.c"
			}
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = photo_table_get_instance ();
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp7_;
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = _tmp9_->photo_id;
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = new_comment;
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo_table_set_comment (_tmp8_, &_tmp10_, _tmp11_);
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp12_;
#line 2377 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp8_);
#line 2378 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = committed;
#line 2378 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp13_) {
#line 18676 "Photo.c"
				PhotoRow* _tmp14_;
				const gchar* _tmp15_;
				gchar* _tmp16_;
#line 2379 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = self->row;
#line 2379 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = new_comment;
#line 2379 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = g_strdup (_tmp15_);
#line 2379 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp14_->comment);
#line 2379 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_->comment = _tmp16_;
#line 18690 "Photo.c"
			}
		}
		__finally364:
		{
			PhotoRow* _tmp17_;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = self->row;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18700 "Photo.c"
		}
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18704 "Photo.c"
			gboolean _tmp18_ = FALSE;
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (new_comment);
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2373 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp18_;
#line 18714 "Photo.c"
		}
	}
#line 2382 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = committed;
#line 2382 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp19_) {
#line 18721 "Photo.c"
		Alteration* _tmp20_;
		Alteration* _tmp21_;
#line 2383 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = alteration_new ("metadata", "comment");
#line 2383 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp20_;
#line 2383 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp21_);
#line 2383 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp21_);
#line 18732 "Photo.c"
	}
#line 2385 "/home/jens/Source/shotwell/src/Photo.vala"
	result = committed;
#line 2385 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (new_comment);
#line 2385 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 18740 "Photo.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 2395 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? g_error_copy (self) : NULL;
#line 18747 "Photo.c"
}


void photo_set_import_id (Photo* self, ImportID* import_id) {
	GError* dberr = NULL;
	GError* _tmp13_;
	GError * _inner_error_ = NULL;
#line 2388 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2388 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (import_id != NULL);
#line 2389 "/home/jens/Source/shotwell/src/Photo.vala"
	dberr = NULL;
#line 18761 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 18768 "Photo.c"
		{
			{
				PhotoTable* _tmp1_;
				PhotoTable* _tmp2_;
				PhotoRow* _tmp3_;
				PhotoID _tmp4_;
				ImportID _tmp5_;
				PhotoRow* _tmp7_;
				ImportID _tmp8_;
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = photo_table_get_instance ();
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp2_ = _tmp1_;
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->photo_id;
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = *import_id;
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_set_import_id (_tmp2_, &_tmp4_, &_tmp5_, &_inner_error_);
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp2_);
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_inner_error_->domain == DATABASE_ERROR) {
#line 18796 "Photo.c"
						goto __catch366_database_error;
					}
					{
						PhotoRow* _tmp6_;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp6_ = self->row;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18805 "Photo.c"
					}
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_error_free0 (dberr);
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 2392 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 18815 "Photo.c"
				}
#line 2393 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = self->row;
#line 2393 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = *import_id;
#line 2393 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_->import_id = _tmp8_;
#line 18823 "Photo.c"
			}
			goto __finally366;
			__catch366_database_error:
			{
				GError* err = NULL;
				GError* _tmp9_;
				GError* _tmp10_;
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				err = _inner_error_;
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 2395 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = err;
#line 2395 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _g_error_copy0 (_tmp9_);
#line 2395 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (dberr);
#line 2395 "/home/jens/Source/shotwell/src/Photo.vala"
				dberr = _tmp10_;
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (err);
#line 18845 "Photo.c"
			}
			__finally366:
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18850 "Photo.c"
				{
					PhotoRow* _tmp11_;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = self->row;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18857 "Photo.c"
				}
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (dberr);
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 2391 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 18867 "Photo.c"
			}
		}
		__finally365:
		{
			PhotoRow* _tmp12_;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = self->row;
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 18877 "Photo.c"
		}
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (dberr);
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2390 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 18889 "Photo.c"
		}
	}
#line 2399 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = dberr;
#line 2399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp13_ == NULL) {
#line 18896 "Photo.c"
		Alteration* _tmp14_;
		Alteration* _tmp15_;
#line 2400 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = alteration_new ("metadata", "import-id");
#line 2400 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = _tmp14_;
#line 2400 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp15_);
#line 2400 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp15_);
#line 18907 "Photo.c"
	} else {
		gchar* _tmp16_;
		gchar* _tmp17_;
		GError* _tmp18_;
		const gchar* _tmp19_;
#line 2402 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 2402 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = _tmp16_;
#line 2402 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = dberr;
#line 2402 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = _tmp18_->message;
#line 2402 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2402: Unable to write import ID for %s: %s", _tmp17_, _tmp19_);
#line 2402 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp17_);
#line 18925 "Photo.c"
	}
#line 2388 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_error_free0 (dberr);
#line 18929 "Photo.c"
}


void photo_set_title_persistent (Photo* self, const gchar* title, GError** error) {
	PhotoFileReader* source = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	PhotoFileFormat _tmp2_;
	gboolean _tmp3_;
	PhotoMetadata* metadata = NULL;
	PhotoFileReader* _tmp8_;
	PhotoMetadata* _tmp9_;
	PhotoMetadata* _tmp10_;
	const gchar* _tmp11_;
	PhotoFileMetadataWriter* writer = NULL;
	PhotoFileReader* _tmp12_;
	PhotoFileMetadataWriter* _tmp13_;
	PhotoFileReader* _tmp14_;
	GFile* _tmp15_;
	GFile* _tmp16_;
	const gchar* _tmp22_;
	GError * _inner_error_ = NULL;
#line 2405 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2406 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_source_reader (self);
#line 2406 "/home/jens/Source/shotwell/src/Photo.vala"
	source = _tmp0_;
#line 2409 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = source;
#line 2409 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2409 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_format_can_write_metadata (_tmp2_);
#line 2409 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp3_) {
#line 18966 "Photo.c"
		PhotoFileReader* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
#line 2410 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = source;
#line 2410 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2410 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_;
#line 2410 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2410: No photo file writer available for %s", _tmp6_);
#line 2410 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp6_);
#line 2412 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = title;
#line 2412 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp7_);
#line 2414 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2414 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 18989 "Photo.c"
	}
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = source;
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = photo_file_reader_read_metadata (_tmp8_, &_inner_error_);
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp9_;
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2417 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19005 "Photo.c"
	}
#line 2418 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = metadata;
#line 2418 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = title;
#line 2418 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_metadata_set_title (_tmp10_, _tmp11_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = source;
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = photo_file_reader_create_metadata_writer (_tmp12_, &_inner_error_);
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
	writer = _tmp13_;
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2420 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19029 "Photo.c"
	}
#line 2421 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = source;
#line 2421 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2421 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = _tmp15_;
#line 2421 "/home/jens/Source/shotwell/src/Photo.vala"
	library_monitor_blacklist_file (_tmp16_, "Photo.set_persistent_title");
#line 2421 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp16_);
#line 19041 "Photo.c"
	{
		PhotoFileMetadataWriter* _tmp17_;
		PhotoMetadata* _tmp18_;
#line 2423 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = writer;
#line 2423 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = metadata;
#line 2423 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_metadata_writer_write_metadata (_tmp17_, _tmp18_, &_inner_error_);
#line 2423 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 19053 "Photo.c"
			goto __finally367;
		}
	}
	__finally367:
	{
		PhotoFileReader* _tmp19_;
		GFile* _tmp20_;
		GFile* _tmp21_;
#line 2425 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = source;
#line 2425 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2425 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp20_;
#line 2425 "/home/jens/Source/shotwell/src/Photo.vala"
		library_monitor_unblacklist_file (_tmp21_);
#line 2425 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp21_);
#line 19072 "Photo.c"
	}
#line 2422 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2422 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2422 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 2422 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2422 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2422 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19086 "Photo.c"
	}
#line 2428 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = title;
#line 2428 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp22_);
#line 2430 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_exif_updated (self);
#line 2405 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (writer);
#line 2405 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 2405 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (source);
#line 19100 "Photo.c"
}


void photo_set_comment_persistent (Photo* self, const gchar* comment, GError** error) {
	PhotoFileReader* source = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	PhotoFileFormat _tmp2_;
	gboolean _tmp3_;
	PhotoMetadata* metadata = NULL;
	PhotoFileReader* _tmp8_;
	PhotoMetadata* _tmp9_;
	PhotoMetadata* _tmp10_;
	const gchar* _tmp11_;
	PhotoFileMetadataWriter* writer = NULL;
	PhotoFileReader* _tmp12_;
	PhotoFileMetadataWriter* _tmp13_;
	PhotoFileReader* _tmp14_;
	GFile* _tmp15_;
	GFile* _tmp16_;
	const gchar* _tmp22_;
	GError * _inner_error_ = NULL;
#line 2433 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2434 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_source_reader (self);
#line 2434 "/home/jens/Source/shotwell/src/Photo.vala"
	source = _tmp0_;
#line 2437 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = source;
#line 2437 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2437 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_format_can_write_metadata (_tmp2_);
#line 2437 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp3_) {
#line 19137 "Photo.c"
		PhotoFileReader* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		const gchar* _tmp7_;
#line 2438 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = source;
#line 2438 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2438 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_;
#line 2438 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2438: No photo file writer available for %s", _tmp6_);
#line 2438 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp6_);
#line 2440 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = comment;
#line 2440 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp7_);
#line 2442 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2442 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19160 "Photo.c"
	}
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = source;
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = photo_file_reader_read_metadata (_tmp8_, &_inner_error_);
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp9_;
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2445 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19176 "Photo.c"
	}
#line 2446 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = metadata;
#line 2446 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = comment;
#line 2446 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_metadata_set_comment (_tmp10_, _tmp11_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = source;
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = photo_file_reader_create_metadata_writer (_tmp12_, &_inner_error_);
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
	writer = _tmp13_;
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2448 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19200 "Photo.c"
	}
#line 2449 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = source;
#line 2449 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2449 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = _tmp15_;
#line 2449 "/home/jens/Source/shotwell/src/Photo.vala"
	library_monitor_blacklist_file (_tmp16_, "Photo.set_persistent_comment");
#line 2449 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp16_);
#line 19212 "Photo.c"
	{
		PhotoFileMetadataWriter* _tmp17_;
		PhotoMetadata* _tmp18_;
#line 2451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = writer;
#line 2451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = metadata;
#line 2451 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_metadata_writer_write_metadata (_tmp17_, _tmp18_, &_inner_error_);
#line 2451 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 19224 "Photo.c"
			goto __finally368;
		}
	}
	__finally368:
	{
		PhotoFileReader* _tmp19_;
		GFile* _tmp20_;
		GFile* _tmp21_;
#line 2453 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = source;
#line 2453 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2453 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp20_;
#line 2453 "/home/jens/Source/shotwell/src/Photo.vala"
		library_monitor_unblacklist_file (_tmp21_);
#line 2453 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp21_);
#line 19243 "Photo.c"
	}
#line 2450 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2450 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2450 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 2450 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2450 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2450 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19257 "Photo.c"
	}
#line 2456 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = comment;
#line 2456 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_set_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp22_);
#line 2458 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_exif_updated (self);
#line 2433 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (writer);
#line 2433 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 2433 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (source);
#line 19271 "Photo.c"
}


static void photo_real_set_exposure_time (Dateable* base, time_t time) {
	Photo * self;
	gboolean committed = FALSE;
	gboolean _tmp12_;
	GError * _inner_error_ = NULL;
#line 2461 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 19282 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 19289 "Photo.c"
		{
			PhotoTable* _tmp1_;
			PhotoTable* _tmp2_;
			PhotoRow* _tmp3_;
			PhotoID _tmp4_;
			time_t _tmp5_;
			gboolean _tmp6_;
			gboolean _tmp7_;
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_table_get_instance ();
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_;
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = _tmp3_->photo_id;
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = time;
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = photo_table_set_exposure_time (_tmp2_, &_tmp4_, _tmp5_);
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp6_;
#line 2464 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp2_);
#line 2465 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = committed;
#line 2465 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp7_) {
#line 19318 "Photo.c"
				PhotoRow* _tmp8_;
				time_t _tmp9_;
				time_t _tmp10_;
#line 2466 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = self->row;
#line 2466 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = time;
#line 2466 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_->exposure_time = _tmp9_;
#line 2467 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = time;
#line 2467 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->cached_exposure_time = _tmp10_;
#line 19332 "Photo.c"
			}
		}
		__finally369:
		{
			PhotoRow* _tmp11_;
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = self->row;
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 19342 "Photo.c"
		}
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2463 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 19352 "Photo.c"
		}
	}
#line 2471 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = committed;
#line 2471 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_) {
#line 19359 "Photo.c"
		Alteration* _tmp13_;
		Alteration* _tmp14_;
#line 2472 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = alteration_new ("metadata", "exposure-time");
#line 2472 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = _tmp13_;
#line 2472 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp14_);
#line 2472 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp14_);
#line 19370 "Photo.c"
	}
}


void photo_set_exposure_time_persistent (Photo* self, time_t time, GError** error) {
	PhotoFileReader* source = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	PhotoFileFormat _tmp2_;
	gboolean _tmp3_;
	PhotoMetadata* metadata = NULL;
	PhotoFileReader* _tmp8_;
	PhotoMetadata* _tmp9_;
	PhotoMetadata* _tmp10_;
	time_t _tmp11_;
	MetadataDateTime* _tmp12_;
	MetadataDateTime* _tmp13_;
	PhotoFileMetadataWriter* writer = NULL;
	PhotoFileReader* _tmp14_;
	PhotoFileMetadataWriter* _tmp15_;
	PhotoFileReader* _tmp16_;
	GFile* _tmp17_;
	GFile* _tmp18_;
	time_t _tmp24_;
	GError * _inner_error_ = NULL;
#line 2475 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2476 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_source_reader (self);
#line 2476 "/home/jens/Source/shotwell/src/Photo.vala"
	source = _tmp0_;
#line 2479 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = source;
#line 2479 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2479 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_format_can_write_metadata (_tmp2_);
#line 2479 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp3_) {
#line 19410 "Photo.c"
		PhotoFileReader* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		time_t _tmp7_;
#line 2480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = source;
#line 2480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_;
#line 2480 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2480: No photo file writer available for %s", _tmp6_);
#line 2480 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp6_);
#line 2482 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = time;
#line 2482 "/home/jens/Source/shotwell/src/Photo.vala"
		dateable_set_exposure_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATEABLE, Dateable), _tmp7_);
#line 2484 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2484 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19433 "Photo.c"
	}
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = source;
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = photo_file_reader_read_metadata (_tmp8_, &_inner_error_);
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp9_;
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2487 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19449 "Photo.c"
	}
#line 2488 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = metadata;
#line 2488 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = time;
#line 2488 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = metadata_date_time_new (_tmp11_);
#line 2488 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_;
#line 2488 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_metadata_set_exposure_date_time (_tmp10_, _tmp13_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 2488 "/home/jens/Source/shotwell/src/Photo.vala"
	_metadata_date_time_unref0 (_tmp13_);
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = source;
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = photo_file_reader_create_metadata_writer (_tmp14_, &_inner_error_);
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
	writer = _tmp15_;
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2490 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19479 "Photo.c"
	}
#line 2491 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = source;
#line 2491 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2491 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = _tmp17_;
#line 2491 "/home/jens/Source/shotwell/src/Photo.vala"
	library_monitor_blacklist_file (_tmp18_, "Photo.set_exposure_time_persistent");
#line 2491 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp18_);
#line 19491 "Photo.c"
	{
		PhotoFileMetadataWriter* _tmp19_;
		PhotoMetadata* _tmp20_;
#line 2493 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = writer;
#line 2493 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = metadata;
#line 2493 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_file_metadata_writer_write_metadata (_tmp19_, _tmp20_, &_inner_error_);
#line 2493 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 19503 "Photo.c"
			goto __finally370;
		}
	}
	__finally370:
	{
		PhotoFileReader* _tmp21_;
		GFile* _tmp22_;
		GFile* _tmp23_;
#line 2495 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = source;
#line 2495 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2495 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = _tmp22_;
#line 2495 "/home/jens/Source/shotwell/src/Photo.vala"
		library_monitor_unblacklist_file (_tmp23_);
#line 2495 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp23_);
#line 19522 "Photo.c"
	}
#line 2492 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2492 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2492 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 2492 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2492 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (source);
#line 2492 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 19536 "Photo.c"
	}
#line 2498 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = time;
#line 2498 "/home/jens/Source/shotwell/src/Photo.vala"
	dateable_set_exposure_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATEABLE, Dateable), _tmp24_);
#line 2500 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_exif_updated (self);
#line 2475 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (writer);
#line 2475 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 2475 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (source);
#line 19550 "Photo.c"
}


/**
     * @brief Returns the width and height of the Photo after various
     * arbitrary stages of the pipeline have been applied in
     * the same order they're applied in get_pixbuf_with_options.
     * With no argument passed, it works exactly like the
     * previous incarnation did.
     *
     * @param disallowed_steps Which pipeline steps should NOT
     *      be taken into account when computing image dimensions
     *      (matching the convention set by get_pixbuf_with_options()).
     *      Pipeline steps that do not affect the image geometry are
     *      ignored.
     */
static void photo_real_get_dimensions (MediaSource* base, PhotoException disallowed_steps, Dimensions* result) {
	Photo * self;
	Dimensions returned_dims = {0};
	Dimensions _tmp0_ = {0};
	PhotoException _tmp1_;
	gboolean _tmp2_;
	PhotoException _tmp10_;
	gboolean _tmp11_;
	PhotoException _tmp22_;
	gboolean _tmp23_;
#line 2516 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 2518 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_raw_dimensions (self, &_tmp0_);
#line 2518 "/home/jens/Source/shotwell/src/Photo.vala"
	returned_dims = _tmp0_;
#line 2521 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = disallowed_steps;
#line 2521 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_exception_allows (_tmp1_, PHOTO_EXCEPTION_ORIENTATION);
#line 2521 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 19589 "Photo.c"
		Orientation ori_tmp = 0;
		Orientation _tmp3_;
		Orientation _tmp4_;
#line 2522 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_get_orientation (self);
#line 2522 "/home/jens/Source/shotwell/src/Photo.vala"
		ori_tmp = _tmp3_;
#line 2525 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = ori_tmp;
#line 2525 "/home/jens/Source/shotwell/src/Photo.vala"
		switch (_tmp4_) {
#line 2525 "/home/jens/Source/shotwell/src/Photo.vala"
			case ORIENTATION_LEFT_TOP:
#line 2525 "/home/jens/Source/shotwell/src/Photo.vala"
			case ORIENTATION_RIGHT_TOP:
#line 2525 "/home/jens/Source/shotwell/src/Photo.vala"
			case ORIENTATION_LEFT_BOTTOM:
#line 2525 "/home/jens/Source/shotwell/src/Photo.vala"
			case ORIENTATION_RIGHT_BOTTOM:
#line 19609 "Photo.c"
			{
				gint width_tmp = 0;
				Dimensions _tmp5_;
				gint _tmp6_;
				Dimensions _tmp7_;
				gint _tmp8_;
				gint _tmp9_;
#line 2531 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = returned_dims;
#line 2531 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = _tmp5_.width;
#line 2531 "/home/jens/Source/shotwell/src/Photo.vala"
				width_tmp = _tmp6_;
#line 2533 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = returned_dims;
#line 2533 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _tmp7_.height;
#line 2533 "/home/jens/Source/shotwell/src/Photo.vala"
				returned_dims.width = _tmp8_;
#line 2534 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = width_tmp;
#line 2534 "/home/jens/Source/shotwell/src/Photo.vala"
				returned_dims.height = _tmp9_;
#line 2535 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 19635 "Photo.c"
			}
			default:
			{
#line 2539 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 19641 "Photo.c"
			}
		}
	}
#line 2544 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = disallowed_steps;
#line 2544 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = photo_exception_allows (_tmp10_, PHOTO_EXCEPTION_STRAIGHTEN);
#line 2544 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_) {
#line 19651 "Photo.c"
		gdouble x_size = 0.0;
		gdouble y_size = 0.0;
		gdouble angle = 0.0;
		gdouble _tmp12_ = 0.0;
		Dimensions _tmp13_;
		gint _tmp14_;
		Dimensions _tmp15_;
		gint _tmp16_;
		gdouble _tmp17_;
		gdouble _tmp18_ = 0.0;
		gdouble _tmp19_ = 0.0;
		gdouble _tmp20_;
		gdouble _tmp21_;
#line 2546 "/home/jens/Source/shotwell/src/Photo.vala"
		angle = 0.0;
#line 2548 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_get_straighten (self, &_tmp12_);
#line 2548 "/home/jens/Source/shotwell/src/Photo.vala"
		angle = _tmp12_;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = returned_dims;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = _tmp13_.width;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = returned_dims;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = _tmp15_.height;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = angle;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		compute_arb_rotated_size ((gdouble) _tmp14_, (gdouble) _tmp16_, _tmp17_, &_tmp18_, &_tmp19_);
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		x_size = _tmp18_;
#line 2550 "/home/jens/Source/shotwell/src/Photo.vala"
		y_size = _tmp19_;
#line 2552 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = x_size;
#line 2552 "/home/jens/Source/shotwell/src/Photo.vala"
		returned_dims.width = (gint) _tmp20_;
#line 2553 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = y_size;
#line 2553 "/home/jens/Source/shotwell/src/Photo.vala"
		returned_dims.height = (gint) _tmp21_;
#line 19695 "Photo.c"
	}
#line 2557 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = disallowed_steps;
#line 2557 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = photo_exception_allows (_tmp22_, PHOTO_EXCEPTION_CROP);
#line 2557 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp23_) {
#line 19703 "Photo.c"
		Box crop = {0};
		PhotoException _tmp24_;
		Box _tmp25_ = {0};
		gboolean _tmp26_;
#line 2559 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = disallowed_steps;
#line 2559 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp26_ = photo_get_crop (self, &_tmp25_, _tmp24_);
#line 2559 "/home/jens/Source/shotwell/src/Photo.vala"
		crop = _tmp25_;
#line 2559 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp26_) {
#line 19716 "Photo.c"
			Dimensions _tmp27_ = {0};
#line 2560 "/home/jens/Source/shotwell/src/Photo.vala"
			box_get_dimensions (&crop, &_tmp27_);
#line 2560 "/home/jens/Source/shotwell/src/Photo.vala"
			returned_dims = _tmp27_;
#line 19722 "Photo.c"
		}
	}
#line 2563 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = returned_dims;
#line 2563 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 19729 "Photo.c"
}


static void photo_locked_create_adjustments_from_data (Photo* self) {
	PixelTransformationBundle* _tmp0_;
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp1_;
	KeyValueMap* _tmp2_;
	PixelTransformationBundle* _tmp6_;
	PixelTransformer* _tmp7_;
#line 2567 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2568 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = pixel_transformation_bundle_new ();
#line 2568 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 2568 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->adjustments = _tmp0_;
#line 2570 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_transformation (self, "adjustments");
#line 2570 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp1_;
#line 2571 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = map;
#line 2571 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ == NULL) {
#line 19756 "Photo.c"
		PixelTransformationBundle* _tmp3_;
#line 2572 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = self->priv->adjustments;
#line 2572 "/home/jens/Source/shotwell/src/Photo.vala"
		pixel_transformation_bundle_set_to_identity (_tmp3_);
#line 19762 "Photo.c"
	} else {
		PixelTransformationBundle* _tmp4_;
		KeyValueMap* _tmp5_;
#line 2574 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = self->priv->adjustments;
#line 2574 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = map;
#line 2574 "/home/jens/Source/shotwell/src/Photo.vala"
		pixel_transformation_bundle_load (_tmp4_, _tmp5_);
#line 19772 "Photo.c"
	}
#line 2576 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = self->priv->adjustments;
#line 2576 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = pixel_transformation_bundle_generate_transformer (_tmp6_);
#line 2576 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformer_unref0 (self->priv->transformer);
#line 2576 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->transformer = _tmp7_;
#line 2567 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 19784 "Photo.c"
}


PixelTransformationBundle* photo_get_color_adjustments (Photo* self) {
	PixelTransformationBundle* result = NULL;
	GError * _inner_error_ = NULL;
#line 2580 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 19793 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 19800 "Photo.c"
		{
			PixelTransformationBundle* _tmp1_;
			PixelTransformationBundle* _tmp2_;
			PixelTransformationBundle* _tmp3_;
#line 2582 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->adjustments;
#line 2582 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp1_ == NULL) {
#line 2583 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_locked_create_adjustments_from_data (self);
#line 19811 "Photo.c"
			}
#line 2585 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->adjustments;
#line 2585 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = pixel_transformation_bundle_copy (_tmp2_);
#line 2585 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 19819 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 19826 "Photo.c"
			}
#line 2585 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 19830 "Photo.c"
		}
		__finally371:
		{
			PhotoRow* _tmp5_;
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 19839 "Photo.c"
		}
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2581 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 19847 "Photo.c"
	}
}


PixelTransformer* photo_get_pixel_transformer (Photo* self) {
	PixelTransformer* result = NULL;
	GError * _inner_error_ = NULL;
#line 2589 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 19857 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 19864 "Photo.c"
		{
			PixelTransformer* _tmp1_;
			PixelTransformer* _tmp2_;
			PixelTransformer* _tmp3_;
#line 2591 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->transformer;
#line 2591 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp1_ == NULL) {
#line 2592 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_locked_create_adjustments_from_data (self);
#line 19875 "Photo.c"
			}
#line 2594 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->transformer;
#line 2594 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = pixel_transformer_copy (_tmp2_);
#line 2594 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp3_;
#line 19883 "Photo.c"
			{
				PhotoRow* _tmp4_;
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 19890 "Photo.c"
			}
#line 2594 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 19894 "Photo.c"
		}
		__finally372:
		{
			PhotoRow* _tmp5_;
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 19903 "Photo.c"
		}
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2590 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 19911 "Photo.c"
	}
}


gboolean photo_has_color_adjustments (Photo* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 2598 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2599 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_has_transformation (self, "adjustments");
#line 2599 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 2599 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 19927 "Photo.c"
}


PixelTransformation* photo_get_color_adjustment (Photo* self, PixelTransformationType type) {
	PixelTransformation* result = NULL;
	PixelTransformationBundle* _tmp0_;
	PixelTransformationBundle* _tmp1_;
	PixelTransformationType _tmp2_;
	PixelTransformation* _tmp3_;
	PixelTransformation* _tmp4_;
#line 2602 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_color_adjustments (self);
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = type;
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = pixel_transformation_bundle_get_transformation (_tmp1_, _tmp2_);
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (_tmp1_);
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 2603 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 19956 "Photo.c"
}


void photo_set_color_adjustments (Photo* self, PixelTransformationBundle* new_adjustments) {
	PixelTransformationBundle* _tmp0_;
	gboolean _tmp1_;
	KeyValueMap* map = NULL;
	PixelTransformationBundle* _tmp8_;
	KeyValueMap* _tmp9_;
	gboolean committed = FALSE;
	gboolean _tmp39_;
	GError * _inner_error_ = NULL;
#line 2606 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2606 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PIXEL_TRANSFORMATION_BUNDLE (new_adjustments));
#line 2609 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = new_adjustments;
#line 2609 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = pixel_transformation_bundle_is_identity (_tmp0_);
#line 2609 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 19979 "Photo.c"
		gboolean _result_ = FALSE;
		gboolean _tmp5_;
		{
			PhotoRow* _tmp2_;
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->row;
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 19988 "Photo.c"
			{
				gboolean _tmp3_;
#line 2612 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = photo_remove_transformation (self, "adjustments");
#line 2612 "/home/jens/Source/shotwell/src/Photo.vala"
				_result_ = _tmp3_;
#line 2613 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 2613 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->adjustments = NULL;
#line 2614 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformer_unref0 (self->priv->transformer);
#line 2614 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->transformer = NULL;
#line 20003 "Photo.c"
			}
			__finally373:
			{
				PhotoRow* _tmp4_;
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 20012 "Photo.c"
			}
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 2611 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 20022 "Photo.c"
			}
		}
#line 2617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _result_;
#line 2617 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp5_) {
#line 20029 "Photo.c"
			Alteration* _tmp6_;
			Alteration* _tmp7_;
#line 2618 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = alteration_new ("image", "color-adjustments");
#line 2618 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _tmp6_;
#line 2618 "/home/jens/Source/shotwell/src/Photo.vala"
			data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp7_);
#line 2618 "/home/jens/Source/shotwell/src/Photo.vala"
			_alteration_unref0 (_tmp7_);
#line 20040 "Photo.c"
		}
#line 2620 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 20044 "Photo.c"
	}
#line 2624 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = new_adjustments;
#line 2624 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = pixel_transformation_bundle_save (_tmp8_, "adjustments");
#line 2624 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp9_;
#line 20052 "Photo.c"
	{
		PhotoRow* _tmp10_;
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = self->row;
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 20059 "Photo.c"
		{
			gboolean _tmp11_ = FALSE;
			PixelTransformer* _tmp12_;
			KeyValueMap* _tmp36_;
			gboolean _tmp37_;
#line 2628 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = self->priv->transformer;
#line 2628 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp12_ == NULL) {
#line 2628 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = TRUE;
#line 20071 "Photo.c"
			} else {
				PixelTransformationBundle* _tmp13_;
#line 2628 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = self->priv->adjustments;
#line 2628 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _tmp13_ == NULL;
#line 20078 "Photo.c"
			}
#line 2628 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp11_) {
#line 20082 "Photo.c"
				PixelTransformationBundle* _tmp14_;
				PixelTransformationBundle* _tmp15_;
				PixelTransformationBundle* _tmp16_;
				PixelTransformer* _tmp17_;
#line 2630 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = new_adjustments;
#line 2630 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = pixel_transformation_bundle_copy (_tmp14_);
#line 2630 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 2630 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->adjustments = _tmp15_;
#line 2631 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = new_adjustments;
#line 2631 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = pixel_transformation_bundle_generate_transformer (_tmp16_);
#line 2631 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformer_unref0 (self->priv->transformer);
#line 2631 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->transformer = _tmp17_;
#line 20103 "Photo.c"
			} else {
				PixelTransformationBundle* _tmp34_;
				PixelTransformationBundle* _tmp35_;
				{
					GeeIterator* _transformation_it = NULL;
					PixelTransformationBundle* _tmp18_;
					GeeIterable* _tmp19_;
					GeeIterable* _tmp20_;
					GeeIterator* _tmp21_;
					GeeIterator* _tmp22_;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = new_adjustments;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = pixel_transformation_bundle_get_transformations (_tmp18_);
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp20_ = _tmp19_;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp21_ = gee_iterable_iterator (_tmp20_);
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp22_ = _tmp21_;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp20_);
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_transformation_it = _tmp22_;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					while (TRUE) {
#line 20130 "Photo.c"
						GeeIterator* _tmp23_;
						gboolean _tmp24_;
						PixelTransformation* transformation = NULL;
						GeeIterator* _tmp25_;
						gpointer _tmp26_;
						PixelTransformer* _tmp27_;
						PixelTransformationBundle* _tmp28_;
						PixelTransformation* _tmp29_;
						PixelTransformationType _tmp30_;
						PixelTransformation* _tmp31_;
						PixelTransformation* _tmp32_;
						PixelTransformation* _tmp33_;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp23_ = _transformation_it;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp24_ = gee_iterator_next (_tmp23_);
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						if (!_tmp24_) {
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
							break;
#line 20151 "Photo.c"
						}
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp25_ = _transformation_it;
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp26_ = gee_iterator_get (_tmp25_);
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						transformation = (PixelTransformation*) _tmp26_;
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp27_ = self->priv->transformer;
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp28_ = self->priv->adjustments;
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp29_ = transformation;
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp30_ = pixel_transformation_get_transformation_type (_tmp29_);
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp31_ = pixel_transformation_bundle_get_transformation (_tmp28_, _tmp30_);
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp32_ = _tmp31_;
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp33_ = transformation;
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						pixel_transformer_replace_transformation (_tmp27_, _tmp32_, _tmp33_);
#line 2635 "/home/jens/Source/shotwell/src/Photo.vala"
						_pixel_transformation_unref0 (_tmp32_);
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
						_pixel_transformation_unref0 (transformation);
#line 20179 "Photo.c"
					}
#line 2634 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_transformation_it);
#line 20183 "Photo.c"
				}
#line 2640 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = new_adjustments;
#line 2640 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = pixel_transformation_bundle_copy (_tmp34_);
#line 2640 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 2640 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->adjustments = _tmp35_;
#line 20193 "Photo.c"
			}
#line 2643 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp36_ = map;
#line 2643 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp37_ = photo_set_transformation (self, _tmp36_);
#line 2643 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp37_;
#line 20201 "Photo.c"
		}
		__finally374:
		{
			PhotoRow* _tmp38_;
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp38_ = self->row;
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 20210 "Photo.c"
		}
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
			_key_value_map_unref0 (map);
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2627 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 20222 "Photo.c"
		}
	}
#line 2646 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = committed;
#line 2646 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp39_) {
#line 20229 "Photo.c"
		Alteration* _tmp40_;
		Alteration* _tmp41_;
#line 2647 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = alteration_new ("image", "color-adjustments");
#line 2647 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = _tmp40_;
#line 2647 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp41_);
#line 2647 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp41_);
#line 20240 "Photo.c"
	}
#line 2606 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 20244 "Photo.c"
}


static PhotoMetadata* photo_real_get_metadata (PhotoSource* base) {
	Photo * self;
	PhotoMetadata* result = NULL;
	GError * _inner_error_ = NULL;
#line 2651 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 20254 "Photo.c"
	{
		PhotoMetadata* _tmp0_ = NULL;
		PhotoFileReader* _tmp1_;
		PhotoFileReader* _tmp2_;
		PhotoMetadata* _tmp3_;
		PhotoMetadata* _tmp4_;
		PhotoMetadata* _tmp5_;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = photo_get_source_reader (self);
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp1_;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_file_reader_read_metadata (_tmp2_, &_inner_error_);
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp3_;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp2_);
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp4_;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20276 "Photo.c"
			goto __catch375_g_error;
		}
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp0_;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = NULL;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp5_;
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (_tmp0_);
#line 2653 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20289 "Photo.c"
	}
	goto __finally375;
	__catch375_g_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 2652 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 2652 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 2655 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = err;
#line 2655 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_->message;
#line 2655 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:2655: Unable to load metadata: %s", _tmp7_);
#line 2657 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 2657 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 2657 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20313 "Photo.c"
	}
	__finally375:
#line 2652 "/home/jens/Source/shotwell/src/Photo.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2652 "/home/jens/Source/shotwell/src/Photo.vala"
	g_clear_error (&_inner_error_);
#line 2652 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 20322 "Photo.c"
}


PhotoMetadata* photo_get_master_metadata (Photo* self, GError** error) {
	PhotoMetadata* result = NULL;
	PhotoMetadata* _tmp0_ = NULL;
	PhotoFileReader* _tmp1_;
	PhotoFileReader* _tmp2_;
	PhotoMetadata* _tmp3_;
	PhotoMetadata* _tmp4_;
	PhotoMetadata* _tmp5_;
	GError * _inner_error_ = NULL;
#line 2661 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_master_reader (self);
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_;
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_reader_read_metadata (_tmp2_, &_inner_error_);
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp2_);
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp4_;
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 20355 "Photo.c"
	}
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp0_;
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp5_;
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (_tmp0_);
#line 2662 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 20367 "Photo.c"
}


PhotoMetadata* photo_get_editable_metadata (Photo* self, GError** error) {
	PhotoMetadata* result = NULL;
	PhotoFileReader* reader = NULL;
	PhotoFileReader* _tmp0_;
	PhotoMetadata* _tmp1_ = NULL;
	PhotoFileReader* _tmp2_;
	GError * _inner_error_ = NULL;
#line 2665 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 2666 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_editable_reader (self);
#line 2666 "/home/jens/Source/shotwell/src/Photo.vala"
	reader = _tmp0_;
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = reader;
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ != NULL) {
#line 20388 "Photo.c"
		PhotoFileReader* _tmp3_;
		PhotoMetadata* _tmp4_;
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = reader;
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = photo_file_reader_read_metadata (_tmp3_, &_inner_error_);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (_tmp1_);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp4_;
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
			_media_metadata_unref0 (_tmp1_);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (reader);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 20409 "Photo.c"
		}
	} else {
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (_tmp1_);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = NULL;
#line 20416 "Photo.c"
	}
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (reader);
#line 2668 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 20424 "Photo.c"
}


gboolean photo_persist_master_metadata (Photo* self, PhotoMetadata* metadata, PhotoReimportMasterState* * state, GError** error) {
	PhotoReimportMasterState* _vala_state = NULL;
	gboolean result = FALSE;
	PhotoFileReader* master_reader = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	PhotoFileFormat _tmp2_;
	gboolean _tmp3_;
	PhotoFileMetadataWriter* _tmp4_ = NULL;
	PhotoFileReader* _tmp5_;
	PhotoFileMetadataWriter* _tmp6_;
	PhotoMetadata* _tmp8_;
	gboolean _tmp10_ = FALSE;
	PhotoReimportMasterState* _tmp11_ = NULL;
	gboolean _tmp12_;
	PhotoReimportMasterState* _tmp14_;
	GError * _inner_error_ = NULL;
#line 2674 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2674 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_METADATA (metadata), FALSE);
#line 2676 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_master_state_unref0 (_vala_state);
#line 2676 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = NULL;
#line 2678 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_master_reader (self);
#line 2678 "/home/jens/Source/shotwell/src/Photo.vala"
	master_reader = _tmp0_;
#line 2680 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = master_reader;
#line 2680 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2680 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_format_can_write_metadata (_tmp2_);
#line 2680 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp3_) {
#line 2681 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2681 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (master_reader);
#line 2681 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 2681 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 20473 "Photo.c"
		} else {
#line 2681 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_master_state_unref0 (_vala_state);
#line 20477 "Photo.c"
		}
#line 2681 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20481 "Photo.c"
	}
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = master_reader;
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_file_reader_create_metadata_writer (_tmp5_, &_inner_error_);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp6_;
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20491 "Photo.c"
		gboolean _tmp7_ = FALSE;
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (master_reader);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp7_;
#line 20499 "Photo.c"
	}
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = metadata;
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_metadata_writer_write_metadata (_tmp4_, _tmp8_, &_inner_error_);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20507 "Photo.c"
		gboolean _tmp9_ = FALSE;
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp4_);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (master_reader);
#line 2683 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp9_;
#line 20517 "Photo.c"
	}
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = photo_prepare_for_reimport_master (self, &_tmp11_, &_inner_error_);
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_master_state_unref0 (_vala_state);
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = _tmp11_;
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = _tmp12_;
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20529 "Photo.c"
		gboolean _tmp13_ = FALSE;
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp4_);
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (master_reader);
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp13_;
#line 20539 "Photo.c"
	}
#line 2685 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp10_) {
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp4_);
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (master_reader);
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 20553 "Photo.c"
		} else {
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_master_state_unref0 (_vala_state);
#line 20557 "Photo.c"
		}
#line 2686 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20561 "Photo.c"
	}
#line 2688 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = _vala_state;
#line 2688 "/home/jens/Source/shotwell/src/Photo.vala"
	G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, PhotoReimportMasterStateImpl)->metadata_only = TRUE;
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp4_);
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (master_reader);
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
	if (state) {
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
		*state = _vala_state;
#line 20577 "Photo.c"
	} else {
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_reimport_master_state_unref0 (_vala_state);
#line 20581 "Photo.c"
	}
#line 2690 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 20585 "Photo.c"
}


void photo_finish_update_master_metadata (Photo* self, PhotoReimportMasterState* state, GError** error) {
	PhotoReimportMasterState* _tmp0_;
	GError * _inner_error_ = NULL;
#line 2693 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2693 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_REIMPORT_MASTER_STATE (state));
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = state;
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_finish_reimport_master (self, _tmp0_, &_inner_error_);
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 20608 "Photo.c"
		} else {
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2694 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 20616 "Photo.c"
		}
	}
}


gboolean photo_persist_editable_metadata (Photo* self, PhotoMetadata* metadata, PhotoReimportEditableState* * state, GError** error) {
	PhotoReimportEditableState* _vala_state = NULL;
	gboolean result = FALSE;
	PhotoFileReader* editable_reader = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	PhotoFileReader* _tmp2_;
	PhotoFileFormat _tmp3_;
	gboolean _tmp4_;
	PhotoFileMetadataWriter* _tmp5_ = NULL;
	PhotoFileReader* _tmp6_;
	PhotoFileMetadataWriter* _tmp7_;
	PhotoMetadata* _tmp9_;
	gboolean _tmp11_ = FALSE;
	PhotoReimportEditableState* _tmp12_ = NULL;
	gboolean _tmp13_;
	PhotoReimportEditableState* _tmp15_;
	GError * _inner_error_ = NULL;
#line 2697 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2697 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_METADATA (metadata), FALSE);
#line 2699 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_editable_state_unref0 (_vala_state);
#line 2699 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = NULL;
#line 2701 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_editable_reader (self);
#line 2701 "/home/jens/Source/shotwell/src/Photo.vala"
	editable_reader = _tmp0_;
#line 2702 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = editable_reader;
#line 2702 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 2703 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2703 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (editable_reader);
#line 2703 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 2703 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 20664 "Photo.c"
		} else {
#line 2703 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_editable_state_unref0 (_vala_state);
#line 20668 "Photo.c"
		}
#line 2703 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20672 "Photo.c"
	}
#line 2705 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = editable_reader;
#line 2705 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 2705 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_file_format_can_write_metadata (_tmp3_);
#line 2705 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp4_) {
#line 2706 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2706 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (editable_reader);
#line 2706 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 2706 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 20690 "Photo.c"
		} else {
#line 2706 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_editable_state_unref0 (_vala_state);
#line 20694 "Photo.c"
		}
#line 2706 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20698 "Photo.c"
	}
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = editable_reader;
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = photo_file_reader_create_metadata_writer (_tmp6_, &_inner_error_);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp7_;
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20708 "Photo.c"
		gboolean _tmp8_ = FALSE;
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (editable_reader);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp8_;
#line 20716 "Photo.c"
	}
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = metadata;
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_metadata_writer_write_metadata (_tmp5_, _tmp9_, &_inner_error_);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20724 "Photo.c"
		gboolean _tmp10_ = FALSE;
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp5_);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (editable_reader);
#line 2708 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp10_;
#line 20734 "Photo.c"
	}
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = photo_prepare_for_reimport_editable (self, &_tmp12_, &_inner_error_);
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_editable_state_unref0 (_vala_state);
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = _tmp12_;
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp13_;
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20746 "Photo.c"
		gboolean _tmp14_ = FALSE;
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp5_);
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (editable_reader);
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp14_;
#line 20756 "Photo.c"
	}
#line 2710 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp11_) {
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp5_);
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (editable_reader);
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 20770 "Photo.c"
		} else {
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_reimport_editable_state_unref0 (_vala_state);
#line 20774 "Photo.c"
		}
#line 2711 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 20778 "Photo.c"
	}
#line 2713 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _vala_state;
#line 2713 "/home/jens/Source/shotwell/src/Photo.vala"
	G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, PhotoReimportEditableStateImpl)->metadata_only = TRUE;
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp5_);
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (editable_reader);
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
	if (state) {
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
		*state = _vala_state;
#line 20794 "Photo.c"
	} else {
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_reimport_editable_state_unref0 (_vala_state);
#line 20798 "Photo.c"
	}
#line 2715 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 20802 "Photo.c"
}


void photo_finish_update_editable_metadata (Photo* self, PhotoReimportEditableState* state, GError** error) {
	PhotoReimportEditableState* _tmp0_;
	GError * _inner_error_ = NULL;
#line 2718 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2718 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_REIMPORT_EDITABLE_STATE (state));
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = state;
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_finish_reimport_editable (self, _tmp0_, &_inner_error_);
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 20825 "Photo.c"
		} else {
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2719 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 20833 "Photo.c"
		}
	}
}


void photo_get_raw_dimensions (Photo* self, Dimensions* result) {
	GError * _inner_error_ = NULL;
#line 2724 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 20843 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 20850 "Photo.c"
		{
			BackingPhotoRow* _tmp1_;
			Dimensions _tmp2_;
#line 2726 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->backing_photo_row;
#line 2726 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->dim;
#line 2726 "/home/jens/Source/shotwell/src/Photo.vala"
			*result = _tmp2_;
#line 20860 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 20867 "Photo.c"
			}
#line 2726 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 20871 "Photo.c"
		}
		__finally376:
		{
			PhotoRow* _tmp4_;
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 20880 "Photo.c"
		}
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2725 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 20888 "Photo.c"
	}
}


gboolean photo_has_transformations (Photo* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2730 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 20898 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp10_ = FALSE;
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 20906 "Photo.c"
		{
			gboolean _tmp1_ = FALSE;
			PhotoRow* _tmp2_;
			Orientation _tmp3_;
			BackingPhotoRow* _tmp4_;
			Orientation _tmp5_;
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->row;
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _tmp2_->orientation;
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->backing_photo_row;
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _tmp4_->original_orientation;
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_ != _tmp5_) {
#line 2733 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = TRUE;
#line 20925 "Photo.c"
			} else {
				PhotoRow* _tmp6_;
				GeeHashMap* _tmp7_;
#line 2734 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->row;
#line 2734 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = _tmp6_->transformations;
#line 2734 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp7_ != NULL;
#line 20935 "Photo.c"
			}
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 20939 "Photo.c"
			{
				PhotoRow* _tmp8_;
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = self->row;
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 20946 "Photo.c"
			}
#line 2732 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 20950 "Photo.c"
		}
		__finally377:
		{
			PhotoRow* _tmp9_;
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 20959 "Photo.c"
		}
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2731 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp10_;
#line 20967 "Photo.c"
	}
}


gboolean photo_only_metadata_changed (Photo* self) {
	gboolean result = FALSE;
	MetadataDateTime* date_time = NULL;
	PhotoMetadata* metadata = NULL;
	PhotoMetadata* _tmp0_;
	PhotoMetadata* _tmp1_;
	GError * _inner_error_ = NULL;
#line 2738 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2739 "/home/jens/Source/shotwell/src/Photo.vala"
	date_time = NULL;
#line 2741 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_source_get_metadata (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource));
#line 2741 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp0_;
#line 2742 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = metadata;
#line 2742 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ != NULL) {
#line 20991 "Photo.c"
		PhotoMetadata* _tmp2_;
		MetadataDateTime* _tmp3_;
#line 2743 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = metadata;
#line 2743 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_metadata_get_exposure_date_time (_tmp2_);
#line 2743 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 2743 "/home/jens/Source/shotwell/src/Photo.vala"
		date_time = _tmp3_;
#line 21002 "Photo.c"
	}
	{
		PhotoRow* _tmp4_;
		gboolean _tmp21_ = FALSE;
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = self->row;
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 21011 "Photo.c"
		{
			gboolean _tmp5_ = FALSE;
			PhotoRow* _tmp6_;
			GeeHashMap* _tmp7_;
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->row;
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _tmp6_->transformations;
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp7_ == NULL) {
#line 21022 "Photo.c"
				gboolean _tmp8_ = FALSE;
				PhotoRow* _tmp9_;
				Orientation _tmp10_;
				BackingPhotoRow* _tmp11_;
				Orientation _tmp12_;
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = self->row;
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tmp9_->orientation;
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = self->backing_photo_row;
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tmp11_->original_orientation;
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp10_ != _tmp12_) {
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp8_ = TRUE;
#line 21040 "Photo.c"
				} else {
					gboolean _tmp13_ = FALSE;
					MetadataDateTime* _tmp14_;
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = date_time;
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp14_ != NULL) {
#line 21048 "Photo.c"
						PhotoRow* _tmp15_;
						time_t _tmp16_;
						MetadataDateTime* _tmp17_;
						time_t _tmp18_;
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp15_ = self->row;
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp16_ = _tmp15_->exposure_time;
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp17_ = date_time;
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp18_ = metadata_date_time_get_timestamp (_tmp17_);
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp13_ = _tmp16_ != _tmp18_;
#line 21063 "Photo.c"
					} else {
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp13_ = FALSE;
#line 21067 "Photo.c"
					}
#line 2748 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp8_ = _tmp13_;
#line 21071 "Photo.c"
				}
#line 2747 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp8_;
#line 21075 "Photo.c"
			} else {
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = FALSE;
#line 21079 "Photo.c"
			}
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp5_;
#line 21083 "Photo.c"
			{
				PhotoRow* _tmp19_;
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = self->row;
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21090 "Photo.c"
			}
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			_media_metadata_unref0 (metadata);
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			_metadata_date_time_unref0 (date_time);
#line 2746 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 21098 "Photo.c"
		}
		__finally378:
		{
			PhotoRow* _tmp20_;
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = self->row;
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21107 "Photo.c"
		}
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2745 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp21_;
#line 21119 "Photo.c"
	}
#line 2738 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 2738 "/home/jens/Source/shotwell/src/Photo.vala"
	_metadata_date_time_unref0 (date_time);
#line 21125 "Photo.c"
}


gboolean photo_has_alterations (Photo* self) {
	gboolean result = FALSE;
	MetadataDateTime* date_time = NULL;
	gchar* title = NULL;
	gchar* comment = NULL;
	PhotoMetadata* metadata = NULL;
	PhotoMetadata* _tmp0_;
	PhotoMetadata* _tmp1_;
	MetadataDateTime* _tmp8_;
	GError * _inner_error_ = NULL;
#line 2752 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2753 "/home/jens/Source/shotwell/src/Photo.vala"
	date_time = NULL;
#line 2754 "/home/jens/Source/shotwell/src/Photo.vala"
	title = NULL;
#line 2755 "/home/jens/Source/shotwell/src/Photo.vala"
	comment = NULL;
#line 2757 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_source_get_metadata (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource));
#line 2757 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp0_;
#line 2758 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = metadata;
#line 2758 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ != NULL) {
#line 21155 "Photo.c"
		PhotoMetadata* _tmp2_;
		MetadataDateTime* _tmp3_;
		PhotoMetadata* _tmp4_;
		gchar* _tmp5_;
		PhotoMetadata* _tmp6_;
		gchar* _tmp7_;
#line 2759 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = metadata;
#line 2759 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_metadata_get_exposure_date_time (_tmp2_);
#line 2759 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 2759 "/home/jens/Source/shotwell/src/Photo.vala"
		date_time = _tmp3_;
#line 2760 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = metadata;
#line 2760 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = media_metadata_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 2760 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (title);
#line 2760 "/home/jens/Source/shotwell/src/Photo.vala"
		title = _tmp5_;
#line 2761 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = metadata;
#line 2761 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = media_metadata_get_comment (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 2761 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (comment);
#line 2761 "/home/jens/Source/shotwell/src/Photo.vala"
		comment = _tmp7_;
#line 21186 "Photo.c"
	}
#line 2765 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = date_time;
#line 2765 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_ == NULL) {
#line 21192 "Photo.c"
		{
			PhotoRow* _tmp9_;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 21199 "Photo.c"
			{
				BackingPhotoRow* _tmp10_;
				time_t _tmp11_;
				PhotoRow* _tmp12_;
				time_t _tmp13_;
#line 2769 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = self->backing_photo_row;
#line 2769 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _tmp10_->timestamp;
#line 2769 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = self->row;
#line 2769 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _tmp12_->exposure_time;
#line 2769 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp11_ != _tmp13_) {
#line 2771 "/home/jens/Source/shotwell/src/Photo.vala"
					result = TRUE;
#line 21217 "Photo.c"
					{
						PhotoRow* _tmp14_;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp14_ = self->row;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
						g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21224 "Photo.c"
					}
#line 2771 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (metadata);
#line 2771 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (comment);
#line 2771 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (title);
#line 2771 "/home/jens/Source/shotwell/src/Photo.vala"
					_metadata_date_time_unref0 (date_time);
#line 2771 "/home/jens/Source/shotwell/src/Photo.vala"
					return result;
#line 21236 "Photo.c"
				}
			}
			__finally379:
			{
				PhotoRow* _tmp15_;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = self->row;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21246 "Photo.c"
			}
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 21250 "Photo.c"
				gboolean _tmp16_ = FALSE;
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				_media_metadata_unref0 (metadata);
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (comment);
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (title);
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				_metadata_date_time_unref0 (date_time);
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 2767 "/home/jens/Source/shotwell/src/Photo.vala"
				return _tmp16_;
#line 21266 "Photo.c"
			}
		}
	}
	{
		PhotoRow* _tmp17_;
		gboolean _tmp42_ = FALSE;
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = self->row;
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 21277 "Photo.c"
		{
			gboolean _tmp18_ = FALSE;
			gboolean _tmp19_ = FALSE;
			gboolean _tmp20_ = FALSE;
			gboolean _tmp21_ = FALSE;
			PhotoRow* _tmp22_;
			GeeHashMap* _tmp23_;
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = self->row;
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_ = _tmp22_->transformations;
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp23_ != NULL) {
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = TRUE;
#line 21293 "Photo.c"
			} else {
				PhotoRow* _tmp24_;
				Orientation _tmp25_;
				BackingPhotoRow* _tmp26_;
				Orientation _tmp27_;
#line 2778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = self->row;
#line 2778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = _tmp24_->orientation;
#line 2778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = self->backing_photo_row;
#line 2778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = _tmp26_->original_orientation;
#line 2778 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = _tmp25_ != _tmp27_;
#line 21309 "Photo.c"
			}
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp21_) {
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = TRUE;
#line 21315 "Photo.c"
			} else {
				gboolean _tmp28_ = FALSE;
				MetadataDateTime* _tmp29_;
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = date_time;
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp29_ != NULL) {
#line 21323 "Photo.c"
					PhotoRow* _tmp30_;
					time_t _tmp31_;
					MetadataDateTime* _tmp32_;
					time_t _tmp33_;
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp30_ = self->row;
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31_ = _tmp30_->exposure_time;
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp32_ = date_time;
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp33_ = metadata_date_time_get_timestamp (_tmp32_);
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp28_ = _tmp31_ != _tmp33_;
#line 21338 "Photo.c"
				} else {
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp28_ = FALSE;
#line 21342 "Photo.c"
				}
#line 2779 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = _tmp28_;
#line 21346 "Photo.c"
			}
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp20_) {
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = TRUE;
#line 21352 "Photo.c"
			} else {
				gchar* _tmp34_;
				gchar* _tmp35_;
				const gchar* _tmp36_;
#line 2780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = media_source_get_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 2780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = _tmp34_;
#line 2780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = comment;
#line 2780 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = g_strcmp0 (_tmp35_, _tmp36_) != 0;
#line 2780 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp35_);
#line 21367 "Photo.c"
			}
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp19_) {
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = TRUE;
#line 21373 "Photo.c"
			} else {
				gchar* _tmp37_;
				gchar* _tmp38_;
				const gchar* _tmp39_;
#line 2781 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = media_source_get_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 2781 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = _tmp37_;
#line 2781 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = title;
#line 2781 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = g_strcmp0 (_tmp38_, _tmp39_) != 0;
#line 2781 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp38_);
#line 21388 "Photo.c"
			}
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp18_;
#line 21392 "Photo.c"
			{
				PhotoRow* _tmp40_;
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = self->row;
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21399 "Photo.c"
			}
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			_media_metadata_unref0 (metadata);
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (comment);
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (title);
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			_metadata_date_time_unref0 (date_time);
#line 2777 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 21411 "Photo.c"
		}
		__finally380:
		{
			PhotoRow* _tmp41_;
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = self->row;
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21420 "Photo.c"
		}
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (comment);
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (title);
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (date_time);
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2776 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp42_;
#line 21436 "Photo.c"
	}
#line 2752 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 2752 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (comment);
#line 2752 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (title);
#line 2752 "/home/jens/Source/shotwell/src/Photo.vala"
	_metadata_date_time_unref0 (date_time);
#line 21446 "Photo.c"
}


PhotoTransformationState* photo_save_transformation_state (Photo* self) {
	PhotoTransformationState* result = NULL;
	GError * _inner_error_ = NULL;
#line 2786 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 21455 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 21462 "Photo.c"
		{
			PixelTransformer* _tmp1_ = NULL;
			PixelTransformer* _tmp2_;
			PixelTransformationBundle* _tmp5_ = NULL;
			PixelTransformationBundle* _tmp6_;
			PhotoRow* _tmp9_;
			Orientation _tmp10_;
			PhotoRow* _tmp11_;
			GeeHashMap* _tmp12_;
			PhotoPhotoTransformationStateImpl* _tmp13_;
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->transformer;
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 21477 "Photo.c"
				PixelTransformer* _tmp3_;
				PixelTransformer* _tmp4_;
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->transformer;
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = pixel_transformer_copy (_tmp3_);
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformer_unref0 (_tmp1_);
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp4_;
#line 21488 "Photo.c"
			} else {
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformer_unref0 (_tmp1_);
#line 2790 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = NULL;
#line 21494 "Photo.c"
			}
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->priv->adjustments;
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp6_ != NULL) {
#line 21500 "Photo.c"
				PixelTransformationBundle* _tmp7_;
				PixelTransformationBundle* _tmp8_;
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = self->priv->adjustments;
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = pixel_transformation_bundle_copy (_tmp7_);
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformation_bundle_unref0 (_tmp5_);
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp8_;
#line 21511 "Photo.c"
			} else {
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformation_bundle_unref0 (_tmp5_);
#line 2791 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = NULL;
#line 21517 "Photo.c"
			}
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = _tmp9_->orientation;
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = self->row;
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = _tmp11_->transformations;
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = photo_photo_transformation_state_impl_new (self, _tmp10_, _tmp12_, _tmp1_, _tmp5_);
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			result = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationState);
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformation_bundle_unref0 (_tmp5_);
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformer_unref0 (_tmp1_);
#line 21535 "Photo.c"
			{
				PhotoRow* _tmp14_;
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = self->row;
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21542 "Photo.c"
			}
#line 2788 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 21546 "Photo.c"
		}
		__finally381:
		{
			PhotoRow* _tmp15_;
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = self->row;
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21555 "Photo.c"
		}
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2787 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 21563 "Photo.c"
	}
}


static gpointer _pixel_transformer_ref0 (gpointer self) {
#line 2812 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? pixel_transformer_ref (self) : NULL;
#line 21571 "Photo.c"
}


static gpointer _pixel_transformation_bundle_ref0 (gpointer self) {
#line 2813 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? pixel_transformation_bundle_ref (self) : NULL;
#line 21578 "Photo.c"
}


gboolean photo_load_transformation_state (Photo* self, PhotoTransformationState* state) {
	gboolean result = FALSE;
	PhotoPhotoTransformationStateImpl* state_impl = NULL;
	PhotoTransformationState* _tmp0_;
	PhotoPhotoTransformationStateImpl* _tmp1_;
	PhotoPhotoTransformationStateImpl* _tmp2_;
	Orientation saved_orientation = 0;
	PhotoPhotoTransformationStateImpl* _tmp3_;
	Orientation _tmp4_;
	GeeHashMap* saved_transformations = NULL;
	PhotoPhotoTransformationStateImpl* _tmp5_;
	GeeHashMap* _tmp6_;
	PixelTransformer* saved_transformer = NULL;
	PhotoPhotoTransformationStateImpl* _tmp7_;
	PixelTransformer* _tmp8_;
	PixelTransformationBundle* saved_adjustments = NULL;
	PhotoPhotoTransformationStateImpl* _tmp9_;
	PixelTransformationBundle* _tmp10_;
	gboolean committed = FALSE;
	gboolean _tmp31_;
	GError * _inner_error_ = NULL;
#line 2795 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2795 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_TRANSFORMATION_STATE (state), FALSE);
#line 2796 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = state;
#line 2796 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL) ? ((PhotoPhotoTransformationStateImpl*) _tmp0_) : NULL);
#line 2796 "/home/jens/Source/shotwell/src/Photo.vala"
	state_impl = _tmp1_;
#line 2797 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = state_impl;
#line 2797 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ == NULL) {
#line 2798 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2798 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (state_impl);
#line 2798 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 21623 "Photo.c"
	}
#line 2800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = state_impl;
#line 2800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_photo_transformation_state_impl_get_orientation (_tmp3_);
#line 2800 "/home/jens/Source/shotwell/src/Photo.vala"
	saved_orientation = _tmp4_;
#line 2801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = state_impl;
#line 2801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_photo_transformation_state_impl_get_transformations (_tmp5_);
#line 2801 "/home/jens/Source/shotwell/src/Photo.vala"
	saved_transformations = _tmp6_;
#line 2802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = state_impl;
#line 2802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo_photo_transformation_state_impl_get_transformer (_tmp7_);
#line 2802 "/home/jens/Source/shotwell/src/Photo.vala"
	saved_transformer = _tmp8_;
#line 2803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = state_impl;
#line 2803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = photo_photo_transformation_state_impl_get_color_adjustments (_tmp9_);
#line 2803 "/home/jens/Source/shotwell/src/Photo.vala"
	saved_adjustments = _tmp10_;
#line 21649 "Photo.c"
	{
		PhotoRow* _tmp11_;
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = self->row;
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 21656 "Photo.c"
		{
			PhotoTable* _tmp12_;
			PhotoTable* _tmp13_;
			PhotoRow* _tmp14_;
			PhotoID _tmp15_;
			Orientation _tmp16_;
			GeeHashMap* _tmp17_;
			gboolean _tmp18_;
			gboolean _tmp19_;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo_table_get_instance ();
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = _tmp12_;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = self->row;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = _tmp14_->photo_id;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = saved_orientation;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = saved_transformations;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = photo_table_set_transformation_state (_tmp13_, &_tmp15_, _tmp16_, _tmp17_);
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			committed = _tmp18_;
#line 2807 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp13_);
#line 2809 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = committed;
#line 2809 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp19_) {
#line 21688 "Photo.c"
				PhotoRow* _tmp20_;
				Orientation _tmp21_;
				PhotoRow* _tmp22_;
				GeeHashMap* _tmp23_;
				GeeHashMap* _tmp24_;
				PixelTransformer* _tmp25_;
				PixelTransformer* _tmp26_;
				PixelTransformationBundle* _tmp27_;
				PixelTransformationBundle* _tmp28_;
#line 2810 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = self->row;
#line 2810 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = saved_orientation;
#line 2810 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_->orientation = _tmp21_;
#line 2811 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = self->row;
#line 2811 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = saved_transformations;
#line 2811 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = _g_object_ref0 (_tmp23_);
#line 2811 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp22_->transformations);
#line 2811 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_->transformations = _tmp24_;
#line 2812 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = saved_transformer;
#line 2812 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = _pixel_transformer_ref0 (_tmp25_);
#line 2812 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformer_unref0 (self->priv->transformer);
#line 2812 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->transformer = _tmp26_;
#line 2813 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = saved_adjustments;
#line 2813 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = _pixel_transformation_bundle_ref0 (_tmp27_);
#line 2813 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 2813 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->adjustments = _tmp28_;
#line 21730 "Photo.c"
			}
		}
		__finally382:
		{
			PhotoRow* _tmp29_;
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp29_ = self->row;
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21740 "Photo.c"
		}
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 21744 "Photo.c"
			gboolean _tmp30_ = FALSE;
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformation_bundle_unref0 (saved_adjustments);
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformer_unref0 (saved_transformer);
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (saved_transformations);
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (state_impl);
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2806 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp30_;
#line 21760 "Photo.c"
		}
	}
#line 2817 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = committed;
#line 2817 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp31_) {
#line 21767 "Photo.c"
		Alteration* _tmp32_;
		Alteration* _tmp33_;
#line 2818 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp32_ = alteration_new ("image", "transformation-state");
#line 2818 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp33_ = _tmp32_;
#line 2818 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp33_);
#line 2818 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp33_);
#line 21778 "Photo.c"
	}
#line 2820 "/home/jens/Source/shotwell/src/Photo.vala"
	result = committed;
#line 2820 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (saved_adjustments);
#line 2820 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformer_unref0 (saved_transformer);
#line 2820 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (saved_transformations);
#line 2820 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (state_impl);
#line 2820 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 21792 "Photo.c"
}


void photo_remove_all_transformations (Photo* self) {
#line 2823 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2824 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_internal_remove_all_transformations (self, TRUE);
#line 21801 "Photo.c"
}


static void photo_internal_remove_all_transformations (Photo* self, gboolean notify) {
	gboolean is_altered = FALSE;
	gboolean _tmp21_ = FALSE;
	gboolean _tmp22_;
	GError * _inner_error_ = NULL;
#line 2827 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2828 "/home/jens/Source/shotwell/src/Photo.vala"
	is_altered = FALSE;
#line 21814 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 21821 "Photo.c"
		{
			PhotoTable* _tmp1_;
			PhotoTable* _tmp2_;
			PhotoRow* _tmp3_;
			PhotoID _tmp4_;
			gboolean _tmp5_;
			PhotoRow* _tmp6_;
			PhotoRow* _tmp7_;
			Orientation _tmp8_;
			BackingPhotoRow* _tmp9_;
			Orientation _tmp10_;
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_table_get_instance ();
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_;
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = _tmp3_->photo_id;
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = photo_table_remove_all_transformations (_tmp2_, &_tmp4_);
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			is_altered = _tmp5_;
#line 2830 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp2_);
#line 2831 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->row;
#line 2831 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp6_->transformations);
#line 2831 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_->transformations = NULL;
#line 2833 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformer_unref0 (self->priv->transformer);
#line 2833 "/home/jens/Source/shotwell/src/Photo.vala"
			self->priv->transformer = NULL;
#line 2834 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 2834 "/home/jens/Source/shotwell/src/Photo.vala"
			self->priv->adjustments = NULL;
#line 2836 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->row;
#line 2836 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp7_->orientation;
#line 2836 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->backing_photo_row;
#line 2836 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = _tmp9_->original_orientation;
#line 2836 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp8_ != _tmp10_) {
#line 21871 "Photo.c"
				PhotoTable* _tmp11_;
				PhotoTable* _tmp12_;
				PhotoRow* _tmp13_;
				PhotoID _tmp14_;
				BackingPhotoRow* _tmp15_;
				Orientation _tmp16_;
				PhotoRow* _tmp17_;
				BackingPhotoRow* _tmp18_;
				Orientation _tmp19_;
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = photo_table_get_instance ();
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tmp11_;
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = self->row;
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = _tmp13_->photo_id;
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = self->backing_photo_row;
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = _tmp15_->original_orientation;
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_table_set_orientation (_tmp12_, &_tmp14_, _tmp16_);
#line 2837 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp12_);
#line 2839 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = self->row;
#line 2839 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = self->backing_photo_row;
#line 2839 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = _tmp18_->original_orientation;
#line 2839 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_->orientation = _tmp19_;
#line 2840 "/home/jens/Source/shotwell/src/Photo.vala"
				is_altered = TRUE;
#line 21907 "Photo.c"
			}
		}
		__finally383:
		{
			PhotoRow* _tmp20_;
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = self->row;
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21917 "Photo.c"
		}
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2829 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 21927 "Photo.c"
		}
	}
#line 2844 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = is_altered;
#line 2844 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp22_) {
#line 21934 "Photo.c"
		gboolean _tmp23_;
#line 2844 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = notify;
#line 2844 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp23_;
#line 21940 "Photo.c"
	} else {
#line 2844 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = FALSE;
#line 21944 "Photo.c"
	}
#line 2844 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp21_) {
#line 21948 "Photo.c"
		Alteration* _tmp24_;
		Alteration* _tmp25_;
#line 2845 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = alteration_new ("image", "revert");
#line 2845 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp24_;
#line 2845 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp25_);
#line 2845 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp25_);
#line 21959 "Photo.c"
	}
}


Orientation photo_get_original_orientation (Photo* self) {
	Orientation result = 0;
	GError * _inner_error_ = NULL;
#line 2848 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 21969 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 21976 "Photo.c"
		{
			BackingPhotoRow* _tmp1_;
			Orientation _tmp2_;
#line 2850 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->backing_photo_row;
#line 2850 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->original_orientation;
#line 2850 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 21986 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 21993 "Photo.c"
			}
#line 2850 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 21997 "Photo.c"
		}
		__finally384:
		{
			PhotoRow* _tmp4_;
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22006 "Photo.c"
		}
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2849 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 22014 "Photo.c"
	}
}


Orientation photo_get_orientation (Photo* self) {
	Orientation result = 0;
	GError * _inner_error_ = NULL;
#line 2854 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), 0);
#line 22024 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22031 "Photo.c"
		{
			PhotoRow* _tmp1_;
			Orientation _tmp2_;
#line 2856 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2856 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->orientation;
#line 2856 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp2_;
#line 22041 "Photo.c"
			{
				PhotoRow* _tmp3_;
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22048 "Photo.c"
			}
#line 2856 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 22052 "Photo.c"
		}
		__finally385:
		{
			PhotoRow* _tmp4_;
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22061 "Photo.c"
		}
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2855 "/home/jens/Source/shotwell/src/Photo.vala"
		return 0;
#line 22069 "Photo.c"
	}
}


gboolean photo_set_orientation (Photo* self, Orientation orientation) {
	gboolean result = FALSE;
	gboolean committed = FALSE;
	gboolean _tmp15_;
	GError * _inner_error_ = NULL;
#line 2860 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2861 "/home/jens/Source/shotwell/src/Photo.vala"
	committed = FALSE;
#line 22083 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22090 "Photo.c"
		{
			PhotoRow* _tmp1_;
			Orientation _tmp2_;
			Orientation _tmp3_;
#line 2863 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2863 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->orientation;
#line 2863 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = orientation;
#line 2863 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != _tmp3_) {
#line 22103 "Photo.c"
				PhotoTable* _tmp4_;
				PhotoTable* _tmp5_;
				PhotoRow* _tmp6_;
				PhotoID _tmp7_;
				Orientation _tmp8_;
				gboolean _tmp9_;
				gboolean _tmp10_;
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = photo_table_get_instance ();
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_;
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->row;
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = _tmp6_->photo_id;
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = orientation;
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = photo_table_set_orientation (_tmp5_, &_tmp7_, _tmp8_);
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				committed = _tmp9_;
#line 2864 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp5_);
#line 2865 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = committed;
#line 2865 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp10_) {
#line 22131 "Photo.c"
					PhotoRow* _tmp11_;
					Orientation _tmp12_;
#line 2866 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = self->row;
#line 2866 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = orientation;
#line 2866 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_->orientation = _tmp12_;
#line 22140 "Photo.c"
				}
			}
		}
		__finally386:
		{
			PhotoRow* _tmp13_;
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = self->row;
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22151 "Photo.c"
		}
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 22155 "Photo.c"
			gboolean _tmp14_ = FALSE;
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2862 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp14_;
#line 22163 "Photo.c"
		}
	}
#line 2870 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = committed;
#line 2870 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp15_) {
#line 22170 "Photo.c"
		Alteration* _tmp16_;
		Alteration* _tmp17_;
#line 2871 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = alteration_new ("image", "orientation");
#line 2871 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = _tmp16_;
#line 2871 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp17_);
#line 2871 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp17_);
#line 22181 "Photo.c"
	}
#line 2873 "/home/jens/Source/shotwell/src/Photo.vala"
	result = committed;
#line 2873 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 22187 "Photo.c"
}


gboolean photo_check_can_rotate (Photo* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 2876 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2877 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->can_rotate_now;
#line 2877 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 2877 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 22202 "Photo.c"
}


static void photo_real_rotate (Photo* self, Rotation rotation) {
	GError * _inner_error_ = NULL;
	{
		PhotoRow* _tmp0_;
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22214 "Photo.c"
		{
			Orientation _tmp1_;
			Rotation _tmp2_;
			Orientation _tmp3_;
#line 2882 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_get_orientation (self);
#line 2882 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = rotation;
#line 2882 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = orientation_perform (_tmp1_, _tmp2_);
#line 2882 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_set_orientation (self, _tmp3_);
#line 22227 "Photo.c"
		}
		__finally387:
		{
			PhotoRow* _tmp4_;
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22236 "Photo.c"
		}
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2881 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 22246 "Photo.c"
		}
	}
}


void photo_rotate (Photo* self, Rotation rotation) {
#line 2880 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2880 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->rotate (self, rotation);
#line 22257 "Photo.c"
}


static gboolean photo_has_transformation (Photo* self, const gchar* name) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2886 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2886 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 22268 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp10_ = FALSE;
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22276 "Photo.c"
		{
			gboolean _tmp1_ = FALSE;
			PhotoRow* _tmp2_;
			GeeHashMap* _tmp3_;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->row;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _tmp2_->transformations;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_ != NULL) {
#line 22287 "Photo.c"
				PhotoRow* _tmp4_;
				GeeHashMap* _tmp5_;
				const gchar* _tmp6_;
				gboolean _tmp7_;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->row;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_->transformations;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = name;
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp6_);
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp7_;
#line 22302 "Photo.c"
			} else {
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = FALSE;
#line 22306 "Photo.c"
			}
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp1_;
#line 22310 "Photo.c"
			{
				PhotoRow* _tmp8_;
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = self->row;
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22317 "Photo.c"
			}
#line 2888 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 22321 "Photo.c"
		}
		__finally388:
		{
			PhotoRow* _tmp9_;
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = self->row;
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22330 "Photo.c"
		}
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2887 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp10_;
#line 22338 "Photo.c"
	}
}


static KeyValueMap* photo_get_transformation (Photo* self, const gchar* name) {
	KeyValueMap* result = NULL;
	KeyValueMap* map = NULL;
	GError * _inner_error_ = NULL;
#line 2895 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 2895 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 2896 "/home/jens/Source/shotwell/src/Photo.vala"
	map = NULL;
#line 22353 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22360 "Photo.c"
		{
			PhotoRow* _tmp1_;
			GeeHashMap* _tmp2_;
#line 2898 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2898 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->transformations;
#line 2898 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 22370 "Photo.c"
				PhotoRow* _tmp3_;
				GeeHashMap* _tmp4_;
				const gchar* _tmp5_;
				gpointer _tmp6_;
				KeyValueMap* _tmp7_;
#line 2899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->transformations;
#line 2899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = name;
#line 2899 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_);
#line 2899 "/home/jens/Source/shotwell/src/Photo.vala"
				_key_value_map_unref0 (map);
#line 2899 "/home/jens/Source/shotwell/src/Photo.vala"
				map = (KeyValueMap*) _tmp6_;
#line 2900 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = map;
#line 2900 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp7_ != NULL) {
#line 22392 "Photo.c"
					KeyValueMap* _tmp8_;
					KeyValueMap* _tmp9_;
#line 2901 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp8_ = map;
#line 2901 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp9_ = key_value_map_copy (_tmp8_);
#line 2901 "/home/jens/Source/shotwell/src/Photo.vala"
					_key_value_map_unref0 (map);
#line 2901 "/home/jens/Source/shotwell/src/Photo.vala"
					map = _tmp9_;
#line 22403 "Photo.c"
				}
			}
		}
		__finally389:
		{
			PhotoRow* _tmp10_;
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = self->row;
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22414 "Photo.c"
		}
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
			_key_value_map_unref0 (map);
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2897 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 22426 "Photo.c"
		}
	}
#line 2905 "/home/jens/Source/shotwell/src/Photo.vala"
	result = map;
#line 2905 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 22433 "Photo.c"
}


static gboolean photo_set_transformation (Photo* self, KeyValueMap* trans) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2908 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2908 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_KEY_VALUE_MAP (trans), FALSE);
#line 22444 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp20_ = FALSE;
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22452 "Photo.c"
		{
			PhotoRow* _tmp1_;
			GeeHashMap* _tmp2_;
			PhotoRow* _tmp5_;
			GeeHashMap* _tmp6_;
			KeyValueMap* _tmp7_;
			gchar* _tmp8_;
			gchar* _tmp9_;
			KeyValueMap* _tmp10_;
			PhotoTable* _tmp11_;
			PhotoTable* _tmp12_;
			PhotoRow* _tmp13_;
			PhotoID _tmp14_;
			KeyValueMap* _tmp15_;
			gboolean _tmp16_;
			gboolean _tmp17_;
#line 2910 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2910 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->transformations;
#line 2910 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ == NULL) {
#line 22475 "Photo.c"
				PhotoRow* _tmp3_;
				GeeHashMap* _tmp4_;
#line 2911 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2911 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_KEY_VALUE_MAP, (GBoxedCopyFunc) key_value_map_ref, (GDestroyNotify) key_value_map_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 2911 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp3_->transformations);
#line 2911 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_->transformations = _tmp4_;
#line 22486 "Photo.c"
			}
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp5_->transformations;
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = trans;
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = key_value_map_get_group (_tmp7_);
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_;
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = trans;
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp9_, _tmp10_);
#line 2913 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp9_);
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = photo_table_get_instance ();
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = _tmp11_;
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = self->row;
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = _tmp13_->photo_id;
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = trans;
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = photo_table_set_transformation (_tmp12_, &_tmp14_, _tmp15_);
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = _tmp16_;
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp12_);
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp17_;
#line 22522 "Photo.c"
			{
				PhotoRow* _tmp18_;
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = self->row;
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22529 "Photo.c"
			}
#line 2915 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 22533 "Photo.c"
		}
		__finally390:
		{
			PhotoRow* _tmp19_;
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = self->row;
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22542 "Photo.c"
		}
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 2909 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp20_;
#line 22550 "Photo.c"
	}
}


static gboolean photo_remove_transformation (Photo* self, const gchar* name) {
	gboolean result = FALSE;
	gboolean altered_cache = FALSE;
	gboolean altered_persistent = FALSE;
	gboolean _tmp20_ = FALSE;
	gboolean _tmp21_;
	GError * _inner_error_ = NULL;
#line 2919 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2919 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 22566 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 22573 "Photo.c"
		{
			PhotoRow* _tmp1_;
			GeeHashMap* _tmp2_;
			PhotoTable* _tmp12_;
			PhotoTable* _tmp13_;
			PhotoRow* _tmp14_;
			PhotoID _tmp15_;
			const gchar* _tmp16_;
			gboolean _tmp17_;
#line 2922 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->row;
#line 2922 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->transformations;
#line 2922 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 22589 "Photo.c"
				PhotoRow* _tmp3_;
				GeeHashMap* _tmp4_;
				const gchar* _tmp5_;
				gboolean _tmp6_;
				PhotoRow* _tmp7_;
				GeeHashMap* _tmp8_;
				gint _tmp9_;
				gint _tmp10_;
#line 2923 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->row;
#line 2923 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->transformations;
#line 2923 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = name;
#line 2923 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_, NULL);
#line 2923 "/home/jens/Source/shotwell/src/Photo.vala"
				altered_cache = _tmp6_;
#line 2924 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = self->row;
#line 2924 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _tmp7_->transformations;
#line 2924 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = gee_abstract_map_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 2924 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tmp9_;
#line 2924 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp10_ == 0) {
#line 22618 "Photo.c"
					PhotoRow* _tmp11_;
#line 2925 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = self->row;
#line 2925 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp11_->transformations);
#line 2925 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_->transformations = NULL;
#line 22626 "Photo.c"
				}
			} else {
#line 2927 "/home/jens/Source/shotwell/src/Photo.vala"
				altered_cache = FALSE;
#line 22631 "Photo.c"
			}
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo_table_get_instance ();
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = _tmp12_;
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = self->row;
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = _tmp14_->photo_id;
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = name;
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = photo_table_remove_transformation (_tmp13_, &_tmp15_, _tmp16_);
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			altered_persistent = _tmp17_;
#line 2930 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp13_);
#line 22649 "Photo.c"
		}
		__finally391:
		{
			PhotoRow* _tmp18_;
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = self->row;
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 22658 "Photo.c"
		}
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 22662 "Photo.c"
			gboolean _tmp19_ = FALSE;
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 2921 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp19_;
#line 22670 "Photo.c"
		}
	}
#line 2934 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = altered_cache;
#line 2934 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp21_) {
#line 2934 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = TRUE;
#line 22679 "Photo.c"
	} else {
#line 2934 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = altered_persistent;
#line 22683 "Photo.c"
	}
#line 2934 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp20_;
#line 2934 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 22689 "Photo.c"
}


gboolean photo_has_crop (Photo* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 2937 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2938 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_has_transformation (self, "crop");
#line 2938 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 2938 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 22704 "Photo.c"
}


gboolean photo_get_raw_crop (Photo* self, Box* crop) {
	Box _vala_crop = {0};
	gboolean result = FALSE;
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp0_;
	KeyValueMap* _tmp1_;
	gint left = 0;
	KeyValueMap* _tmp2_;
	gint _tmp3_;
	gint top = 0;
	KeyValueMap* _tmp4_;
	gint _tmp5_;
	gint right = 0;
	KeyValueMap* _tmp6_;
	gint _tmp7_;
	gint bottom = 0;
	KeyValueMap* _tmp8_;
	gint _tmp9_;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp12_ = FALSE;
	gint _tmp13_;
	gint _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	gint _tmp20_;
#line 2942 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2943 "/home/jens/Source/shotwell/src/Photo.vala"
	box_init (&_vala_crop, 0, 0, 0, 0);
#line 2945 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_transformation (self, "crop");
#line 2945 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 2946 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = map;
#line 2946 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 2947 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2947 "/home/jens/Source/shotwell/src/Photo.vala"
		_key_value_map_unref0 (map);
#line 2947 "/home/jens/Source/shotwell/src/Photo.vala"
		if (crop) {
#line 2947 "/home/jens/Source/shotwell/src/Photo.vala"
			*crop = _vala_crop;
#line 22754 "Photo.c"
		}
#line 2947 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 22758 "Photo.c"
	}
#line 2949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = map;
#line 2949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = key_value_map_get_int (_tmp2_, "left", -1);
#line 2949 "/home/jens/Source/shotwell/src/Photo.vala"
	left = _tmp3_;
#line 2950 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = map;
#line 2950 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = key_value_map_get_int (_tmp4_, "top", -1);
#line 2950 "/home/jens/Source/shotwell/src/Photo.vala"
	top = _tmp5_;
#line 2951 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = map;
#line 2951 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = key_value_map_get_int (_tmp6_, "right", -1);
#line 2951 "/home/jens/Source/shotwell/src/Photo.vala"
	right = _tmp7_;
#line 2952 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = map;
#line 2952 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = key_value_map_get_int (_tmp8_, "bottom", -1);
#line 2952 "/home/jens/Source/shotwell/src/Photo.vala"
	bottom = _tmp9_;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = left;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp13_ == -1) {
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = TRUE;
#line 22790 "Photo.c"
	} else {
		gint _tmp14_;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = top;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp14_ == -1;
#line 22797 "Photo.c"
	}
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_) {
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = TRUE;
#line 22803 "Photo.c"
	} else {
		gint _tmp15_;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = right;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = _tmp15_ == -1;
#line 22810 "Photo.c"
	}
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_) {
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = TRUE;
#line 22816 "Photo.c"
	} else {
		gint _tmp16_;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = bottom;
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = _tmp16_ == -1;
#line 22823 "Photo.c"
	}
#line 2954 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp10_) {
#line 2955 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2955 "/home/jens/Source/shotwell/src/Photo.vala"
		_key_value_map_unref0 (map);
#line 2955 "/home/jens/Source/shotwell/src/Photo.vala"
		if (crop) {
#line 2955 "/home/jens/Source/shotwell/src/Photo.vala"
			*crop = _vala_crop;
#line 22835 "Photo.c"
		}
#line 2955 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 22839 "Photo.c"
	}
#line 2957 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = left;
#line 2957 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = top;
#line 2957 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = right;
#line 2957 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = bottom;
#line 2957 "/home/jens/Source/shotwell/src/Photo.vala"
	box_init (&_vala_crop, _tmp17_, _tmp18_, _tmp19_, _tmp20_);
#line 2959 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 2959 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 2959 "/home/jens/Source/shotwell/src/Photo.vala"
	if (crop) {
#line 2959 "/home/jens/Source/shotwell/src/Photo.vala"
		*crop = _vala_crop;
#line 22859 "Photo.c"
	}
#line 2959 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 22863 "Photo.c"
}


static void photo_set_raw_crop (Photo* self, Box* crop) {
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp0_;
	KeyValueMap* _tmp1_;
	Box _tmp2_;
	gint _tmp3_;
	KeyValueMap* _tmp4_;
	Box _tmp5_;
	gint _tmp6_;
	KeyValueMap* _tmp7_;
	Box _tmp8_;
	gint _tmp9_;
	KeyValueMap* _tmp10_;
	Box _tmp11_;
	gint _tmp12_;
	KeyValueMap* _tmp13_;
	gboolean _tmp14_;
#line 2963 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2963 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (crop != NULL);
#line 2964 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = key_value_map_new ("crop");
#line 2964 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 2965 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = map;
#line 2965 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = *crop;
#line 2965 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_.left;
#line 2965 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_int (_tmp1_, "left", _tmp3_);
#line 2966 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = map;
#line 2966 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = *crop;
#line 2966 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _tmp5_.top;
#line 2966 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_int (_tmp4_, "top", _tmp6_);
#line 2967 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = map;
#line 2967 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = *crop;
#line 2967 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _tmp8_.right;
#line 2967 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_int (_tmp7_, "right", _tmp9_);
#line 2968 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = map;
#line 2968 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = *crop;
#line 2968 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = _tmp11_.bottom;
#line 2968 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_int (_tmp10_, "bottom", _tmp12_);
#line 2970 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = map;
#line 2970 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = photo_set_transformation (self, _tmp13_);
#line 2970 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp14_) {
#line 22930 "Photo.c"
		Alteration* _tmp15_;
		Alteration* _tmp16_;
#line 2971 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = alteration_new ("image", "crop");
#line 2971 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = _tmp15_;
#line 2971 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp16_);
#line 2971 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp16_);
#line 22941 "Photo.c"
	}
#line 2963 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 22945 "Photo.c"
}


static gboolean photo_get_raw_straighten (Photo* self, gdouble* angle) {
	gdouble _vala_angle = 0.0;
	gboolean result = FALSE;
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp0_;
	KeyValueMap* _tmp1_;
	KeyValueMap* _tmp2_;
	gdouble _tmp3_;
#line 2974 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 2975 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_transformation (self, "straighten");
#line 2975 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 2976 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = map;
#line 2976 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 2977 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_angle = 0.0;
#line 2979 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 2979 "/home/jens/Source/shotwell/src/Photo.vala"
		_key_value_map_unref0 (map);
#line 2979 "/home/jens/Source/shotwell/src/Photo.vala"
		if (angle) {
#line 2979 "/home/jens/Source/shotwell/src/Photo.vala"
			*angle = _vala_angle;
#line 22977 "Photo.c"
		}
#line 2979 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 22981 "Photo.c"
	}
#line 2982 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = map;
#line 2982 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = key_value_map_get_double (_tmp2_, "angle", 0.0);
#line 2982 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_angle = _tmp3_;
#line 2984 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 2984 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 2984 "/home/jens/Source/shotwell/src/Photo.vala"
	if (angle) {
#line 2984 "/home/jens/Source/shotwell/src/Photo.vala"
		*angle = _vala_angle;
#line 22997 "Photo.c"
	}
#line 2984 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 23001 "Photo.c"
}


static void photo_set_raw_straighten (Photo* self, gdouble theta) {
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp0_;
	KeyValueMap* _tmp1_;
	gdouble _tmp2_;
	KeyValueMap* _tmp3_;
	gboolean _tmp4_;
#line 2987 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 2988 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = key_value_map_new ("straighten");
#line 2988 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 2989 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = map;
#line 2989 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = theta;
#line 2989 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_double (_tmp1_, "angle", _tmp2_);
#line 2991 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = map;
#line 2991 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_set_transformation (self, _tmp3_);
#line 2991 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp4_) {
#line 23030 "Photo.c"
		Alteration* _tmp5_;
		Alteration* _tmp6_;
#line 2992 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = alteration_new ("image", "straighten");
#line 2992 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_;
#line 2992 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp6_);
#line 2992 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp6_);
#line 23041 "Photo.c"
	}
#line 2987 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 23045 "Photo.c"
}


static EditingToolsRedeyeInstance* photo_get_raw_redeye_instances (Photo* self, int* result_length1) {
	EditingToolsRedeyeInstance* result = NULL;
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp0_;
	KeyValueMap* _tmp1_;
	gint num_points = 0;
	KeyValueMap* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	EditingToolsRedeyeInstance* res = NULL;
	gint _tmp7_;
	EditingToolsRedeyeInstance* _tmp8_;
	gint res_length1;
	gint _res_size_;
	GdkPoint default_point = {0};
	GdkPoint _tmp9_ = {0};
	EditingToolsRedeyeInstance* _tmp47_;
	gint _tmp47__length1;
#line 2997 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 2998 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_transformation (self, "redeye");
#line 2998 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 2999 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = map;
#line 2999 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 23077 "Photo.c"
		EditingToolsRedeyeInstance* _tmp2_;
		EditingToolsRedeyeInstance* _tmp3_;
		gint _tmp3__length1;
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = g_new0 (EditingToolsRedeyeInstance, 0);
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3__length1 = 0;
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		if (result_length1) {
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
			*result_length1 = _tmp3__length1;
#line 23091 "Photo.c"
		}
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp3_;
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		_key_value_map_unref0 (map);
#line 3000 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 23099 "Photo.c"
	}
#line 3002 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = map;
#line 3002 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = key_value_map_get_int (_tmp4_, "num_points", -1);
#line 3002 "/home/jens/Source/shotwell/src/Photo.vala"
	num_points = _tmp5_;
#line 3003 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = num_points;
#line 3003 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp6_ > 0, "num_points > 0");
#line 3005 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = num_points;
#line 3005 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = g_new0 (EditingToolsRedeyeInstance, _tmp7_);
#line 3005 "/home/jens/Source/shotwell/src/Photo.vala"
	res = _tmp8_;
#line 3005 "/home/jens/Source/shotwell/src/Photo.vala"
	res_length1 = _tmp7_;
#line 3005 "/home/jens/Source/shotwell/src/Photo.vala"
	_res_size_ = res_length1;
#line 3007 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_.x = 0;
#line 3007 "/home/jens/Source/shotwell/src/Photo.vala"
	default_point = _tmp9_;
#line 3008 "/home/jens/Source/shotwell/src/Photo.vala"
	default_point.x = -1;
#line 3009 "/home/jens/Source/shotwell/src/Photo.vala"
	default_point.y = -1;
#line 23129 "Photo.c"
	{
		gint i = 0;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
		i = 0;
#line 23134 "Photo.c"
		{
			gboolean _tmp10_ = FALSE;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = TRUE;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 23141 "Photo.c"
				gint _tmp12_;
				gint _tmp13_;
				gchar* center_key = NULL;
				gint _tmp14_;
				gchar* _tmp15_;
				gchar* radius_key = NULL;
				gint _tmp16_;
				gchar* _tmp17_;
				EditingToolsRedeyeInstance* _tmp18_;
				gint _tmp18__length1;
				gint _tmp19_;
				KeyValueMap* _tmp20_;
				const gchar* _tmp21_;
				GdkPoint _tmp22_;
				GdkPoint _tmp23_ = {0};
				EditingToolsRedeyeInstance* _tmp24_;
				gint _tmp24__length1;
				gint _tmp25_;
				EditingToolsRedeyeInstance _tmp26_;
				GdkPoint _tmp27_;
				gint _tmp28_;
				GdkPoint _tmp29_;
				gint _tmp30_;
				EditingToolsRedeyeInstance* _tmp31_;
				gint _tmp31__length1;
				gint _tmp32_;
				EditingToolsRedeyeInstance _tmp33_;
				GdkPoint _tmp34_;
				gint _tmp35_;
				GdkPoint _tmp36_;
				gint _tmp37_;
				EditingToolsRedeyeInstance* _tmp38_;
				gint _tmp38__length1;
				gint _tmp39_;
				KeyValueMap* _tmp40_;
				const gchar* _tmp41_;
				gint _tmp42_;
				EditingToolsRedeyeInstance* _tmp43_;
				gint _tmp43__length1;
				gint _tmp44_;
				EditingToolsRedeyeInstance _tmp45_;
				gint _tmp46_;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp10_) {
#line 23186 "Photo.c"
					gint _tmp11_;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = i;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
					i = _tmp11_ + 1;
#line 23192 "Photo.c"
				}
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = FALSE;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = i;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = num_points;
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp12_ < _tmp13_)) {
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 23204 "Photo.c"
				}
#line 3012 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = i;
#line 3012 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = g_strdup_printf ("center%d", _tmp14_);
#line 3012 "/home/jens/Source/shotwell/src/Photo.vala"
				center_key = _tmp15_;
#line 3013 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = i;
#line 3013 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = g_strdup_printf ("radius%d", _tmp16_);
#line 3013 "/home/jens/Source/shotwell/src/Photo.vala"
				radius_key = _tmp17_;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = res;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18__length1 = res_length1;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = i;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = map;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = center_key;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = default_point;
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				key_value_map_get_point (_tmp20_, _tmp21_, &_tmp22_, &_tmp23_);
#line 3015 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_[_tmp19_].center = _tmp23_;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = res;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24__length1 = res_length1;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = i;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = _tmp24_[_tmp25_];
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = _tmp26_.center;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = _tmp27_.x;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = default_point;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = _tmp29_.x;
#line 3016 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_assert (_tmp28_ != _tmp30_, "res[i].center.x != default_point.x");
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = res;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31__length1 = res_length1;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = i;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = _tmp31_[_tmp32_];
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = _tmp33_.center;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = _tmp34_.y;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = default_point;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = _tmp36_.y;
#line 3017 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_assert (_tmp35_ != _tmp37_, "res[i].center.y != default_point.y");
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = res;
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38__length1 = res_length1;
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = i;
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = map;
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp41_ = radius_key;
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp42_ = key_value_map_get_int (_tmp40_, _tmp41_, -1);
#line 3019 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_[_tmp39_].radius = _tmp42_;
#line 3020 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = res;
#line 3020 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43__length1 = res_length1;
#line 3020 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = i;
#line 3020 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = _tmp43_[_tmp44_];
#line 3020 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = _tmp45_.radius;
#line 3020 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_assert (_tmp46_ != -1, "res[i].radius != -1");
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (radius_key);
#line 3011 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (center_key);
#line 23300 "Photo.c"
			}
		}
	}
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = res;
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47__length1 = res_length1;
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
	if (result_length1) {
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
		*result_length1 = _tmp47__length1;
#line 23312 "Photo.c"
	}
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp47_;
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 3023 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 23320 "Photo.c"
}


gboolean photo_has_redeye_transformations (Photo* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 3026 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 3027 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_has_transformation (self, "redeye");
#line 3027 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 3027 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 23335 "Photo.c"
}


void photo_add_redeye_instance (Photo* self, EditingToolsRedeyeInstance* redeye) {
	KeyValueMap* map = NULL;
	KeyValueMap* _tmp0_;
	KeyValueMap* _tmp1_;
	gint num_points = 0;
	KeyValueMap* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	gchar* radius_key = NULL;
	gint _tmp8_;
	gchar* _tmp9_;
	gchar* center_key = NULL;
	gint _tmp10_;
	gchar* _tmp11_;
	KeyValueMap* _tmp12_;
	const gchar* _tmp13_;
	EditingToolsRedeyeInstance _tmp14_;
	gint _tmp15_;
	KeyValueMap* _tmp16_;
	const gchar* _tmp17_;
	EditingToolsRedeyeInstance _tmp18_;
	GdkPoint _tmp19_;
	KeyValueMap* _tmp20_;
	gint _tmp21_;
	KeyValueMap* _tmp22_;
	gboolean _tmp23_;
#line 3031 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3031 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (redeye != NULL);
#line 3032 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_transformation (self, "redeye");
#line 3032 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 3033 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = map;
#line 3033 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 23378 "Photo.c"
		KeyValueMap* _tmp2_;
		KeyValueMap* _tmp3_;
#line 3034 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = key_value_map_new ("redeye");
#line 3034 "/home/jens/Source/shotwell/src/Photo.vala"
		_key_value_map_unref0 (map);
#line 3034 "/home/jens/Source/shotwell/src/Photo.vala"
		map = _tmp2_;
#line 3035 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = map;
#line 3035 "/home/jens/Source/shotwell/src/Photo.vala"
		key_value_map_set_int (_tmp3_, "num_points", 0);
#line 23391 "Photo.c"
	}
#line 3038 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = map;
#line 3038 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = key_value_map_get_int (_tmp4_, "num_points", -1);
#line 3038 "/home/jens/Source/shotwell/src/Photo.vala"
	num_points = _tmp5_;
#line 3039 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = num_points;
#line 3039 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp6_ >= 0, "num_points >= 0");
#line 3041 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = num_points;
#line 3041 "/home/jens/Source/shotwell/src/Photo.vala"
	num_points = _tmp7_ + 1;
#line 3043 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = num_points;
#line 3043 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = g_strdup_printf ("radius%d", _tmp8_ - 1);
#line 3043 "/home/jens/Source/shotwell/src/Photo.vala"
	radius_key = _tmp9_;
#line 3044 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = num_points;
#line 3044 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = g_strdup_printf ("center%d", _tmp10_ - 1);
#line 3044 "/home/jens/Source/shotwell/src/Photo.vala"
	center_key = _tmp11_;
#line 3046 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = map;
#line 3046 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = radius_key;
#line 3046 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = *redeye;
#line 3046 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_.radius;
#line 3046 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_int (_tmp12_, _tmp13_, _tmp15_);
#line 3047 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = map;
#line 3047 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = center_key;
#line 3047 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = *redeye;
#line 3047 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = _tmp18_.center;
#line 3047 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_point (_tmp16_, _tmp17_, &_tmp19_);
#line 3049 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = map;
#line 3049 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = num_points;
#line 3049 "/home/jens/Source/shotwell/src/Photo.vala"
	key_value_map_set_int (_tmp20_, "num_points", _tmp21_);
#line 3051 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = map;
#line 3051 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = photo_set_transformation (self, _tmp22_);
#line 3051 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp23_) {
#line 23451 "Photo.c"
		Alteration* _tmp24_;
		Alteration* _tmp25_;
#line 3052 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = alteration_new ("image", "redeye");
#line 3052 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp24_;
#line 3052 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp25_);
#line 3052 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp25_);
#line 23462 "Photo.c"
	}
#line 3031 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (center_key);
#line 3031 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (radius_key);
#line 3031 "/home/jens/Source/shotwell/src/Photo.vala"
	_key_value_map_unref0 (map);
#line 23470 "Photo.c"
}


static gboolean photo_calculate_pixbuf_dimensions (Photo* self, Scaling* scaling, PhotoException exceptions, Dimensions* scaled_image, Dimensions* scaled_to_viewport) {
	Dimensions _vala_scaled_image = {0};
	Dimensions _vala_scaled_to_viewport = {0};
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 3066 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 3066 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, FALSE);
#line 23483 "Photo.c"
	{
		PhotoRow* _tmp0_;
		gboolean _tmp8_ = FALSE;
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 23491 "Photo.c"
		{
			Scaling _tmp1_;
			PhotoException _tmp2_;
			Dimensions _tmp3_ = {0};
			Dimensions _tmp4_ = {0};
			gboolean _tmp5_;
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = *scaling;
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = exceptions;
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = photo_locked_calculate_pixbuf_dimensions (self, &_tmp1_, _tmp2_, &_tmp3_, &_tmp4_);
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_scaled_image = _tmp3_;
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_scaled_to_viewport = _tmp4_;
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp5_;
#line 23510 "Photo.c"
			{
				PhotoRow* _tmp6_;
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->row;
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 23517 "Photo.c"
			}
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			if (scaled_image) {
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
				*scaled_image = _vala_scaled_image;
#line 23523 "Photo.c"
			}
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			if (scaled_to_viewport) {
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
				*scaled_to_viewport = _vala_scaled_to_viewport;
#line 23529 "Photo.c"
			}
#line 3070 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 23533 "Photo.c"
		}
		__finally392:
		{
			PhotoRow* _tmp7_;
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->row;
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 23542 "Photo.c"
		}
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 3068 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp8_;
#line 23550 "Photo.c"
	}
#line 3066 "/home/jens/Source/shotwell/src/Photo.vala"
	if (scaled_image) {
#line 3066 "/home/jens/Source/shotwell/src/Photo.vala"
		*scaled_image = _vala_scaled_image;
#line 23556 "Photo.c"
	}
#line 3066 "/home/jens/Source/shotwell/src/Photo.vala"
	if (scaled_to_viewport) {
#line 3066 "/home/jens/Source/shotwell/src/Photo.vala"
		*scaled_to_viewport = _vala_scaled_to_viewport;
#line 23562 "Photo.c"
	}
}


static gboolean photo_locked_calculate_pixbuf_dimensions (Photo* self, Scaling* scaling, PhotoException exceptions, Dimensions* scaled_image, Dimensions* scaled_to_viewport) {
	Dimensions _vala_scaled_image = {0};
	Dimensions _vala_scaled_to_viewport = {0};
	gboolean result = FALSE;
	Dimensions raw = {0};
	Dimensions _tmp0_ = {0};
	gboolean _tmp1_;
	Orientation orientation = 0;
	Orientation _tmp4_;
	PhotoException _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp38_;
	gboolean _tmp53_ = FALSE;
	Dimensions _tmp54_;
	gint _tmp55_;
	Dimensions _tmp56_;
	gint _tmp57_;
	gboolean _tmp63_;
	gboolean _tmp64_;
#line 3076 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 3076 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, FALSE);
#line 3078 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_raw_dimensions (self, &_tmp0_);
#line 3078 "/home/jens/Source/shotwell/src/Photo.vala"
	raw = _tmp0_;
#line 3080 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = scaling_is_unscaled (scaling);
#line 3080 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 23598 "Photo.c"
		Dimensions _tmp2_;
		Dimensions _tmp3_;
#line 3081 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = raw;
#line 3081 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_scaled_image = _tmp2_;
#line 3082 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = raw;
#line 3082 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_scaled_to_viewport = _tmp3_;
#line 3084 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 3084 "/home/jens/Source/shotwell/src/Photo.vala"
		if (scaled_image) {
#line 3084 "/home/jens/Source/shotwell/src/Photo.vala"
			*scaled_image = _vala_scaled_image;
#line 23615 "Photo.c"
		}
#line 3084 "/home/jens/Source/shotwell/src/Photo.vala"
		if (scaled_to_viewport) {
#line 3084 "/home/jens/Source/shotwell/src/Photo.vala"
			*scaled_to_viewport = _vala_scaled_to_viewport;
#line 23621 "Photo.c"
		}
#line 3084 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 23625 "Photo.c"
	}
#line 3087 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_get_orientation (self);
#line 3087 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation = _tmp4_;
#line 3092 "/home/jens/Source/shotwell/src/Photo.vala"
	dimensions_init (&_vala_scaled_image, 0, 0);
#line 3093 "/home/jens/Source/shotwell/src/Photo.vala"
	dimensions_init (&_vala_scaled_to_viewport, 0, 0);
#line 3095 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = exceptions;
#line 3095 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_exception_allows (_tmp5_, PHOTO_EXCEPTION_CROP);
#line 3095 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_) {
#line 23641 "Photo.c"
		Box crop = {0};
		Box _tmp7_ = {0};
		gboolean _tmp8_;
#line 3097 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = photo_get_raw_crop (self, &_tmp7_);
#line 3097 "/home/jens/Source/shotwell/src/Photo.vala"
		crop = _tmp7_;
#line 3097 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp8_) {
#line 23651 "Photo.c"
			Dimensions rotated_raw = {0};
			Dimensions _tmp9_;
			PhotoException _tmp10_;
			gboolean _tmp11_;
			Box scaled_crop = {0};
			Dimensions _tmp19_ = {0};
			Dimensions _tmp20_ = {0};
			Box _tmp21_ = {0};
			Dimensions _tmp22_ = {0};
			gboolean _tmp23_ = FALSE;
			gint _tmp24_;
			gint _tmp25_;
			Dimensions _tmp30_ = {0};
			Dimensions _tmp31_ = {0};
			Dimensions _tmp32_ = {0};
			PhotoException _tmp33_;
			gboolean _tmp34_;
#line 3100 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = raw;
#line 3100 "/home/jens/Source/shotwell/src/Photo.vala"
			rotated_raw = _tmp9_;
#line 3101 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = exceptions;
#line 3101 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = photo_exception_allows (_tmp10_, PHOTO_EXCEPTION_ORIENTATION);
#line 3101 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp11_) {
#line 23679 "Photo.c"
				Orientation _tmp12_;
				Dimensions _tmp13_;
				Box _tmp14_;
				Box _tmp15_ = {0};
				Orientation _tmp16_;
				Dimensions _tmp17_;
				Dimensions _tmp18_ = {0};
#line 3102 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = orientation;
#line 3102 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = raw;
#line 3102 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = crop;
#line 3102 "/home/jens/Source/shotwell/src/Photo.vala"
				orientation_rotate_box (_tmp12_, &_tmp13_, &_tmp14_, &_tmp15_);
#line 3102 "/home/jens/Source/shotwell/src/Photo.vala"
				crop = _tmp15_;
#line 3103 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = orientation;
#line 3103 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = raw;
#line 3103 "/home/jens/Source/shotwell/src/Photo.vala"
				orientation_rotate_dimensions (_tmp16_, &_tmp17_, &_tmp18_);
#line 3103 "/home/jens/Source/shotwell/src/Photo.vala"
				rotated_raw = _tmp18_;
#line 23705 "Photo.c"
			}
#line 3107 "/home/jens/Source/shotwell/src/Photo.vala"
			box_get_dimensions (&crop, &_tmp19_);
#line 3107 "/home/jens/Source/shotwell/src/Photo.vala"
			scaling_get_scaled_dimensions (scaling, &_tmp19_, &_tmp20_);
#line 3107 "/home/jens/Source/shotwell/src/Photo.vala"
			box_get_scaled (&crop, &_tmp20_, &_tmp21_);
#line 3107 "/home/jens/Source/shotwell/src/Photo.vala"
			scaled_crop = _tmp21_;
#line 3110 "/home/jens/Source/shotwell/src/Photo.vala"
			box_get_dimensions (&scaled_crop, &_tmp22_);
#line 3110 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_scaled_to_viewport = _tmp22_;
#line 3113 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = box_get_width (&crop);
#line 3113 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp25_ = box_get_width (&scaled_crop);
#line 3113 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp24_ <= _tmp25_) {
#line 23725 "Photo.c"
				gint _tmp26_;
				gint _tmp27_;
#line 3114 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = box_get_height (&crop);
#line 3114 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = box_get_height (&scaled_crop);
#line 3114 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = _tmp26_ <= _tmp27_;
#line 23734 "Photo.c"
			} else {
#line 3113 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = FALSE;
#line 23738 "Photo.c"
			}
#line 3113 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp23_) {
#line 23742 "Photo.c"
				Dimensions _tmp28_;
				Dimensions _tmp29_ = {0};
#line 3115 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = raw;
#line 3115 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_scaled_image = _tmp28_;
#line 3116 "/home/jens/Source/shotwell/src/Photo.vala"
				box_get_dimensions (&crop, &_tmp29_);
#line 3116 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_scaled_to_viewport = _tmp29_;
#line 3118 "/home/jens/Source/shotwell/src/Photo.vala"
				result = FALSE;
#line 3118 "/home/jens/Source/shotwell/src/Photo.vala"
				if (scaled_image) {
#line 3118 "/home/jens/Source/shotwell/src/Photo.vala"
					*scaled_image = _vala_scaled_image;
#line 23759 "Photo.c"
				}
#line 3118 "/home/jens/Source/shotwell/src/Photo.vala"
				if (scaled_to_viewport) {
#line 3118 "/home/jens/Source/shotwell/src/Photo.vala"
					*scaled_to_viewport = _vala_scaled_to_viewport;
#line 23765 "Photo.c"
				}
#line 3118 "/home/jens/Source/shotwell/src/Photo.vala"
				return result;
#line 23769 "Photo.c"
			}
#line 3123 "/home/jens/Source/shotwell/src/Photo.vala"
			box_get_dimensions (&crop, &_tmp30_);
#line 3123 "/home/jens/Source/shotwell/src/Photo.vala"
			box_get_dimensions (&scaled_crop, &_tmp31_);
#line 3123 "/home/jens/Source/shotwell/src/Photo.vala"
			dimensions_get_scaled_similar (&rotated_raw, &_tmp30_, &_tmp31_, &_tmp32_);
#line 3123 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_scaled_image = _tmp32_;
#line 3127 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp33_ = exceptions;
#line 3127 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp34_ = photo_exception_allows (_tmp33_, PHOTO_EXCEPTION_ORIENTATION);
#line 3127 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp34_) {
#line 23785 "Photo.c"
				Orientation _tmp35_;
				Dimensions _tmp36_;
				Dimensions _tmp37_ = {0};
#line 3128 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = orientation;
#line 3128 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = _vala_scaled_image;
#line 3128 "/home/jens/Source/shotwell/src/Photo.vala"
				orientation_derotate_dimensions (_tmp35_, &_tmp36_, &_tmp37_);
#line 3128 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_scaled_image = _tmp37_;
#line 23797 "Photo.c"
			}
		}
	}
#line 3133 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = dimensions_has_area (&_vala_scaled_image);
#line 3133 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp38_) {
#line 23805 "Photo.c"
		Dimensions rotated_raw = {0};
		Dimensions _tmp39_;
		PhotoException _tmp40_;
		gboolean _tmp41_;
		Dimensions _tmp45_;
		Dimensions _tmp46_ = {0};
		Dimensions _tmp47_;
		PhotoException _tmp48_;
		gboolean _tmp49_;
#line 3135 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = raw;
#line 3135 "/home/jens/Source/shotwell/src/Photo.vala"
		rotated_raw = _tmp39_;
#line 3136 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = exceptions;
#line 3136 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = photo_exception_allows (_tmp40_, PHOTO_EXCEPTION_ORIENTATION);
#line 3136 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp41_) {
#line 23825 "Photo.c"
			Orientation _tmp42_;
			Dimensions _tmp43_;
			Dimensions _tmp44_ = {0};
#line 3137 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = orientation;
#line 3137 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp43_ = raw;
#line 3137 "/home/jens/Source/shotwell/src/Photo.vala"
			orientation_rotate_dimensions (_tmp42_, &_tmp43_, &_tmp44_);
#line 3137 "/home/jens/Source/shotwell/src/Photo.vala"
			rotated_raw = _tmp44_;
#line 23837 "Photo.c"
		}
#line 3139 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = rotated_raw;
#line 3139 "/home/jens/Source/shotwell/src/Photo.vala"
		scaling_get_scaled_dimensions (scaling, &_tmp45_, &_tmp46_);
#line 3139 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_scaled_image = _tmp46_;
#line 3140 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = _vala_scaled_image;
#line 3140 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_scaled_to_viewport = _tmp47_;
#line 3143 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = exceptions;
#line 3143 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = photo_exception_allows (_tmp48_, PHOTO_EXCEPTION_ORIENTATION);
#line 3143 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp49_) {
#line 23855 "Photo.c"
			Orientation _tmp50_;
			Dimensions _tmp51_;
			Dimensions _tmp52_ = {0};
#line 3144 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp50_ = orientation;
#line 3144 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp51_ = _vala_scaled_image;
#line 3144 "/home/jens/Source/shotwell/src/Photo.vala"
			orientation_derotate_dimensions (_tmp50_, &_tmp51_, &_tmp52_);
#line 3144 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_scaled_image = _tmp52_;
#line 23867 "Photo.c"
		}
	}
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp54_ = _vala_scaled_image;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp55_ = _tmp54_.width;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp56_ = raw;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp57_ = _tmp56_.width;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp55_ >= _tmp57_) {
#line 23880 "Photo.c"
		Dimensions _tmp58_;
		gint _tmp59_;
		Dimensions _tmp60_;
		gint _tmp61_;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp58_ = _vala_scaled_image;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp59_ = _tmp58_.height;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp60_ = raw;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp61_ = _tmp60_.height;
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp53_ = _tmp59_ >= _tmp61_;
#line 23895 "Photo.c"
	} else {
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp53_ = FALSE;
#line 23899 "Photo.c"
	}
#line 3148 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp53_) {
#line 23903 "Photo.c"
		Dimensions _tmp62_;
#line 3149 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp62_ = raw;
#line 3149 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_scaled_image = _tmp62_;
#line 3151 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 3151 "/home/jens/Source/shotwell/src/Photo.vala"
		if (scaled_image) {
#line 3151 "/home/jens/Source/shotwell/src/Photo.vala"
			*scaled_image = _vala_scaled_image;
#line 23915 "Photo.c"
		}
#line 3151 "/home/jens/Source/shotwell/src/Photo.vala"
		if (scaled_to_viewport) {
#line 3151 "/home/jens/Source/shotwell/src/Photo.vala"
			*scaled_to_viewport = _vala_scaled_to_viewport;
#line 23921 "Photo.c"
		}
#line 3151 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 23925 "Photo.c"
	}
#line 3154 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp63_ = dimensions_has_area (&_vala_scaled_image);
#line 3154 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp63_, "scaled_image.has_area()");
#line 3155 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp64_ = dimensions_has_area (&_vala_scaled_to_viewport);
#line 3155 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp64_, "scaled_to_viewport.has_area()");
#line 3157 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 3157 "/home/jens/Source/shotwell/src/Photo.vala"
	if (scaled_image) {
#line 3157 "/home/jens/Source/shotwell/src/Photo.vala"
		*scaled_image = _vala_scaled_image;
#line 23941 "Photo.c"
	}
#line 3157 "/home/jens/Source/shotwell/src/Photo.vala"
	if (scaled_to_viewport) {
#line 3157 "/home/jens/Source/shotwell/src/Photo.vala"
		*scaled_to_viewport = _vala_scaled_to_viewport;
#line 23947 "Photo.c"
	}
#line 3157 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 23951 "Photo.c"
}


static GdkPixbuf* photo_load_raw_pixbuf (Photo* self, Scaling* scaling, PhotoException exceptions, BackingFetchMode fetch_mode, GError** error) {
	GdkPixbuf* result = NULL;
	PhotoFileReader* loader = NULL;
	BackingFetchMode _tmp0_;
	PhotoFileReader* _tmp1_;
	gboolean _tmp2_;
	Dimensions scaled_image = {0};
	Dimensions scaled_to_viewport = {0};
	gboolean is_scaled = FALSE;
	Scaling _tmp7_;
	PhotoException _tmp8_;
	Dimensions _tmp9_ = {0};
	Dimensions _tmp10_ = {0};
	gboolean _tmp11_;
	gboolean _tmp12_;
	GdkPixbuf* pixbuf = NULL;
	PhotoFileReader* _tmp17_;
	Dimensions _tmp18_ = {0};
	Dimensions _tmp19_;
	GdkPixbuf* _tmp20_;
	GdkPixbuf* _tmp21_;
	Dimensions _tmp22_ = {0};
	gboolean _tmp23_;
	GError * _inner_error_ = NULL;
#line 3163 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3163 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 3166 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = fetch_mode;
#line 3166 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_backing_reader (self, _tmp0_);
#line 3166 "/home/jens/Source/shotwell/src/Photo.vala"
	loader = _tmp1_;
#line 3169 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = scaling_is_unscaled (scaling);
#line 3169 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 23993 "Photo.c"
		GdkPixbuf* _tmp3_ = NULL;
		PhotoFileReader* _tmp4_;
		GdkPixbuf* _tmp5_;
		GdkPixbuf* _tmp6_;
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = loader;
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = photo_file_reader_unscaled_read (_tmp4_, &_inner_error_);
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp5_;
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (loader);
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 24012 "Photo.c"
		}
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp3_;
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = NULL;
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp6_;
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (loader);
#line 3174 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 24026 "Photo.c"
	}
#line 3179 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = *scaling;
#line 3179 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = exceptions;
#line 3179 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = photo_calculate_pixbuf_dimensions (self, &_tmp7_, _tmp8_, &_tmp9_, &_tmp10_);
#line 3179 "/home/jens/Source/shotwell/src/Photo.vala"
	scaled_image = _tmp9_;
#line 3179 "/home/jens/Source/shotwell/src/Photo.vala"
	scaled_to_viewport = _tmp10_;
#line 3179 "/home/jens/Source/shotwell/src/Photo.vala"
	is_scaled = _tmp11_;
#line 3181 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = is_scaled;
#line 3181 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp12_) {
#line 24044 "Photo.c"
		GdkPixbuf* _tmp13_ = NULL;
		PhotoFileReader* _tmp14_;
		GdkPixbuf* _tmp15_;
		GdkPixbuf* _tmp16_;
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = loader;
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = photo_file_reader_unscaled_read (_tmp14_, &_inner_error_);
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _tmp15_;
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (loader);
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 24063 "Photo.c"
		}
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = _tmp13_;
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = NULL;
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp16_;
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp13_);
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (loader);
#line 3186 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 24077 "Photo.c"
	}
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = loader;
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_raw_dimensions (self, &_tmp18_);
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = scaled_image;
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = photo_file_reader_scaled_read (_tmp17_, &_tmp18_, &_tmp19_, &_inner_error_);
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
	pixbuf = _tmp20_;
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (loader);
#line 3189 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24097 "Photo.c"
	}
#line 3197 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = pixbuf;
#line 3197 "/home/jens/Source/shotwell/src/Photo.vala"
	dimensions_for_pixbuf (_tmp21_, &_tmp22_);
#line 3197 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = dimensions_approx_equals (&scaled_image, &_tmp22_, PHOTO_SCALING_FUDGE);
#line 3197 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp23_, "scaled_image.approx_equals(Dimensions.for_pixbuf(pixbuf), SCALING_FUDGE)");
#line 3199 "/home/jens/Source/shotwell/src/Photo.vala"
	result = pixbuf;
#line 3199 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (loader);
#line 3199 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24113 "Photo.c"
}


GdkPixbuf* photo_get_master_pixbuf (Photo* self, Scaling* scaling, gboolean rotate, GError** error) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	Scaling _tmp1_;
	gboolean _tmp2_;
	GdkPixbuf* _tmp3_;
	GdkPixbuf* _tmp4_;
	GError * _inner_error_ = NULL;
#line 3204 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3204 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = *scaling;
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = rotate;
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_get_untransformed_pixbuf (self, &_tmp1_, _tmp2_, BACKING_FETCH_MODE_MASTER, &_inner_error_);
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp3_;
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24143 "Photo.c"
	}
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp0_;
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp0_);
#line 3205 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24155 "Photo.c"
}


GdkPixbuf* photo_get_unmodified_pixbuf (Photo* self, Scaling* scaling, gboolean rotate, GError** error) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	Scaling _tmp1_;
	gboolean _tmp2_;
	GdkPixbuf* _tmp3_;
	GdkPixbuf* _tmp4_;
	GError * _inner_error_ = NULL;
#line 3209 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3209 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = *scaling;
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = rotate;
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_get_untransformed_pixbuf (self, &_tmp1_, _tmp2_, BACKING_FETCH_MODE_UNMODIFIED, &_inner_error_);
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp3_;
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24185 "Photo.c"
	}
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp0_;
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp0_);
#line 3210 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24197 "Photo.c"
}


static GdkPixbuf* photo_get_untransformed_pixbuf (Photo* self, Scaling* scaling, gboolean rotate, BackingFetchMode fetch_mode, GError** error) {
	GdkPixbuf* result = NULL;
	Dimensions scaled_image = {0};
	Dimensions scaled_to_viewport = {0};
	Orientation original_orientation = 0;
	GdkPixbuf* pixbuf = NULL;
	Scaling _tmp6_;
	BackingFetchMode _tmp7_;
	GdkPixbuf* _tmp8_;
	gboolean _tmp9_;
	GError * _inner_error_ = NULL;
#line 3214 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3214 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 24216 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 24223 "Photo.c"
		{
			Scaling _tmp1_;
			Dimensions _tmp2_ = {0};
			Dimensions _tmp3_ = {0};
			Orientation _tmp4_;
#line 3229 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = *scaling;
#line 3229 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_calculate_pixbuf_dimensions (self, &_tmp1_, PHOTO_EXCEPTION_NONE, &_tmp2_, &_tmp3_);
#line 3229 "/home/jens/Source/shotwell/src/Photo.vala"
			scaled_image = _tmp2_;
#line 3229 "/home/jens/Source/shotwell/src/Photo.vala"
			scaled_to_viewport = _tmp3_;
#line 3231 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = photo_get_original_orientation (self);
#line 3231 "/home/jens/Source/shotwell/src/Photo.vala"
			original_orientation = _tmp4_;
#line 24241 "Photo.c"
		}
		__finally393:
		{
			PhotoRow* _tmp5_;
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = self->row;
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 24250 "Photo.c"
		}
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3228 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 24258 "Photo.c"
		}
	}
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = *scaling;
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = fetch_mode;
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo_load_raw_pixbuf (self, &_tmp6_, PHOTO_EXCEPTION_NONE, _tmp7_, &_inner_error_);
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
	pixbuf = _tmp8_;
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3235 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24275 "Photo.c"
	}
#line 3241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = rotate;
#line 3241 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp9_) {
#line 24281 "Photo.c"
		GdkPixbuf* _tmp10_;
		GdkPixbuf* _tmp11_;
#line 3242 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = pixbuf;
#line 3242 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = orientation_rotate_pixbuf (original_orientation, _tmp10_);
#line 3242 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3242 "/home/jens/Source/shotwell/src/Photo.vala"
		pixbuf = _tmp11_;
#line 24292 "Photo.c"
	}
#line 3251 "/home/jens/Source/shotwell/src/Photo.vala"
	result = pixbuf;
#line 3251 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24298 "Photo.c"
}


static GdkPixbuf* photo_real_get_pixbuf (PhotoSource* base, Scaling* scaling, GError** error) {
	Photo * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	Scaling _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
	GError * _inner_error_ = NULL;
#line 3254 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO, Photo);
#line 3254 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = *scaling;
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_get_pixbuf_with_options (self, &_tmp1_, PHOTO_EXCEPTION_NONE, BACKING_FETCH_MODE_BASELINE, &_inner_error_);
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp2_;
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24326 "Photo.c"
	}
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp0_;
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp0_);
#line 3255 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24338 "Photo.c"
}


/**
     * One-stop shopping for the source pixbuf cache.
     *
     * The source pixbuf cache holds untransformed, unscaled (full-sized) pixbufs of Photo objects.
     * These can be rather large and shouldn't be held in memory for too long, nor should many be
     * allowed to stack up.
     *
     * If locate is non-null, a source pixbuf is returned for the Photo.  If keep is true, the
     * pixbuf is stored in the cache.  (Thus, passing a Photo w/ keep == false will drop the cached
     * pixbuf.)  If Photo is non-null but keep is false, null is returned.
     *
     * Whether locate is null or not, the cache is walked in its entirety, dropping expired pixbufs
     * and dropping excessive pixbufs from the LRU.  Locating a Photo "touches" the pixbuf, i.e.
     * it moves to the head of the LRU.
     */
static gpointer _photo_cached_pixbuf_ref0 (gpointer self) {
#line 3290 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? photo_cached_pixbuf_ref (self) : NULL;
#line 24360 "Photo.c"
}


static gboolean _photo_trim_source_pixbuf_cache_gsource_func (gpointer self) {
	gboolean result;
	result = photo_trim_source_pixbuf_cache ();
#line 3342 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24369 "Photo.c"
}


static GdkPixbuf* photo_run_source_pixbuf_cache (Photo* locate, gboolean keep, GError** error) {
	GdkPixbuf* result = NULL;
	GError * _inner_error_ = NULL;
#line 3273 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((locate == NULL) || IS_PHOTO (locate), NULL);
#line 24378 "Photo.c"
	{
		GeeLinkedList* _tmp0_;
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = photo_source_pixbuf_cache;
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&__lock_photo_source_pixbuf_cache);
#line 24385 "Photo.c"
		{
			PhotoCachedPixbuf* found = NULL;
			gdouble min_elapsed = 0.0;
			gint count = 0;
			GeeIterator* iter = NULL;
			GeeLinkedList* _tmp1_;
			GeeIterator* _tmp2_;
			gboolean _tmp29_ = FALSE;
			gboolean _tmp30_ = FALSE;
			PhotoCachedPixbuf* _tmp31_;
			gboolean _tmp43_ = FALSE;
			PhotoCachedPixbuf* _tmp44_;
			guint _tmp59_;
			GeeLinkedList* _tmp61_;
			gint _tmp62_;
			gint _tmp63_;
			GdkPixbuf* _tmp69_ = NULL;
			PhotoCachedPixbuf* _tmp70_;
			GdkPixbuf* _tmp73_;
#line 3275 "/home/jens/Source/shotwell/src/Photo.vala"
			found = NULL;
#line 3279 "/home/jens/Source/shotwell/src/Photo.vala"
			min_elapsed = DBL_MAX;
#line 3280 "/home/jens/Source/shotwell/src/Photo.vala"
			count = 0;
#line 3281 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_source_pixbuf_cache;
#line 3281 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = gee_abstract_collection_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 3281 "/home/jens/Source/shotwell/src/Photo.vala"
			iter = _tmp2_;
#line 3282 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 24419 "Photo.c"
				GeeIterator* _tmp3_;
				gboolean _tmp4_;
				PhotoCachedPixbuf* cached_pixbuf = NULL;
				GeeIterator* _tmp5_;
				gpointer _tmp6_;
				gdouble elapsed = 0.0;
				PhotoCachedPixbuf* _tmp7_;
				GTimer* _tmp8_;
				gdouble _tmp9_;
				gdouble _tmp10_;
				gboolean _tmp11_ = FALSE;
				Photo* _tmp12_;
#line 3282 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = iter;
#line 3282 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_iterator_next (_tmp3_);
#line 3282 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp4_) {
#line 3282 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 24440 "Photo.c"
				}
#line 3283 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = iter;
#line 3283 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = gee_iterator_get (_tmp5_);
#line 3283 "/home/jens/Source/shotwell/src/Photo.vala"
				cached_pixbuf = (PhotoCachedPixbuf*) _tmp6_;
#line 3285 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = cached_pixbuf;
#line 3285 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _tmp7_->last_touched;
#line 3285 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = g_timer_elapsed (_tmp8_, NULL);
#line 3285 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = trunc (_tmp9_);
#line 3285 "/home/jens/Source/shotwell/src/Photo.vala"
				elapsed = _tmp10_ + 1;
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = locate;
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp12_ != NULL) {
#line 24462 "Photo.c"
					PhotoCachedPixbuf* _tmp13_;
					Photo* _tmp14_;
					Photo* _tmp15_;
					gboolean _tmp16_;
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = cached_pixbuf;
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = _tmp13_->photo;
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = locate;
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = data_source_equals (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_DATA_SOURCE, DataSource), G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, TYPE_DATA_SOURCE, DataSource));
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = _tmp16_;
#line 24477 "Photo.c"
				} else {
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = FALSE;
#line 24481 "Photo.c"
				}
#line 3287 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp11_) {
#line 24485 "Photo.c"
					GeeIterator* _tmp17_;
					PhotoCachedPixbuf* _tmp18_;
					PhotoCachedPixbuf* _tmp19_;
					gint _tmp20_;
#line 3289 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = iter;
#line 3289 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_iterator_remove (_tmp17_);
#line 3290 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = cached_pixbuf;
#line 3290 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = _photo_cached_pixbuf_ref0 (_tmp18_);
#line 3290 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_cached_pixbuf_unref0 (found);
#line 3290 "/home/jens/Source/shotwell/src/Photo.vala"
					found = _tmp19_;
#line 3293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp20_ = count;
#line 3293 "/home/jens/Source/shotwell/src/Photo.vala"
					count = _tmp20_ + 1;
#line 24506 "Photo.c"
				} else {
					gdouble _tmp21_;
#line 3294 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp21_ = elapsed;
#line 3294 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp21_ >= ((gdouble) PHOTO_SOURCE_PIXBUF_TIME_TO_LIVE_SEC)) {
#line 24513 "Photo.c"
						GeeIterator* _tmp22_;
#line 3295 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp22_ = iter;
#line 3295 "/home/jens/Source/shotwell/src/Photo.vala"
						gee_iterator_remove (_tmp22_);
#line 24519 "Photo.c"
					} else {
						gint _tmp23_;
#line 3296 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp23_ = count;
#line 3296 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp23_ >= PHOTO_SOURCE_PIXBUF_MAX_LRU_COUNT) {
#line 24526 "Photo.c"
							GeeIterator* _tmp24_;
#line 3297 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp24_ = iter;
#line 3297 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_iterator_remove (_tmp24_);
#line 24532 "Photo.c"
						} else {
							gdouble _tmp25_;
							gdouble _tmp26_;
							gdouble _tmp27_;
							gint _tmp28_;
#line 3301 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp25_ = elapsed;
#line 3301 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp26_ = min_elapsed;
#line 3301 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp27_ = MIN (_tmp25_, _tmp26_);
#line 3301 "/home/jens/Source/shotwell/src/Photo.vala"
							min_elapsed = _tmp27_;
#line 3302 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp28_ = count;
#line 3302 "/home/jens/Source/shotwell/src/Photo.vala"
							count = _tmp28_ + 1;
#line 24550 "Photo.c"
						}
					}
				}
#line 3282 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_cached_pixbuf_unref0 (cached_pixbuf);
#line 24556 "Photo.c"
			}
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp31_ = found;
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp31_ == NULL) {
#line 24562 "Photo.c"
				Photo* _tmp32_;
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = locate;
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = _tmp32_ != NULL;
#line 24568 "Photo.c"
			} else {
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = FALSE;
#line 24572 "Photo.c"
			}
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp30_) {
#line 24576 "Photo.c"
				gboolean _tmp33_;
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = keep;
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = _tmp33_;
#line 24582 "Photo.c"
			} else {
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = FALSE;
#line 24586 "Photo.c"
			}
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp29_) {
#line 24590 "Photo.c"
				GdkPixbuf* _tmp34_ = NULL;
				Photo* _tmp35_;
				Scaling _tmp36_ = {0};
				GdkPixbuf* _tmp37_;
				Photo* _tmp38_;
				PhotoCachedPixbuf* _tmp39_;
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = locate;
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
				scaling_for_original (&_tmp36_);
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = photo_load_raw_pixbuf (_tmp35_, &_tmp36_, PHOTO_EXCEPTION_ALL, BACKING_FETCH_MODE_SOURCE, &_inner_error_);
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = _tmp37_;
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (iter);
#line 3309 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_cached_pixbuf_unref0 (found);
#line 24611 "Photo.c"
					goto __finally394;
				}
#line 3308 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = locate;
#line 3308 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = photo_cached_pixbuf_new (_tmp38_, _tmp34_);
#line 3308 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_cached_pixbuf_unref0 (found);
#line 3308 "/home/jens/Source/shotwell/src/Photo.vala"
				found = _tmp39_;
#line 3307 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp34_);
#line 24624 "Photo.c"
			} else {
				PhotoCachedPixbuf* _tmp40_;
#line 3310 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = found;
#line 3310 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp40_ != NULL) {
#line 24631 "Photo.c"
					PhotoCachedPixbuf* _tmp41_;
					GTimer* _tmp42_;
#line 3312 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp41_ = found;
#line 3312 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp42_ = _tmp41_->last_touched;
#line 3312 "/home/jens/Source/shotwell/src/Photo.vala"
					g_timer_start (_tmp42_);
#line 24640 "Photo.c"
				}
			}
#line 3316 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp44_ = found;
#line 3316 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp44_ != NULL) {
#line 24647 "Photo.c"
				gboolean _tmp45_;
#line 3316 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = keep;
#line 3316 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = _tmp45_;
#line 24653 "Photo.c"
			} else {
#line 3316 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = FALSE;
#line 24657 "Photo.c"
			}
#line 3316 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp43_) {
#line 24661 "Photo.c"
				GeeLinkedList* _tmp46_;
				PhotoCachedPixbuf* _tmp47_;
				PhotoCachedPixbuf* _tmp48_;
				GTimer* _tmp49_;
				gdouble _tmp50_;
				gdouble _tmp51_;
				gdouble _tmp52_;
#line 3317 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = photo_source_pixbuf_cache;
#line 3317 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = found;
#line 3317 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_list_insert (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), 0, _tmp47_);
#line 3322 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = found;
#line 3322 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp49_ = _tmp48_->last_touched;
#line 3322 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp50_ = g_timer_elapsed (_tmp49_, NULL);
#line 3322 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp51_ = min_elapsed;
#line 3322 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp52_ = MIN (_tmp50_, _tmp51_);
#line 3322 "/home/jens/Source/shotwell/src/Photo.vala"
				min_elapsed = _tmp52_;
#line 3326 "/home/jens/Source/shotwell/src/Photo.vala"
				while (TRUE) {
#line 24689 "Photo.c"
					GeeLinkedList* _tmp53_;
					gint _tmp54_;
					gint _tmp55_;
					GeeLinkedList* _tmp56_;
					gpointer _tmp57_;
					PhotoCachedPixbuf* _tmp58_;
#line 3326 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp53_ = photo_source_pixbuf_cache;
#line 3326 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp54_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 3326 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp55_ = _tmp54_;
#line 3326 "/home/jens/Source/shotwell/src/Photo.vala"
					if (!(_tmp55_ > PHOTO_SOURCE_PIXBUF_MAX_LRU_COUNT)) {
#line 3326 "/home/jens/Source/shotwell/src/Photo.vala"
						break;
#line 24706 "Photo.c"
					}
#line 3327 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp56_ = photo_source_pixbuf_cache;
#line 3327 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp57_ = gee_deque_poll_tail (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, GEE_TYPE_DEQUE, GeeDeque));
#line 3327 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp58_ = (PhotoCachedPixbuf*) _tmp57_;
#line 3327 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_cached_pixbuf_unref0 (_tmp58_);
#line 24716 "Photo.c"
				}
			}
#line 3331 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp59_ = photo_discard_source_id;
#line 3331 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp59_ != ((guint) 0)) {
#line 24723 "Photo.c"
				guint _tmp60_;
#line 3332 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp60_ = photo_discard_source_id;
#line 3332 "/home/jens/Source/shotwell/src/Photo.vala"
				g_source_remove (_tmp60_);
#line 3333 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_discard_source_id = (guint) 0;
#line 24731 "Photo.c"
			}
#line 3337 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp61_ = photo_source_pixbuf_cache;
#line 3337 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp62_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 3337 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp63_ = _tmp62_;
#line 3337 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp63_ > PHOTO_SOURCE_PIXBUF_MIN_LRU_COUNT) {
#line 24741 "Photo.c"
				gdouble _tmp64_;
				guint retry_sec = 0U;
				gdouble _tmp65_;
				gdouble _tmp66_;
				guint _tmp67_;
				guint _tmp68_;
#line 3338 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp64_ = min_elapsed;
#line 3338 "/home/jens/Source/shotwell/src/Photo.vala"
				_vala_assert (_tmp64_ >= 0.0, "min_elapsed >= 0.0");
#line 3341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp65_ = min_elapsed;
#line 3341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp66_ = trunc (_tmp65_);
#line 3341 "/home/jens/Source/shotwell/src/Photo.vala"
				retry_sec = PHOTO_SOURCE_PIXBUF_TIME_TO_LIVE_SEC - ((guint) _tmp66_);
#line 3342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp67_ = retry_sec;
#line 3342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp68_ = g_timeout_add_seconds_full (G_PRIORITY_LOW, _tmp67_, _photo_trim_source_pixbuf_cache_gsource_func, NULL, NULL);
#line 3342 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_discard_source_id = _tmp68_;
#line 24764 "Photo.c"
			}
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp70_ = found;
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp70_ != NULL) {
#line 24770 "Photo.c"
				PhotoCachedPixbuf* _tmp71_;
				GdkPixbuf* _tmp72_;
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp71_ = found;
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp72_ = _tmp71_->pixbuf;
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp69_ = _tmp72_;
#line 24779 "Photo.c"
			} else {
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp69_ = NULL;
#line 24783 "Photo.c"
			}
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp73_ = _g_object_ref0 (_tmp69_);
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp73_;
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (iter);
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_cached_pixbuf_unref0 (found);
#line 24793 "Photo.c"
			{
				GeeLinkedList* _tmp74_;
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp74_ = photo_source_pixbuf_cache;
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&__lock_photo_source_pixbuf_cache);
#line 24800 "Photo.c"
			}
#line 3345 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 24804 "Photo.c"
		}
		__finally394:
		{
			GeeLinkedList* _tmp75_;
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp75_ = photo_source_pixbuf_cache;
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&__lock_photo_source_pixbuf_cache);
#line 24813 "Photo.c"
		}
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3274 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24819 "Photo.c"
	}
}


static gboolean photo_trim_source_pixbuf_cache (void) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
	{
		GdkPixbuf* _tmp0_;
		GdkPixbuf* _tmp1_;
#line 3351 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = photo_run_source_pixbuf_cache (NULL, FALSE, &_inner_error_);
#line 3351 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp0_;
#line 3351 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp1_);
#line 3351 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 24838 "Photo.c"
			goto __catch395_g_error;
		}
	}
	goto __finally395;
	__catch395_g_error:
	{
		GError* err = NULL;
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 24852 "Photo.c"
	}
	__finally395:
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 24857 "Photo.c"
		gboolean _tmp2_ = FALSE;
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 3350 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp2_;
#line 24865 "Photo.c"
	}
#line 3355 "/home/jens/Source/shotwell/src/Photo.vala"
	result = FALSE;
#line 3355 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24871 "Photo.c"
}


/**
     * @brief Get a copy of what's in the cache.
     *
     * @return A copy of the Pixbuf with the image data from unmodified_precached.
     */
GdkPixbuf* photo_get_prefetched_copy (Photo* self, GError** error) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_;
	GdkPixbuf* _tmp2_;
	GError * _inner_error_ = NULL;
#line 3363 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_run_source_pixbuf_cache (self, TRUE, &_inner_error_);
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp1_;
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 24898 "Photo.c"
	}
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gdk_pixbuf_copy (_tmp0_);
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp2_;
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp0_);
#line 3364 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 24908 "Photo.c"
}


/**
     * @brief Discards the cached version of the unmodified image.
     */
void photo_discard_prefetched (Photo* self) {
	GError * _inner_error_ = NULL;
#line 3370 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 24919 "Photo.c"
	{
		GdkPixbuf* _tmp0_;
		GdkPixbuf* _tmp1_;
#line 3372 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = photo_run_source_pixbuf_cache (self, FALSE, &_inner_error_);
#line 3372 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp0_;
#line 3372 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp1_);
#line 3372 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 24931 "Photo.c"
			goto __catch396_g_error;
		}
	}
	goto __finally396;
	__catch396_g_error:
	{
		GError* err = NULL;
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 24945 "Photo.c"
	}
	__finally396:
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 3371 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 24956 "Photo.c"
	}
}


/**
     * @brief Returns a fully transformed and scaled pixbuf.  Transformations may be excluded via
     * the mask. If the image is smaller than the scaling, it will be returned in its actual size.
     * The caller is responsible for scaling thereafter.
     *
     * @param scaling A scaling object that describes the size the output pixbuf should be.
     * @param exceptions The parts of the pipeline that should be skipped; defaults to NONE if
     *      left unset.
     * @param fetch_mode The fetch mode; if left unset, defaults to BASELINE so that
     *      we get the image exactly as it is in the file.
     */
GdkPixbuf* photo_get_pixbuf_with_options (Photo* self, Scaling* scaling, PhotoException exceptions, BackingFetchMode fetch_mode, GError** error) {
	GdkPixbuf* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean is_scaled = FALSE;
	gboolean is_cropped = FALSE;
	gboolean is_straightened = FALSE;
	Dimensions scaled_to_viewport = {0};
	Dimensions original = {0};
	Dimensions scaled = {0};
	EditingToolsRedeyeInstance* redeye_instances = NULL;
	gint redeye_instances_length1;
	gint _redeye_instances_size_;
	Box crop = {0};
	gdouble straightening_angle = 0.0;
	PixelTransformer* transformer = NULL;
	Orientation orientation = 0;
	GdkPixbuf* pixbuf = NULL;
	GdkPixbuf* _tmp33_;
	PhotoException _tmp34_;
	gboolean _tmp35_;
	PhotoException _tmp40_;
	gboolean _tmp41_;
	PhotoException _tmp46_;
	gboolean _tmp47_;
	PhotoException _tmp85_;
	gboolean _tmp86_;
	gboolean _tmp89_;
	PhotoException _tmp96_;
	gboolean _tmp97_;
	gboolean _tmp101_ = FALSE;
	gboolean _tmp102_;
	GError * _inner_error_ = NULL;
#line 3388 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3388 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_get_develop_raw_photos_to_files ();
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp4_) {
#line 25018 "Photo.c"
		PhotoFileFormat _tmp5_;
#line 3402 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = photo_get_master_file_format (self);
#line 3402 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp5_ == PHOTO_FILE_FORMAT_RAW;
#line 25024 "Photo.c"
	} else {
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = FALSE;
#line 25028 "Photo.c"
	}
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 25032 "Photo.c"
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
		BackingFetchMode _tmp8_;
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = fetch_mode;
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp8_ == BACKING_FETCH_MODE_BASELINE) {
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = TRUE;
#line 25042 "Photo.c"
		} else {
			BackingFetchMode _tmp9_;
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = fetch_mode;
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _tmp9_ == BACKING_FETCH_MODE_UNMODIFIED;
#line 25049 "Photo.c"
		}
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp7_) {
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = TRUE;
#line 25055 "Photo.c"
		} else {
			BackingFetchMode _tmp10_;
#line 3404 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = fetch_mode;
#line 3404 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tmp10_ == BACKING_FETCH_MODE_SOURCE;
#line 25062 "Photo.c"
		}
#line 3403 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp6_;
#line 25066 "Photo.c"
	} else {
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = FALSE;
#line 25070 "Photo.c"
	}
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 25074 "Photo.c"
		RawDeveloper _tmp11_;
		gboolean _tmp12_;
#line 3405 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = photo_get_raw_developer (self);
#line 3405 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = photo_is_raw_developer_complete (self, _tmp11_);
#line 3405 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = !_tmp12_;
#line 25083 "Photo.c"
	} else {
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = FALSE;
#line 25087 "Photo.c"
	}
#line 3401 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_) {
#line 25091 "Photo.c"
		RawDeveloper _tmp13_;
#line 3406 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = photo_get_raw_developer (self);
#line 3406 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_set_raw_developer (self, _tmp13_, TRUE);
#line 25097 "Photo.c"
	}
#line 3411 "/home/jens/Source/shotwell/src/Photo.vala"
	dimensions_init (&original, 0, 0);
#line 3412 "/home/jens/Source/shotwell/src/Photo.vala"
	dimensions_init (&scaled, 0, 0);
#line 3413 "/home/jens/Source/shotwell/src/Photo.vala"
	redeye_instances = NULL;
#line 3413 "/home/jens/Source/shotwell/src/Photo.vala"
	redeye_instances_length1 = 0;
#line 3413 "/home/jens/Source/shotwell/src/Photo.vala"
	_redeye_instances_size_ = redeye_instances_length1;
#line 3416 "/home/jens/Source/shotwell/src/Photo.vala"
	transformer = NULL;
#line 25111 "Photo.c"
	{
		PhotoRow* _tmp14_;
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = self->row;
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 25118 "Photo.c"
		{
			Dimensions _tmp15_ = {0};
			PhotoException _tmp16_;
			Dimensions _tmp17_ = {0};
			Dimensions _tmp18_ = {0};
			Dimensions _tmp19_;
			Dimensions _tmp20_ = {0};
			Dimensions _tmp21_;
			gboolean _tmp22_;
			gint _tmp23_;
			EditingToolsRedeyeInstance* _tmp24_;
			Box _tmp25_ = {0};
			gboolean _tmp26_;
			gdouble _tmp27_ = 0.0;
			gboolean _tmp28_;
			gboolean _tmp29_;
			Orientation _tmp31_;
#line 3420 "/home/jens/Source/shotwell/src/Photo.vala"
			media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_ALL, &_tmp15_);
#line 3420 "/home/jens/Source/shotwell/src/Photo.vala"
			original = _tmp15_;
#line 3421 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = exceptions;
#line 3421 "/home/jens/Source/shotwell/src/Photo.vala"
			media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), _tmp16_, &_tmp17_);
#line 3421 "/home/jens/Source/shotwell/src/Photo.vala"
			scaling_get_scaled_dimensions (scaling, &_tmp17_, &_tmp18_);
#line 3421 "/home/jens/Source/shotwell/src/Photo.vala"
			scaled = _tmp18_;
#line 3422 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = scaled;
#line 3422 "/home/jens/Source/shotwell/src/Photo.vala"
			scaled_to_viewport = _tmp19_;
#line 3424 "/home/jens/Source/shotwell/src/Photo.vala"
			media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_NONE, &_tmp20_);
#line 3424 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = scaled;
#line 3424 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = dimensions_equals (&_tmp20_, &_tmp21_);
#line 3424 "/home/jens/Source/shotwell/src/Photo.vala"
			is_scaled = !_tmp22_;
#line 3426 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = photo_get_raw_redeye_instances (self, &_tmp23_);
#line 3426 "/home/jens/Source/shotwell/src/Photo.vala"
			redeye_instances = (g_free (redeye_instances), NULL);
#line 3426 "/home/jens/Source/shotwell/src/Photo.vala"
			redeye_instances = _tmp24_;
#line 3426 "/home/jens/Source/shotwell/src/Photo.vala"
			redeye_instances_length1 = _tmp23_;
#line 3426 "/home/jens/Source/shotwell/src/Photo.vala"
			_redeye_instances_size_ = redeye_instances_length1;
#line 3428 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = photo_get_raw_crop (self, &_tmp25_);
#line 3428 "/home/jens/Source/shotwell/src/Photo.vala"
			crop = _tmp25_;
#line 3428 "/home/jens/Source/shotwell/src/Photo.vala"
			is_cropped = _tmp26_;
#line 3430 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp28_ = photo_get_raw_straighten (self, &_tmp27_);
#line 3430 "/home/jens/Source/shotwell/src/Photo.vala"
			straightening_angle = _tmp27_;
#line 3430 "/home/jens/Source/shotwell/src/Photo.vala"
			is_straightened = _tmp28_;
#line 3432 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp29_ = photo_has_color_adjustments (self);
#line 3432 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp29_) {
#line 25186 "Photo.c"
				PixelTransformer* _tmp30_;
#line 3433 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = photo_get_pixel_transformer (self);
#line 3433 "/home/jens/Source/shotwell/src/Photo.vala"
				_pixel_transformer_unref0 (transformer);
#line 3433 "/home/jens/Source/shotwell/src/Photo.vala"
				transformer = _tmp30_;
#line 25194 "Photo.c"
			}
#line 3435 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp31_ = photo_get_orientation (self);
#line 3435 "/home/jens/Source/shotwell/src/Photo.vala"
			orientation = _tmp31_;
#line 25200 "Photo.c"
		}
		__finally397:
		{
			PhotoRow* _tmp32_;
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp32_ = self->row;
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 25209 "Photo.c"
		}
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformer_unref0 (transformer);
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
			redeye_instances = (g_free (redeye_instances), NULL);
#line 3419 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 25221 "Photo.c"
		}
	}
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = photo_get_prefetched_copy (self, &_inner_error_);
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
	pixbuf = _tmp33_;
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_transformer_unref0 (transformer);
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
		redeye_instances = (g_free (redeye_instances), NULL);
#line 3442 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 25238 "Photo.c"
	}
#line 3449 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = exceptions;
#line 3449 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = photo_exception_allows (_tmp34_, PHOTO_EXCEPTION_REDEYE);
#line 3449 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp35_) {
#line 25246 "Photo.c"
		EditingToolsRedeyeInstance* _tmp36_;
		gint _tmp36__length1;
#line 3454 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = redeye_instances;
#line 3454 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36__length1 = redeye_instances_length1;
#line 25253 "Photo.c"
		{
			EditingToolsRedeyeInstance* instance_collection = NULL;
			gint instance_collection_length1 = 0;
			gint _instance_collection_size_ = 0;
			gint instance_it = 0;
#line 3454 "/home/jens/Source/shotwell/src/Photo.vala"
			instance_collection = _tmp36_;
#line 3454 "/home/jens/Source/shotwell/src/Photo.vala"
			instance_collection_length1 = _tmp36__length1;
#line 3454 "/home/jens/Source/shotwell/src/Photo.vala"
			for (instance_it = 0; instance_it < _tmp36__length1; instance_it = instance_it + 1) {
#line 25265 "Photo.c"
				EditingToolsRedeyeInstance instance = {0};
#line 3454 "/home/jens/Source/shotwell/src/Photo.vala"
				instance = instance_collection[instance_it];
#line 25269 "Photo.c"
				{
					GdkPixbuf* _tmp37_;
					EditingToolsRedeyeInstance _tmp38_;
					GdkPixbuf* _tmp39_;
#line 3455 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp37_ = pixbuf;
#line 3455 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp38_ = instance;
#line 3455 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp39_ = photo_do_redeye (self, _tmp37_, &_tmp38_);
#line 3455 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (pixbuf);
#line 3455 "/home/jens/Source/shotwell/src/Photo.vala"
					pixbuf = _tmp39_;
#line 25284 "Photo.c"
				}
			}
		}
	}
#line 3463 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = exceptions;
#line 3463 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = photo_exception_allows (_tmp40_, PHOTO_EXCEPTION_STRAIGHTEN);
#line 3463 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp41_) {
#line 25295 "Photo.c"
		gboolean _tmp42_;
#line 3467 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = is_straightened;
#line 3467 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp42_) {
#line 25301 "Photo.c"
			GdkPixbuf* _tmp43_;
			gdouble _tmp44_;
			GdkPixbuf* _tmp45_;
#line 3468 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp43_ = pixbuf;
#line 3468 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp44_ = straightening_angle;
#line 3468 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp45_ = rotate_arb (_tmp43_, _tmp44_);
#line 3468 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (pixbuf);
#line 3468 "/home/jens/Source/shotwell/src/Photo.vala"
			pixbuf = _tmp45_;
#line 25315 "Photo.c"
		}
	}
#line 3477 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp46_ = exceptions;
#line 3477 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = photo_exception_allows (_tmp46_, PHOTO_EXCEPTION_CROP);
#line 3477 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp47_) {
#line 25324 "Photo.c"
		gboolean _tmp48_;
#line 3481 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = is_cropped;
#line 3481 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp48_) {
#line 25330 "Photo.c"
			Box _tmp49_;
			gint _tmp50_;
			GdkPixbuf* _tmp51_;
			gint _tmp52_;
			gint _tmp53_;
			gint _tmp54_;
			Box _tmp55_;
			gint _tmp56_;
			GdkPixbuf* _tmp57_;
			gint _tmp58_;
			gint _tmp59_;
			gint _tmp60_;
			Box _tmp61_;
			gint _tmp62_;
			Box _tmp63_;
			gint _tmp64_;
			GdkPixbuf* _tmp65_;
			gint _tmp66_;
			gint _tmp67_;
			gint _tmp68_;
			Box _tmp69_;
			gint _tmp70_;
			Box _tmp71_;
			gint _tmp72_;
			GdkPixbuf* _tmp73_;
			gint _tmp74_;
			gint _tmp75_;
			gint _tmp76_;
			GdkPixbuf* _tmp77_;
			Box _tmp78_;
			gint _tmp79_;
			Box _tmp80_;
			gint _tmp81_;
			gint _tmp82_;
			gint _tmp83_;
			GdkPixbuf* _tmp84_;
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp49_ = crop;
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp50_ = _tmp49_.left;
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp51_ = pixbuf;
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp52_ = gdk_pixbuf_get_width (_tmp51_);
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp53_ = _tmp52_;
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp54_ = CLAMP (_tmp50_, 0, _tmp53_ - 2);
#line 3486 "/home/jens/Source/shotwell/src/Photo.vala"
			crop.left = _tmp54_;
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp55_ = crop;
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp56_ = _tmp55_.top;
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp57_ = pixbuf;
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp58_ = gdk_pixbuf_get_height (_tmp57_);
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp59_ = _tmp58_;
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp60_ = CLAMP (_tmp56_, 0, _tmp59_ - 2);
#line 3487 "/home/jens/Source/shotwell/src/Photo.vala"
			crop.top = _tmp60_;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp61_ = crop;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp62_ = _tmp61_.right;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp63_ = crop;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp64_ = _tmp63_.left;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp65_ = pixbuf;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp66_ = gdk_pixbuf_get_width (_tmp65_);
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp67_ = _tmp66_;
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp68_ = CLAMP (_tmp62_, _tmp64_ + 1, _tmp67_ - 1);
#line 3489 "/home/jens/Source/shotwell/src/Photo.vala"
			crop.right = _tmp68_;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp69_ = crop;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp70_ = _tmp69_.bottom;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp71_ = crop;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp72_ = _tmp71_.top;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp73_ = pixbuf;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp74_ = gdk_pixbuf_get_height (_tmp73_);
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp75_ = _tmp74_;
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp76_ = CLAMP (_tmp70_, _tmp72_ + 1, _tmp75_ - 1);
#line 3490 "/home/jens/Source/shotwell/src/Photo.vala"
			crop.bottom = _tmp76_;
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp77_ = pixbuf;
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp78_ = crop;
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp79_ = _tmp78_.left;
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp80_ = crop;
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp81_ = _tmp80_.top;
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp82_ = box_get_width (&crop);
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp83_ = box_get_height (&crop);
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp84_ = gdk_pixbuf_new_subpixbuf (_tmp77_, _tmp79_, _tmp81_, _tmp82_, _tmp83_);
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (pixbuf);
#line 3492 "/home/jens/Source/shotwell/src/Photo.vala"
			pixbuf = _tmp84_;
#line 25451 "Photo.c"
		}
	}
#line 3502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp85_ = exceptions;
#line 3502 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp86_ = photo_exception_allows (_tmp85_, PHOTO_EXCEPTION_ORIENTATION);
#line 3502 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp86_) {
#line 25460 "Photo.c"
		GdkPixbuf* _tmp87_;
		GdkPixbuf* _tmp88_;
#line 3506 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp87_ = pixbuf;
#line 3506 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp88_ = orientation_rotate_pixbuf (orientation, _tmp87_);
#line 3506 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3506 "/home/jens/Source/shotwell/src/Photo.vala"
		pixbuf = _tmp88_;
#line 25471 "Photo.c"
	}
#line 3513 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp89_ = is_scaled;
#line 3513 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp89_) {
#line 25477 "Photo.c"
		GdkPixbuf* _tmp90_;
		Dimensions _tmp91_;
		gint _tmp92_;
		Dimensions _tmp93_;
		gint _tmp94_;
		GdkPixbuf* _tmp95_;
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp90_ = pixbuf;
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp91_ = scaled_to_viewport;
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp92_ = _tmp91_.width;
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp93_ = scaled_to_viewport;
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp94_ = _tmp93_.height;
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp95_ = gdk_pixbuf_scale_simple (_tmp90_, _tmp92_, _tmp94_, GDK_INTERP_BILINEAR);
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3517 "/home/jens/Source/shotwell/src/Photo.vala"
		pixbuf = _tmp95_;
#line 25500 "Photo.c"
	}
#line 3525 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp96_ = exceptions;
#line 3525 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp97_ = photo_exception_allows (_tmp96_, PHOTO_EXCEPTION_ADJUST);
#line 3525 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp97_) {
#line 25508 "Photo.c"
		PixelTransformer* _tmp98_;
#line 3529 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp98_ = transformer;
#line 3529 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp98_ != NULL) {
#line 25514 "Photo.c"
			PixelTransformer* _tmp99_;
			GdkPixbuf* _tmp100_;
#line 3530 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp99_ = transformer;
#line 3530 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp100_ = pixbuf;
#line 3530 "/home/jens/Source/shotwell/src/Photo.vala"
			pixel_transformer_transform_pixbuf (_tmp99_, _tmp100_, NULL);
#line 25523 "Photo.c"
		}
	}
#line 3539 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp102_ = is_scaled;
#line 3539 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp102_) {
#line 25530 "Photo.c"
		gboolean _tmp103_;
#line 3539 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp103_ = is_straightened;
#line 3539 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp101_ = !_tmp103_;
#line 25536 "Photo.c"
	} else {
#line 3539 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp101_ = FALSE;
#line 25540 "Photo.c"
	}
#line 3539 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp101_) {
#line 25544 "Photo.c"
		GdkPixbuf* _tmp104_;
		Dimensions _tmp105_ = {0};
		gboolean _tmp106_;
#line 3540 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp104_ = pixbuf;
#line 3540 "/home/jens/Source/shotwell/src/Photo.vala"
		dimensions_for_pixbuf (_tmp104_, &_tmp105_);
#line 3540 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp106_ = dimensions_approx_equals (&scaled_to_viewport, &_tmp105_, PHOTO_SCALING_FUDGE);
#line 3540 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_assert (_tmp106_, "scaled_to_viewport.approx_equals(Dimensions.for_pixbuf(pixbuf), SCALING_FUDGE)");
#line 25556 "Photo.c"
	}
#line 3548 "/home/jens/Source/shotwell/src/Photo.vala"
	result = pixbuf;
#line 3548 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformer_unref0 (transformer);
#line 3548 "/home/jens/Source/shotwell/src/Photo.vala"
	redeye_instances = (g_free (redeye_instances), NULL);
#line 3548 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 25566 "Photo.c"
}


static gboolean photo_real_has_user_generated_metadata (Photo* self) {
	gboolean _tmp0_ = FALSE;
#line 3556 "/home/jens/Source/shotwell/src/Photo.vala"
	g_critical ("Type `%s' does not implement abstract method `photo_has_user_generated_metadata'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 3556 "/home/jens/Source/shotwell/src/Photo.vala"
	return _tmp0_;
#line 25576 "Photo.c"
}


gboolean photo_has_user_generated_metadata (Photo* self) {
#line 3556 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 3556 "/home/jens/Source/shotwell/src/Photo.vala"
	return PHOTO_GET_CLASS (self)->has_user_generated_metadata (self);
#line 25585 "Photo.c"
}


static void photo_real_set_user_metadata_for_export (Photo* self, PhotoMetadata* metadata) {
#line 3560 "/home/jens/Source/shotwell/src/Photo.vala"
	g_critical ("Type `%s' does not implement abstract method `photo_set_user_metadata_for_export'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 3560 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 25594 "Photo.c"
}


void photo_set_user_metadata_for_export (Photo* self, PhotoMetadata* metadata) {
#line 3560 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3560 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_GET_CLASS (self)->set_user_metadata_for_export (self, metadata);
#line 25603 "Photo.c"
}


gchar* photo_get_export_basename (Photo* self, PhotoFileFormat* file_format) {
	gchar* result = NULL;
	PhotoFileFormat* _tmp0_;
#line 3567 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 3568 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file_format;
#line 3568 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != NULL) {
#line 25616 "Photo.c"
		PhotoFileFormat* _tmp1_;
		PhotoFileFormatProperties* _tmp2_;
		PhotoFileFormatProperties* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = file_format;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = photo_file_format_get_properties (*_tmp1_);
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = photo_file_format_properties_convert_file_extension (_tmp3_, _tmp5_);
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = g_file_get_basename (_tmp7_);
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = _tmp8_;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp7_);
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp5_);
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (_tmp3_);
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp9_;
#line 3569 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 25654 "Photo.c"
	} else {
		PhotoFileFormat _tmp10_;
		gboolean _tmp11_;
#line 3571 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = photo_get_file_format (self);
#line 3571 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = photo_file_format_can_write (_tmp10_);
#line 3571 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp11_) {
#line 25664 "Photo.c"
			PhotoFileFormat _tmp12_;
			PhotoFileFormatProperties* _tmp13_;
			PhotoFileFormatProperties* _tmp14_;
			GFile* _tmp15_;
			GFile* _tmp16_;
			GFile* _tmp17_;
			GFile* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = photo_get_file_format (self);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = photo_file_format_get_properties (_tmp12_);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = _tmp13_;
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = _tmp15_;
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = photo_file_format_properties_convert_file_extension (_tmp14_, _tmp16_);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = _tmp17_;
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = g_file_get_basename (_tmp18_);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = _tmp19_;
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp18_);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp16_);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_format_properties_unref0 (_tmp14_);
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp20_;
#line 3572 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 25702 "Photo.c"
		} else {
			PhotoFileFormat _tmp21_;
			PhotoFileFormatProperties* _tmp22_;
			PhotoFileFormatProperties* _tmp23_;
			GFile* _tmp24_;
			GFile* _tmp25_;
			GFile* _tmp26_;
			GFile* _tmp27_;
			gchar* _tmp28_;
			gchar* _tmp29_;
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = photo_file_format_get_system_default_format ();
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = photo_file_format_get_properties (_tmp21_);
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_ = _tmp22_;
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp25_ = _tmp24_;
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = photo_file_format_properties_convert_file_extension (_tmp23_, _tmp25_);
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = _tmp26_;
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp28_ = g_file_get_basename (_tmp27_);
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp29_ = _tmp28_;
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp27_);
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp25_);
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_format_properties_unref0 (_tmp23_);
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			result = _tmp29_;
#line 3575 "/home/jens/Source/shotwell/src/Photo.vala"
			return result;
#line 25741 "Photo.c"
		}
	}
}


static gboolean photo_export_fullsized_backing (Photo* self, GFile* file, gboolean export_metadata, GError** error) {
	gboolean result = FALSE;
	PhotoFileReader* export_reader = NULL;
	gboolean is_master = FALSE;
	PhotoFileReader* _tmp30_;
	PhotoFileFormatProperties* format_properties = NULL;
	PhotoFileReader* _tmp31_;
	PhotoFileFormat _tmp32_;
	PhotoFileFormatProperties* _tmp33_;
	GFile* dest_file = NULL;
	PhotoFileFormatProperties* _tmp34_;
	GFile* _tmp35_;
	GFile* _tmp36_;
	PhotoFileMetadataWriter* writer = NULL;
	PhotoFileReader* _tmp37_;
	PhotoFileFormat _tmp38_;
	GFile* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	PhotoFileMetadataWriter* _tmp42_;
	PhotoFileMetadataWriter* _tmp43_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	PhotoFileMetadataWriter* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	PhotoFileReader* _tmp50_;
	GFile* _tmp51_;
	GFile* _tmp52_;
	GFile* _tmp53_;
	gboolean _tmp55_ = FALSE;
	gboolean _tmp56_ = FALSE;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp58_ = FALSE;
	gboolean _tmp59_ = FALSE;
	gboolean _tmp60_;
	PhotoMetadata* metadata = NULL;
	PhotoFileReader* _tmp68_;
	PhotoMetadata* _tmp69_;
	PhotoMetadata* _tmp71_;
	PhotoFileMetadataWriter* _tmp75_;
	gchar* _tmp76_;
	gchar* _tmp77_;
	time_t _tmp78_;
	gboolean _tmp84_;
	PhotoFileMetadataWriter* _tmp101_;
	PhotoMetadata* _tmp102_;
	GError * _inner_error_ = NULL;
#line 3581 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 3581 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 3584 "/home/jens/Source/shotwell/src/Photo.vala"
	export_reader = NULL;
#line 3585 "/home/jens/Source/shotwell/src/Photo.vala"
	is_master = TRUE;
#line 25803 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 25810 "Photo.c"
		{
			gboolean _tmp1_ = FALSE;
			PhotoBackingReaders* _tmp2_;
			PhotoFileReader* _tmp3_;
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = self->priv->readers;
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _tmp2_->editable;
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp3_ != NULL) {
#line 25821 "Photo.c"
				PhotoBackingReaders* _tmp4_;
				PhotoFileReader* _tmp5_;
				PhotoFileFormat _tmp6_;
				gboolean _tmp7_;
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = self->priv->readers;
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _tmp4_->editable;
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = photo_file_format_can_write_metadata (_tmp6_);
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = _tmp7_;
#line 25836 "Photo.c"
			} else {
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp1_ = FALSE;
#line 25840 "Photo.c"
			}
#line 3587 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp1_) {
#line 25844 "Photo.c"
				PhotoBackingReaders* _tmp8_;
				PhotoFileReader* _tmp9_;
				PhotoFileReader* _tmp10_;
#line 3588 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = self->priv->readers;
#line 3588 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tmp8_->editable;
#line 3588 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _photo_file_adapter_ref0 (_tmp9_);
#line 3588 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (export_reader);
#line 3588 "/home/jens/Source/shotwell/src/Photo.vala"
				export_reader = _tmp10_;
#line 3589 "/home/jens/Source/shotwell/src/Photo.vala"
				is_master = FALSE;
#line 25860 "Photo.c"
			} else {
				gboolean _tmp11_ = FALSE;
				PhotoBackingReaders* _tmp12_;
				PhotoFileReader* _tmp13_;
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = self->priv->readers;
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _tmp12_->developer;
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp13_ != NULL) {
#line 25871 "Photo.c"
					PhotoBackingReaders* _tmp14_;
					PhotoFileReader* _tmp15_;
					PhotoFileFormat _tmp16_;
					gboolean _tmp17_;
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = self->priv->readers;
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = _tmp14_->developer;
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = photo_file_format_can_write_metadata (_tmp16_);
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = _tmp17_;
#line 25886 "Photo.c"
				} else {
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = FALSE;
#line 25890 "Photo.c"
				}
#line 3590 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp11_) {
#line 25894 "Photo.c"
					PhotoBackingReaders* _tmp18_;
					PhotoFileReader* _tmp19_;
					PhotoFileReader* _tmp20_;
#line 3591 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = self->priv->readers;
#line 3591 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = _tmp18_->developer;
#line 3591 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp20_ = _photo_file_adapter_ref0 (_tmp19_);
#line 3591 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (export_reader);
#line 3591 "/home/jens/Source/shotwell/src/Photo.vala"
					export_reader = _tmp20_;
#line 3592 "/home/jens/Source/shotwell/src/Photo.vala"
					is_master = FALSE;
#line 25910 "Photo.c"
				} else {
					PhotoBackingReaders* _tmp21_;
					PhotoFileReader* _tmp22_;
					PhotoFileFormat _tmp23_;
					gboolean _tmp24_;
#line 3593 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp21_ = self->priv->readers;
#line 3593 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp22_ = _tmp21_->master;
#line 3593 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp23_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3593 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp24_ = photo_file_format_can_write_metadata (_tmp23_);
#line 3593 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp24_) {
#line 25926 "Photo.c"
						PhotoBackingReaders* _tmp25_;
						PhotoFileReader* _tmp26_;
						PhotoFileReader* _tmp27_;
#line 3594 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp25_ = self->priv->readers;
#line 3594 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp26_ = _tmp25_->master;
#line 3594 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp27_ = _photo_file_adapter_ref0 (_tmp26_);
#line 3594 "/home/jens/Source/shotwell/src/Photo.vala"
						_photo_file_adapter_unref0 (export_reader);
#line 3594 "/home/jens/Source/shotwell/src/Photo.vala"
						export_reader = _tmp27_;
#line 25940 "Photo.c"
					}
				}
			}
		}
		__finally398:
		{
			PhotoBackingReaders* _tmp28_;
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp28_ = self->priv->readers;
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 25952 "Photo.c"
		}
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 25956 "Photo.c"
			gboolean _tmp29_ = FALSE;
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (export_reader);
#line 3586 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp29_;
#line 25964 "Photo.c"
		}
	}
#line 3598 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = export_reader;
#line 3598 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp30_ == NULL) {
#line 3599 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 3599 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (export_reader);
#line 3599 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 25977 "Photo.c"
	}
#line 3601 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = export_reader;
#line 3601 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3601 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = photo_file_format_get_properties (_tmp32_);
#line 3601 "/home/jens/Source/shotwell/src/Photo.vala"
	format_properties = _tmp33_;
#line 3604 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = format_properties;
#line 3604 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = file;
#line 3604 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = photo_file_format_properties_convert_file_extension (_tmp34_, _tmp35_);
#line 3604 "/home/jens/Source/shotwell/src/Photo.vala"
	dest_file = _tmp36_;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = export_reader;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = dest_file;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = g_file_get_path (_tmp39_);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = _tmp40_;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = photo_file_format_create_metadata_writer (_tmp38_, _tmp41_, &_inner_error_);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp43_ = _tmp42_;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp41_);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	writer = _tmp43_;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 26015 "Photo.c"
		gboolean _tmp44_ = FALSE;
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dest_file);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (format_properties);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (export_reader);
#line 3607 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp44_;
#line 26027 "Photo.c"
	}
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp46_ = _tmp45_;
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = writer;
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp48_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp49_ = _tmp48_;
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:3610: Exporting full-sized copy of %s to %s", _tmp46_, _tmp49_);
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp49_);
#line 3610 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp46_);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp50_ = export_reader;
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp52_ = _tmp51_;
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp53_ = dest_file;
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_copy (_tmp52_, _tmp53_, G_FILE_COPY_OVERWRITE | G_FILE_COPY_TARGET_DEFAULT_PERMS, NULL, NULL, NULL, &_inner_error_);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp52_);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 26059 "Photo.c"
		gboolean _tmp54_ = FALSE;
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dest_file);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (format_properties);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (export_reader);
#line 3612 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp54_;
#line 26073 "Photo.c"
	}
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp60_ = photo_has_alterations (self);
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp60_) {
#line 26079 "Photo.c"
		gboolean _tmp61_;
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp61_ = is_master;
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp59_ = _tmp61_;
#line 26085 "Photo.c"
	} else {
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp59_ = FALSE;
#line 26089 "Photo.c"
	}
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp59_) {
#line 26093 "Photo.c"
		gboolean _tmp62_;
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp62_ = photo_has_user_generated_metadata (self);
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp58_ = !_tmp62_;
#line 26099 "Photo.c"
	} else {
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp58_ = FALSE;
#line 26103 "Photo.c"
	}
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp58_) {
#line 26107 "Photo.c"
		gchar* _tmp63_;
		gchar* _tmp64_;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp63_ = media_source_get_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp64_ = _tmp63_;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57_ = _tmp64_ == NULL;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp64_);
#line 26118 "Photo.c"
	} else {
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57_ = FALSE;
#line 26122 "Photo.c"
	}
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp57_) {
#line 26126 "Photo.c"
		gchar* _tmp65_;
		gchar* _tmp66_;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp65_ = media_source_get_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp66_ = _tmp65_;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp56_ = _tmp66_ == NULL;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp66_);
#line 26137 "Photo.c"
	} else {
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp56_ = FALSE;
#line 26141 "Photo.c"
	}
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp56_) {
#line 26145 "Photo.c"
		gboolean _tmp67_;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp67_ = export_metadata;
#line 3618 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp55_ = _tmp67_;
#line 26151 "Photo.c"
	} else {
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp55_ = FALSE;
#line 26155 "Photo.c"
	}
#line 3617 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp55_) {
#line 3619 "/home/jens/Source/shotwell/src/Photo.vala"
		result = TRUE;
#line 3619 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3619 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dest_file);
#line 3619 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (format_properties);
#line 3619 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (export_reader);
#line 3619 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 26171 "Photo.c"
	}
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp68_ = export_reader;
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp69_ = photo_file_reader_read_metadata (_tmp68_, &_inner_error_);
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp69_;
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 26181 "Photo.c"
		gboolean _tmp70_ = FALSE;
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dest_file);
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (format_properties);
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (export_reader);
#line 3622 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp70_;
#line 26195 "Photo.c"
	}
#line 3623 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp71_ = metadata;
#line 3623 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp71_ == NULL) {
#line 26201 "Photo.c"
		PhotoFileReader* _tmp72_;
		PhotoFileFormat _tmp73_;
		PhotoMetadata* _tmp74_;
#line 3624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp72_ = export_reader;
#line 3624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp73_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp74_ = photo_file_format_create_metadata (_tmp73_);
#line 3624 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3624 "/home/jens/Source/shotwell/src/Photo.vala"
		metadata = _tmp74_;
#line 26215 "Photo.c"
	}
#line 3626 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp75_ = writer;
#line 3626 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp76_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3626 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp77_ = _tmp76_;
#line 3626 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:3626: Updating metadata of %s", _tmp77_);
#line 3626 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp77_);
#line 3628 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp78_ = media_source_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3628 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp78_ != ((time_t) 0)) {
#line 26231 "Photo.c"
		PhotoMetadata* _tmp79_;
		time_t _tmp80_;
		MetadataDateTime* _tmp81_;
		MetadataDateTime* _tmp82_;
#line 3629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp79_ = metadata;
#line 3629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp80_ = media_source_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp81_ = metadata_date_time_new (_tmp80_);
#line 3629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp82_ = _tmp81_;
#line 3629 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_exposure_date_time (_tmp79_, _tmp82_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3629 "/home/jens/Source/shotwell/src/Photo.vala"
		_metadata_date_time_unref0 (_tmp82_);
#line 26248 "Photo.c"
	} else {
		PhotoMetadata* _tmp83_;
#line 3631 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp83_ = metadata;
#line 3631 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_exposure_date_time (_tmp83_, NULL, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 26255 "Photo.c"
	}
#line 3633 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp84_ = export_metadata;
#line 3633 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp84_) {
#line 26261 "Photo.c"
		PhotoMetadata* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		PhotoMetadata* _tmp88_;
		gchar* _tmp89_;
		gchar* _tmp90_;
		PhotoMetadata* _tmp91_;
		Dimensions _tmp92_ = {0};
		PhotoMetadata* _tmp93_;
		Orientation _tmp94_;
		PhotoMetadata* _tmp95_;
		Orientation _tmp96_;
		Orientation _tmp97_;
		PhotoMetadata* _tmp99_;
#line 3635 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp85_ = metadata;
#line 3635 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp86_ = media_source_get_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3635 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp87_ = _tmp86_;
#line 3635 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_title (_tmp85_, _tmp87_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3635 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp87_);
#line 3636 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp88_ = metadata;
#line 3636 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp89_ = media_source_get_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3636 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp90_ = _tmp89_;
#line 3636 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_comment (_tmp88_, _tmp90_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3636 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp90_);
#line 3637 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp91_ = metadata;
#line 3637 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_NONE, &_tmp92_);
#line 3637 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_pixel_dimensions (_tmp91_, &_tmp92_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3638 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp93_ = metadata;
#line 3638 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp94_ = photo_get_orientation (self);
#line 3638 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_orientation (_tmp93_, _tmp94_);
#line 3639 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp95_ = metadata;
#line 3639 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_software (_tmp95_, RESOURCES_APP_TITLE, RESOURCES_APP_VERSION);
#line 3641 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp96_ = photo_get_orientation (self);
#line 3641 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp97_ = photo_get_original_orientation (self);
#line 3641 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp96_ != _tmp97_) {
#line 26318 "Photo.c"
			PhotoMetadata* _tmp98_;
#line 3642 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp98_ = metadata;
#line 3642 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_metadata_remove_exif_thumbnail (_tmp98_);
#line 26324 "Photo.c"
		}
#line 3644 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp99_ = metadata;
#line 3644 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_set_user_metadata_for_export (self, _tmp99_);
#line 26330 "Photo.c"
	} else {
		PhotoMetadata* _tmp100_;
#line 3648 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp100_ = metadata;
#line 3648 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_clear (_tmp100_);
#line 26337 "Photo.c"
	}
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp101_ = writer;
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp102_ = metadata;
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_metadata_writer_write_metadata (_tmp101_, _tmp102_, &_inner_error_);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 26347 "Photo.c"
		gboolean _tmp103_ = FALSE;
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dest_file);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (format_properties);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (export_reader);
#line 3650 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp103_;
#line 26363 "Photo.c"
	}
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (writer);
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (dest_file);
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_format_properties_unref0 (format_properties);
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (export_reader);
#line 3652 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 26379 "Photo.c"
}


gboolean photo_is_export_required (Photo* self, Scaling* scaling, PhotoFileFormat export_format) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_;
#line 3658 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 3658 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, FALSE);
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = scaling_is_unscaled (scaling);
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp3_) {
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = TRUE;
#line 26399 "Photo.c"
	} else {
		gboolean _tmp4_;
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = photo_has_alterations (self);
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp4_;
#line 26406 "Photo.c"
	}
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = TRUE;
#line 26412 "Photo.c"
	} else {
		gboolean _tmp5_;
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = photo_has_user_generated_metadata (self);
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp5_;
#line 26419 "Photo.c"
	}
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = TRUE;
#line 26425 "Photo.c"
	} else {
		PhotoFileFormat _tmp6_;
		PhotoFileFormat _tmp7_;
#line 3660 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = export_format;
#line 3660 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = photo_get_file_format (self);
#line 3660 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp6_ != _tmp7_;
#line 26435 "Photo.c"
	}
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 3659 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 26441 "Photo.c"
}


void photo_export (Photo* self, GFile* dest_file, Scaling* scaling, JpegQuality quality, PhotoFileFormat export_format, gboolean direct_copy_unmodified, gboolean export_metadata, GError** error) {
	gboolean _tmp0_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_;
	PhotoMetadata* metadata = NULL;
	PhotoMetadata* _tmp18_;
	PhotoMetadata* _tmp19_;
	PhotoFileFormat _tmp22_;
	gboolean _tmp23_;
	PhotoFileWriter* writer = NULL;
	PhotoFileFormat _tmp25_;
	GFile* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	PhotoFileWriter* _tmp29_;
	PhotoFileWriter* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	PhotoFileWriter* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	PhotoFileFormat _tmp36_;
	GEnumValue* _tmp37_;
	GdkPixbuf* pixbuf = NULL;
	gboolean _tmp38_ = FALSE;
	PhotoFileFormat _tmp39_;
	PhotoFileWriter* _tmp49_;
	GdkPixbuf* _tmp50_;
	JpegQuality _tmp51_;
	PhotoFileWriter* _tmp52_;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gboolean _tmp55_;
	gboolean _tmp75_ = FALSE;
	PhotoFileFormat _tmp76_;
	PhotoFileMetadataWriter* _tmp86_ = NULL;
	PhotoFileFormat _tmp87_;
	GFile* _tmp88_;
	gchar* _tmp89_;
	gchar* _tmp90_;
	PhotoFileMetadataWriter* _tmp91_;
	PhotoFileMetadataWriter* _tmp92_;
	PhotoMetadata* _tmp93_;
	GError * _inner_error_ = NULL;
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE (dest_file));
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (scaling != NULL);
#line 3668 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = direct_copy_unmodified;
#line 3668 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_) {
#line 26501 "Photo.c"
		GFile* _tmp1_;
		GFile* _tmp2_;
		GFile* _tmp3_;
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp1_;
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = dest_file;
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
		g_file_copy (_tmp2_, _tmp3_, G_FILE_COPY_OVERWRITE | G_FILE_COPY_TARGET_DEFAULT_PERMS, NULL, NULL, NULL, &_inner_error_);
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp2_);
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3669 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 26521 "Photo.c"
		}
#line 3671 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 26525 "Photo.c"
	}
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = scaling_is_unscaled (scaling);
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp7_) {
#line 26531 "Photo.c"
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_;
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = photo_has_alterations (self);
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
		if (!_tmp9_) {
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = TRUE;
#line 26540 "Photo.c"
		} else {
			gboolean _tmp10_;
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = photo_only_metadata_changed (self);
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp10_;
#line 26547 "Photo.c"
		}
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp8_;
#line 26551 "Photo.c"
	} else {
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = FALSE;
#line 26555 "Photo.c"
	}
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_) {
#line 26559 "Photo.c"
		PhotoFileFormat _tmp11_;
		PhotoFileFormat _tmp12_;
#line 3679 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = export_format;
#line 3679 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = photo_get_file_format (self);
#line 3679 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp11_ == _tmp12_;
#line 26568 "Photo.c"
	} else {
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = FALSE;
#line 26572 "Photo.c"
	}
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 26576 "Photo.c"
		PhotoFileFormat _tmp13_;
#line 3679 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = photo_get_file_format (self);
#line 3679 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp13_ == PHOTO_FILE_FORMAT_JFIF;
#line 26582 "Photo.c"
	} else {
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = FALSE;
#line 26586 "Photo.c"
	}
#line 3678 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp4_) {
#line 26590 "Photo.c"
		gboolean _tmp14_ = FALSE;
		GFile* _tmp15_;
		gboolean _tmp16_;
		gboolean _tmp17_;
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = dest_file;
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = export_metadata;
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = photo_export_fullsized_backing (self, _tmp15_, _tmp16_, &_inner_error_);
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = _tmp17_;
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 26609 "Photo.c"
		}
#line 3680 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp14_) {
#line 3681 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 26615 "Photo.c"
		}
	}
#line 3687 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = photo_source_get_metadata (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource));
#line 3687 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp18_;
#line 3688 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = metadata;
#line 3688 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp19_ == NULL) {
#line 26626 "Photo.c"
		PhotoFileFormat _tmp20_;
		PhotoMetadata* _tmp21_;
#line 3689 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = export_format;
#line 3689 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = photo_file_format_create_metadata (_tmp20_);
#line 3689 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3689 "/home/jens/Source/shotwell/src/Photo.vala"
		metadata = _tmp21_;
#line 26637 "Photo.c"
	}
#line 3691 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = export_format;
#line 3691 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = photo_file_format_can_write (_tmp22_);
#line 3691 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp23_) {
#line 26645 "Photo.c"
		PhotoFileFormat _tmp24_;
#line 3692 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = photo_file_format_get_system_default_format ();
#line 3692 "/home/jens/Source/shotwell/src/Photo.vala"
		export_format = _tmp24_;
#line 26651 "Photo.c"
	}
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = export_format;
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = dest_file;
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = g_file_get_path (_tmp26_);
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = _tmp27_;
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = photo_file_format_create_writer (_tmp25_, _tmp28_, &_inner_error_);
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = _tmp29_;
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp28_);
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	writer = _tmp30_;
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3694 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 26677 "Photo.c"
	}
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = _tmp31_;
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = writer;
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = _tmp34_;
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = export_format;
#line 3697 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = g_enum_get_value (g_type_class_ref (TYPE_PHOTO_FILE_FORMAT), _tmp36_);
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:3696: Saving transformed version of %s to %s in file format" \
" %s", _tmp32_, _tmp35_, (_tmp37_ != NULL) ? _tmp37_->value_name : NULL);
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp35_);
#line 3696 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp32_);
#line 3703 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = photo_get_file_format (self);
#line 3703 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp39_ == PHOTO_FILE_FORMAT_JFIF) {
#line 3703 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp38_ = TRUE;
#line 26705 "Photo.c"
	} else {
		PhotoFileFormat _tmp40_;
#line 3704 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = photo_get_file_format (self);
#line 3704 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp38_ = _tmp40_ == PHOTO_FILE_FORMAT_RAW;
#line 26712 "Photo.c"
	}
#line 3703 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp38_) {
#line 26716 "Photo.c"
		GdkPixbuf* _tmp41_ = NULL;
		Scaling _tmp42_;
		GdkPixbuf* _tmp43_;
		GdkPixbuf* _tmp44_;
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = *scaling;
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = photo_get_pixbuf_with_options (self, &_tmp42_, PHOTO_EXCEPTION_ORIENTATION, BACKING_FETCH_MODE_SOURCE, &_inner_error_);
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = _tmp43_;
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (pixbuf);
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (writer);
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
			_media_metadata_unref0 (metadata);
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 26739 "Photo.c"
		}
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp44_ = _tmp41_;
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = NULL;
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3705 "/home/jens/Source/shotwell/src/Photo.vala"
		pixbuf = _tmp44_;
#line 3703 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp41_);
#line 26751 "Photo.c"
	} else {
		GdkPixbuf* _tmp45_ = NULL;
		Scaling _tmp46_;
		GdkPixbuf* _tmp47_;
		GdkPixbuf* _tmp48_;
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = *scaling;
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = photo_get_pixbuf_with_options (self, &_tmp46_, PHOTO_EXCEPTION_NONE, BACKING_FETCH_MODE_SOURCE, &_inner_error_);
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = _tmp47_;
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (pixbuf);
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (writer);
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
			_media_metadata_unref0 (metadata);
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 26775 "Photo.c"
		}
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = _tmp45_;
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = NULL;
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3709 "/home/jens/Source/shotwell/src/Photo.vala"
		pixbuf = _tmp48_;
#line 3703 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp45_);
#line 26787 "Photo.c"
	}
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp49_ = writer;
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp50_ = pixbuf;
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = quality;
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_writer_write (_tmp49_, _tmp50_, _tmp51_, &_inner_error_);
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3713 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 26809 "Photo.c"
	}
#line 3715 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp52_ = writer;
#line 3715 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp53_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3715 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp54_ = _tmp53_;
#line 3715 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:3715: Setting EXIF for %s", _tmp54_);
#line 3715 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp54_);
#line 3718 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp55_ = export_metadata;
#line 3718 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp55_) {
#line 26825 "Photo.c"
		PhotoMetadata* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
		PhotoMetadata* _tmp59_;
		gchar* _tmp60_;
		gchar* _tmp61_;
		PhotoMetadata* _tmp62_;
		time_t _tmp63_;
		PhotoMetadata* _tmp69_;
		PhotoMetadata* _tmp70_;
		PhotoMetadata* _tmp71_;
		gboolean _tmp72_;
#line 3720 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp56_ = metadata;
#line 3720 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp57_ = media_source_get_title (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3720 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp58_ = _tmp57_;
#line 3720 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_title (_tmp56_, _tmp58_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3720 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp58_);
#line 3721 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp59_ = metadata;
#line 3721 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp60_ = media_source_get_comment (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3721 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp61_ = _tmp60_;
#line 3721 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_comment (_tmp59_, _tmp61_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3721 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp61_);
#line 3722 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp62_ = metadata;
#line 3722 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_software (_tmp62_, RESOURCES_APP_TITLE, RESOURCES_APP_VERSION);
#line 3724 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp63_ = media_source_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3724 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp63_ != ((time_t) 0)) {
#line 26866 "Photo.c"
			PhotoMetadata* _tmp64_;
			time_t _tmp65_;
			MetadataDateTime* _tmp66_;
			MetadataDateTime* _tmp67_;
#line 3725 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp64_ = metadata;
#line 3725 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp65_ = media_source_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3725 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp66_ = metadata_date_time_new (_tmp65_);
#line 3725 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp67_ = _tmp66_;
#line 3725 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_metadata_set_exposure_date_time (_tmp64_, _tmp67_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3725 "/home/jens/Source/shotwell/src/Photo.vala"
			_metadata_date_time_unref0 (_tmp67_);
#line 26883 "Photo.c"
		} else {
			PhotoMetadata* _tmp68_;
#line 3727 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp68_ = metadata;
#line 3727 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_metadata_set_exposure_date_time (_tmp68_, NULL, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 26890 "Photo.c"
		}
#line 3729 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp69_ = metadata;
#line 3729 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_remove_tag (_tmp69_, "Exif.Iop.RelatedImageWidth");
#line 3730 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp70_ = metadata;
#line 3730 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_remove_tag (_tmp70_, "Exif.Iop.RelatedImageHeight");
#line 3731 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp71_ = metadata;
#line 3731 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_remove_exif_thumbnail (_tmp71_);
#line 3733 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp72_ = photo_has_user_generated_metadata (self);
#line 3733 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp72_) {
#line 26908 "Photo.c"
			PhotoMetadata* _tmp73_;
#line 3734 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp73_ = metadata;
#line 3734 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_set_user_metadata_for_export (self, _tmp73_);
#line 26914 "Photo.c"
		}
	} else {
		PhotoMetadata* _tmp74_;
#line 3738 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp74_ = metadata;
#line 3738 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_clear (_tmp74_);
#line 26922 "Photo.c"
	}
#line 3745 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp76_ = photo_get_file_format (self);
#line 3745 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp76_ == PHOTO_FILE_FORMAT_JFIF) {
#line 3745 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp75_ = TRUE;
#line 26930 "Photo.c"
	} else {
		PhotoFileFormat _tmp77_;
#line 3746 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp77_ = photo_get_file_format (self);
#line 3746 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp75_ = _tmp77_ == PHOTO_FILE_FORMAT_RAW;
#line 26937 "Photo.c"
	}
#line 3745 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp75_) {
#line 26941 "Photo.c"
		PhotoMetadata* _tmp78_;
		Dimensions _tmp79_ = {0};
		PhotoMetadata* _tmp80_;
		Orientation _tmp81_;
#line 3747 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp78_ = metadata;
#line 3747 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_ORIENTATION, &_tmp79_);
#line 3747 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_pixel_dimensions (_tmp78_, &_tmp79_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3748 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp80_ = metadata;
#line 3748 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp81_ = photo_get_orientation (self);
#line 3748 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_orientation (_tmp80_, _tmp81_);
#line 26958 "Photo.c"
	} else {
		PhotoMetadata* _tmp82_;
		GdkPixbuf* _tmp83_;
		Dimensions _tmp84_ = {0};
		PhotoMetadata* _tmp85_;
#line 3751 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp82_ = metadata;
#line 3751 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp83_ = pixbuf;
#line 3751 "/home/jens/Source/shotwell/src/Photo.vala"
		dimensions_for_pixbuf (_tmp83_, &_tmp84_);
#line 3751 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_pixel_dimensions (_tmp82_, &_tmp84_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 3752 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp85_ = metadata;
#line 3752 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_orientation (_tmp85_, ORIENTATION_TOP_LEFT);
#line 26976 "Photo.c"
	}
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp87_ = export_format;
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp88_ = dest_file;
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp89_ = g_file_get_path (_tmp88_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp90_ = _tmp89_;
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp91_ = photo_file_format_create_metadata_writer (_tmp87_, _tmp90_, &_inner_error_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp92_ = _tmp91_;
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp90_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp86_ = _tmp92_;
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 27006 "Photo.c"
	}
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp93_ = metadata;
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_file_metadata_writer_write_metadata (_tmp86_, _tmp93_, &_inner_error_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (_tmp86_);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (writer);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 3755 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 27026 "Photo.c"
	}
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp86_);
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (pixbuf);
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (writer);
#line 3666 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 27036 "Photo.c"
}


static GFile* photo_generate_new_editable_file (Photo* self, PhotoFileFormat* file_format, GError** error) {
	PhotoFileFormat _vala_file_format = 0;
	GFile* result = NULL;
	GFile* backing = NULL;
	PhotoFileFormat _tmp4_;
	gboolean _tmp5_;
	gchar* name = NULL;
	gchar* ext = NULL;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	const gchar* _tmp12_;
	gchar* editable_basename = NULL;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	gboolean collision = FALSE;
	GFile* _tmp25_ = NULL;
	GFile* _tmp26_;
	GFile* _tmp27_;
	gboolean _tmp28_ = FALSE;
	GFile* _tmp29_;
	GFile* _tmp30_;
	GFile* _tmp31_;
	GError * _inner_error_ = NULL;
#line 3758 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 27069 "Photo.c"
	{
		PhotoRow* _tmp0_;
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->row;
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 27076 "Photo.c"
		{
			PhotoFileFormat _tmp1_;
			GFile* _tmp2_;
#line 3761 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = photo_get_file_format (self);
#line 3761 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_file_format = _tmp1_;
#line 3762 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = media_source_get_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3762 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (backing);
#line 3762 "/home/jens/Source/shotwell/src/Photo.vala"
			backing = _tmp2_;
#line 27090 "Photo.c"
		}
		__finally399:
		{
			PhotoRow* _tmp3_;
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = self->row;
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 27099 "Photo.c"
		}
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (backing);
#line 3760 "/home/jens/Source/shotwell/src/Photo.vala"
			return NULL;
#line 27109 "Photo.c"
		}
	}
#line 3765 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _vala_file_format;
#line 3765 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_file_format_can_write (_tmp4_);
#line 3765 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp5_) {
#line 27118 "Photo.c"
		PhotoFileFormat _tmp6_;
#line 3766 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = photo_file_format_get_system_default_format ();
#line 3766 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_file_format = _tmp6_;
#line 27124 "Photo.c"
	}
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = g_file_get_basename (backing);
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_;
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	disassemble_filename (_tmp8_, &_tmp9_, &_tmp10_);
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (name);
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	name = _tmp9_;
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (ext);
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	ext = _tmp10_;
#line 3769 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp8_);
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = ext;
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_ == NULL) {
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = TRUE;
#line 27148 "Photo.c"
	} else {
		PhotoFileFormat _tmp13_;
		PhotoFileFormatProperties* _tmp14_;
		PhotoFileFormatProperties* _tmp15_;
		const gchar* _tmp16_;
		gboolean _tmp17_;
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = _vala_file_format;
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = photo_file_format_get_properties (_tmp13_);
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = _tmp14_;
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = ext;
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = photo_file_format_properties_is_recognized_extension (_tmp15_, _tmp16_);
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = !_tmp17_;
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (_tmp15_);
#line 27169 "Photo.c"
	}
#line 3771 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_) {
#line 27173 "Photo.c"
		PhotoFileFormat _tmp18_;
		PhotoFileFormatProperties* _tmp19_;
		PhotoFileFormatProperties* _tmp20_;
		gchar* _tmp21_;
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = _vala_file_format;
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = photo_file_format_get_properties (_tmp18_);
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = _tmp19_;
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = photo_file_format_properties_get_default_extension (_tmp20_);
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (ext);
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		ext = _tmp21_;
#line 3772 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_format_properties_unref0 (_tmp20_);
#line 27192 "Photo.c"
	}
#line 3774 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = name;
#line 3774 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = ext;
#line 3774 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = g_strdup_printf ("%s_%s.%s", _tmp22_, _ ("modified"), _tmp23_);
#line 3774 "/home/jens/Source/shotwell/src/Photo.vala"
	editable_basename = _tmp24_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = g_file_get_parent (backing);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = _tmp26_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = generate_unique_file (_tmp27_, editable_basename, &_tmp28_, &_inner_error_);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	collision = _tmp28_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = _tmp29_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp27_);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = _tmp30_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (editable_basename);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (ext);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (name);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (backing);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 27230 "Photo.c"
	}
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = _tmp25_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = NULL;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp31_;
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp25_);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (editable_basename);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (ext);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (name);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (backing);
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	if (file_format) {
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
		*file_format = _vala_file_format;
#line 27252 "Photo.c"
	}
#line 3777 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 27256 "Photo.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 27263 "Photo.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
	g_list_free (self);
#line 27272 "Photo.c"
}


static gboolean photo_launch_editor (GFile* file, PhotoFileFormat file_format, GError** error) {
	gboolean result = FALSE;
	gchar* _tmp0_ = NULL;
	PhotoFileFormat _tmp1_;
	gchar* commandline = NULL;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	gboolean _tmp10_;
	GAppInfo* app = NULL;
	GList* files = NULL;
	GFile* _tmp16_;
	GFile* _tmp17_;
	GAppInfo* _tmp18_;
	gchar** argv = NULL;
	gchar** _tmp24_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp25_;
	gint _tmp25__length1;
	const gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gchar** _tmp29_;
	gint _tmp29__length1;
	GFile* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	GPid child_pid = 0;
	gboolean _tmp33_ = FALSE;
	gchar** _tmp34_;
	gint _tmp34__length1;
	GPid _tmp35_ = 0;
	gboolean _tmp36_;
	GError * _inner_error_ = NULL;
#line 3780 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file_format;
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == PHOTO_FILE_FORMAT_RAW) {
#line 27316 "Photo.c"
		ConfigFacade* _tmp2_;
		ConfigFacade* _tmp3_;
		gchar* _tmp4_;
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = config_facade_get_instance ();
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = configuration_facade_get_external_raw_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp4_;
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 27332 "Photo.c"
	} else {
		ConfigFacade* _tmp5_;
		ConfigFacade* _tmp6_;
		gchar* _tmp7_;
#line 3782 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = config_facade_get_instance ();
#line 3782 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_;
#line 3782 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = configuration_facade_get_external_photo_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 3782 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 3782 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp7_;
#line 3782 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp6_);
#line 27349 "Photo.c"
	}
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = g_strdup (_tmp0_);
#line 3781 "/home/jens/Source/shotwell/src/Photo.vala"
	commandline = _tmp8_;
#line 3784 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = commandline;
#line 3784 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = is_string_empty (_tmp9_);
#line 3784 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp10_) {
#line 3785 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 3785 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (commandline);
#line 3785 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 3785 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 27369 "Photo.c"
	}
	{
		GAppInfo* _tmp11_ = NULL;
		const gchar* _tmp12_;
		GAppInfo* _tmp13_;
		GAppInfo* _tmp14_;
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = commandline;
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = g_app_info_create_from_commandline (_tmp12_, "", G_APP_INFO_CREATE_NONE, &_inner_error_);
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = _tmp13_;
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27384 "Photo.c"
			goto __catch400_g_error;
		}
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = _tmp11_;
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = NULL;
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (app);
#line 3789 "/home/jens/Source/shotwell/src/Photo.vala"
		app = _tmp14_;
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp11_);
#line 27397 "Photo.c"
	}
	goto __finally400;
	__catch400_g_error:
	{
		GError* er = NULL;
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		er = _inner_error_;
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 3792 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (app);
#line 3792 "/home/jens/Source/shotwell/src/Photo.vala"
		app = NULL;
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (er);
#line 27413 "Photo.c"
	}
	__finally400:
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27418 "Photo.c"
		gboolean _tmp15_ = FALSE;
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (app);
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (commandline);
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 3788 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp15_;
#line 27430 "Photo.c"
	}
#line 3795 "/home/jens/Source/shotwell/src/Photo.vala"
	files = NULL;
#line 3796 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = file;
#line 3796 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = _g_object_ref0 (_tmp16_);
#line 3796 "/home/jens/Source/shotwell/src/Photo.vala"
	files = g_list_insert (files, _tmp17_, -1);
#line 3798 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = app;
#line 3798 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp18_ != NULL) {
#line 27444 "Photo.c"
		gboolean _tmp19_ = FALSE;
		GAppInfo* _tmp20_;
		GList* _tmp21_;
		gboolean _tmp22_;
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = app;
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = files;
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = g_app_info_launch (_tmp20_, _tmp21_, NULL, &_inner_error_);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = _tmp22_;
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27459 "Photo.c"
			gboolean _tmp23_ = FALSE;
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
			__g_list_free__g_object_unref0_0 (files);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (app);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (commandline);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp0_);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp23_;
#line 27473 "Photo.c"
		}
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp19_;
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		__g_list_free__g_object_unref0_0 (files);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (app);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (commandline);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 3799 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 27487 "Photo.c"
	}
#line 3801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = g_new0 (gchar*, 2 + 1);
#line 3801 "/home/jens/Source/shotwell/src/Photo.vala"
	argv = _tmp24_;
#line 3801 "/home/jens/Source/shotwell/src/Photo.vala"
	argv_length1 = 2;
#line 3801 "/home/jens/Source/shotwell/src/Photo.vala"
	_argv_size_ = argv_length1;
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = argv;
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25__length1 = argv_length1;
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = commandline;
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = g_strdup (_tmp26_);
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp25_[0]);
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_[0] = _tmp27_;
#line 3802 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = _tmp25_[0];
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = argv;
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29__length1 = argv_length1;
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = file;
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = g_file_get_path (_tmp30_);
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp29_[1]);
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_[1] = _tmp31_;
#line 3803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = _tmp29_[1];
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = argv;
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34__length1 = argv_length1;
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = g_spawn_async ("/", _tmp34_, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &_tmp35_, &_inner_error_);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	child_pid = _tmp35_;
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = _tmp36_;
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27537 "Photo.c"
		gboolean _tmp37_ = FALSE;
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		argv = (_vala_array_free (argv, argv_length1, (GDestroyNotify) g_free), NULL);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		__g_list_free__g_object_unref0_0 (files);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (app);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (commandline);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp0_);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp37_;
#line 27553 "Photo.c"
	}
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp33_;
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	argv = (_vala_array_free (argv, argv_length1, (GDestroyNotify) g_free), NULL);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	__g_list_free__g_object_unref0_0 (files);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (app);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (commandline);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp0_);
#line 3807 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 27569 "Photo.c"
}


void photo_open_with_raw_external_editor (Photo* self, GError** error) {
	GFile* _tmp0_;
	GFile* _tmp1_;
	PhotoFileFormat _tmp2_;
	GError * _inner_error_ = NULL;
#line 3817 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_get_master_file_format (self);
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_launch_editor (_tmp1_, _tmp2_, &_inner_error_);
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp1_);
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3818 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 27596 "Photo.c"
	}
}


void photo_open_with_external_editor (Photo* self, GError** error) {
	GFile* current_editable_file = NULL;
	GFile* create_editable_file = NULL;
	PhotoFileFormat editable_file_format = 0;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	GFile* _tmp17_;
	gboolean _tmp25_ = FALSE;
	GFile* _tmp26_;
	GFile* _tmp44_;
	GFileMonitor* _tmp45_;
	GFile* _tmp47_;
	PhotoFileFormat _tmp48_;
	GError * _inner_error_ = NULL;
#line 3822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3823 "/home/jens/Source/shotwell/src/Photo.vala"
	current_editable_file = NULL;
#line 3824 "/home/jens/Source/shotwell/src/Photo.vala"
	create_editable_file = NULL;
#line 27621 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 27628 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			GFile* _tmp6_;
#line 3827 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 3827 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 3827 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 27639 "Photo.c"
				PhotoBackingReaders* _tmp3_;
				PhotoFileReader* _tmp4_;
				GFile* _tmp5_;
#line 3828 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 3828 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->editable;
#line 3828 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3828 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (current_editable_file);
#line 3828 "/home/jens/Source/shotwell/src/Photo.vala"
				current_editable_file = _tmp5_;
#line 27653 "Photo.c"
			}
#line 3830 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = current_editable_file;
#line 3830 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp6_ == NULL) {
#line 27659 "Photo.c"
				GFile* _tmp7_ = NULL;
				PhotoFileFormat _tmp8_ = 0;
				GFile* _tmp9_;
				GFile* _tmp10_;
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = photo_generate_new_editable_file (self, &_tmp8_, &_inner_error_);
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				editable_file_format = _tmp8_;
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = _tmp9_;
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27672 "Photo.c"
					goto __finally401;
				}
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tmp7_;
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = NULL;
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (create_editable_file);
#line 3831 "/home/jens/Source/shotwell/src/Photo.vala"
				create_editable_file = _tmp10_;
#line 3830 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp7_);
#line 27685 "Photo.c"
			} else {
				PhotoBackingReaders* _tmp11_;
				PhotoFileReader* _tmp12_;
				PhotoFileFormat _tmp13_;
#line 3833 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = self->priv->readers;
#line 3833 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tmp11_->editable;
#line 3833 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = photo_file_adapter_get_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3833 "/home/jens/Source/shotwell/src/Photo.vala"
				editable_file_format = _tmp13_;
#line 27698 "Photo.c"
			}
		}
		__finally401:
		{
			PhotoBackingReaders* _tmp14_;
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = self->priv->readers;
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 27708 "Photo.c"
		}
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (create_editable_file);
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (current_editable_file);
#line 3826 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 27720 "Photo.c"
		}
	}
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = create_editable_file;
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp17_ == NULL) {
#line 27727 "Photo.c"
		GFile* _tmp18_;
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = current_editable_file;
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = _tmp18_ != NULL;
#line 27733 "Photo.c"
	} else {
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = FALSE;
#line 27737 "Photo.c"
	}
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp16_) {
#line 27741 "Photo.c"
		gboolean _tmp19_ = FALSE;
		GFile* _tmp20_;
		gboolean _tmp21_;
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = current_editable_file;
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = g_file_query_exists (_tmp20_, NULL);
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
		if (!_tmp21_) {
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = TRUE;
#line 27753 "Photo.c"
		} else {
			gboolean _tmp22_;
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = photo_has_transformations (self);
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = _tmp22_;
#line 27760 "Photo.c"
		}
#line 3839 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = _tmp19_;
#line 27764 "Photo.c"
	} else {
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = FALSE;
#line 27768 "Photo.c"
	}
#line 3838 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp15_) {
#line 27772 "Photo.c"
		GFile* _tmp23_;
		GFile* _tmp24_;
#line 3840 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = current_editable_file;
#line 3840 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = _g_object_ref0 (_tmp23_);
#line 3840 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (create_editable_file);
#line 3840 "/home/jens/Source/shotwell/src/Photo.vala"
		create_editable_file = _tmp24_;
#line 27783 "Photo.c"
	}
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = create_editable_file;
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp26_ != NULL) {
#line 27789 "Photo.c"
		PhotoFileFormat _tmp27_;
		gboolean _tmp28_;
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp27_ = editable_file_format;
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = photo_file_format_can_write (_tmp27_);
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp28_;
#line 27798 "Photo.c"
	} else {
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = FALSE;
#line 27802 "Photo.c"
	}
#line 3843 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp25_) {
#line 27806 "Photo.c"
		PhotoFileFormat _tmp40_;
		GFile* _tmp41_;
		GFile* _tmp42_;
		GFile* _tmp43_;
#line 3844 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_halt_monitoring_editable (self);
#line 27813 "Photo.c"
		{
			GFile* _tmp29_;
			Scaling _tmp30_ = {0};
			PhotoFileFormat _tmp31_;
#line 3847 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp29_ = create_editable_file;
#line 3847 "/home/jens/Source/shotwell/src/Photo.vala"
			scaling_for_original (&_tmp30_);
#line 3847 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp31_ = editable_file_format;
#line 3847 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_export (self, _tmp29_, &_tmp30_, JPEG_QUALITY_MAXIMUM, _tmp31_, FALSE, TRUE, &_inner_error_);
#line 3847 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27828 "Photo.c"
				goto __catch402_g_error;
			}
		}
		goto __finally402;
		__catch402_g_error:
		{
			GError* err = NULL;
			GError* _tmp38_;
			GError* _tmp39_;
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 27842 "Photo.c"
			{
				GFile* _tmp32_;
#line 3852 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = create_editable_file;
#line 3852 "/home/jens/Source/shotwell/src/Photo.vala"
				g_file_delete (_tmp32_, NULL, &_inner_error_);
#line 3852 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 27851 "Photo.c"
					goto __catch403_g_error;
				}
			}
			goto __finally403;
			__catch403_g_error:
			{
				GError* delete_err = NULL;
				GFile* _tmp33_;
				gchar* _tmp34_;
				gchar* _tmp35_;
				GError* _tmp36_;
				const gchar* _tmp37_;
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				delete_err = _inner_error_;
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				_inner_error_ = NULL;
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = create_editable_file;
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = g_file_get_path (_tmp33_);
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = _tmp34_;
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = delete_err;
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = _tmp36_->message;
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				g_warning ("Photo.vala:3855: Unable to delete editable file %s after export error:" \
" %s", _tmp35_, _tmp37_);
#line 3855 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp35_);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (delete_err);
#line 27884 "Photo.c"
			}
			__finally403:
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (err);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_error_free0 (err);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (create_editable_file);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (current_editable_file);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				g_clear_error (&_inner_error_);
#line 3851 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 27903 "Photo.c"
			}
#line 3859 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp38_ = err;
#line 3859 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp39_ = _g_error_copy0 (_tmp38_);
#line 3859 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = _tmp39_;
#line 3859 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 27913 "Photo.c"
			goto __finally402;
		}
		__finally402:
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (create_editable_file);
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (current_editable_file);
#line 3846 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 27927 "Photo.c"
		}
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp40_ = editable_file_format;
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp41_ = create_editable_file;
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_attach_editable (self, _tmp40_, _tmp41_, &_inner_error_);
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (create_editable_file);
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (current_editable_file);
#line 3863 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 27945 "Photo.c"
		}
#line 3865 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = create_editable_file;
#line 3865 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = _g_object_ref0 (_tmp42_);
#line 3865 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (current_editable_file);
#line 3865 "/home/jens/Source/shotwell/src/Photo.vala"
		current_editable_file = _tmp43_;
#line 27955 "Photo.c"
	}
#line 3868 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = current_editable_file;
#line 3868 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp44_ != NULL, "current_editable_file != null");
#line 3871 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = self->priv->editable_monitor;
#line 3871 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp45_ == NULL) {
#line 27965 "Photo.c"
		GFile* _tmp46_;
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = current_editable_file;
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_start_monitoring_editable (self, _tmp46_, &_inner_error_);
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (create_editable_file);
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (current_editable_file);
#line 3872 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 27981 "Photo.c"
		}
	}
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = current_editable_file;
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp48_ = photo_get_file_format (self);
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_launch_editor (_tmp47_, _tmp48_, &_inner_error_);
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (create_editable_file);
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (current_editable_file);
#line 3874 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28000 "Photo.c"
	}
#line 3822 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (create_editable_file);
#line 3822 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (current_editable_file);
#line 28006 "Photo.c"
}


void photo_revert_to_master (Photo* self, gboolean notify) {
	gboolean _tmp0_;
#line 3877 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3878 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = notify;
#line 3878 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_detach_editable (self, TRUE, TRUE, _tmp0_);
#line 28018 "Photo.c"
}


static void _photo_on_editable_file_changed_g_file_monitor_changed (GFileMonitor* _sender, GFile* file, GFile* other_file, GFileMonitorEvent event_type, gpointer self) {
#line 3888 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_on_editable_file_changed ((Photo*) self, file, other_file, event_type);
#line 28025 "Photo.c"
}


static void photo_start_monitoring_editable (Photo* self, GFile* file, GError** error) {
	GFile* _tmp0_;
	GFileMonitor* _tmp1_ = NULL;
	GFile* _tmp2_;
	GFileMonitor* _tmp3_;
	GFileMonitor* _tmp4_;
	GFileMonitor* _tmp5_;
	GError * _inner_error_ = NULL;
#line 3881 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3881 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 3882 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_halt_monitoring_editable (self);
#line 3885 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 3885 "/home/jens/Source/shotwell/src/Photo.vala"
	library_monitor_blacklist_file (_tmp0_, "Photo.start_monitoring_editable");
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = file;
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = g_file_monitor (_tmp2_, G_FILE_MONITOR_NONE, NULL, &_inner_error_);
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp3_;
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28059 "Photo.c"
	}
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp1_;
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = NULL;
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->editable_monitor);
#line 3887 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->editable_monitor = _tmp4_;
#line 3888 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = self->priv->editable_monitor;
#line 3888 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_connect_object (_tmp5_, "changed", (GCallback) _photo_on_editable_file_changed_g_file_monitor_changed, self, 0);
#line 3881 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp1_);
#line 28075 "Photo.c"
}


static void photo_halt_monitoring_editable (Photo* self) {
	GFileMonitor* _tmp0_;
	GFile* file = NULL;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFileMonitor* _tmp4_;
	guint _tmp5_;
	GFileMonitor* _tmp6_;
#line 3891 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3892 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->editable_monitor;
#line 3892 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ == NULL) {
#line 3893 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28095 "Photo.c"
	}
#line 3896 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_editable_file (self);
#line 3896 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp1_;
#line 3897 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = file;
#line 3897 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ != NULL) {
#line 28105 "Photo.c"
		GFile* _tmp3_;
#line 3898 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = file;
#line 3898 "/home/jens/Source/shotwell/src/Photo.vala"
		library_monitor_unblacklist_file (_tmp3_);
#line 28111 "Photo.c"
	}
#line 3900 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = self->priv->editable_monitor;
#line 3900 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_parse_name ("changed", g_file_monitor_get_type (), &_tmp5_, NULL, FALSE);
#line 3900 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _photo_on_editable_file_changed_g_file_monitor_changed, self);
#line 3901 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = self->priv->editable_monitor;
#line 3901 "/home/jens/Source/shotwell/src/Photo.vala"
	g_file_monitor_cancel (_tmp6_);
#line 3902 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->editable_monitor);
#line 3902 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->editable_monitor = NULL;
#line 3891 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 28129 "Photo.c"
}


static void photo_attach_editable (Photo* self, PhotoFileFormat file_format, GFile* file, GError** error) {
	PhotoFileFormat _tmp0_;
	GFile* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PhotoFileReader* _tmp4_;
	PhotoFileReader* _tmp5_;
	GError * _inner_error_ = NULL;
#line 3905 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3905 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 3910 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_internal_remove_all_transformations (self, FALSE);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file_format;
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = g_file_get_path (_tmp1_);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_file_format_create_reader (_tmp0_, _tmp3_);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_;
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_update_editable (self, FALSE, _tmp5_, &_inner_error_);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (_tmp5_);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp3_);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3911 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28171 "Photo.c"
	}
}


static void photo_update_editable_attributes (Photo* self, GError** error) {
	GError * _inner_error_ = NULL;
#line 3914 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3915 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_update_editable (self, TRUE, NULL, &_inner_error_);
#line 3915 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3915 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3915 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28188 "Photo.c"
	}
}


void photo_reimport_editable (Photo* self, GError** error) {
	GError * _inner_error_ = NULL;
#line 3918 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3919 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_update_editable (self, FALSE, NULL, &_inner_error_);
#line 3919 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3919 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3919 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28205 "Photo.c"
	}
}


static void _vala_array_add107 (gchar** * array, int* length, int* size, gchar* value) {
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 28217 "Photo.c"
	}
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 28223 "Photo.c"
}


static void _vala_array_add108 (gchar** * array, int* length, int* size, gchar* value) {
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 28234 "Photo.c"
	}
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 28240 "Photo.c"
}


static void _vala_array_add109 (gchar** * array, int* length, int* size, gchar* value) {
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 28251 "Photo.c"
	}
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 28257 "Photo.c"
}


static void _vala_array_add110 (gchar** * array, int* length, int* size, gchar* value) {
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 28268 "Photo.c"
	}
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 28274 "Photo.c"
}


static void _vala_array_add111 (gchar** * array, int* length, int* size, gchar* value) {
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 28285 "Photo.c"
	}
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 28291 "Photo.c"
}


static void _vala_array_add112 (gchar** * array, int* length, int* size, gchar* value) {
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((*length) == (*size)) {
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 28302 "Photo.c"
	}
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[(*length)++] = value;
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
	(*array)[*length] = NULL;
#line 28308 "Photo.c"
}


static void photo_update_editable (Photo* self, gboolean only_attributes, PhotoFileReader* new_reader, GError** error) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_;
	PhotoFileReader* old_reader = NULL;
	PhotoFileReader* _tmp5_;
	PhotoFileReader* _tmp6_ = NULL;
	PhotoFileReader* _tmp7_;
	PhotoFileReader* reader = NULL;
	PhotoFileReader* _tmp9_;
	PhotoFileReader* _tmp10_;
	gboolean timestamp_changed = FALSE;
	gboolean filesize_changed = FALSE;
	gboolean is_new_editable = FALSE;
	BackingPhotoID editable_id = {0};
	BackingPhotoID _tmp11_ = {0};
	GFile* file = NULL;
	PhotoFileReader* _tmp12_;
	GFile* _tmp13_;
	DetectedPhotoInformation* detected = NULL;
	BackingPhotoRow* backing = NULL;
	GFile* _tmp14_;
	DetectedPhotoInformation* _tmp15_ = NULL;
	BackingPhotoRow* _tmp16_;
	gboolean _tmp17_;
	gboolean _tmp35_;
	PhotoFileReader* _tmp94_;
	gboolean _tmp100_ = FALSE;
	gboolean _tmp101_;
	gchar** alteration_list = NULL;
	gchar** _tmp112_;
	gint alteration_list_length1;
	gint _alteration_list_size_;
	gboolean _tmp113_;
	gboolean _tmp121_ = FALSE;
	gboolean _tmp122_;
	gchar** _tmp131_;
	gint _tmp131__length1;
	GError * _inner_error_ = NULL;
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((new_reader == NULL) || IS_PHOTO_FILE_READER (new_reader));
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = only_attributes;
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_) {
#line 28359 "Photo.c"
		PhotoFileReader* _tmp3_;
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = new_reader;
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp3_ == NULL;
#line 28365 "Photo.c"
	} else {
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = FALSE;
#line 28369 "Photo.c"
	}
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = TRUE;
#line 28375 "Photo.c"
	} else {
		gboolean _tmp4_;
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = only_attributes;
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = !_tmp4_;
#line 28382 "Photo.c"
	}
#line 3926 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp0_, "(only_attributes && new_reader == null) || (!only_attributes)");
#line 3928 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_get_editable_reader (self);
#line 3928 "/home/jens/Source/shotwell/src/Photo.vala"
	old_reader = _tmp5_;
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = new_reader;
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _tmp7_;
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_ == NULL) {
#line 28396 "Photo.c"
		PhotoFileReader* _tmp8_;
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = old_reader;
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp8_;
#line 28402 "Photo.c"
	}
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _photo_file_adapter_ref0 (_tmp6_);
#line 3930 "/home/jens/Source/shotwell/src/Photo.vala"
	reader = _tmp9_;
#line 3931 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = reader;
#line 3931 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp10_ == NULL) {
#line 3932 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_detach_editable (self, FALSE, TRUE, TRUE);
#line 3934 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (reader);
#line 3934 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (old_reader);
#line 3934 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28420 "Photo.c"
	}
#line 3937 "/home/jens/Source/shotwell/src/Photo.vala"
	timestamp_changed = FALSE;
#line 3938 "/home/jens/Source/shotwell/src/Photo.vala"
	filesize_changed = FALSE;
#line 3939 "/home/jens/Source/shotwell/src/Photo.vala"
	is_new_editable = FALSE;
#line 3941 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_editable_id (self, &_tmp11_);
#line 3941 "/home/jens/Source/shotwell/src/Photo.vala"
	editable_id = _tmp11_;
#line 3942 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = reader;
#line 3942 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 3942 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp13_;
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = file;
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = photo_query_backing_photo_row (self, _tmp14_, PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5, &_tmp15_, &_inner_error_);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
	detected = _tmp15_;
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
	backing = _tmp16_;
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (reader);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (old_reader);
#line 3945 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 28462 "Photo.c"
	}
#line 3949 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = backing_photo_id_is_invalid (&editable_id);
#line 3949 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp17_) {
#line 28468 "Photo.c"
		BackingPhotoRow* _tmp18_;
#line 3951 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = backing;
#line 3951 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp18_ != NULL) {
#line 28474 "Photo.c"
			BackingPhotoTable* _tmp19_;
			BackingPhotoTable* _tmp20_;
			BackingPhotoRow* _tmp21_;
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = backing_photo_table_get_instance ();
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = _tmp19_;
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = backing;
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
			backing_photo_table_add (_tmp20_, _tmp21_, &_inner_error_);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp20_);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (reader);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (old_reader);
#line 3952 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 28504 "Photo.c"
			}
			{
				PhotoRow* _tmp22_;
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = self->row;
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_lock (&self->priv->__lock_row);
#line 28512 "Photo.c"
				{
					PhotoTable* _tmp23_;
					PhotoTable* _tmp24_;
					PhotoRow* _tmp25_;
					BackingPhotoRow* _tmp26_;
					BackingPhotoID _tmp27_;
					BackingPhotoRow* _tmp28_;
					BackingPhotoRow* _tmp29_;
					BackingPhotoRow* _tmp30_;
					BackingPhotoRow* _tmp31_;
					BackingPhotoRow* _tmp32_;
					Orientation _tmp33_;
#line 3954 "/home/jens/Source/shotwell/src/Photo.vala"
					timestamp_changed = TRUE;
#line 3955 "/home/jens/Source/shotwell/src/Photo.vala"
					filesize_changed = TRUE;
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp23_ = photo_table_get_instance ();
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp24_ = _tmp23_;
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp25_ = self->row;
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp26_ = backing;
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp27_ = _tmp26_->id;
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					photo_table_attach_editable (_tmp24_, _tmp25_, &_tmp27_, &_inner_error_);
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					_database_table_unref0 (_tmp24_);
#line 3957 "/home/jens/Source/shotwell/src/Photo.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 28545 "Photo.c"
						goto __finally404;
					}
#line 3958 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp28_ = backing;
#line 3958 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp29_ = _backing_photo_row_ref0 (_tmp28_);
#line 3958 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (self->priv->editable);
#line 3958 "/home/jens/Source/shotwell/src/Photo.vala"
					self->priv->editable = _tmp29_;
#line 3959 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp30_ = self->priv->editable;
#line 3959 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31_ = _backing_photo_row_ref0 (_tmp30_);
#line 3959 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (self->backing_photo_row);
#line 3959 "/home/jens/Source/shotwell/src/Photo.vala"
					self->backing_photo_row = _tmp31_;
#line 3960 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp32_ = self->backing_photo_row;
#line 3960 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp33_ = _tmp32_->original_orientation;
#line 3960 "/home/jens/Source/shotwell/src/Photo.vala"
					photo_set_orientation (self, _tmp33_);
#line 28570 "Photo.c"
				}
				__finally404:
				{
					PhotoRow* _tmp34_;
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp34_ = self->row;
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 28579 "Photo.c"
				}
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					g_propagate_error (error, _inner_error_);
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (backing);
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					_detected_photo_information_unref0 (detected);
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (file);
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (reader);
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (old_reader);
#line 3953 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 28597 "Photo.c"
				}
			}
		}
#line 3963 "/home/jens/Source/shotwell/src/Photo.vala"
		is_new_editable = TRUE;
#line 28603 "Photo.c"
	}
#line 3966 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = only_attributes;
#line 3966 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp35_) {
#line 28609 "Photo.c"
		gboolean _tmp36_;
		GFileInfo* info = NULL;
		GTimeVal timestamp = {0};
		GFileInfo* _tmp45_;
		GTimeVal _tmp46_ = {0};
		BackingPhotoTable* _tmp47_;
		BackingPhotoTable* _tmp48_;
		BackingPhotoID _tmp49_;
		GTimeVal _tmp50_;
		glong _tmp51_;
		GFileInfo* _tmp52_;
		gint64 _tmp53_;
#line 3968 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp36_ = backing_photo_id_is_valid (&editable_id);
#line 3968 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_assert (_tmp36_, "editable_id.is_valid()");
#line 28626 "Photo.c"
		{
			GFileInfo* _tmp37_ = NULL;
			GFile* _tmp38_;
			GFileInfo* _tmp39_;
			GFileInfo* _tmp40_;
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp38_ = file;
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp39_ = g_file_query_filesystem_info (_tmp38_, DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES, NULL, &_inner_error_);
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp37_ = _tmp39_;
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 28640 "Photo.c"
				goto __catch405_g_error;
			}
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp40_ = _tmp37_;
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp37_ = NULL;
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 3972 "/home/jens/Source/shotwell/src/Photo.vala"
			info = _tmp40_;
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp37_);
#line 28653 "Photo.c"
		}
		goto __finally405;
		__catch405_g_error:
		{
			GError* err = NULL;
			gchar* _tmp41_;
			gchar* _tmp42_;
			GError* _tmp43_;
			const gchar* _tmp44_;
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 3974 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 3974 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = _tmp41_;
#line 3974 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp43_ = err;
#line 3974 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp44_ = _tmp43_->message;
#line 3974 "/home/jens/Source/shotwell/src/Photo.vala"
			g_warning ("Photo.vala:3974: Unable to read editable filesystem info for %s: %s", _tmp42_, _tmp44_);
#line 3974 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp42_);
#line 3975 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_detach_editable (self, FALSE, TRUE, TRUE);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (reader);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (old_reader);
#line 3977 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 28697 "Photo.c"
		}
		__finally405:
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (reader);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (old_reader);
#line 3971 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 28718 "Photo.c"
		}
#line 3980 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = info;
#line 3980 "/home/jens/Source/shotwell/src/Photo.vala"
		g_file_info_get_modification_time (_tmp45_, &_tmp46_);
#line 3980 "/home/jens/Source/shotwell/src/Photo.vala"
		timestamp = _tmp46_;
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = backing_photo_table_get_instance ();
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = _tmp47_;
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = editable_id;
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp50_ = timestamp;
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp51_ = _tmp50_.tv_sec;
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp52_ = info;
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp53_ = g_file_info_get_size (_tmp52_);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		backing_photo_table_update_attributes (_tmp48_, &_tmp49_, (time_t) _tmp51_, _tmp53_, &_inner_error_);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		_database_table_unref0 (_tmp48_);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (info);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			_backing_photo_row_unref0 (backing);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (reader);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			_photo_file_adapter_unref0 (old_reader);
#line 3982 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 28762 "Photo.c"
		}
		{
			PhotoRow* _tmp54_;
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp54_ = self->row;
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_row);
#line 28770 "Photo.c"
			{
				BackingPhotoRow* _tmp55_;
				time_t _tmp56_;
				GTimeVal _tmp57_;
				glong _tmp58_;
				BackingPhotoRow* _tmp59_;
				gint64 _tmp60_;
				GFileInfo* _tmp61_;
				gint64 _tmp62_;
				BackingPhotoRow* _tmp63_;
				GTimeVal _tmp64_;
				glong _tmp65_;
				BackingPhotoRow* _tmp66_;
				GFileInfo* _tmp67_;
				gint64 _tmp68_;
#line 3985 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp55_ = self->priv->editable;
#line 3985 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp56_ = _tmp55_->timestamp;
#line 3985 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp57_ = timestamp;
#line 3985 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp58_ = _tmp57_.tv_sec;
#line 3985 "/home/jens/Source/shotwell/src/Photo.vala"
				timestamp_changed = _tmp56_ != ((time_t) _tmp58_);
#line 3986 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp59_ = self->priv->editable;
#line 3986 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp60_ = _tmp59_->filesize;
#line 3986 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp61_ = info;
#line 3986 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp62_ = g_file_info_get_size (_tmp61_);
#line 3986 "/home/jens/Source/shotwell/src/Photo.vala"
				filesize_changed = _tmp60_ != _tmp62_;
#line 3988 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp63_ = self->priv->editable;
#line 3988 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp64_ = timestamp;
#line 3988 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp65_ = _tmp64_.tv_sec;
#line 3988 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp63_->timestamp = (time_t) _tmp65_;
#line 3989 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp66_ = self->priv->editable;
#line 3989 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp67_ = info;
#line 3989 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp68_ = g_file_info_get_size (_tmp67_);
#line 3989 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp66_->filesize = _tmp68_;
#line 28822 "Photo.c"
			}
			__finally406:
			{
				PhotoRow* _tmp69_;
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp69_ = self->row;
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_row);
#line 28831 "Photo.c"
			}
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (info);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (reader);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (old_reader);
#line 3984 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 28851 "Photo.c"
			}
		}
#line 3966 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (info);
#line 28856 "Photo.c"
	} else {
		gboolean _tmp70_ = FALSE;
		gboolean _tmp71_;
#line 3993 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp71_ = backing_photo_id_is_valid (&editable_id);
#line 3993 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp71_) {
#line 28864 "Photo.c"
			gboolean _tmp72_;
#line 3993 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp72_ = is_new_editable;
#line 3993 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp70_ = !_tmp72_;
#line 28870 "Photo.c"
		} else {
#line 3993 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp70_ = FALSE;
#line 28874 "Photo.c"
		}
#line 3993 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp70_) {
#line 28878 "Photo.c"
			BackingPhotoRow* _tmp73_;
			BackingPhotoID _tmp74_;
			BackingPhotoTable* _tmp75_;
			BackingPhotoTable* _tmp76_;
			BackingPhotoRow* _tmp77_;
#line 3998 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp73_ = backing;
#line 3998 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp74_ = editable_id;
#line 3998 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp73_->id = _tmp74_;
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp75_ = backing_photo_table_get_instance ();
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp76_ = _tmp75_;
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp77_ = backing;
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
			backing_photo_table_update (_tmp76_, _tmp77_, &_inner_error_);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp76_);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (reader);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (old_reader);
#line 3999 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 28916 "Photo.c"
			}
			{
				PhotoRow* _tmp78_;
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp78_ = self->row;
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_lock (&self->priv->__lock_row);
#line 28924 "Photo.c"
				{
					BackingPhotoRow* _tmp79_;
					time_t _tmp80_;
					BackingPhotoRow* _tmp81_;
					time_t _tmp82_;
					BackingPhotoRow* _tmp83_;
					gint64 _tmp84_;
					BackingPhotoRow* _tmp85_;
					gint64 _tmp86_;
					BackingPhotoRow* _tmp87_;
					BackingPhotoRow* _tmp88_;
					BackingPhotoRow* _tmp89_;
					BackingPhotoRow* _tmp90_;
					BackingPhotoRow* _tmp91_;
					Orientation _tmp92_;
#line 4001 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp79_ = self->priv->editable;
#line 4001 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp80_ = _tmp79_->timestamp;
#line 4001 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp81_ = backing;
#line 4001 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp82_ = _tmp81_->timestamp;
#line 4001 "/home/jens/Source/shotwell/src/Photo.vala"
					timestamp_changed = _tmp80_ != _tmp82_;
#line 4002 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp83_ = self->priv->editable;
#line 4002 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp84_ = _tmp83_->filesize;
#line 4002 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp85_ = backing;
#line 4002 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp86_ = _tmp85_->filesize;
#line 4002 "/home/jens/Source/shotwell/src/Photo.vala"
					filesize_changed = _tmp84_ != _tmp86_;
#line 4004 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp87_ = backing;
#line 4004 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp88_ = _backing_photo_row_ref0 (_tmp87_);
#line 4004 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (self->priv->editable);
#line 4004 "/home/jens/Source/shotwell/src/Photo.vala"
					self->priv->editable = _tmp88_;
#line 4005 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp89_ = self->priv->editable;
#line 4005 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp90_ = _backing_photo_row_ref0 (_tmp89_);
#line 4005 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (self->backing_photo_row);
#line 4005 "/home/jens/Source/shotwell/src/Photo.vala"
					self->backing_photo_row = _tmp90_;
#line 4006 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp91_ = self->backing_photo_row;
#line 4006 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp92_ = _tmp91_->original_orientation;
#line 4006 "/home/jens/Source/shotwell/src/Photo.vala"
					photo_set_orientation (self, _tmp92_);
#line 28982 "Photo.c"
				}
				__finally407:
				{
					PhotoRow* _tmp93_;
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp93_ = self->row;
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 28991 "Photo.c"
				}
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					g_propagate_error (error, _inner_error_);
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (backing);
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					_detected_photo_information_unref0 (detected);
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (file);
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (reader);
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					_photo_file_adapter_unref0 (old_reader);
#line 4000 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 29009 "Photo.c"
				}
			}
		}
	}
#line 4012 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp94_ = new_reader;
#line 4012 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp94_ != NULL) {
#line 29018 "Photo.c"
		{
			PhotoBackingReaders* _tmp95_;
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp95_ = self->priv->readers;
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_lock (&self->priv->__lock_readers);
#line 29025 "Photo.c"
			{
				PhotoBackingReaders* _tmp96_;
				PhotoFileReader* _tmp97_;
				PhotoFileReader* _tmp98_;
#line 4014 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp96_ = self->priv->readers;
#line 4014 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp97_ = new_reader;
#line 4014 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp98_ = _photo_file_adapter_ref0 (_tmp97_);
#line 4014 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (_tmp96_->editable);
#line 4014 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp96_->editable = _tmp98_;
#line 29040 "Photo.c"
			}
			__finally408:
			{
				PhotoBackingReaders* _tmp99_;
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp99_ = self->priv->readers;
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 29049 "Photo.c"
			}
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (backing);
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (reader);
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (old_reader);
#line 4013 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 29067 "Photo.c"
			}
		}
	}
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp101_ = only_attributes;
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp101_) {
#line 29075 "Photo.c"
		PhotoFileReader* _tmp102_;
		PhotoFileReader* _tmp103_;
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp102_ = reader;
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp103_ = old_reader;
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp100_ = _tmp102_ != _tmp103_;
#line 29084 "Photo.c"
	} else {
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp100_ = FALSE;
#line 29088 "Photo.c"
	}
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp100_) {
#line 29092 "Photo.c"
		GFile* _tmp104_ = NULL;
		PhotoFileReader* _tmp105_;
		GFile* _tmp108_ = NULL;
		PhotoFileReader* _tmp109_;
#line 4019 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_baseline_replaced (self);
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp105_ = old_reader;
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp105_ != NULL) {
#line 29103 "Photo.c"
			PhotoFileReader* _tmp106_;
			GFile* _tmp107_;
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp106_ = old_reader;
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp107_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp106_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp104_);
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp104_ = _tmp107_;
#line 29114 "Photo.c"
		} else {
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp104_);
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp104_ = NULL;
#line 29120 "Photo.c"
		}
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp109_ = new_reader;
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp109_ != NULL) {
#line 29126 "Photo.c"
			PhotoFileReader* _tmp110_;
			GFile* _tmp111_;
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp110_ = new_reader;
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp111_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp110_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp108_);
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp108_ = _tmp111_;
#line 29137 "Photo.c"
		} else {
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp108_);
#line 4021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp108_ = NULL;
#line 29143 "Photo.c"
		}
#line 4020 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_editable_replaced (self, _tmp104_, _tmp108_);
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp108_);
#line 4018 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp104_);
#line 29151 "Photo.c"
	}
#line 4024 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp112_ = g_new0 (gchar*, 0 + 1);
#line 4024 "/home/jens/Source/shotwell/src/Photo.vala"
	alteration_list = _tmp112_;
#line 4024 "/home/jens/Source/shotwell/src/Photo.vala"
	alteration_list_length1 = 0;
#line 4024 "/home/jens/Source/shotwell/src/Photo.vala"
	_alteration_list_size_ = alteration_list_length1;
#line 4025 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp113_ = timestamp_changed;
#line 4025 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp113_) {
#line 29165 "Photo.c"
		gchar** _tmp114_;
		gint _tmp114__length1;
		gchar* _tmp115_;
		gchar** _tmp116_;
		gint _tmp116__length1;
		gchar* _tmp117_;
		gboolean _tmp118_;
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp114_ = alteration_list;
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp114__length1 = alteration_list_length1;
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp115_ = g_strdup ("metadata:editable-timestamp");
#line 4026 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add107 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp115_);
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp116_ = alteration_list;
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp116__length1 = alteration_list_length1;
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp117_ = g_strdup ("metadata:baseline-timestamp");
#line 4027 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add108 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp117_);
#line 4029 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp118_ = photo_is_editable_source (self);
#line 4029 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp118_) {
#line 29193 "Photo.c"
			gchar** _tmp119_;
			gint _tmp119__length1;
			gchar* _tmp120_;
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp119_ = alteration_list;
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp119__length1 = alteration_list_length1;
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp120_ = g_strdup ("metadata:source-timestamp");
#line 4030 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add109 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp120_);
#line 29205 "Photo.c"
		}
	}
#line 4033 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp122_ = filesize_changed;
#line 4033 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp122_) {
#line 4033 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp121_ = TRUE;
#line 29214 "Photo.c"
	} else {
		PhotoFileReader* _tmp123_;
#line 4033 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp123_ = new_reader;
#line 4033 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp121_ = _tmp123_ != NULL;
#line 29221 "Photo.c"
	}
#line 4033 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp121_) {
#line 29225 "Photo.c"
		gchar** _tmp124_;
		gint _tmp124__length1;
		gchar* _tmp125_;
		gchar** _tmp126_;
		gint _tmp126__length1;
		gchar* _tmp127_;
		gboolean _tmp128_;
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp124_ = alteration_list;
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp124__length1 = alteration_list_length1;
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp125_ = g_strdup ("image:editable");
#line 4034 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add110 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp125_);
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp126_ = alteration_list;
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp126__length1 = alteration_list_length1;
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp127_ = g_strdup ("image:baseline");
#line 4035 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_array_add111 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp127_);
#line 4037 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp128_ = photo_is_editable_source (self);
#line 4037 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp128_) {
#line 29253 "Photo.c"
			gchar** _tmp129_;
			gint _tmp129__length1;
			gchar* _tmp130_;
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp129_ = alteration_list;
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp129__length1 = alteration_list_length1;
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp130_ = g_strdup ("image:source");
#line 4038 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_array_add112 (&alteration_list, &alteration_list_length1, &_alteration_list_size_, _tmp130_);
#line 29265 "Photo.c"
		}
	}
#line 4041 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp131_ = alteration_list;
#line 4041 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp131__length1 = alteration_list_length1;
#line 4041 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp131__length1 > 0) {
#line 29274 "Photo.c"
		gchar** _tmp132_;
		gint _tmp132__length1;
		Alteration* _tmp133_;
		Alteration* _tmp134_;
#line 4042 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp132_ = alteration_list;
#line 4042 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp132__length1 = alteration_list_length1;
#line 4042 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp133_ = alteration_new_from_array (_tmp132_, _tmp132__length1);
#line 4042 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp134_ = _tmp133_;
#line 4042 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp134_);
#line 4042 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp134_);
#line 29291 "Photo.c"
	}
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	alteration_list = (_vala_array_free (alteration_list, alteration_list_length1, (GDestroyNotify) g_free), NULL);
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (backing);
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	_detected_photo_information_unref0 (detected);
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (reader);
#line 3924 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (old_reader);
#line 29305 "Photo.c"
}


static void photo_detach_editable (Photo* self, gboolean delete_editable, gboolean remove_transformations, gboolean notify) {
	gboolean has_editable = FALSE;
	GFile* editable_file = NULL;
	gboolean _tmp8_;
	gboolean _tmp28_;
	gboolean _tmp29_;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_;
	gboolean _tmp42_ = FALSE;
	gboolean _tmp43_ = FALSE;
	gboolean _tmp44_;
	GError * _inner_error_ = NULL;
#line 4045 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4046 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_halt_monitoring_editable (self);
#line 4048 "/home/jens/Source/shotwell/src/Photo.vala"
	has_editable = FALSE;
#line 4049 "/home/jens/Source/shotwell/src/Photo.vala"
	editable_file = NULL;
#line 29329 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 29336 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
#line 4051 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 4051 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 4051 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp2_ != NULL) {
#line 29346 "Photo.c"
				PhotoBackingReaders* _tmp3_;
				PhotoFileReader* _tmp4_;
				GFile* _tmp5_;
				PhotoBackingReaders* _tmp6_;
#line 4052 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = self->priv->readers;
#line 4052 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = _tmp3_->editable;
#line 4052 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 4052 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (editable_file);
#line 4052 "/home/jens/Source/shotwell/src/Photo.vala"
				editable_file = _tmp5_;
#line 4053 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = self->priv->readers;
#line 4053 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_file_adapter_unref0 (_tmp6_->editable);
#line 4053 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_->editable = NULL;
#line 4054 "/home/jens/Source/shotwell/src/Photo.vala"
				has_editable = TRUE;
#line 29369 "Photo.c"
			}
		}
		__finally409:
		{
			PhotoBackingReaders* _tmp7_;
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = self->priv->readers;
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 29379 "Photo.c"
		}
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (editable_file);
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 4050 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 29391 "Photo.c"
		}
	}
#line 4058 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = has_editable;
#line 4058 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_) {
#line 29398 "Photo.c"
		BackingPhotoID editable_id = {0};
#line 4059 "/home/jens/Source/shotwell/src/Photo.vala"
		backing_photo_id_init (&editable_id, BACKING_PHOTO_ID_INVALID);
#line 29402 "Photo.c"
		{
			{
				PhotoRow* _tmp9_;
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = self->row;
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
				g_rec_mutex_lock (&self->priv->__lock_row);
#line 29410 "Photo.c"
				{
					PhotoRow* _tmp10_;
					BackingPhotoID _tmp11_;
					gboolean _tmp12_;
					PhotoRow* _tmp16_;
					BackingPhotoRow* _tmp17_;
					BackingPhotoRow* _tmp18_;
#line 4062 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp10_ = self->row;
#line 4062 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp11_ = _tmp10_->editable_id;
#line 4062 "/home/jens/Source/shotwell/src/Photo.vala"
					editable_id = _tmp11_;
#line 4063 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = backing_photo_id_is_valid (&editable_id);
#line 4063 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_tmp12_) {
#line 29428 "Photo.c"
						PhotoTable* _tmp13_;
						PhotoTable* _tmp14_;
						PhotoRow* _tmp15_;
#line 4064 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp13_ = photo_table_get_instance ();
#line 4064 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp14_ = _tmp13_;
#line 4064 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp15_ = self->row;
#line 4064 "/home/jens/Source/shotwell/src/Photo.vala"
						photo_table_detach_editable (_tmp14_, _tmp15_, &_inner_error_);
#line 4064 "/home/jens/Source/shotwell/src/Photo.vala"
						_database_table_unref0 (_tmp14_);
#line 4064 "/home/jens/Source/shotwell/src/Photo.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 29444 "Photo.c"
							goto __finally411;
						}
					}
#line 4065 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = self->row;
#line 4065 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = _tmp16_->master;
#line 4065 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = _backing_photo_row_ref0 (_tmp17_);
#line 4065 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (self->backing_photo_row);
#line 4065 "/home/jens/Source/shotwell/src/Photo.vala"
					self->backing_photo_row = _tmp18_;
#line 29458 "Photo.c"
				}
				__finally411:
				{
					PhotoRow* _tmp19_;
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = self->row;
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_row);
#line 29467 "Photo.c"
				}
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_inner_error_->domain == DATABASE_ERROR) {
#line 29473 "Photo.c"
						goto __catch410_database_error;
					}
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (editable_file);
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 4061 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 29484 "Photo.c"
				}
			}
		}
		goto __finally410;
		__catch410_database_error:
		{
			GError* err = NULL;
			GError* _tmp20_;
			const gchar* _tmp21_;
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 4068 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = err;
#line 4068 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = _tmp20_->message;
#line 4068 "/home/jens/Source/shotwell/src/Photo.vala"
			g_warning ("Photo.vala:4068: Unable to remove editable from PhotoTable: %s", _tmp21_);
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 29506 "Photo.c"
		}
		__finally410:
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (editable_file);
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 4060 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 29519 "Photo.c"
		}
		{
			gboolean _tmp22_;
#line 4072 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = backing_photo_id_is_valid (&editable_id);
#line 4072 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp22_) {
#line 29527 "Photo.c"
				BackingPhotoTable* _tmp23_;
				BackingPhotoTable* _tmp24_;
				BackingPhotoID _tmp25_;
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = backing_photo_table_get_instance ();
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = _tmp23_;
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = editable_id;
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
				backing_photo_table_remove (_tmp24_, &_tmp25_, &_inner_error_);
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
				_database_table_unref0 (_tmp24_);
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
					if (_inner_error_->domain == DATABASE_ERROR) {
#line 29545 "Photo.c"
						goto __catch412_database_error;
					}
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (editable_file);
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
					g_clear_error (&_inner_error_);
#line 4073 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 29556 "Photo.c"
				}
			}
		}
		goto __finally412;
		__catch412_database_error:
		{
			GError* err = NULL;
			GError* _tmp26_;
			const gchar* _tmp27_;
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 4075 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = err;
#line 4075 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = _tmp26_->message;
#line 4075 "/home/jens/Source/shotwell/src/Photo.vala"
			g_warning ("Photo.vala:4075: Unable to remove editable from BackingPhotoTable: %s", _tmp27_);
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 29578 "Photo.c"
		}
		__finally412:
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (editable_file);
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 4071 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 29591 "Photo.c"
		}
	}
#line 4079 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = remove_transformations;
#line 4079 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp28_) {
#line 4080 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_internal_remove_all_transformations (self, FALSE);
#line 29600 "Photo.c"
	}
#line 4082 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = has_editable;
#line 4082 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp29_) {
#line 29606 "Photo.c"
		GFile* _tmp30_;
#line 4083 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_baseline_replaced (self);
#line 4084 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = editable_file;
#line 4084 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_notify_editable_replaced (self, _tmp30_, NULL);
#line 29614 "Photo.c"
	}
#line 4087 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = delete_editable;
#line 4087 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp32_) {
#line 29620 "Photo.c"
		GFile* _tmp33_;
#line 4087 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp33_ = editable_file;
#line 4087 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = _tmp33_ != NULL;
#line 29626 "Photo.c"
	} else {
#line 4087 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = FALSE;
#line 29630 "Photo.c"
	}
#line 4087 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp31_) {
#line 29634 "Photo.c"
		{
			GFile* _tmp34_;
#line 4089 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp34_ = editable_file;
#line 4089 "/home/jens/Source/shotwell/src/Photo.vala"
			g_file_trash (_tmp34_, NULL, &_inner_error_);
#line 4089 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 29643 "Photo.c"
				goto __catch413_g_error;
			}
		}
		goto __finally413;
		__catch413_g_error:
		{
			GError* err = NULL;
			GFile* _tmp35_;
			gchar* _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
			gchar* _tmp39_;
			GError* _tmp40_;
			const gchar* _tmp41_;
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			err = _inner_error_;
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			_inner_error_ = NULL;
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp35_ = editable_file;
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp36_ = g_file_get_path (_tmp35_);
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp37_ = _tmp36_;
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp38_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp39_ = _tmp38_;
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp40_ = err;
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = _tmp40_->message;
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			g_warning ("Photo.vala:4091: Unable to trash editable %s for %s: %s", _tmp37_, _tmp39_, _tmp41_);
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp39_);
#line 4091 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (_tmp37_);
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_error_free0 (err);
#line 29684 "Photo.c"
		}
		__finally413:
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (editable_file);
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 4088 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 29697 "Photo.c"
		}
	}
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = has_editable;
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp44_) {
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = TRUE;
#line 29706 "Photo.c"
	} else {
		gboolean _tmp45_;
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp45_ = remove_transformations;
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = _tmp45_;
#line 29713 "Photo.c"
	}
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp43_) {
#line 29717 "Photo.c"
		gboolean _tmp46_;
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = notify;
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = _tmp46_;
#line 29723 "Photo.c"
	} else {
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp42_ = FALSE;
#line 29727 "Photo.c"
	}
#line 4096 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp42_) {
#line 29731 "Photo.c"
		Alteration* _tmp47_;
		Alteration* _tmp48_;
#line 4097 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = alteration_new ("image", "revert");
#line 4097 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = _tmp47_;
#line 4097 "/home/jens/Source/shotwell/src/Photo.vala"
		data_object_notify_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject), _tmp48_);
#line 4097 "/home/jens/Source/shotwell/src/Photo.vala"
		_alteration_unref0 (_tmp48_);
#line 29742 "Photo.c"
	}
#line 4045 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (editable_file);
#line 29746 "Photo.c"
}


static void _photo_on_reimport_editable_one_shot_callback (gpointer self) {
#line 4119 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_on_reimport_editable ((Photo*) self);
#line 29753 "Photo.c"
}


static void _photo_on_update_editable_attributes_one_shot_callback (gpointer self) {
#line 4128 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_on_update_editable_attributes ((Photo*) self);
#line 29760 "Photo.c"
}


static void _photo_on_remove_editable_one_shot_callback (gpointer self) {
#line 4137 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_on_remove_editable ((Photo*) self);
#line 29767 "Photo.c"
}


static void photo_on_editable_file_changed (Photo* self, GFile* file, GFile* other_file, GFileMonitorEvent event) {
	GFileMonitorEvent _tmp12_;
	GEnumValue* _tmp13_;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GFileMonitorEvent _tmp17_;
	GError * _inner_error_ = NULL;
#line 4100 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4100 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 4100 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((other_file == NULL) || G_IS_FILE (other_file));
#line 29785 "Photo.c"
	{
		PhotoBackingReaders* _tmp0_;
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->readers;
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_readers);
#line 29792 "Photo.c"
		{
			PhotoBackingReaders* _tmp1_;
			PhotoFileReader* _tmp2_;
			GFile* _tmp3_;
			PhotoBackingReaders* _tmp4_;
			PhotoFileReader* _tmp5_;
			GFile* _tmp6_;
			GFile* _tmp7_;
			gboolean _tmp8_;
			gboolean _tmp9_;
#line 4103 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = self->priv->readers;
#line 4103 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = _tmp1_->editable;
#line 4103 "/home/jens/Source/shotwell/src/Photo.vala"
			_vala_assert (_tmp2_ != NULL, "readers.editable != null");
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = file;
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->priv->readers;
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _tmp4_->editable;
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _tmp6_;
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = g_file_equal (_tmp3_, _tmp7_);
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = !_tmp8_;
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp7_);
#line 4105 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp9_) {
#line 29827 "Photo.c"
				{
					PhotoBackingReaders* _tmp10_;
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp10_ = self->priv->readers;
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
					g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 29834 "Photo.c"
				}
#line 4109 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 29838 "Photo.c"
			}
		}
		__finally414:
		{
			PhotoBackingReaders* _tmp11_;
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = self->priv->readers;
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_readers);
#line 29848 "Photo.c"
		}
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 4102 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 29858 "Photo.c"
		}
	}
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = event;
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = g_enum_get_value (g_type_class_ref (g_file_monitor_event_get_type ()), _tmp12_);
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = file;
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = g_file_get_path (_tmp14_);
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = _tmp15_;
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:4113: EDITABLE %s: %s", (_tmp13_ != NULL) ? _tmp13_->value_name : NULL, _tmp16_);
#line 4113 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp16_);
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = event;
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (_tmp17_) {
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
		case G_FILE_MONITOR_EVENT_CHANGED:
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
		case G_FILE_MONITOR_EVENT_CREATED:
#line 29883 "Photo.c"
		{
			OneShotScheduler* _tmp18_;
			OneShotScheduler* _tmp20_;
#line 4118 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = self->priv->reimport_editable_scheduler;
#line 4118 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp18_ == NULL) {
#line 29891 "Photo.c"
				OneShotScheduler* _tmp19_;
#line 4119 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = one_shot_scheduler_new ("Photo.reimport_editable", _photo_on_reimport_editable_one_shot_callback, self);
#line 4119 "/home/jens/Source/shotwell/src/Photo.vala"
				_one_shot_scheduler_unref0 (self->priv->reimport_editable_scheduler);
#line 4119 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->reimport_editable_scheduler = _tmp19_;
#line 29899 "Photo.c"
			}
#line 4123 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = self->priv->reimport_editable_scheduler;
#line 4123 "/home/jens/Source/shotwell/src/Photo.vala"
			one_shot_scheduler_after_timeout (_tmp20_, (guint) 1000, TRUE);
#line 4124 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 29907 "Photo.c"
		}
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
		case G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED:
#line 29911 "Photo.c"
		{
			OneShotScheduler* _tmp21_;
			OneShotScheduler* _tmp23_;
#line 4127 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = self->priv->update_editable_attributes_scheduler;
#line 4127 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp21_ == NULL) {
#line 29919 "Photo.c"
				OneShotScheduler* _tmp22_;
#line 4128 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = one_shot_scheduler_new ("Photo.update_editable_attributes", _photo_on_update_editable_attributes_one_shot_callback, self);
#line 4128 "/home/jens/Source/shotwell/src/Photo.vala"
				_one_shot_scheduler_unref0 (self->priv->update_editable_attributes_scheduler);
#line 4128 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->update_editable_attributes_scheduler = _tmp22_;
#line 29927 "Photo.c"
			}
#line 4132 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_ = self->priv->update_editable_attributes_scheduler;
#line 4132 "/home/jens/Source/shotwell/src/Photo.vala"
			one_shot_scheduler_after_timeout (_tmp23_, (guint) 1000, TRUE);
#line 4133 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 29935 "Photo.c"
		}
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
		case G_FILE_MONITOR_EVENT_DELETED:
#line 29939 "Photo.c"
		{
			OneShotScheduler* _tmp24_;
			OneShotScheduler* _tmp26_;
#line 4136 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = self->priv->remove_editable_scheduler;
#line 4136 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp24_ == NULL) {
#line 29947 "Photo.c"
				OneShotScheduler* _tmp25_;
#line 4137 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = one_shot_scheduler_new ("Photo.remove_editable", _photo_on_remove_editable_one_shot_callback, self);
#line 4137 "/home/jens/Source/shotwell/src/Photo.vala"
				_one_shot_scheduler_unref0 (self->priv->remove_editable_scheduler);
#line 4137 "/home/jens/Source/shotwell/src/Photo.vala"
				self->priv->remove_editable_scheduler = _tmp25_;
#line 29955 "Photo.c"
			}
#line 4141 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = self->priv->remove_editable_scheduler;
#line 4141 "/home/jens/Source/shotwell/src/Photo.vala"
			one_shot_scheduler_after_timeout (_tmp26_, (guint) 3000, TRUE);
#line 4142 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 29963 "Photo.c"
		}
		default:
#line 4115 "/home/jens/Source/shotwell/src/Photo.vala"
		case G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT:
#line 29968 "Photo.c"
		{
#line 4147 "/home/jens/Source/shotwell/src/Photo.vala"
			break;
#line 29972 "Photo.c"
		}
	}
#line 4152 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_discard_prefetched (self);
#line 29977 "Photo.c"
}


static void photo_on_reimport_editable (Photo* self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 4155 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4157 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_discard_prefetched (self);
#line 4159 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 4159 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4159 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:4159: Reimporting editable for %s", _tmp1_);
#line 4159 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp1_);
#line 29997 "Photo.c"
	{
#line 4161 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_editable (self, &_inner_error_);
#line 4161 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 30003 "Photo.c"
			goto __catch415_g_error;
		}
	}
	goto __finally415;
	__catch415_g_error:
	{
		GError* err = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 4163 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 4163 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 4163 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = err;
#line 4163 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_->message;
#line 4163 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:4163: Unable to reimport photo %s changed by external edito" \
"r: %s", _tmp3_, _tmp5_);
#line 4163 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp3_);
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 30033 "Photo.c"
	}
	__finally415:
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 4160 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 30044 "Photo.c"
	}
}


static void photo_on_update_editable_attributes (Photo* self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 4168 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4169 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 4169 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4169 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:4169: Updating editable attributes for %s", _tmp1_);
#line 4169 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp1_);
#line 30063 "Photo.c"
	{
#line 4171 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_update_editable_attributes (self, &_inner_error_);
#line 4171 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 30069 "Photo.c"
			goto __catch416_g_error;
		}
	}
	goto __finally416;
	__catch416_g_error:
	{
		GError* err = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 4173 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = err;
#line 4173 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_->message;
#line 4173 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:4173: Unable to update editable attributes: %s", _tmp3_);
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 30091 "Photo.c"
	}
	__finally416:
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 4170 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 30102 "Photo.c"
	}
}


static void photo_on_remove_editable (Photo* self) {
	PhotoFileReader* reader = NULL;
	PhotoFileReader* _tmp0_;
	PhotoFileReader* _tmp1_;
	GFile* file = NULL;
	PhotoFileReader* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	gboolean _tmp5_;
	gchar* _tmp8_;
	gchar* _tmp9_;
#line 4177 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4178 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_editable_reader (self);
#line 4178 "/home/jens/Source/shotwell/src/Photo.vala"
	reader = _tmp0_;
#line 4179 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = reader;
#line 4179 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 4180 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (reader);
#line 4180 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 30132 "Photo.c"
	}
#line 4182 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = reader;
#line 4182 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 4182 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp3_;
#line 4183 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = file;
#line 4183 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = g_file_query_exists (_tmp4_, NULL);
#line 4183 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 30146 "Photo.c"
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 4184 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 4184 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 4184 "/home/jens/Source/shotwell/src/Photo.vala"
		g_debug ("Photo.vala:4184: Not removing editable for %s: file exists", _tmp7_);
#line 4184 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp7_);
#line 4186 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (file);
#line 4186 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_file_adapter_unref0 (reader);
#line 4186 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 30163 "Photo.c"
	}
#line 4189 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 4189 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _tmp8_;
#line 4189 "/home/jens/Source/shotwell/src/Photo.vala"
	g_debug ("Photo.vala:4189: Removing editable for %s: file no longer exists", _tmp9_);
#line 4189 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp9_);
#line 4190 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_detach_editable (self, FALSE, TRUE, TRUE);
#line 4177 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 4177 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (reader);
#line 30179 "Photo.c"
}


void photo_get_original_dimensions (Photo* self, Dimensions* result) {
	Dimensions dim = {0};
	Dimensions _tmp0_ = {0};
	Orientation orientation = 0;
	Orientation _tmp1_;
	Dimensions _tmp2_;
	Dimensions _tmp3_ = {0};
#line 4198 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4199 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_raw_dimensions (self, &_tmp0_);
#line 4199 "/home/jens/Source/shotwell/src/Photo.vala"
	dim = _tmp0_;
#line 4200 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_orientation (self);
#line 4200 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation = _tmp1_;
#line 4202 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = dim;
#line 4202 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation_rotate_dimensions (orientation, &_tmp2_, &_tmp3_);
#line 4202 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = _tmp3_;
#line 4202 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 30208 "Photo.c"
}


void photo_get_master_dimensions (Photo* self, Dimensions* result) {
	Orientation _tmp0_;
	Dimensions _tmp1_ = {0};
	Dimensions _tmp2_ = {0};
#line 4206 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4207 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_original_orientation (self);
#line 4207 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_raw_dimensions (self, &_tmp1_);
#line 4207 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation_rotate_dimensions (_tmp0_, &_tmp1_, &_tmp2_);
#line 4207 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = _tmp2_;
#line 4207 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 30228 "Photo.c"
}


gboolean photo_get_crop (Photo* self, Box* crop, PhotoException exceptions) {
	Box _vala_crop = {0};
	gboolean result = FALSE;
	Box raw = {0};
	Box _tmp0_ = {0};
	gboolean _tmp1_;
	Dimensions dim = {0};
	Dimensions _tmp2_ = {0};
	Orientation orientation = 0;
	Orientation _tmp3_;
	PhotoException _tmp4_;
	gboolean _tmp5_;
#line 4211 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 4213 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_raw_crop (self, &_tmp0_);
#line 4213 "/home/jens/Source/shotwell/src/Photo.vala"
	raw = _tmp0_;
#line 4213 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp1_) {
#line 4214 "/home/jens/Source/shotwell/src/Photo.vala"
		box_init (&_vala_crop, 0, 0, 0, 0);
#line 4216 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 4216 "/home/jens/Source/shotwell/src/Photo.vala"
		if (crop) {
#line 4216 "/home/jens/Source/shotwell/src/Photo.vala"
			*crop = _vala_crop;
#line 30260 "Photo.c"
		}
#line 4216 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 30264 "Photo.c"
	}
#line 4219 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_CROP | PHOTO_EXCEPTION_ORIENTATION, &_tmp2_);
#line 4219 "/home/jens/Source/shotwell/src/Photo.vala"
	dim = _tmp2_;
#line 4220 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_get_orientation (self);
#line 4220 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation = _tmp3_;
#line 4222 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = exceptions;
#line 4222 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_exception_allows (_tmp4_, PHOTO_EXCEPTION_ORIENTATION);
#line 4222 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 30280 "Photo.c"
		Orientation _tmp6_;
		Dimensions _tmp7_;
		Box _tmp8_;
		Box _tmp9_ = {0};
#line 4223 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = orientation;
#line 4223 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = dim;
#line 4223 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = raw;
#line 4223 "/home/jens/Source/shotwell/src/Photo.vala"
		orientation_rotate_box (_tmp6_, &_tmp7_, &_tmp8_, &_tmp9_);
#line 4223 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_crop = _tmp9_;
#line 30295 "Photo.c"
	} else {
		Box _tmp10_;
#line 4225 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = raw;
#line 4225 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_crop = _tmp10_;
#line 30302 "Photo.c"
	}
#line 4227 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 4227 "/home/jens/Source/shotwell/src/Photo.vala"
	if (crop) {
#line 4227 "/home/jens/Source/shotwell/src/Photo.vala"
		*crop = _vala_crop;
#line 30310 "Photo.c"
	}
#line 4227 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 30314 "Photo.c"
}


void photo_set_crop (Photo* self, Box* crop) {
	Dimensions dim = {0};
	Dimensions _tmp0_ = {0};
	Orientation orientation = 0;
	Orientation _tmp1_;
	Box derotated = {0};
	Dimensions _tmp2_;
	Box _tmp3_;
	Box _tmp4_ = {0};
	Box _tmp5_;
	gint _tmp6_;
	Dimensions _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	Box _tmp10_;
	gint _tmp11_;
	Box _tmp12_;
	gint _tmp13_;
	Dimensions _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	Box _tmp17_;
	gint _tmp18_;
	Dimensions _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	Box _tmp22_;
	gint _tmp23_;
	Box _tmp24_;
	gint _tmp25_;
	Dimensions _tmp26_;
	gint _tmp27_;
	gint _tmp28_;
	Box _tmp29_;
#line 4231 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4231 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (crop != NULL);
#line 4232 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_CROP | PHOTO_EXCEPTION_ORIENTATION, &_tmp0_);
#line 4232 "/home/jens/Source/shotwell/src/Photo.vala"
	dim = _tmp0_;
#line 4233 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_orientation (self);
#line 4233 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation = _tmp1_;
#line 4235 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = dim;
#line 4235 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = *crop;
#line 4235 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation_derotate_box (orientation, &_tmp2_, &_tmp3_, &_tmp4_);
#line 4235 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated = _tmp4_;
#line 4237 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = derotated;
#line 4237 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _tmp5_.left;
#line 4237 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = dim;
#line 4237 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_.width;
#line 4237 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = CLAMP (_tmp6_, 0, _tmp8_ - 2);
#line 4237 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated.left = _tmp9_;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = derotated;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp10_.right;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = derotated;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_.left;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = dim;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_.width;
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = CLAMP (_tmp11_, _tmp13_, _tmp15_ - 1);
#line 4238 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated.right = _tmp16_;
#line 4240 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = derotated;
#line 4240 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = _tmp17_.top;
#line 4240 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = dim;
#line 4240 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = _tmp19_.height;
#line 4240 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = CLAMP (_tmp18_, 0, _tmp20_ - 2);
#line 4240 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated.top = _tmp21_;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = derotated;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = _tmp22_.bottom;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = derotated;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = _tmp24_.top;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = dim;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = _tmp26_.height;
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = CLAMP (_tmp23_, _tmp25_, _tmp27_ - 1);
#line 4241 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated.bottom = _tmp28_;
#line 4243 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = derotated;
#line 4243 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_set_raw_crop (self, &_tmp29_);
#line 30432 "Photo.c"
}


gboolean photo_get_straighten (Photo* self, gdouble* theta) {
	gdouble _vala_theta = 0.0;
	gboolean result = FALSE;
	gdouble _tmp0_ = 0.0;
	gboolean _tmp1_;
#line 4246 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 4247 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_raw_straighten (self, &_tmp0_);
#line 4247 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_theta = _tmp0_;
#line 4247 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp1_) {
#line 4248 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 4248 "/home/jens/Source/shotwell/src/Photo.vala"
		if (theta) {
#line 4248 "/home/jens/Source/shotwell/src/Photo.vala"
			*theta = _vala_theta;
#line 30455 "Photo.c"
		}
#line 4248 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 30459 "Photo.c"
	}
#line 4250 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 4250 "/home/jens/Source/shotwell/src/Photo.vala"
	if (theta) {
#line 4250 "/home/jens/Source/shotwell/src/Photo.vala"
		*theta = _vala_theta;
#line 30467 "Photo.c"
	}
#line 4250 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 30471 "Photo.c"
}


void photo_set_straighten (Photo* self, gdouble theta) {
	gdouble _tmp0_;
#line 4253 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4254 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = theta;
#line 4254 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_set_raw_straighten (self, _tmp0_);
#line 30483 "Photo.c"
}


static GdkPixbuf* photo_do_redeye (Photo* self, GdkPixbuf* pixbuf, EditingToolsRedeyeInstance* inst) {
	GdkPixbuf* result = NULL;
	gdouble r = 0.0;
	EditingToolsRedeyeInstance _tmp0_;
	gint _tmp1_;
	gint* x_insets_first_quadrant = NULL;
	EditingToolsRedeyeInstance _tmp2_;
	gint _tmp3_;
	gint* _tmp4_;
	gint x_insets_first_quadrant_length1;
	gint _x_insets_first_quadrant_size_;
	gint i = 0;
	gint x_bounds_min = 0;
	EditingToolsRedeyeInstance _tmp22_;
	GdkPoint _tmp23_;
	gint _tmp24_;
	EditingToolsRedeyeInstance _tmp25_;
	gint _tmp26_;
	gint x_bounds_max = 0;
	EditingToolsRedeyeInstance _tmp27_;
	GdkPoint _tmp28_;
	gint _tmp29_;
	EditingToolsRedeyeInstance _tmp30_;
	gint _tmp31_;
	gint ymin = 0;
	EditingToolsRedeyeInstance _tmp32_;
	GdkPoint _tmp33_;
	gint _tmp34_;
	EditingToolsRedeyeInstance _tmp35_;
	gint _tmp36_;
	gint _tmp37_ = 0;
	gint _tmp38_;
	gint ymax = 0;
	EditingToolsRedeyeInstance _tmp40_;
	GdkPoint _tmp41_;
	gint _tmp42_;
	gint _tmp43_ = 0;
	gint _tmp44_;
	GdkPixbuf* _tmp45_;
	gint _tmp46_;
	gint _tmp47_;
	gint inset_index = 0;
	EditingToolsRedeyeInstance _tmp88_;
	GdkPoint _tmp89_;
	gint _tmp90_;
	EditingToolsRedeyeInstance _tmp91_;
	GdkPoint _tmp92_;
	gint _tmp93_;
	EditingToolsRedeyeInstance _tmp94_;
	gint _tmp95_;
	gint* _tmp96_;
	gint _tmp96__length1;
	GdkPixbuf* _tmp133_;
	GdkPixbuf* _tmp134_;
#line 4257 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 4257 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
#line 4257 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (inst != NULL, NULL);
#line 4267 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = *inst;
#line 4267 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_.radius;
#line 4267 "/home/jens/Source/shotwell/src/Photo.vala"
	r = (gdouble) _tmp1_;
#line 4268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = *inst;
#line 4268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_.radius;
#line 4268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = g_new0 (gint, _tmp3_ + 1);
#line 4268 "/home/jens/Source/shotwell/src/Photo.vala"
	x_insets_first_quadrant = _tmp4_;
#line 4268 "/home/jens/Source/shotwell/src/Photo.vala"
	x_insets_first_quadrant_length1 = _tmp3_ + 1;
#line 4268 "/home/jens/Source/shotwell/src/Photo.vala"
	_x_insets_first_quadrant_size_ = x_insets_first_quadrant_length1;
#line 4270 "/home/jens/Source/shotwell/src/Photo.vala"
	i = 0;
#line 30567 "Photo.c"
	{
		gdouble y = 0.0;
		gdouble _tmp5_;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = r;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
		y = _tmp5_;
#line 30575 "Photo.c"
		{
			gboolean _tmp6_ = FALSE;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = TRUE;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 30582 "Photo.c"
				gdouble _tmp8_;
				gdouble theta = 0.0;
				gdouble _tmp9_;
				gdouble _tmp10_;
				gdouble _tmp11_;
				gint x = 0;
				gdouble _tmp12_;
				gdouble _tmp13_;
				gdouble _tmp14_;
				gint* _tmp15_;
				gint _tmp15__length1;
				gint _tmp16_;
				EditingToolsRedeyeInstance _tmp17_;
				gint _tmp18_;
				gint _tmp19_;
				gint _tmp20_;
				gint _tmp21_;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp6_) {
#line 30602 "Photo.c"
					gdouble _tmp7_;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp7_ = y;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
					y = _tmp7_ - 1.0;
#line 30608 "Photo.c"
				}
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = FALSE;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = y;
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp8_ >= 0.0)) {
#line 4271 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 30618 "Photo.c"
				}
#line 4272 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = y;
#line 4272 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = r;
#line 4272 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = asin (_tmp9_ / _tmp10_);
#line 4272 "/home/jens/Source/shotwell/src/Photo.vala"
				theta = _tmp11_;
#line 4273 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = r;
#line 4273 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = theta;
#line 4273 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = cos (_tmp13_);
#line 4273 "/home/jens/Source/shotwell/src/Photo.vala"
				x = (gint) ((_tmp12_ * _tmp14_) + 0.5);
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = x_insets_first_quadrant;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15__length1 = x_insets_first_quadrant_length1;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = i;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = *inst;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = _tmp17_.radius;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = x;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_[_tmp16_] = _tmp18_ - _tmp19_;
#line 4274 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = _tmp15_[_tmp16_];
#line 4276 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = i;
#line 4276 "/home/jens/Source/shotwell/src/Photo.vala"
				i = _tmp21_ + 1;
#line 30656 "Photo.c"
			}
		}
	}
#line 4279 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = *inst;
#line 4279 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = _tmp22_.center;
#line 4279 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = _tmp23_.x;
#line 4279 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = *inst;
#line 4279 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = _tmp25_.radius;
#line 4279 "/home/jens/Source/shotwell/src/Photo.vala"
	x_bounds_min = _tmp24_ - _tmp26_;
#line 4280 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = *inst;
#line 4280 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = _tmp27_.center;
#line 4280 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = _tmp28_.x;
#line 4280 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = *inst;
#line 4280 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = _tmp30_.radius;
#line 4280 "/home/jens/Source/shotwell/src/Photo.vala"
	x_bounds_max = _tmp29_ + _tmp31_;
#line 4281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = *inst;
#line 4281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = _tmp32_.center;
#line 4281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = _tmp33_.y;
#line 4281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = *inst;
#line 4281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = _tmp35_.radius;
#line 4281 "/home/jens/Source/shotwell/src/Photo.vala"
	ymin = _tmp34_ - _tmp36_;
#line 4282 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = ymin;
#line 4282 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp38_ < 0) {
#line 4282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp37_ = 0;
#line 30702 "Photo.c"
	} else {
		gint _tmp39_;
#line 4282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp39_ = ymin;
#line 4282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp37_ = _tmp39_;
#line 30709 "Photo.c"
	}
#line 4282 "/home/jens/Source/shotwell/src/Photo.vala"
	ymin = _tmp37_;
#line 4283 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = *inst;
#line 4283 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = _tmp40_.center;
#line 4283 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = _tmp41_.y;
#line 4283 "/home/jens/Source/shotwell/src/Photo.vala"
	ymax = _tmp42_;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = ymax;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = pixbuf;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp46_ = gdk_pixbuf_get_height (_tmp45_);
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = _tmp46_;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp44_ > (_tmp47_ - 1)) {
#line 30731 "Photo.c"
		GdkPixbuf* _tmp48_;
		gint _tmp49_;
		gint _tmp50_;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = pixbuf;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = gdk_pixbuf_get_height (_tmp48_);
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp50_ = _tmp49_;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = _tmp50_ - 1;
#line 30743 "Photo.c"
	} else {
		gint _tmp51_;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp51_ = ymax;
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp43_ = _tmp51_;
#line 30750 "Photo.c"
	}
#line 4284 "/home/jens/Source/shotwell/src/Photo.vala"
	ymax = _tmp43_;
#line 4288 "/home/jens/Source/shotwell/src/Photo.vala"
	inset_index = 0;
#line 30756 "Photo.c"
	{
		gint y_it = 0;
		gint _tmp52_;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp52_ = ymin;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
		y_it = _tmp52_;
#line 30764 "Photo.c"
		{
			gboolean _tmp53_ = FALSE;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp53_ = TRUE;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 30771 "Photo.c"
				gint _tmp55_;
				gint _tmp56_;
				gint xmin = 0;
				gint _tmp57_;
				gint* _tmp58_;
				gint _tmp58__length1;
				gint _tmp59_;
				gint _tmp60_;
				gint _tmp61_ = 0;
				gint _tmp62_;
				gint xmax = 0;
				gint _tmp64_;
				gint* _tmp65_;
				gint _tmp65__length1;
				gint _tmp66_;
				gint _tmp67_;
				gint _tmp68_ = 0;
				gint _tmp69_;
				GdkPixbuf* _tmp70_;
				gint _tmp71_;
				gint _tmp72_;
				gint _tmp87_;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp53_) {
#line 30796 "Photo.c"
					gint _tmp54_;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp54_ = y_it;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
					y_it = _tmp54_ + 1;
#line 30802 "Photo.c"
				}
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp53_ = FALSE;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp55_ = y_it;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp56_ = ymax;
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp55_ <= _tmp56_)) {
#line 4289 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 30814 "Photo.c"
				}
#line 4290 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp57_ = x_bounds_min;
#line 4290 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp58_ = x_insets_first_quadrant;
#line 4290 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp58__length1 = x_insets_first_quadrant_length1;
#line 4290 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp59_ = inset_index;
#line 4290 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp60_ = _tmp58_[_tmp59_];
#line 4290 "/home/jens/Source/shotwell/src/Photo.vala"
				xmin = _tmp57_ + _tmp60_;
#line 4291 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp62_ = xmin;
#line 4291 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp62_ < 0) {
#line 4291 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp61_ = 0;
#line 30834 "Photo.c"
				} else {
					gint _tmp63_;
#line 4291 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp63_ = xmin;
#line 4291 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp61_ = _tmp63_;
#line 30841 "Photo.c"
				}
#line 4291 "/home/jens/Source/shotwell/src/Photo.vala"
				xmin = _tmp61_;
#line 4292 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp64_ = x_bounds_max;
#line 4292 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp65_ = x_insets_first_quadrant;
#line 4292 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp65__length1 = x_insets_first_quadrant_length1;
#line 4292 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp66_ = inset_index;
#line 4292 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp67_ = _tmp65_[_tmp66_];
#line 4292 "/home/jens/Source/shotwell/src/Photo.vala"
				xmax = _tmp64_ - _tmp67_;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp69_ = xmax;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp70_ = pixbuf;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp71_ = gdk_pixbuf_get_width (_tmp70_);
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp72_ = _tmp71_;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp69_ > (_tmp72_ - 1)) {
#line 30867 "Photo.c"
					GdkPixbuf* _tmp73_;
					gint _tmp74_;
					gint _tmp75_;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp73_ = pixbuf;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp74_ = gdk_pixbuf_get_width (_tmp73_);
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp75_ = _tmp74_;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp68_ = _tmp75_ - 1;
#line 30879 "Photo.c"
				} else {
					gint _tmp76_;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp76_ = xmax;
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp68_ = _tmp76_;
#line 30886 "Photo.c"
				}
#line 4293 "/home/jens/Source/shotwell/src/Photo.vala"
				xmax = _tmp68_;
#line 30890 "Photo.c"
				{
					gint x_it = 0;
					gint _tmp77_;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp77_ = xmin;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
					x_it = _tmp77_;
#line 30898 "Photo.c"
					{
						gboolean _tmp78_ = FALSE;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp78_ = TRUE;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 30905 "Photo.c"
							gint _tmp80_;
							gint _tmp81_;
							GdkPixbuf* _tmp82_;
							gint _tmp83_;
							gint _tmp84_;
							GdkPixbuf* _tmp85_;
							GdkPixbuf* _tmp86_;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp78_) {
#line 30915 "Photo.c"
								gint _tmp79_;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp79_ = x_it;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
								x_it = _tmp79_ + 1;
#line 30921 "Photo.c"
							}
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp78_ = FALSE;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp80_ = x_it;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp81_ = xmax;
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!(_tmp80_ <= _tmp81_)) {
#line 4295 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 30933 "Photo.c"
							}
#line 4296 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp82_ = pixbuf;
#line 4296 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp83_ = x_it;
#line 4296 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp84_ = y_it;
#line 4296 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp85_ = photo_red_reduce_pixel (self, _tmp82_, _tmp83_, _tmp84_);
#line 4296 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp86_ = _tmp85_;
#line 4296 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp86_);
#line 30947 "Photo.c"
						}
					}
				}
#line 4298 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp87_ = inset_index;
#line 4298 "/home/jens/Source/shotwell/src/Photo.vala"
				inset_index = _tmp87_ + 1;
#line 30955 "Photo.c"
			}
		}
	}
#line 4303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp88_ = *inst;
#line 4303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp89_ = _tmp88_.center;
#line 4303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp90_ = _tmp89_.y;
#line 4303 "/home/jens/Source/shotwell/src/Photo.vala"
	ymin = _tmp90_;
#line 4304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp91_ = *inst;
#line 4304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp92_ = _tmp91_.center;
#line 4304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp93_ = _tmp92_.y;
#line 4304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp94_ = *inst;
#line 4304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp95_ = _tmp94_.radius;
#line 4304 "/home/jens/Source/shotwell/src/Photo.vala"
	ymax = _tmp93_ + _tmp95_;
#line 4305 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp96_ = x_insets_first_quadrant;
#line 4305 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp96__length1 = x_insets_first_quadrant_length1;
#line 4305 "/home/jens/Source/shotwell/src/Photo.vala"
	inset_index = _tmp96__length1 - 1;
#line 30985 "Photo.c"
	{
		gint y_it = 0;
		gint _tmp97_;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp97_ = ymin;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
		y_it = _tmp97_;
#line 30993 "Photo.c"
		{
			gboolean _tmp98_ = FALSE;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp98_ = TRUE;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 31000 "Photo.c"
				gint _tmp100_;
				gint _tmp101_;
				gint xmin = 0;
				gint _tmp102_;
				gint* _tmp103_;
				gint _tmp103__length1;
				gint _tmp104_;
				gint _tmp105_;
				gint _tmp106_ = 0;
				gint _tmp107_;
				gint xmax = 0;
				gint _tmp109_;
				gint* _tmp110_;
				gint _tmp110__length1;
				gint _tmp111_;
				gint _tmp112_;
				gint _tmp113_ = 0;
				gint _tmp114_;
				GdkPixbuf* _tmp115_;
				gint _tmp116_;
				gint _tmp117_;
				gint _tmp132_;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp98_) {
#line 31025 "Photo.c"
					gint _tmp99_;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp99_ = y_it;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
					y_it = _tmp99_ + 1;
#line 31031 "Photo.c"
				}
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp98_ = FALSE;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp100_ = y_it;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp101_ = ymax;
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp100_ <= _tmp101_)) {
#line 4306 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 31043 "Photo.c"
				}
#line 4307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp102_ = x_bounds_min;
#line 4307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp103_ = x_insets_first_quadrant;
#line 4307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp103__length1 = x_insets_first_quadrant_length1;
#line 4307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp104_ = inset_index;
#line 4307 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp105_ = _tmp103_[_tmp104_];
#line 4307 "/home/jens/Source/shotwell/src/Photo.vala"
				xmin = _tmp102_ + _tmp105_;
#line 4308 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp107_ = xmin;
#line 4308 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp107_ < 0) {
#line 4308 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp106_ = 0;
#line 31063 "Photo.c"
				} else {
					gint _tmp108_;
#line 4308 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp108_ = xmin;
#line 4308 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp106_ = _tmp108_;
#line 31070 "Photo.c"
				}
#line 4308 "/home/jens/Source/shotwell/src/Photo.vala"
				xmin = _tmp106_;
#line 4309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp109_ = x_bounds_max;
#line 4309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp110_ = x_insets_first_quadrant;
#line 4309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp110__length1 = x_insets_first_quadrant_length1;
#line 4309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp111_ = inset_index;
#line 4309 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp112_ = _tmp110_[_tmp111_];
#line 4309 "/home/jens/Source/shotwell/src/Photo.vala"
				xmax = _tmp109_ - _tmp112_;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp114_ = xmax;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp115_ = pixbuf;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp116_ = gdk_pixbuf_get_width (_tmp115_);
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp117_ = _tmp116_;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp114_ > (_tmp117_ - 1)) {
#line 31096 "Photo.c"
					GdkPixbuf* _tmp118_;
					gint _tmp119_;
					gint _tmp120_;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp118_ = pixbuf;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp119_ = gdk_pixbuf_get_width (_tmp118_);
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp120_ = _tmp119_;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp113_ = _tmp120_ - 1;
#line 31108 "Photo.c"
				} else {
					gint _tmp121_;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp121_ = xmax;
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp113_ = _tmp121_;
#line 31115 "Photo.c"
				}
#line 4310 "/home/jens/Source/shotwell/src/Photo.vala"
				xmax = _tmp113_;
#line 31119 "Photo.c"
				{
					gint x_it = 0;
					gint _tmp122_;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp122_ = xmin;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
					x_it = _tmp122_;
#line 31127 "Photo.c"
					{
						gboolean _tmp123_ = FALSE;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp123_ = TRUE;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 31134 "Photo.c"
							gint _tmp125_;
							gint _tmp126_;
							GdkPixbuf* _tmp127_;
							gint _tmp128_;
							gint _tmp129_;
							GdkPixbuf* _tmp130_;
							GdkPixbuf* _tmp131_;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp123_) {
#line 31144 "Photo.c"
								gint _tmp124_;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp124_ = x_it;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
								x_it = _tmp124_ + 1;
#line 31150 "Photo.c"
							}
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp123_ = FALSE;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp125_ = x_it;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp126_ = xmax;
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!(_tmp125_ <= _tmp126_)) {
#line 4312 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 31162 "Photo.c"
							}
#line 4313 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp127_ = pixbuf;
#line 4313 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp128_ = x_it;
#line 4313 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp129_ = y_it;
#line 4313 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp130_ = photo_red_reduce_pixel (self, _tmp127_, _tmp128_, _tmp129_);
#line 4313 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp131_ = _tmp130_;
#line 4313 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp131_);
#line 31176 "Photo.c"
						}
					}
				}
#line 4315 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp132_ = inset_index;
#line 4315 "/home/jens/Source/shotwell/src/Photo.vala"
				inset_index = _tmp132_ - 1;
#line 31184 "Photo.c"
			}
		}
	}
#line 4318 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp133_ = pixbuf;
#line 4318 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp134_ = _g_object_ref0 (_tmp133_);
#line 4318 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp134_;
#line 4318 "/home/jens/Source/shotwell/src/Photo.vala"
	x_insets_first_quadrant = (g_free (x_insets_first_quadrant), NULL);
#line 4318 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 31198 "Photo.c"
}


static GdkPixbuf* photo_red_reduce_pixel (Photo* self, GdkPixbuf* pixbuf, gint x, gint y) {
	GdkPixbuf* result = NULL;
	gint px_start_byte_offset = 0;
	gint _tmp0_;
	GdkPixbuf* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GdkPixbuf* _tmp4_;
	gint _tmp5_;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	gint _tmp9_;
	GdkPixbuf* _tmp33_;
	GdkPixbuf* _tmp34_;
#line 4321 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 4321 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = y;
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = pixbuf;
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gdk_pixbuf_get_rowstride (_tmp1_);
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = x;
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = pixbuf;
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = gdk_pixbuf_get_n_channels (_tmp4_);
#line 4322 "/home/jens/Source/shotwell/src/Photo.vala"
	px_start_byte_offset = (_tmp0_ * _tmp2_) + (_tmp3_ * _tmp5_);
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = x;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp9_ >= 0) {
#line 31239 "Photo.c"
		gint _tmp10_;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = y;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = _tmp10_ >= 0;
#line 31245 "Photo.c"
	} else {
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = FALSE;
#line 31249 "Photo.c"
	}
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_) {
#line 31253 "Photo.c"
		gint _tmp11_;
		GdkPixbuf* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = x;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = pixbuf;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = gdk_pixbuf_get_width (_tmp12_);
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = _tmp13_;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp11_ < _tmp14_;
#line 31268 "Photo.c"
	} else {
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = FALSE;
#line 31272 "Photo.c"
	}
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp7_) {
#line 31276 "Photo.c"
		gint _tmp15_;
		GdkPixbuf* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = y;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = pixbuf;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = gdk_pixbuf_get_height (_tmp16_);
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = _tmp17_;
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp15_ < _tmp18_;
#line 31291 "Photo.c"
	} else {
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = FALSE;
#line 31295 "Photo.c"
	}
#line 4329 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_) {
#line 31299 "Photo.c"
		guchar* pixel_data = NULL;
		GdkPixbuf* _tmp19_;
		guint8* _tmp20_;
		gint pixel_data_length1;
		gint _pixel_data_size_;
		guchar g = '\0';
		guchar* _tmp21_;
		gint _tmp21__length1;
		gint _tmp22_;
		guchar _tmp23_;
		guchar b = '\0';
		guchar* _tmp24_;
		gint _tmp24__length1;
		gint _tmp25_;
		guchar _tmp26_;
		guchar r = '\0';
		guchar _tmp27_;
		guchar _tmp28_;
		guchar* _tmp29_;
		gint _tmp29__length1;
		gint _tmp30_;
		guchar _tmp31_;
		guchar _tmp32_;
#line 4330 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = pixbuf;
#line 4330 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = gdk_pixbuf_get_pixels (_tmp19_);
#line 4330 "/home/jens/Source/shotwell/src/Photo.vala"
		pixel_data = _tmp20_;
#line 4330 "/home/jens/Source/shotwell/src/Photo.vala"
		pixel_data_length1 = -1;
#line 4330 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_data_size_ = pixel_data_length1;
#line 4340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = pixel_data;
#line 4340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21__length1 = pixel_data_length1;
#line 4340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = px_start_byte_offset;
#line 4340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = _tmp21_[_tmp22_ + 1];
#line 4340 "/home/jens/Source/shotwell/src/Photo.vala"
		g = _tmp23_;
#line 4341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = pixel_data;
#line 4341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24__length1 = pixel_data_length1;
#line 4341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = px_start_byte_offset;
#line 4341 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp26_ = _tmp24_[_tmp25_ + 2];
#line 4341 "/home/jens/Source/shotwell/src/Photo.vala"
		b = _tmp26_;
#line 4343 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp27_ = g;
#line 4343 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = b;
#line 4343 "/home/jens/Source/shotwell/src/Photo.vala"
		r = (guchar) ((_tmp27_ + _tmp28_) / 2);
#line 4345 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_ = pixel_data;
#line 4345 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29__length1 = pixel_data_length1;
#line 4345 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = px_start_byte_offset;
#line 4345 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = r;
#line 4345 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp29_[_tmp30_] = _tmp31_;
#line 4345 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp32_ = _tmp29_[_tmp30_];
#line 31371 "Photo.c"
	}
#line 4348 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = pixbuf;
#line 4348 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = _g_object_ref0 (_tmp33_);
#line 4348 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp34_;
#line 4348 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 31381 "Photo.c"
}


void photo_unscaled_to_raw_point (Photo* self, GdkPoint* unscaled_point, GdkPoint* result) {
	Orientation unscaled_orientation = 0;
	Orientation _tmp0_;
	Dimensions unscaled_dims = {0};
	Orientation _tmp1_;
	Dimensions _tmp2_ = {0};
	Dimensions _tmp3_ = {0};
	gint unscaled_x_offset_raw = 0;
	gint unscaled_y_offset_raw = 0;
	Box crop_box = {0};
	Box _tmp4_ = {0};
	gboolean _tmp5_;
	GdkPoint derotated_point = {0};
	Orientation _tmp10_;
	Dimensions _tmp11_;
	GdkPoint _tmp12_;
	GdkPoint _tmp13_ = {0};
	gint _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
#line 4351 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4351 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (unscaled_point != NULL);
#line 4352 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_orientation (self);
#line 4352 "/home/jens/Source/shotwell/src/Photo.vala"
	unscaled_orientation = _tmp0_;
#line 4354 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = unscaled_orientation;
#line 4354 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_get_dimensions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), PHOTO_EXCEPTION_NONE, &_tmp2_);
#line 4354 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation_rotate_dimensions (_tmp1_, &_tmp2_, &_tmp3_);
#line 4354 "/home/jens/Source/shotwell/src/Photo.vala"
	unscaled_dims = _tmp3_;
#line 4357 "/home/jens/Source/shotwell/src/Photo.vala"
	unscaled_x_offset_raw = 0;
#line 4358 "/home/jens/Source/shotwell/src/Photo.vala"
	unscaled_y_offset_raw = 0;
#line 4361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_get_raw_crop (self, &_tmp4_);
#line 4361 "/home/jens/Source/shotwell/src/Photo.vala"
	crop_box = _tmp4_;
#line 4361 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 31432 "Photo.c"
		Box _tmp6_;
		gint _tmp7_;
		Box _tmp8_;
		gint _tmp9_;
#line 4362 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = crop_box;
#line 4362 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_.left;
#line 4362 "/home/jens/Source/shotwell/src/Photo.vala"
		unscaled_x_offset_raw = _tmp7_;
#line 4363 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = crop_box;
#line 4363 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = _tmp8_.top;
#line 4363 "/home/jens/Source/shotwell/src/Photo.vala"
		unscaled_y_offset_raw = _tmp9_;
#line 31449 "Photo.c"
	}
#line 4366 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = unscaled_orientation;
#line 4366 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = unscaled_dims;
#line 4366 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = *unscaled_point;
#line 4366 "/home/jens/Source/shotwell/src/Photo.vala"
	orientation_derotate_point (_tmp10_, &_tmp11_, &_tmp12_, &_tmp13_);
#line 4366 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated_point = _tmp13_;
#line 4370 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = derotated_point.x;
#line 4370 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = unscaled_x_offset_raw;
#line 4370 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated_point.x = _tmp14_ + _tmp15_;
#line 4371 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = derotated_point.y;
#line 4371 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = unscaled_y_offset_raw;
#line 4371 "/home/jens/Source/shotwell/src/Photo.vala"
	derotated_point.y = _tmp16_ + _tmp17_;
#line 4373 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = derotated_point;
#line 4373 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 31477 "Photo.c"
}


void photo_unscaled_to_raw_rect (Photo* self, GdkRectangle* unscaled_rect, GdkRectangle* result) {
	GdkPoint upper_left = {0};
	GdkPoint _tmp0_ = {0};
	GdkPoint lower_right = {0};
	GdkPoint _tmp1_ = {0};
	GdkRectangle _tmp2_;
	gint _tmp3_;
	GdkRectangle _tmp4_;
	gint _tmp5_;
	GdkPoint _tmp6_;
	gint _tmp7_;
	GdkRectangle _tmp8_;
	gint _tmp9_;
	GdkPoint _tmp10_;
	gint _tmp11_;
	GdkRectangle _tmp12_;
	gint _tmp13_;
	GdkPoint _tmp14_;
	GdkPoint _tmp15_ = {0};
	GdkPoint _tmp16_;
	GdkPoint _tmp17_ = {0};
	GdkPoint _tmp18_;
	gint _tmp19_;
	GdkPoint _tmp20_;
	gint _tmp21_;
	GdkPoint _tmp27_;
	gint _tmp28_;
	GdkPoint _tmp29_;
	gint _tmp30_;
	GdkRectangle raw_rect = {0};
	GdkPoint _tmp36_;
	gint _tmp37_;
	GdkPoint _tmp38_;
	gint _tmp39_;
	GdkPoint _tmp40_;
	gint _tmp41_;
	GdkPoint _tmp42_;
	gint _tmp43_;
	GdkPoint _tmp44_;
	gint _tmp45_;
	GdkPoint _tmp46_;
	gint _tmp47_;
#line 4376 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (self));
#line 4376 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (unscaled_rect != NULL);
#line 4377 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_.x = 0;
#line 4377 "/home/jens/Source/shotwell/src/Photo.vala"
	upper_left = _tmp0_;
#line 4378 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_.x = 0;
#line 4378 "/home/jens/Source/shotwell/src/Photo.vala"
	lower_right = _tmp1_;
#line 4379 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = *unscaled_rect;
#line 4379 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_.x;
#line 4379 "/home/jens/Source/shotwell/src/Photo.vala"
	upper_left.x = _tmp3_;
#line 4380 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = *unscaled_rect;
#line 4380 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_.y;
#line 4380 "/home/jens/Source/shotwell/src/Photo.vala"
	upper_left.y = _tmp5_;
#line 4381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = upper_left;
#line 4381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = _tmp6_.x;
#line 4381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = *unscaled_rect;
#line 4381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _tmp8_.width;
#line 4381 "/home/jens/Source/shotwell/src/Photo.vala"
	lower_right.x = _tmp7_ + _tmp9_;
#line 4382 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = upper_left;
#line 4382 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp10_.y;
#line 4382 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = *unscaled_rect;
#line 4382 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_.height;
#line 4382 "/home/jens/Source/shotwell/src/Photo.vala"
	lower_right.y = _tmp11_ + _tmp13_;
#line 4384 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = upper_left;
#line 4384 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_unscaled_to_raw_point (self, &_tmp14_, &_tmp15_);
#line 4384 "/home/jens/Source/shotwell/src/Photo.vala"
	upper_left = _tmp15_;
#line 4385 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = lower_right;
#line 4385 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_unscaled_to_raw_point (self, &_tmp16_, &_tmp17_);
#line 4385 "/home/jens/Source/shotwell/src/Photo.vala"
	lower_right = _tmp17_;
#line 4387 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = upper_left;
#line 4387 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = _tmp18_.x;
#line 4387 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = lower_right;
#line 4387 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = _tmp20_.x;
#line 4387 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp19_ > _tmp21_) {
#line 31589 "Photo.c"
		gint temp = 0;
		GdkPoint _tmp22_;
		gint _tmp23_;
		GdkPoint _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
#line 4388 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = upper_left;
#line 4388 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = _tmp22_.x;
#line 4388 "/home/jens/Source/shotwell/src/Photo.vala"
		temp = _tmp23_;
#line 4389 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = lower_right;
#line 4389 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp24_.x;
#line 4389 "/home/jens/Source/shotwell/src/Photo.vala"
		upper_left.x = _tmp25_;
#line 4390 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp26_ = temp;
#line 4390 "/home/jens/Source/shotwell/src/Photo.vala"
		lower_right.x = _tmp26_;
#line 31612 "Photo.c"
	}
#line 4392 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = upper_left;
#line 4392 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = _tmp27_.y;
#line 4392 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = lower_right;
#line 4392 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp30_ = _tmp29_.y;
#line 4392 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp28_ > _tmp30_) {
#line 31624 "Photo.c"
		gint temp = 0;
		GdkPoint _tmp31_;
		gint _tmp32_;
		GdkPoint _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
#line 4393 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp31_ = upper_left;
#line 4393 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp32_ = _tmp31_.y;
#line 4393 "/home/jens/Source/shotwell/src/Photo.vala"
		temp = _tmp32_;
#line 4394 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp33_ = lower_right;
#line 4394 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp34_ = _tmp33_.y;
#line 4394 "/home/jens/Source/shotwell/src/Photo.vala"
		upper_left.y = _tmp34_;
#line 4395 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp35_ = temp;
#line 4395 "/home/jens/Source/shotwell/src/Photo.vala"
		lower_right.y = _tmp35_;
#line 31647 "Photo.c"
	}
#line 4398 "/home/jens/Source/shotwell/src/Photo.vala"
	memset (&raw_rect, 0, sizeof (GdkRectangle));
#line 4399 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = upper_left;
#line 4399 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = _tmp36_.x;
#line 4399 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_rect.x = _tmp37_;
#line 4400 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = upper_left;
#line 4400 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = _tmp38_.y;
#line 4400 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_rect.y = _tmp39_;
#line 4401 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = lower_right;
#line 4401 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = _tmp40_.x;
#line 4401 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = upper_left;
#line 4401 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp43_ = _tmp42_.x;
#line 4401 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_rect.width = _tmp41_ - _tmp43_;
#line 4402 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = lower_right;
#line 4402 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = _tmp44_.y;
#line 4402 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp46_ = upper_left;
#line 4402 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp47_ = _tmp46_.y;
#line 4402 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_rect.height = _tmp45_ - _tmp47_;
#line 4404 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = raw_rect;
#line 4404 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 31687 "Photo.c"
}


PixelTransformationBundle* photo_get_enhance_transformations (Photo* self) {
	PixelTransformationBundle* result = NULL;
	GdkPixbuf* pixbuf = NULL;
	PixelTransformationBundle* transformations = NULL;
	GdkPixbuf* _tmp4_;
	PixelTransformationBundle* _tmp5_;
	GError * _inner_error_ = NULL;
#line 4407 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), NULL);
#line 4408 "/home/jens/Source/shotwell/src/Photo.vala"
	pixbuf = NULL;
#line 31702 "Photo.c"
	{
		GdkPixbuf* _tmp0_ = NULL;
		Scaling _tmp1_ = {0};
		GdkPixbuf* _tmp2_;
		GdkPixbuf* _tmp3_;
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		scaling_for_best_fit (360, FALSE, &_tmp1_);
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = photo_get_pixbuf_with_options (self, &_tmp1_, PHOTO_EXCEPTION_ALL, BACKING_FETCH_MODE_BASELINE, &_inner_error_);
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp2_;
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 31716 "Photo.c"
			goto __catch417_g_error;
		}
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp0_;
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = NULL;
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 4415 "/home/jens/Source/shotwell/src/Photo.vala"
		pixbuf = _tmp3_;
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp0_);
#line 31729 "Photo.c"
	}
	goto __finally417;
	__catch417_g_error:
	{
		GError* e = NULL;
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		e = _inner_error_;
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 4422 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:4422: %s", "Photo: get_enhance_transformations: couldn't obtain pixbuf to build " "transform histogram");
#line 4424 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 4424 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (e);
#line 4424 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 4424 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 31749 "Photo.c"
	}
	__finally417:
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (pixbuf);
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 4414 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 31762 "Photo.c"
	}
#line 4431 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = pixbuf;
#line 4431 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = auto_enhance_create_auto_enhance_adjustments (_tmp4_);
#line 4431 "/home/jens/Source/shotwell/src/Photo.vala"
	transformations = _tmp5_;
#line 4439 "/home/jens/Source/shotwell/src/Photo.vala"
	result = transformations;
#line 4439 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (pixbuf);
#line 4439 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 31776 "Photo.c"
}


gboolean photo_enhance (Photo* self) {
	gboolean result = FALSE;
	PixelTransformationBundle* transformations = NULL;
	PixelTransformationBundle* _tmp0_;
	PixelTransformationBundle* _tmp1_;
	GError * _inner_error_ = NULL;
#line 4442 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (self), FALSE);
#line 4443 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_get_enhance_transformations (self);
#line 4443 "/home/jens/Source/shotwell/src/Photo.vala"
	transformations = _tmp0_;
#line 4445 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = transformations;
#line 4445 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 4446 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 4446 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_transformation_bundle_unref0 (transformations);
#line 4446 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 31802 "Photo.c"
	}
	{
		PhotoRow* _tmp2_;
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->row;
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
		g_rec_mutex_lock (&self->priv->__lock_row);
#line 31810 "Photo.c"
		{
			PixelTransformationBundle* _tmp3_;
#line 4452 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = transformations;
#line 4452 "/home/jens/Source/shotwell/src/Photo.vala"
			photo_set_color_adjustments (self, _tmp3_);
#line 31817 "Photo.c"
		}
		__finally418:
		{
			PhotoRow* _tmp4_;
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = self->row;
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
			g_rec_mutex_unlock (&self->priv->__lock_row);
#line 31826 "Photo.c"
		}
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 31830 "Photo.c"
			gboolean _tmp5_ = FALSE;
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
			_pixel_transformation_bundle_unref0 (transformations);
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 4451 "/home/jens/Source/shotwell/src/Photo.vala"
			return _tmp5_;
#line 31840 "Photo.c"
		}
	}
#line 4459 "/home/jens/Source/shotwell/src/Photo.vala"
	result = TRUE;
#line 4459 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (transformations);
#line 4459 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 31849 "Photo.c"
}


gboolean photo_get_develop_raw_photos_to_files (void) {
	gboolean result;
	gboolean _tmp0_;
#line 349 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo__develop_raw_photos_to_files;
#line 349 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 349 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 31862 "Photo.c"
}


void photo_set_develop_raw_photos_to_files (gboolean value) {
	gboolean _tmp0_;
#line 349 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = value;
#line 349 "/home/jens/Source/shotwell/src/Photo.vala"
	photo__develop_raw_photos_to_files = _tmp0_;
#line 31872 "Photo.c"
}


static void photo_real_editable_replaced (Photo* self, GFile* old_file, GFile* new_file) {
#line 358 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((old_file == NULL) || G_IS_FILE (old_file));
#line 358 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((new_file == NULL) || G_IS_FILE (new_file));
#line 31881 "Photo.c"
}


static void g_cclosure_user_marshal_VOID__OBJECT_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_OBJECT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (n_param_values == 3);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data1 = closure->data;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data2 = param_values->data[0].v_pointer;
#line 31900 "Photo.c"
	} else {
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data1 = param_values->data[0].v_pointer;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data2 = closure->data;
#line 31906 "Photo.c"
	}
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	callback = (GMarshalFunc_VOID__OBJECT_OBJECT) (marshal_data ? marshal_data : cc->callback);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_object (param_values + 2), data2);
#line 31912 "Photo.c"
}


static void photo_real_raw_development_modified (Photo* self) {
}


static void photo_real_baseline_replaced (Photo* self) {
}


static void photo_real_master_reimported (Photo* self, PhotoMetadata* metadata) {
#line 376 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 31927 "Photo.c"
}


static void g_cclosure_user_marshal_VOID__MEDIA_METADATA (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__MEDIA_METADATA) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__MEDIA_METADATA callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (n_param_values == 2);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data1 = closure->data;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data2 = param_values->data[0].v_pointer;
#line 31946 "Photo.c"
	} else {
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data1 = param_values->data[0].v_pointer;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		data2 = closure->data;
#line 31952 "Photo.c"
	}
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	callback = (GMarshalFunc_VOID__MEDIA_METADATA) (marshal_data ? marshal_data : cc->callback);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	callback (data1, value_get_media_metadata (param_values + 1), data2);
#line 31958 "Photo.c"
}


static void photo_real_editable_reimported (Photo* self, PhotoMetadata* metadata) {
#line 380 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 31965 "Photo.c"
}


static void photo_real_baseline_reimported (Photo* self, PhotoMetadata* metadata) {
#line 387 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 31972 "Photo.c"
}


static void photo_real_source_reimported (Photo* self, PhotoMetadata* metadata) {
#line 394 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 31979 "Photo.c"
}


static void _photo_photo_transformation_state_impl_on_photo_baseline_replaced_photo_baseline_replaced (Photo* _sender, gpointer self) {
#line 257 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_photo_transformation_state_impl_on_photo_baseline_replaced ((PhotoPhotoTransformationStateImpl*) self);
#line 31986 "Photo.c"
}


static PhotoPhotoTransformationStateImpl* photo_photo_transformation_state_impl_construct (GType object_type, Photo* photo, Orientation orientation, GeeHashMap* transformations, PixelTransformer* transformer, PixelTransformationBundle* adjustments) {
	PhotoPhotoTransformationStateImpl * self = NULL;
	Photo* _tmp0_;
	Photo* _tmp1_;
	Orientation _tmp2_;
	GeeHashMap* _tmp3_;
	GeeHashMap* _tmp4_;
	PixelTransformer* _tmp5_;
	PixelTransformer* _tmp6_;
	PixelTransformationBundle* _tmp7_;
	PixelTransformationBundle* _tmp8_;
	Photo* _tmp9_;
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (photo), NULL);
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((transformations == NULL) || GEE_IS_HASH_MAP (transformations), NULL);
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((transformer == NULL) || IS_PIXEL_TRANSFORMER (transformer), NULL);
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((adjustments == NULL) || IS_PIXEL_TRANSFORMATION_BUNDLE (adjustments), NULL);
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoPhotoTransformationStateImpl*) photo_transformation_state_construct (object_type);
#line 247 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 247 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 247 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->photo);
#line 247 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->photo = _tmp1_;
#line 248 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = orientation;
#line 248 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->orientation = _tmp2_;
#line 249 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = transformations;
#line 249 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_photo_transformation_state_impl_copy_transformations (_tmp3_);
#line 249 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->transformations);
#line 249 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->transformations = _tmp4_;
#line 250 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = transformer;
#line 250 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _pixel_transformer_ref0 (_tmp5_);
#line 250 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformer_unref0 (self->priv->transformer);
#line 250 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->transformer = _tmp6_;
#line 251 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = adjustments;
#line 251 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _pixel_transformation_bundle_ref0 (_tmp7_);
#line 251 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 251 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->adjustments = _tmp8_;
#line 253 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = photo;
#line 253 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_connect_object (_tmp9_, "baseline-replaced", (GCallback) _photo_photo_transformation_state_impl_on_photo_baseline_replaced_photo_baseline_replaced, self, 0);
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 32054 "Photo.c"
}


static PhotoPhotoTransformationStateImpl* photo_photo_transformation_state_impl_new (Photo* photo, Orientation orientation, GeeHashMap* transformations, PixelTransformer* transformer, PixelTransformationBundle* adjustments) {
#line 244 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_photo_transformation_state_impl_construct (PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL, photo, orientation, transformations, transformer, adjustments);
#line 32061 "Photo.c"
}


static Orientation photo_photo_transformation_state_impl_get_orientation (PhotoPhotoTransformationStateImpl* self) {
	Orientation result = 0;
	Orientation _tmp0_;
#line 260 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL (self), 0);
#line 261 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->orientation;
#line 261 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 261 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 32076 "Photo.c"
}


static GeeHashMap* photo_photo_transformation_state_impl_get_transformations (PhotoPhotoTransformationStateImpl* self) {
	GeeHashMap* result = NULL;
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
#line 264 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL (self), NULL);
#line 265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->transformations;
#line 265 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_photo_transformation_state_impl_copy_transformations (_tmp0_);
#line 265 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 265 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 32094 "Photo.c"
}


static PixelTransformer* photo_photo_transformation_state_impl_get_transformer (PhotoPhotoTransformationStateImpl* self) {
	PixelTransformer* result = NULL;
	PixelTransformer* _tmp0_ = NULL;
	PixelTransformer* _tmp1_;
#line 268 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL (self), NULL);
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = self->priv->transformer;
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ != NULL) {
#line 32108 "Photo.c"
		PixelTransformer* _tmp2_;
		PixelTransformer* _tmp3_;
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->priv->transformer;
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = pixel_transformer_copy (_tmp2_);
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_transformer_unref0 (_tmp0_);
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp3_;
#line 32119 "Photo.c"
	} else {
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_transformer_unref0 (_tmp0_);
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = NULL;
#line 32125 "Photo.c"
	}
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 269 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 32131 "Photo.c"
}


static PixelTransformationBundle* photo_photo_transformation_state_impl_get_color_adjustments (PhotoPhotoTransformationStateImpl* self) {
	PixelTransformationBundle* result = NULL;
	PixelTransformationBundle* _tmp0_ = NULL;
	PixelTransformationBundle* _tmp1_;
#line 272 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL (self), NULL);
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = self->priv->adjustments;
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ != NULL) {
#line 32145 "Photo.c"
		PixelTransformationBundle* _tmp2_;
		PixelTransformationBundle* _tmp3_;
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = self->priv->adjustments;
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = pixel_transformation_bundle_copy (_tmp2_);
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_transformation_bundle_unref0 (_tmp0_);
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp3_;
#line 32156 "Photo.c"
	} else {
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
		_pixel_transformation_bundle_unref0 (_tmp0_);
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = NULL;
#line 32162 "Photo.c"
	}
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 273 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 32168 "Photo.c"
}


static GeeHashMap* photo_photo_transformation_state_impl_copy_transformations (GeeHashMap* original) {
	GeeHashMap* result = NULL;
	GeeHashMap* _tmp0_;
	GeeHashMap* clone = NULL;
	GeeHashMap* _tmp1_;
#line 276 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((original == NULL) || GEE_IS_HASH_MAP (original), NULL);
#line 278 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = original;
#line 278 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ == NULL) {
#line 279 "/home/jens/Source/shotwell/src/Photo.vala"
		result = NULL;
#line 279 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 32187 "Photo.c"
	}
#line 281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_KEY_VALUE_MAP, (GBoxedCopyFunc) key_value_map_ref, (GDestroyNotify) key_value_map_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 281 "/home/jens/Source/shotwell/src/Photo.vala"
	clone = _tmp1_;
#line 32193 "Photo.c"
	{
		GeeIterator* _object_it = NULL;
		GeeHashMap* _tmp2_;
		GeeSet* _tmp3_;
		GeeSet* _tmp4_;
		GeeSet* _tmp5_;
		GeeIterator* _tmp6_;
		GeeIterator* _tmp7_;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = original;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = gee_abstract_map_get_keys (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp3_;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ITERABLE, GeeIterable));
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = _tmp6_;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp5_);
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_object_it = _tmp7_;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 32220 "Photo.c"
			GeeIterator* _tmp8_;
			gboolean _tmp9_;
			gchar* object = NULL;
			GeeIterator* _tmp10_;
			gpointer _tmp11_;
			GeeHashMap* _tmp12_;
			const gchar* _tmp13_;
			GeeHashMap* _tmp14_;
			const gchar* _tmp15_;
			gpointer _tmp16_;
			KeyValueMap* _tmp17_;
			KeyValueMap* _tmp18_;
			KeyValueMap* _tmp19_;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _object_it;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = gee_iterator_next (_tmp8_);
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp9_) {
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 32242 "Photo.c"
			}
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = _object_it;
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = gee_iterator_get (_tmp10_);
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			object = (gchar*) _tmp11_;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = clone;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = object;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = original;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = object;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp15_);
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = (KeyValueMap*) _tmp16_;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = key_value_map_copy (_tmp17_);
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = _tmp18_;
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp13_, _tmp19_);
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_key_value_map_unref0 (_tmp19_);
#line 283 "/home/jens/Source/shotwell/src/Photo.vala"
			_key_value_map_unref0 (_tmp17_);
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_free0 (object);
#line 32274 "Photo.c"
		}
#line 282 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_object_it);
#line 32278 "Photo.c"
	}
#line 285 "/home/jens/Source/shotwell/src/Photo.vala"
	result = clone;
#line 285 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 32284 "Photo.c"
}


static void photo_photo_transformation_state_impl_on_photo_baseline_replaced (PhotoPhotoTransformationStateImpl* self) {
	gboolean _tmp0_;
#line 288 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_PHOTO_TRANSFORMATION_STATE_IMPL (self));
#line 289 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_transformation_state_is_broken (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationState));
#line 289 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp0_) {
#line 290 "/home/jens/Source/shotwell/src/Photo.vala"
		g_signal_emit (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_TRANSFORMATION_STATE, PhotoTransformationState), photo_transformation_state_signals[PHOTO_TRANSFORMATION_STATE_BROKEN_SIGNAL], 0);
#line 32298 "Photo.c"
	}
}


static void photo_photo_transformation_state_impl_class_init (PhotoPhotoTransformationStateImplClass * klass) {
#line 237 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_photo_transformation_state_impl_parent_class = g_type_class_peek_parent (klass);
#line 237 "/home/jens/Source/shotwell/src/Photo.vala"
	g_type_class_add_private (klass, sizeof (PhotoPhotoTransformationStateImplPrivate));
#line 237 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (klass)->finalize = photo_photo_transformation_state_impl_finalize;
#line 32310 "Photo.c"
}


static void photo_photo_transformation_state_impl_instance_init (PhotoPhotoTransformationStateImpl * self) {
#line 237 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv = PHOTO_PHOTO_TRANSFORMATION_STATE_IMPL_GET_PRIVATE (self);
#line 32317 "Photo.c"
}


static void photo_photo_transformation_state_impl_finalize (GObject * obj) {
	PhotoPhotoTransformationStateImpl * self;
	Photo* _tmp0_;
	guint _tmp1_;
#line 237 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_PHOTO_TRANSFORMATION_STATE_IMPL, PhotoPhotoTransformationStateImpl);
#line 257 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->photo;
#line 257 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_parse_name ("baseline-replaced", TYPE_PHOTO, &_tmp1_, NULL, FALSE);
#line 257 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _photo_photo_transformation_state_impl_on_photo_baseline_replaced_photo_baseline_replaced, self);
#line 238 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->photo);
#line 240 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->transformations);
#line 241 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformer_unref0 (self->priv->transformer);
#line 242 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 237 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (photo_photo_transformation_state_impl_parent_class)->finalize (obj);
#line 32343 "Photo.c"
}


static GType photo_photo_transformation_state_impl_get_type (void) {
	static volatile gsize photo_photo_transformation_state_impl_type_id__volatile = 0;
	if (g_once_init_enter (&photo_photo_transformation_state_impl_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoPhotoTransformationStateImplClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_photo_transformation_state_impl_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoPhotoTransformationStateImpl), 0, (GInstanceInitFunc) photo_photo_transformation_state_impl_instance_init, NULL };
		GType photo_photo_transformation_state_impl_type_id;
		photo_photo_transformation_state_impl_type_id = g_type_register_static (TYPE_PHOTO_TRANSFORMATION_STATE, "PhotoPhotoTransformationStateImpl", &g_define_type_info, 0);
		g_once_init_leave (&photo_photo_transformation_state_impl_type_id__volatile, photo_photo_transformation_state_impl_type_id);
	}
	return photo_photo_transformation_state_impl_type_id__volatile;
}


static PhotoBackingReaders* photo_backing_readers_construct (GType object_type) {
	PhotoBackingReaders* self = NULL;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoBackingReaders*) g_type_create_instance (object_type);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 32365 "Photo.c"
}


static PhotoBackingReaders* photo_backing_readers_new (void) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_backing_readers_construct (PHOTO_TYPE_BACKING_READERS);
#line 32372 "Photo.c"
}


static void photo_value_backing_readers_init (GValue* value) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 32379 "Photo.c"
}


static void photo_value_backing_readers_free_value (GValue* value) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_backing_readers_unref (value->data[0].v_pointer);
#line 32388 "Photo.c"
	}
}


static void photo_value_backing_readers_copy_value (const GValue* src_value, GValue* dest_value) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_backing_readers_ref (src_value->data[0].v_pointer);
#line 32398 "Photo.c"
	} else {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 32402 "Photo.c"
	}
}


static gpointer photo_value_backing_readers_peek_pointer (const GValue* value) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 32410 "Photo.c"
}


static gchar* photo_value_backing_readers_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 32417 "Photo.c"
		PhotoBackingReaders * object;
		object = collect_values[0].v_pointer;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 32424 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 32428 "Photo.c"
		}
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_backing_readers_ref (object);
#line 32432 "Photo.c"
	} else {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32436 "Photo.c"
	}
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 32440 "Photo.c"
}


static gchar* photo_value_backing_readers_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoBackingReaders ** object_p;
	object_p = collect_values[0].v_pointer;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 32451 "Photo.c"
	}
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 32457 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 32461 "Photo.c"
	} else {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_backing_readers_ref (value->data[0].v_pointer);
#line 32465 "Photo.c"
	}
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 32469 "Photo.c"
}


static GParamSpec* photo_param_spec_backing_readers (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PhotoParamSpecBackingReaders* spec;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PHOTO_TYPE_BACKING_READERS), NULL);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 32483 "Photo.c"
}


static gpointer photo_value_get_backing_readers (const GValue* value) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_BACKING_READERS), NULL);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 32492 "Photo.c"
}


static void photo_value_set_backing_readers (GValue* value, gpointer v_object) {
	PhotoBackingReaders * old;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_BACKING_READERS));
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_BACKING_READERS));
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_backing_readers_ref (value->data[0].v_pointer);
#line 32512 "Photo.c"
	} else {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32516 "Photo.c"
	}
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_backing_readers_unref (old);
#line 32522 "Photo.c"
	}
}


static void photo_value_take_backing_readers (GValue* value, gpointer v_object) {
	PhotoBackingReaders * old;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_BACKING_READERS));
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_BACKING_READERS));
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 32541 "Photo.c"
	} else {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32545 "Photo.c"
	}
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_backing_readers_unref (old);
#line 32551 "Photo.c"
	}
}


static void photo_backing_readers_class_init (PhotoBackingReadersClass * klass) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_backing_readers_parent_class = g_type_class_peek_parent (klass);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoBackingReadersClass *) klass)->finalize = photo_backing_readers_finalize;
#line 32561 "Photo.c"
}


static void photo_backing_readers_instance_init (PhotoBackingReaders * self) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 32568 "Photo.c"
}


static void photo_backing_readers_finalize (PhotoBackingReaders * obj) {
	PhotoBackingReaders * self;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_BACKING_READERS, PhotoBackingReaders);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 295 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (self->master);
#line 296 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (self->developer);
#line 297 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_file_adapter_unref0 (self->editable);
#line 32584 "Photo.c"
}


static GType photo_backing_readers_get_type (void) {
	static volatile gsize photo_backing_readers_type_id__volatile = 0;
	if (g_once_init_enter (&photo_backing_readers_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { photo_value_backing_readers_init, photo_value_backing_readers_free_value, photo_value_backing_readers_copy_value, photo_value_backing_readers_peek_pointer, "p", photo_value_backing_readers_collect_value, "p", photo_value_backing_readers_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoBackingReadersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_backing_readers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoBackingReaders), 0, (GInstanceInitFunc) photo_backing_readers_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_backing_readers_type_id;
		photo_backing_readers_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoBackingReaders", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&photo_backing_readers_type_id__volatile, photo_backing_readers_type_id);
	}
	return photo_backing_readers_type_id__volatile;
}


static gpointer photo_backing_readers_ref (gpointer instance) {
	PhotoBackingReaders * self;
	self = instance;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 32609 "Photo.c"
}


static void photo_backing_readers_unref (gpointer instance) {
	PhotoBackingReaders * self;
	self = instance;
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_BACKING_READERS_GET_CLASS (self)->finalize (self);
#line 294 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 32622 "Photo.c"
	}
}


static PhotoCachedPixbuf* photo_cached_pixbuf_construct (GType object_type, Photo* photo, GdkPixbuf* pixbuf) {
	PhotoCachedPixbuf* self = NULL;
	Photo* _tmp0_;
	Photo* _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
#line 305 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO (photo), NULL);
#line 305 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (GDK_IS_PIXBUF (pixbuf), NULL);
#line 305 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoCachedPixbuf*) g_type_create_instance (object_type);
#line 306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 306 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 306 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->photo);
#line 306 "/home/jens/Source/shotwell/src/Photo.vala"
	self->photo = _tmp1_;
#line 307 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = pixbuf;
#line 307 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 307 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->pixbuf);
#line 307 "/home/jens/Source/shotwell/src/Photo.vala"
	self->pixbuf = _tmp3_;
#line 305 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 32657 "Photo.c"
}


static PhotoCachedPixbuf* photo_cached_pixbuf_new (Photo* photo, GdkPixbuf* pixbuf) {
#line 305 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_cached_pixbuf_construct (PHOTO_TYPE_CACHED_PIXBUF, photo, pixbuf);
#line 32664 "Photo.c"
}


static void photo_value_cached_pixbuf_init (GValue* value) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 32671 "Photo.c"
}


static void photo_value_cached_pixbuf_free_value (GValue* value) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_cached_pixbuf_unref (value->data[0].v_pointer);
#line 32680 "Photo.c"
	}
}


static void photo_value_cached_pixbuf_copy_value (const GValue* src_value, GValue* dest_value) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_cached_pixbuf_ref (src_value->data[0].v_pointer);
#line 32690 "Photo.c"
	} else {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 32694 "Photo.c"
	}
}


static gpointer photo_value_cached_pixbuf_peek_pointer (const GValue* value) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 32702 "Photo.c"
}


static gchar* photo_value_cached_pixbuf_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 32709 "Photo.c"
		PhotoCachedPixbuf * object;
		object = collect_values[0].v_pointer;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 32716 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 32720 "Photo.c"
		}
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_cached_pixbuf_ref (object);
#line 32724 "Photo.c"
	} else {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32728 "Photo.c"
	}
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 32732 "Photo.c"
}


static gchar* photo_value_cached_pixbuf_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoCachedPixbuf ** object_p;
	object_p = collect_values[0].v_pointer;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 32743 "Photo.c"
	}
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 32749 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 32753 "Photo.c"
	} else {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_cached_pixbuf_ref (value->data[0].v_pointer);
#line 32757 "Photo.c"
	}
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 32761 "Photo.c"
}


static GParamSpec* photo_param_spec_cached_pixbuf (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PhotoParamSpecCachedPixbuf* spec;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PHOTO_TYPE_CACHED_PIXBUF), NULL);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 32775 "Photo.c"
}


static gpointer photo_value_get_cached_pixbuf (const GValue* value) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_CACHED_PIXBUF), NULL);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 32784 "Photo.c"
}


static void photo_value_set_cached_pixbuf (GValue* value, gpointer v_object) {
	PhotoCachedPixbuf * old;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_CACHED_PIXBUF));
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_CACHED_PIXBUF));
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_cached_pixbuf_ref (value->data[0].v_pointer);
#line 32804 "Photo.c"
	} else {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32808 "Photo.c"
	}
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_cached_pixbuf_unref (old);
#line 32814 "Photo.c"
	}
}


static void photo_value_take_cached_pixbuf (GValue* value, gpointer v_object) {
	PhotoCachedPixbuf * old;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_CACHED_PIXBUF));
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_CACHED_PIXBUF));
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 32833 "Photo.c"
	} else {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32837 "Photo.c"
	}
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_cached_pixbuf_unref (old);
#line 32843 "Photo.c"
	}
}


static void photo_cached_pixbuf_class_init (PhotoCachedPixbufClass * klass) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_cached_pixbuf_parent_class = g_type_class_peek_parent (klass);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoCachedPixbufClass *) klass)->finalize = photo_cached_pixbuf_finalize;
#line 32853 "Photo.c"
}


static void photo_cached_pixbuf_instance_init (PhotoCachedPixbuf * self) {
	GTimer* _tmp0_;
#line 303 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = g_timer_new ();
#line 303 "/home/jens/Source/shotwell/src/Photo.vala"
	self->last_touched = _tmp0_;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 32865 "Photo.c"
}


static void photo_cached_pixbuf_finalize (PhotoCachedPixbuf * obj) {
	PhotoCachedPixbuf * self;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_CACHED_PIXBUF, PhotoCachedPixbuf);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 301 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->photo);
#line 302 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->pixbuf);
#line 303 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_timer_destroy0 (self->last_touched);
#line 32881 "Photo.c"
}


static GType photo_cached_pixbuf_get_type (void) {
	static volatile gsize photo_cached_pixbuf_type_id__volatile = 0;
	if (g_once_init_enter (&photo_cached_pixbuf_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { photo_value_cached_pixbuf_init, photo_value_cached_pixbuf_free_value, photo_value_cached_pixbuf_copy_value, photo_value_cached_pixbuf_peek_pointer, "p", photo_value_cached_pixbuf_collect_value, "p", photo_value_cached_pixbuf_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoCachedPixbufClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_cached_pixbuf_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoCachedPixbuf), 0, (GInstanceInitFunc) photo_cached_pixbuf_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_cached_pixbuf_type_id;
		photo_cached_pixbuf_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoCachedPixbuf", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&photo_cached_pixbuf_type_id__volatile, photo_cached_pixbuf_type_id);
	}
	return photo_cached_pixbuf_type_id__volatile;
}


static gpointer photo_cached_pixbuf_ref (gpointer instance) {
	PhotoCachedPixbuf * self;
	self = instance;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 32906 "Photo.c"
}


static void photo_cached_pixbuf_unref (gpointer instance) {
	PhotoCachedPixbuf * self;
	self = instance;
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_CACHED_PIXBUF_GET_CLASS (self)->finalize (self);
#line 300 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 32919 "Photo.c"
	}
}


PhotoReimportMasterState* photo_reimport_master_state_construct (GType object_type) {
	PhotoReimportMasterState* self = NULL;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportMasterState*) g_type_create_instance (object_type);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 32930 "Photo.c"
}


static void photo_value_reimport_master_state_init (GValue* value) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 32937 "Photo.c"
}


static void photo_value_reimport_master_state_free_value (GValue* value) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_master_state_unref (value->data[0].v_pointer);
#line 32946 "Photo.c"
	}
}


static void photo_value_reimport_master_state_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_reimport_master_state_ref (src_value->data[0].v_pointer);
#line 32956 "Photo.c"
	} else {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 32960 "Photo.c"
	}
}


static gpointer photo_value_reimport_master_state_peek_pointer (const GValue* value) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 32968 "Photo.c"
}


static gchar* photo_value_reimport_master_state_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 32975 "Photo.c"
		PhotoReimportMasterState * object;
		object = collect_values[0].v_pointer;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 32982 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 32986 "Photo.c"
		}
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_reimport_master_state_ref (object);
#line 32990 "Photo.c"
	} else {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 32994 "Photo.c"
	}
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 32998 "Photo.c"
}


static gchar* photo_value_reimport_master_state_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoReimportMasterState ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 33009 "Photo.c"
	}
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 33015 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 33019 "Photo.c"
	} else {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_reimport_master_state_ref (value->data[0].v_pointer);
#line 33023 "Photo.c"
	}
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 33027 "Photo.c"
}


GParamSpec* photo_param_spec_reimport_master_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PhotoParamSpecReimportMasterState* spec;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PHOTO_TYPE_REIMPORT_MASTER_STATE), NULL);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 33041 "Photo.c"
}


gpointer photo_value_get_reimport_master_state (const GValue* value) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_MASTER_STATE), NULL);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 33050 "Photo.c"
}


void photo_value_set_reimport_master_state (GValue* value, gpointer v_object) {
	PhotoReimportMasterState * old;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_MASTER_STATE));
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_REIMPORT_MASTER_STATE));
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_master_state_ref (value->data[0].v_pointer);
#line 33070 "Photo.c"
	} else {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33074 "Photo.c"
	}
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_master_state_unref (old);
#line 33080 "Photo.c"
	}
}


void photo_value_take_reimport_master_state (GValue* value, gpointer v_object) {
	PhotoReimportMasterState * old;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_MASTER_STATE));
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_REIMPORT_MASTER_STATE));
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 33099 "Photo.c"
	} else {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33103 "Photo.c"
	}
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_master_state_unref (old);
#line 33109 "Photo.c"
	}
}


static void photo_reimport_master_state_class_init (PhotoReimportMasterStateClass * klass) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_master_state_parent_class = g_type_class_peek_parent (klass);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportMasterStateClass *) klass)->finalize = photo_reimport_master_state_finalize;
#line 33119 "Photo.c"
}


static void photo_reimport_master_state_instance_init (PhotoReimportMasterState * self) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 33126 "Photo.c"
}


static void photo_reimport_master_state_finalize (PhotoReimportMasterState * obj) {
	PhotoReimportMasterState * self;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_REIMPORT_MASTER_STATE, PhotoReimportMasterState);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 33136 "Photo.c"
}


GType photo_reimport_master_state_get_type (void) {
	static volatile gsize photo_reimport_master_state_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_master_state_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { photo_value_reimport_master_state_init, photo_value_reimport_master_state_free_value, photo_value_reimport_master_state_copy_value, photo_value_reimport_master_state_peek_pointer, "p", photo_value_reimport_master_state_collect_value, "p", photo_value_reimport_master_state_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportMasterStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_master_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportMasterState), 0, (GInstanceInitFunc) photo_reimport_master_state_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_reimport_master_state_type_id;
		photo_reimport_master_state_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoReimportMasterState", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&photo_reimport_master_state_type_id__volatile, photo_reimport_master_state_type_id);
	}
	return photo_reimport_master_state_type_id__volatile;
}


gpointer photo_reimport_master_state_ref (gpointer instance) {
	PhotoReimportMasterState * self;
	self = instance;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 33161 "Photo.c"
}


void photo_reimport_master_state_unref (gpointer instance) {
	PhotoReimportMasterState * self;
	self = instance;
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_REIMPORT_MASTER_STATE_GET_CLASS (self)->finalize (self);
#line 1369 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 33174 "Photo.c"
	}
}


static gchar** _vala_array_dup24 (gchar** self, int length) {
	gchar** result;
	int i;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	result = g_new0 (gchar*, length + 1);
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	for (i = 0; i < length; i++) {
#line 33186 "Photo.c"
		gchar* _tmp0_;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = g_strdup (self[i]);
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
		result[i] = _tmp0_;
#line 33192 "Photo.c"
	}
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 33196 "Photo.c"
}


static PhotoReimportMasterStateImpl* photo_reimport_master_state_impl_construct (GType object_type, PhotoRow* row, PhotoMetadata* metadata, gchar** alterations, int alterations_length1) {
	PhotoReimportMasterStateImpl* self = NULL;
	PhotoRow* _tmp0_;
	PhotoRow* _tmp1_;
	PhotoMetadata* _tmp2_;
	PhotoMetadata* _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	gchar** _tmp5_;
	gint _tmp5__length1;
#line 1378 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_ROW (row), NULL);
#line 1378 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata), NULL);
#line 1378 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportMasterStateImpl*) photo_reimport_master_state_construct (object_type);
#line 1379 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = row;
#line 1379 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _photo_row_ref0 (_tmp0_);
#line 1379 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (self->row);
#line 1379 "/home/jens/Source/shotwell/src/Photo.vala"
	self->row = _tmp1_;
#line 1380 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 1380 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _media_metadata_ref0 (_tmp2_);
#line 1380 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (self->metadata);
#line 1380 "/home/jens/Source/shotwell/src/Photo.vala"
	self->metadata = _tmp3_;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = alterations;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4__length1 = alterations_length1;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = (_tmp4_ != NULL) ? _vala_array_dup24 (_tmp4_, _tmp4__length1) : ((gpointer) _tmp4_);
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5__length1 = _tmp4__length1;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	self->alterations = (_vala_array_free (self->alterations, self->alterations_length1, (GDestroyNotify) g_free), NULL);
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	self->alterations = _tmp5_;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	self->alterations_length1 = _tmp5__length1;
#line 1381 "/home/jens/Source/shotwell/src/Photo.vala"
	self->_alterations_size_ = self->alterations_length1;
#line 1378 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 33250 "Photo.c"
}


static PhotoReimportMasterStateImpl* photo_reimport_master_state_impl_new (PhotoRow* row, PhotoMetadata* metadata, gchar** alterations, int alterations_length1) {
#line 1378 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_reimport_master_state_impl_construct (PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, row, metadata, alterations, alterations_length1);
#line 33257 "Photo.c"
}


static void photo_reimport_master_state_impl_class_init (PhotoReimportMasterStateImplClass * klass) {
#line 1372 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_master_state_impl_parent_class = g_type_class_peek_parent (klass);
#line 1372 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportMasterStateClass *) klass)->finalize = photo_reimport_master_state_impl_finalize;
#line 33266 "Photo.c"
}


static void photo_reimport_master_state_impl_instance_init (PhotoReimportMasterStateImpl * self) {
	PhotoRow* _tmp0_;
#line 1373 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_row_new ();
#line 1373 "/home/jens/Source/shotwell/src/Photo.vala"
	self->row = _tmp0_;
#line 1376 "/home/jens/Source/shotwell/src/Photo.vala"
	self->metadata_only = FALSE;
#line 33278 "Photo.c"
}


static void photo_reimport_master_state_impl_finalize (PhotoReimportMasterState * obj) {
	PhotoReimportMasterStateImpl * self;
#line 1372 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_REIMPORT_MASTER_STATE_IMPL, PhotoReimportMasterStateImpl);
#line 1373 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (self->row);
#line 1374 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (self->metadata);
#line 1375 "/home/jens/Source/shotwell/src/Photo.vala"
	self->alterations = (_vala_array_free (self->alterations, self->alterations_length1, (GDestroyNotify) g_free), NULL);
#line 1372 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_REIMPORT_MASTER_STATE_CLASS (photo_reimport_master_state_impl_parent_class)->finalize (obj);
#line 33294 "Photo.c"
}


static GType photo_reimport_master_state_impl_get_type (void) {
	static volatile gsize photo_reimport_master_state_impl_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_master_state_impl_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportMasterStateImplClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_master_state_impl_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportMasterStateImpl), 0, (GInstanceInitFunc) photo_reimport_master_state_impl_instance_init, NULL };
		GType photo_reimport_master_state_impl_type_id;
		photo_reimport_master_state_impl_type_id = g_type_register_static (PHOTO_TYPE_REIMPORT_MASTER_STATE, "PhotoReimportMasterStateImpl", &g_define_type_info, 0);
		g_once_init_leave (&photo_reimport_master_state_impl_type_id__volatile, photo_reimport_master_state_impl_type_id);
	}
	return photo_reimport_master_state_impl_type_id__volatile;
}


PhotoReimportEditableState* photo_reimport_editable_state_construct (GType object_type) {
	PhotoReimportEditableState* self = NULL;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportEditableState*) g_type_create_instance (object_type);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 33316 "Photo.c"
}


static void photo_value_reimport_editable_state_init (GValue* value) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 33323 "Photo.c"
}


static void photo_value_reimport_editable_state_free_value (GValue* value) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_editable_state_unref (value->data[0].v_pointer);
#line 33332 "Photo.c"
	}
}


static void photo_value_reimport_editable_state_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_reimport_editable_state_ref (src_value->data[0].v_pointer);
#line 33342 "Photo.c"
	} else {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 33346 "Photo.c"
	}
}


static gpointer photo_value_reimport_editable_state_peek_pointer (const GValue* value) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 33354 "Photo.c"
}


static gchar* photo_value_reimport_editable_state_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 33361 "Photo.c"
		PhotoReimportEditableState * object;
		object = collect_values[0].v_pointer;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 33368 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 33372 "Photo.c"
		}
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_reimport_editable_state_ref (object);
#line 33376 "Photo.c"
	} else {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33380 "Photo.c"
	}
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 33384 "Photo.c"
}


static gchar* photo_value_reimport_editable_state_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoReimportEditableState ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 33395 "Photo.c"
	}
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 33401 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 33405 "Photo.c"
	} else {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_reimport_editable_state_ref (value->data[0].v_pointer);
#line 33409 "Photo.c"
	}
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 33413 "Photo.c"
}


GParamSpec* photo_param_spec_reimport_editable_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PhotoParamSpecReimportEditableState* spec;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PHOTO_TYPE_REIMPORT_EDITABLE_STATE), NULL);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 33427 "Photo.c"
}


gpointer photo_value_get_reimport_editable_state (const GValue* value) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_EDITABLE_STATE), NULL);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 33436 "Photo.c"
}


void photo_value_set_reimport_editable_state (GValue* value, gpointer v_object) {
	PhotoReimportEditableState * old;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_EDITABLE_STATE));
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_REIMPORT_EDITABLE_STATE));
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_editable_state_ref (value->data[0].v_pointer);
#line 33456 "Photo.c"
	} else {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33460 "Photo.c"
	}
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_editable_state_unref (old);
#line 33466 "Photo.c"
	}
}


void photo_value_take_reimport_editable_state (GValue* value, gpointer v_object) {
	PhotoReimportEditableState * old;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_EDITABLE_STATE));
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_REIMPORT_EDITABLE_STATE));
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 33485 "Photo.c"
	} else {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33489 "Photo.c"
	}
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_editable_state_unref (old);
#line 33495 "Photo.c"
	}
}


static void photo_reimport_editable_state_class_init (PhotoReimportEditableStateClass * klass) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_editable_state_parent_class = g_type_class_peek_parent (klass);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportEditableStateClass *) klass)->finalize = photo_reimport_editable_state_finalize;
#line 33505 "Photo.c"
}


static void photo_reimport_editable_state_instance_init (PhotoReimportEditableState * self) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 33512 "Photo.c"
}


static void photo_reimport_editable_state_finalize (PhotoReimportEditableState * obj) {
	PhotoReimportEditableState * self;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_REIMPORT_EDITABLE_STATE, PhotoReimportEditableState);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 33522 "Photo.c"
}


GType photo_reimport_editable_state_get_type (void) {
	static volatile gsize photo_reimport_editable_state_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_editable_state_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { photo_value_reimport_editable_state_init, photo_value_reimport_editable_state_free_value, photo_value_reimport_editable_state_copy_value, photo_value_reimport_editable_state_peek_pointer, "p", photo_value_reimport_editable_state_collect_value, "p", photo_value_reimport_editable_state_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportEditableStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_editable_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportEditableState), 0, (GInstanceInitFunc) photo_reimport_editable_state_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_reimport_editable_state_type_id;
		photo_reimport_editable_state_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoReimportEditableState", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&photo_reimport_editable_state_type_id__volatile, photo_reimport_editable_state_type_id);
	}
	return photo_reimport_editable_state_type_id__volatile;
}


gpointer photo_reimport_editable_state_ref (gpointer instance) {
	PhotoReimportEditableState * self;
	self = instance;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 33547 "Photo.c"
}


void photo_reimport_editable_state_unref (gpointer instance) {
	PhotoReimportEditableState * self;
	self = instance;
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_REIMPORT_EDITABLE_STATE_GET_CLASS (self)->finalize (self);
#line 1385 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 33560 "Photo.c"
	}
}


static PhotoReimportEditableStateImpl* photo_reimport_editable_state_impl_construct (GType object_type, BackingPhotoRow* backing_state, PhotoMetadata* metadata) {
	PhotoReimportEditableStateImpl* self = NULL;
	BackingPhotoRow* _tmp0_;
	BackingPhotoRow* _tmp1_;
	PhotoMetadata* _tmp2_;
	PhotoMetadata* _tmp3_;
#line 1393 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_BACKING_PHOTO_ROW (backing_state), NULL);
#line 1393 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata), NULL);
#line 1393 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportEditableStateImpl*) photo_reimport_editable_state_construct (object_type);
#line 1394 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backing_state;
#line 1394 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _backing_photo_row_ref0 (_tmp0_);
#line 1394 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (self->backing_state);
#line 1394 "/home/jens/Source/shotwell/src/Photo.vala"
	self->backing_state = _tmp1_;
#line 1395 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 1395 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _media_metadata_ref0 (_tmp2_);
#line 1395 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (self->metadata);
#line 1395 "/home/jens/Source/shotwell/src/Photo.vala"
	self->metadata = _tmp3_;
#line 1393 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 33595 "Photo.c"
}


static PhotoReimportEditableStateImpl* photo_reimport_editable_state_impl_new (BackingPhotoRow* backing_state, PhotoMetadata* metadata) {
#line 1393 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_reimport_editable_state_impl_construct (PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, backing_state, metadata);
#line 33602 "Photo.c"
}


static void photo_reimport_editable_state_impl_class_init (PhotoReimportEditableStateImplClass * klass) {
#line 1388 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_editable_state_impl_parent_class = g_type_class_peek_parent (klass);
#line 1388 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportEditableStateClass *) klass)->finalize = photo_reimport_editable_state_impl_finalize;
#line 33611 "Photo.c"
}


static void photo_reimport_editable_state_impl_instance_init (PhotoReimportEditableStateImpl * self) {
	BackingPhotoRow* _tmp0_;
#line 1389 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backing_photo_row_new ();
#line 1389 "/home/jens/Source/shotwell/src/Photo.vala"
	self->backing_state = _tmp0_;
#line 1391 "/home/jens/Source/shotwell/src/Photo.vala"
	self->metadata_only = FALSE;
#line 33623 "Photo.c"
}


static void photo_reimport_editable_state_impl_finalize (PhotoReimportEditableState * obj) {
	PhotoReimportEditableStateImpl * self;
#line 1388 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_REIMPORT_EDITABLE_STATE_IMPL, PhotoReimportEditableStateImpl);
#line 1389 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (self->backing_state);
#line 1390 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (self->metadata);
#line 1388 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_REIMPORT_EDITABLE_STATE_CLASS (photo_reimport_editable_state_impl_parent_class)->finalize (obj);
#line 33637 "Photo.c"
}


static GType photo_reimport_editable_state_impl_get_type (void) {
	static volatile gsize photo_reimport_editable_state_impl_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_editable_state_impl_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportEditableStateImplClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_editable_state_impl_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportEditableStateImpl), 0, (GInstanceInitFunc) photo_reimport_editable_state_impl_instance_init, NULL };
		GType photo_reimport_editable_state_impl_type_id;
		photo_reimport_editable_state_impl_type_id = g_type_register_static (PHOTO_TYPE_REIMPORT_EDITABLE_STATE, "PhotoReimportEditableStateImpl", &g_define_type_info, 0);
		g_once_init_leave (&photo_reimport_editable_state_impl_type_id__volatile, photo_reimport_editable_state_impl_type_id);
	}
	return photo_reimport_editable_state_impl_type_id__volatile;
}


PhotoReimportRawDevelopmentState* photo_reimport_raw_development_state_construct (GType object_type) {
	PhotoReimportRawDevelopmentState* self = NULL;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportRawDevelopmentState*) g_type_create_instance (object_type);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 33659 "Photo.c"
}


static void photo_value_reimport_raw_development_state_init (GValue* value) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 33666 "Photo.c"
}


static void photo_value_reimport_raw_development_state_free_value (GValue* value) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_unref (value->data[0].v_pointer);
#line 33675 "Photo.c"
	}
}


static void photo_value_reimport_raw_development_state_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_reimport_raw_development_state_ref (src_value->data[0].v_pointer);
#line 33685 "Photo.c"
	} else {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 33689 "Photo.c"
	}
}


static gpointer photo_value_reimport_raw_development_state_peek_pointer (const GValue* value) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 33697 "Photo.c"
}


static gchar* photo_value_reimport_raw_development_state_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 33704 "Photo.c"
		PhotoReimportRawDevelopmentState * object;
		object = collect_values[0].v_pointer;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 33711 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 33715 "Photo.c"
		}
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_reimport_raw_development_state_ref (object);
#line 33719 "Photo.c"
	} else {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33723 "Photo.c"
	}
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 33727 "Photo.c"
}


static gchar* photo_value_reimport_raw_development_state_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoReimportRawDevelopmentState ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 33738 "Photo.c"
	}
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 33744 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 33748 "Photo.c"
	} else {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_reimport_raw_development_state_ref (value->data[0].v_pointer);
#line 33752 "Photo.c"
	}
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 33756 "Photo.c"
}


GParamSpec* photo_param_spec_reimport_raw_development_state (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PhotoParamSpecReimportRawDevelopmentState* spec;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE), NULL);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 33770 "Photo.c"
}


gpointer photo_value_get_reimport_raw_development_state (const GValue* value) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE), NULL);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 33779 "Photo.c"
}


void photo_value_set_reimport_raw_development_state (GValue* value, gpointer v_object) {
	PhotoReimportRawDevelopmentState * old;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE));
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE));
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_ref (value->data[0].v_pointer);
#line 33799 "Photo.c"
	} else {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33803 "Photo.c"
	}
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_unref (old);
#line 33809 "Photo.c"
	}
}


void photo_value_take_reimport_raw_development_state (GValue* value, gpointer v_object) {
	PhotoReimportRawDevelopmentState * old;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE));
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE));
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 33828 "Photo.c"
	} else {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 33832 "Photo.c"
	}
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_unref (old);
#line 33838 "Photo.c"
	}
}


static void photo_reimport_raw_development_state_class_init (PhotoReimportRawDevelopmentStateClass * klass) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_raw_development_state_parent_class = g_type_class_peek_parent (klass);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportRawDevelopmentStateClass *) klass)->finalize = photo_reimport_raw_development_state_finalize;
#line 33848 "Photo.c"
}


static void photo_reimport_raw_development_state_instance_init (PhotoReimportRawDevelopmentState * self) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 33855 "Photo.c"
}


static void photo_reimport_raw_development_state_finalize (PhotoReimportRawDevelopmentState * obj) {
	PhotoReimportRawDevelopmentState * self;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE, PhotoReimportRawDevelopmentState);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 33865 "Photo.c"
}


GType photo_reimport_raw_development_state_get_type (void) {
	static volatile gsize photo_reimport_raw_development_state_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_raw_development_state_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { photo_value_reimport_raw_development_state_init, photo_value_reimport_raw_development_state_free_value, photo_value_reimport_raw_development_state_copy_value, photo_value_reimport_raw_development_state_peek_pointer, "p", photo_value_reimport_raw_development_state_collect_value, "p", photo_value_reimport_raw_development_state_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportRawDevelopmentStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_raw_development_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportRawDevelopmentState), 0, (GInstanceInitFunc) photo_reimport_raw_development_state_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_reimport_raw_development_state_type_id;
		photo_reimport_raw_development_state_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoReimportRawDevelopmentState", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&photo_reimport_raw_development_state_type_id__volatile, photo_reimport_raw_development_state_type_id);
	}
	return photo_reimport_raw_development_state_type_id__volatile;
}


gpointer photo_reimport_raw_development_state_ref (gpointer instance) {
	PhotoReimportRawDevelopmentState * self;
	self = instance;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 33890 "Photo.c"
}


void photo_reimport_raw_development_state_unref (gpointer instance) {
	PhotoReimportRawDevelopmentState * self;
	self = instance;
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_GET_CLASS (self)->finalize (self);
#line 1399 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 33903 "Photo.c"
	}
}


static PhotoReimportRawDevelopmentStateImpl* photo_reimport_raw_development_state_impl_construct (GType object_type) {
	PhotoReimportRawDevelopmentStateImpl* self = NULL;
#line 1416 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportRawDevelopmentStateImpl*) photo_reimport_raw_development_state_construct (object_type);
#line 1416 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 33914 "Photo.c"
}


static PhotoReimportRawDevelopmentStateImpl* photo_reimport_raw_development_state_impl_new (void) {
#line 1416 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_reimport_raw_development_state_impl_construct (PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL);
#line 33921 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_add (PhotoReimportRawDevelopmentStateImpl* self, BackingPhotoRow* backing, PhotoMetadata* metadata) {
	GeeCollection* _tmp0_;
	BackingPhotoRow* _tmp1_;
	PhotoMetadata* _tmp2_;
	PhotoReimportRawDevelopmentStateImplDevToReimport* _tmp3_;
	PhotoReimportRawDevelopmentStateImplDevToReimport* _tmp4_;
#line 1419 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL (self));
#line 1419 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (backing));
#line 1419 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->list;
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = backing;
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_reimport_raw_development_state_impl_dev_to_reimport_new (_tmp1_, _tmp2_);
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	gee_collection_add (_tmp0_, _tmp4_);
#line 1420 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_reimport_raw_development_state_impl_dev_to_reimport_unref0 (_tmp4_);
#line 33951 "Photo.c"
}


static gint photo_reimport_raw_development_state_impl_get_size (PhotoReimportRawDevelopmentStateImpl* self) {
	gint result = 0;
	GeeCollection* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 1423 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (PHOTO_IS_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL (self), 0);
#line 1424 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->list;
#line 1424 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = gee_collection_get_size (_tmp0_);
#line 1424 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_;
#line 1424 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp2_;
#line 1424 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 33972 "Photo.c"
}


static PhotoReimportRawDevelopmentStateImplDevToReimport* photo_reimport_raw_development_state_impl_dev_to_reimport_construct (GType object_type, BackingPhotoRow* backing, PhotoMetadata* metadata) {
	PhotoReimportRawDevelopmentStateImplDevToReimport* self = NULL;
	BackingPhotoRow* _tmp0_;
	BackingPhotoRow* _tmp1_;
	PhotoMetadata* _tmp2_;
	PhotoMetadata* _tmp3_;
#line 1407 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_BACKING_PHOTO_ROW (backing), NULL);
#line 1407 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata), NULL);
#line 1407 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (PhotoReimportRawDevelopmentStateImplDevToReimport*) g_type_create_instance (object_type);
#line 1408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backing;
#line 1408 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _backing_photo_row_ref0 (_tmp0_);
#line 1408 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (self->backing);
#line 1408 "/home/jens/Source/shotwell/src/Photo.vala"
	self->backing = _tmp1_;
#line 1409 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 1409 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _media_metadata_ref0 (_tmp2_);
#line 1409 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (self->metadata);
#line 1409 "/home/jens/Source/shotwell/src/Photo.vala"
	self->metadata = _tmp3_;
#line 1407 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 34006 "Photo.c"
}


static PhotoReimportRawDevelopmentStateImplDevToReimport* photo_reimport_raw_development_state_impl_dev_to_reimport_new (BackingPhotoRow* backing, PhotoMetadata* metadata) {
#line 1407 "/home/jens/Source/shotwell/src/Photo.vala"
	return photo_reimport_raw_development_state_impl_dev_to_reimport_construct (PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT, backing, metadata);
#line 34013 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_value_dev_to_reimport_init (GValue* value) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	value->data[0].v_pointer = NULL;
#line 34020 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_value_dev_to_reimport_free_value (GValue* value) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (value->data[0].v_pointer) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_impl_dev_to_reimport_unref (value->data[0].v_pointer);
#line 34029 "Photo.c"
	}
}


static void photo_reimport_raw_development_state_impl_value_dev_to_reimport_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (src_value->data[0].v_pointer) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = photo_reimport_raw_development_state_impl_dev_to_reimport_ref (src_value->data[0].v_pointer);
#line 34039 "Photo.c"
	} else {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		dest_value->data[0].v_pointer = NULL;
#line 34043 "Photo.c"
	}
}


static gpointer photo_reimport_raw_development_state_impl_value_dev_to_reimport_peek_pointer (const GValue* value) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 34051 "Photo.c"
}


static gchar* photo_reimport_raw_development_state_impl_value_dev_to_reimport_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (collect_values[0].v_pointer) {
#line 34058 "Photo.c"
		PhotoReimportRawDevelopmentStateImplDevToReimport * object;
		object = collect_values[0].v_pointer;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 34065 "Photo.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 34069 "Photo.c"
		}
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = photo_reimport_raw_development_state_impl_dev_to_reimport_ref (object);
#line 34073 "Photo.c"
	} else {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 34077 "Photo.c"
	}
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 34081 "Photo.c"
}


static gchar* photo_reimport_raw_development_state_impl_value_dev_to_reimport_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoReimportRawDevelopmentStateImplDevToReimport ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!object_p) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 34092 "Photo.c"
	}
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!value->data[0].v_pointer) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = NULL;
#line 34098 "Photo.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = value->data[0].v_pointer;
#line 34102 "Photo.c"
	} else {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		*object_p = photo_reimport_raw_development_state_impl_dev_to_reimport_ref (value->data[0].v_pointer);
#line 34106 "Photo.c"
	}
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	return NULL;
#line 34110 "Photo.c"
}


static GParamSpec* photo_reimport_raw_development_state_impl_param_spec_dev_to_reimport (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PhotoReimportRawDevelopmentStateImplParamSpecDevToReimport* spec;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT), NULL);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	return G_PARAM_SPEC (spec);
#line 34124 "Photo.c"
}


static gpointer photo_reimport_raw_development_state_impl_value_get_dev_to_reimport (const GValue* value) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT), NULL);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	return value->data[0].v_pointer;
#line 34133 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_value_set_dev_to_reimport (GValue* value, gpointer v_object) {
	PhotoReimportRawDevelopmentStateImplDevToReimport * old;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT));
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT));
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_impl_dev_to_reimport_ref (value->data[0].v_pointer);
#line 34153 "Photo.c"
	} else {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 34157 "Photo.c"
	}
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_impl_dev_to_reimport_unref (old);
#line 34163 "Photo.c"
	}
}


static void photo_reimport_raw_development_state_impl_value_take_dev_to_reimport (GValue* value, gpointer v_object) {
	PhotoReimportRawDevelopmentStateImplDevToReimport * old;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT));
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	old = value->data[0].v_pointer;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (v_object) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT));
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = v_object;
#line 34182 "Photo.c"
	} else {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		value->data[0].v_pointer = NULL;
#line 34186 "Photo.c"
	}
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (old) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_reimport_raw_development_state_impl_dev_to_reimport_unref (old);
#line 34192 "Photo.c"
	}
}


static void photo_reimport_raw_development_state_impl_dev_to_reimport_class_init (PhotoReimportRawDevelopmentStateImplDevToReimportClass * klass) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_raw_development_state_impl_dev_to_reimport_parent_class = g_type_class_peek_parent (klass);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportRawDevelopmentStateImplDevToReimportClass *) klass)->finalize = photo_reimport_raw_development_state_impl_dev_to_reimport_finalize;
#line 34202 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_dev_to_reimport_instance_init (PhotoReimportRawDevelopmentStateImplDevToReimport * self) {
	BackingPhotoRow* _tmp0_;
#line 1404 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backing_photo_row_new ();
#line 1404 "/home/jens/Source/shotwell/src/Photo.vala"
	self->backing = _tmp0_;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	self->ref_count = 1;
#line 34214 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_dev_to_reimport_finalize (PhotoReimportRawDevelopmentStateImplDevToReimport * obj) {
	PhotoReimportRawDevelopmentStateImplDevToReimport * self;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT, PhotoReimportRawDevelopmentStateImplDevToReimport);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_handlers_destroy (self);
#line 1404 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (self->backing);
#line 1405 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (self->metadata);
#line 34228 "Photo.c"
}


GType photo_reimport_raw_development_state_impl_dev_to_reimport_get_type (void) {
	static volatile gsize photo_reimport_raw_development_state_impl_dev_to_reimport_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_raw_development_state_impl_dev_to_reimport_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { photo_reimport_raw_development_state_impl_value_dev_to_reimport_init, photo_reimport_raw_development_state_impl_value_dev_to_reimport_free_value, photo_reimport_raw_development_state_impl_value_dev_to_reimport_copy_value, photo_reimport_raw_development_state_impl_value_dev_to_reimport_peek_pointer, "p", photo_reimport_raw_development_state_impl_value_dev_to_reimport_collect_value, "p", photo_reimport_raw_development_state_impl_value_dev_to_reimport_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportRawDevelopmentStateImplDevToReimportClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_raw_development_state_impl_dev_to_reimport_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportRawDevelopmentStateImplDevToReimport), 0, (GInstanceInitFunc) photo_reimport_raw_development_state_impl_dev_to_reimport_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_reimport_raw_development_state_impl_dev_to_reimport_type_id;
		photo_reimport_raw_development_state_impl_dev_to_reimport_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoReimportRawDevelopmentStateImplDevToReimport", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&photo_reimport_raw_development_state_impl_dev_to_reimport_type_id__volatile, photo_reimport_raw_development_state_impl_dev_to_reimport_type_id);
	}
	return photo_reimport_raw_development_state_impl_dev_to_reimport_type_id__volatile;
}


static gpointer photo_reimport_raw_development_state_impl_dev_to_reimport_ref (gpointer instance) {
	PhotoReimportRawDevelopmentStateImplDevToReimport * self;
	self = instance;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	return instance;
#line 34253 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_dev_to_reimport_unref (gpointer instance) {
	PhotoReimportRawDevelopmentStateImplDevToReimport * self;
	self = instance;
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_DEV_TO_REIMPORT_GET_CLASS (self)->finalize (self);
#line 1403 "/home/jens/Source/shotwell/src/Photo.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 34266 "Photo.c"
	}
}


static void photo_reimport_raw_development_state_impl_class_init (PhotoReimportRawDevelopmentStateImplClass * klass) {
#line 1402 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_reimport_raw_development_state_impl_parent_class = g_type_class_peek_parent (klass);
#line 1402 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoReimportRawDevelopmentStateClass *) klass)->finalize = photo_reimport_raw_development_state_impl_finalize;
#line 34276 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_instance_init (PhotoReimportRawDevelopmentStateImpl * self) {
	GeeArrayList* _tmp0_;
#line 1413 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = gee_array_list_new (PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL_TYPE_DEV_TO_REIMPORT, (GBoxedCopyFunc) photo_reimport_raw_development_state_impl_dev_to_reimport_ref, (GDestroyNotify) photo_reimport_raw_development_state_impl_dev_to_reimport_unref, NULL, NULL, NULL);
#line 1413 "/home/jens/Source/shotwell/src/Photo.vala"
	self->list = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection);
#line 1414 "/home/jens/Source/shotwell/src/Photo.vala"
	self->metadata_only = FALSE;
#line 34288 "Photo.c"
}


static void photo_reimport_raw_development_state_impl_finalize (PhotoReimportRawDevelopmentState * obj) {
	PhotoReimportRawDevelopmentStateImpl * self;
#line 1402 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE_IMPL, PhotoReimportRawDevelopmentStateImpl);
#line 1413 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->list);
#line 1402 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_REIMPORT_RAW_DEVELOPMENT_STATE_CLASS (photo_reimport_raw_development_state_impl_parent_class)->finalize (obj);
#line 34300 "Photo.c"
}


static GType photo_reimport_raw_development_state_impl_get_type (void) {
	static volatile gsize photo_reimport_raw_development_state_impl_type_id__volatile = 0;
	if (g_once_init_enter (&photo_reimport_raw_development_state_impl_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoReimportRawDevelopmentStateImplClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_reimport_raw_development_state_impl_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoReimportRawDevelopmentStateImpl), 0, (GInstanceInitFunc) photo_reimport_raw_development_state_impl_instance_init, NULL };
		GType photo_reimport_raw_development_state_impl_type_id;
		photo_reimport_raw_development_state_impl_type_id = g_type_register_static (PHOTO_TYPE_REIMPORT_RAW_DEVELOPMENT_STATE, "PhotoReimportRawDevelopmentStateImpl", &g_define_type_info, 0);
		g_once_init_leave (&photo_reimport_raw_development_state_impl_type_id__volatile, photo_reimport_raw_development_state_impl_type_id);
	}
	return photo_reimport_raw_development_state_impl_type_id__volatile;
}


static void photo_class_init (PhotoClass * klass) {
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_parent_class = g_type_class_peek_parent (klass);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	g_type_class_add_private (klass, sizeof (PhotoPrivate));
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_editable_replaced = (void (*) (Photo *, GFile*, GFile*)) photo_real_notify_editable_replaced;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_raw_development_modified = (void (*) (Photo *)) photo_real_notify_raw_development_modified;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_baseline_replaced = (void (*) (Photo *)) photo_real_notify_baseline_replaced;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_master_reimported = (void (*) (Photo *, PhotoMetadata*)) photo_real_notify_master_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_editable_reimported = (void (*) (Photo *, PhotoMetadata*)) photo_real_notify_editable_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_source_reimported = (void (*) (Photo *, PhotoMetadata*)) photo_real_notify_source_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_baseline_reimported = (void (*) (Photo *, PhotoMetadata*)) photo_real_notify_baseline_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->internal_delete_backing = (gboolean (*) (DataSource *, GError**)) photo_real_internal_delete_backing;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_backing_files_state = (BackingFileState** (*) (MediaSource *, int*)) photo_real_get_backing_files_state;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->apply_user_metadata_for_reimport = (void (*) (Photo *, PhotoMetadata*)) photo_real_apply_user_metadata_for_reimport;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->get_typename = (gchar* (*) (DataSource *)) photo_real_get_typename;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->get_instance_id = (gint64 (*) (DataSource *)) photo_real_get_instance_id;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->get_source_id = (gchar* (*) (DataSource *)) photo_real_get_source_id;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((ThumbnailSourceClass *) klass)->get_preferred_thumbnail_format = (PhotoFileFormat (*) (ThumbnailSource *)) photo_real_get_preferred_thumbnail_format;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((ThumbnailSourceClass *) klass)->create_thumbnail = (GdkPixbuf* (*) (ThumbnailSource *, gint, GError**)) photo_real_create_thumbnail;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_file = (GFile* (*) (MediaSource *)) photo_real_get_file;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_master_file = (GFile* (*) (MediaSource *)) photo_real_get_master_file;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_timestamp = (time_t (*) (MediaSource *)) photo_real_get_timestamp;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_event_id = (void (*) (MediaSource *, EventID*)) photo_real_get_event_id;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_import_id = (void (*) (MediaSource *, ImportID*)) photo_real_get_import_id;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_master_md5 = (gchar* (*) (MediaSource *)) photo_real_get_master_md5;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_rating = (Rating (*) (MediaSource *)) photo_real_get_rating;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->set_rating = (void (*) (MediaSource *, Rating)) photo_real_set_rating;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->increase_rating = (void (*) (MediaSource *)) photo_real_increase_rating;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->decrease_rating = (void (*) (MediaSource *)) photo_real_decrease_rating;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->commit_backlinks = (void (*) (DataSource *, SourceCollection*, const gchar*)) photo_real_commit_backlinks;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->set_event_id = (gboolean (*) (MediaSource *, EventID*)) photo_real_set_event_id;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataObjectClass *) klass)->to_string = (gchar* (*) (DataObject *)) photo_real_to_string;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->equals = (gboolean (*) (DataSource *, DataSource*)) photo_real_equals;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_filesize = (guint64 (*) (MediaSource *)) photo_real_get_filesize;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_master_filesize = (guint64 (*) (MediaSource *)) photo_real_get_master_filesize;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_exposure_time = (time_t (*) (MediaSource *)) photo_real_get_exposure_time;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_basename = (gchar* (*) (MediaSource *)) photo_real_get_basename;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_title = (gchar* (*) (MediaSource *)) photo_real_get_title;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_comment = (gchar* (*) (MediaSource *)) photo_real_get_comment;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->set_title = (void (*) (MediaSource *, const gchar*)) photo_real_set_title;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->set_comment = (gboolean (*) (MediaSource *, const gchar*)) photo_real_set_comment;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_dimensions = (void (*) (MediaSource *, PhotoException, Dimensions*)) photo_real_get_dimensions;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoSourceClass *) klass)->get_metadata = (PhotoMetadata* (*) (PhotoSource *)) photo_real_get_metadata;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->rotate = (void (*) (Photo *, Rotation)) photo_real_rotate;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoSourceClass *) klass)->get_pixbuf = (GdkPixbuf* (*) (PhotoSource *, Scaling*, GError**)) photo_real_get_pixbuf;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->has_user_generated_metadata = (gboolean (*) (Photo *)) photo_real_has_user_generated_metadata;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->set_user_metadata_for_export = (void (*) (Photo *, PhotoMetadata*)) photo_real_set_user_metadata_for_export;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->editable_replaced = photo_real_editable_replaced;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->raw_development_modified = photo_real_raw_development_modified;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->baseline_replaced = photo_real_baseline_replaced;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->master_reimported = photo_real_master_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->editable_reimported = photo_real_editable_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->baseline_reimported = photo_real_baseline_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->source_reimported = photo_real_source_reimported;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_photo_get_property;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_photo_set_property;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (klass)->finalize = photo_finalize;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_EDITABLE_REPLACED_SIGNAL] = g_signal_new ("editable-replaced", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, editable_replaced), NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_OBJECT, G_TYPE_NONE, 2, g_file_get_type (), g_file_get_type ());
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_RAW_DEVELOPMENT_MODIFIED_SIGNAL] = g_signal_new ("raw-development-modified", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, raw_development_modified), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_BASELINE_REPLACED_SIGNAL] = g_signal_new ("baseline-replaced", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, baseline_replaced), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_MASTER_REIMPORTED_SIGNAL] = g_signal_new ("master-reimported", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, master_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__MEDIA_METADATA, G_TYPE_NONE, 1, TYPE_PHOTO_METADATA);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_EDITABLE_REIMPORTED_SIGNAL] = g_signal_new ("editable-reimported", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, editable_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__MEDIA_METADATA, G_TYPE_NONE, 1, TYPE_PHOTO_METADATA);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_BASELINE_REIMPORTED_SIGNAL] = g_signal_new ("baseline-reimported", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, baseline_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__MEDIA_METADATA, G_TYPE_NONE, 1, TYPE_PHOTO_METADATA);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_signals[PHOTO_SOURCE_REIMPORTED_SIGNAL] = g_signal_new ("source-reimported", TYPE_PHOTO, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (PhotoClass, source_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__MEDIA_METADATA, G_TYPE_NONE, 1, TYPE_PHOTO_METADATA);
#line 326 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_init (&__lock_photo_source_pixbuf_cache);
#line 34443 "Photo.c"
}


static void photo_dateable_interface_init (DateableIface * iface) {
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_dateable_parent_iface = g_type_interface_peek_parent (iface);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->get_exposure_time = (time_t (*) (Dateable *)) photo_real_get_exposure_time;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->set_exposure_time = (void (*) (Dateable *, time_t)) photo_real_set_exposure_time;
#line 34454 "Photo.c"
}


static void photo_instance_init (Photo * self) {
	BackingPhotoRow* _tmp0_;
	PhotoBackingReaders* _tmp1_;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv = PHOTO_GET_PRIVATE (self);
#line 331 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_init (&self->priv->__lock_row);
#line 332 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backing_photo_row_new ();
#line 332 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->editable = _tmp0_;
#line 333 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_init (&self->priv->__lock_readers);
#line 333 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_backing_readers_new ();
#line 333 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->readers = _tmp1_;
#line 334 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->transformer = NULL;
#line 335 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->adjustments = NULL;
#line 337 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->file_title = NULL;
#line 338 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->editable_monitor = NULL;
#line 339 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->reimport_editable_scheduler = NULL;
#line 340 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->update_editable_attributes_scheduler = NULL;
#line 341 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->remove_editable_scheduler = NULL;
#line 343 "/home/jens/Source/shotwell/src/Photo.vala"
	self->can_rotate_now = TRUE;
#line 346 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_init (&self->priv->__lock_developments);
#line 346 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->developments = NULL;
#line 353 "/home/jens/Source/shotwell/src/Photo.vala"
	self->backing_photo_row = NULL;
#line 34497 "Photo.c"
}


static void photo_finalize (GObject * obj) {
	Photo * self;
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHOTO, Photo);
#line 331 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_clear (&self->priv->__lock_row);
#line 331 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (self->row);
#line 332 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (self->priv->editable);
#line 333 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_clear (&self->priv->__lock_readers);
#line 333 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_backing_readers_unref0 (self->priv->readers);
#line 334 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformer_unref0 (self->priv->transformer);
#line 335 "/home/jens/Source/shotwell/src/Photo.vala"
	_pixel_transformation_bundle_unref0 (self->priv->adjustments);
#line 337 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (self->priv->file_title);
#line 338 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->editable_monitor);
#line 339 "/home/jens/Source/shotwell/src/Photo.vala"
	_one_shot_scheduler_unref0 (self->priv->reimport_editable_scheduler);
#line 340 "/home/jens/Source/shotwell/src/Photo.vala"
	_one_shot_scheduler_unref0 (self->priv->update_editable_attributes_scheduler);
#line 341 "/home/jens/Source/shotwell/src/Photo.vala"
	_one_shot_scheduler_unref0 (self->priv->remove_editable_scheduler);
#line 346 "/home/jens/Source/shotwell/src/Photo.vala"
	g_rec_mutex_clear (&self->priv->__lock_developments);
#line 346 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->developments);
#line 353 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (self->backing_photo_row);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (photo_parent_class)->finalize (obj);
#line 34537 "Photo.c"
}


GType photo_get_type (void) {
	static volatile gsize photo_type_id__volatile = 0;
	if (g_once_init_enter (&photo_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Photo), 0, (GInstanceInitFunc) photo_instance_init, NULL };
		static const GInterfaceInfo dateable_info = { (GInterfaceInitFunc) photo_dateable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType photo_type_id;
		photo_type_id = g_type_register_static (TYPE_PHOTO_SOURCE, "Photo", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (photo_type_id, TYPE_DATEABLE, &dateable_info);
		g_once_init_leave (&photo_type_id__volatile, photo_type_id);
	}
	return photo_type_id__volatile;
}


static void _vala_photo_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	Photo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_PHOTO, Photo);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (property_id) {
#line 34560 "Photo.c"
		default:
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		break;
#line 34566 "Photo.c"
	}
}


static void _vala_photo_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	Photo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_PHOTO, Photo);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
	switch (property_id) {
#line 34576 "Photo.c"
		default:
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 161 "/home/jens/Source/shotwell/src/Photo.vala"
		break;
#line 34582 "Photo.c"
	}
}


GType library_photo_source_collection_state_get_type (void) {
	static volatile gsize library_photo_source_collection_state_type_id__volatile = 0;
	if (g_once_init_enter (&library_photo_source_collection_state_type_id__volatile)) {
		static const GEnumValue values[] = {{LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_UNKNOWN, "LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_UNKNOWN", "unknown"}, {LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_ONLINE, "LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_ONLINE", "online"}, {LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_OFFLINE, "LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_OFFLINE", "offline"}, {LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_TRASH, "LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_TRASH", "trash"}, {LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_EDITABLE, "LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_EDITABLE", "editable"}, {LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_DEVELOPER, "LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_DEVELOPER", "developer"}, {0, NULL, NULL}};
		GType library_photo_source_collection_state_type_id;
		library_photo_source_collection_state_type_id = g_enum_register_static ("LibraryPhotoSourceCollectionState", values);
		g_once_init_leave (&library_photo_source_collection_state_type_id__volatile, library_photo_source_collection_state_type_id);
	}
	return library_photo_source_collection_state_type_id__volatile;
}


static guint _file_hash_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = file_hash ((GFile*) v);
#line 4483 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34604 "Photo.c"
}


static gboolean _file_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = file_equal ((GFile*) a, (GFile*) b);
#line 4483 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34613 "Photo.c"
}


static gint _int64_compare_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = int64_compare ((gint64*) a, (gint64*) b);
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34622 "Photo.c"
}


static gint64* _int64_dup (gint64* self) {
	gint64* dup;
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	dup = g_new0 (gint64, 1);
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	memcpy (dup, self, sizeof (gint64));
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	return dup;
#line 34634 "Photo.c"
}


static gboolean _int64_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = int64_equal ((gint64*) a, (gint64*) b);
#line 4489 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34643 "Photo.c"
}


static gint64 _photo_get_photo_key_get_source_database_key (DataSource* source, gpointer self) {
	gint64 result;
	result = photo_get_photo_key (source);
#line 4509 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34652 "Photo.c"
}


static void _library_photo_source_collection_on_trashcan_contents_altered_source_holding_tank_contents_altered (SourceHoldingTank* _sender, GeeCollection* added, GeeCollection* removed, gpointer self) {
#line 4511 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_on_trashcan_contents_altered ((LibraryPhotoSourceCollection*) self, added, removed);
#line 34659 "Photo.c"
}


static void _library_photo_source_collection_on_offline_contents_altered_source_holding_tank_contents_altered (SourceHoldingTank* _sender, GeeCollection* added, GeeCollection* removed, gpointer self) {
#line 4512 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_on_offline_contents_altered ((LibraryPhotoSourceCollection*) self, added, removed);
#line 34666 "Photo.c"
}


LibraryPhotoSourceCollection* library_photo_source_collection_construct (GType object_type) {
	LibraryPhotoSourceCollection* self = NULL;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	MediaSourceHoldingTank* _tmp2_;
	MediaSourceHoldingTank* _tmp3_;
#line 4509 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (LibraryPhotoSourceCollection*) media_source_collection_construct (object_type, "LibraryPhotoSourceCollection", _photo_get_photo_key_get_source_database_key, NULL);
#line 4511 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_trashcan (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4511 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4511 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), "contents-altered", (GCallback) _library_photo_source_collection_on_trashcan_contents_altered_source_holding_tank_contents_altered, self);
#line 4511 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4512 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4512 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 4512 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), "contents-altered", (GCallback) _library_photo_source_collection_on_offline_contents_altered_source_holding_tank_contents_altered, self);
#line 4512 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp3_);
#line 4508 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 34696 "Photo.c"
}


LibraryPhotoSourceCollection* library_photo_source_collection_new (void) {
#line 4508 "/home/jens/Source/shotwell/src/Photo.vala"
	return library_photo_source_collection_construct (TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION);
#line 34703 "Photo.c"
}


static gboolean _library_photo_source_collection_check_if_trashed_photo_source_holding_tank_check_to_keep (DataSource* source, Alteration* alteration, gpointer self) {
	gboolean result;
	result = library_photo_source_collection_check_if_trashed_photo ((LibraryPhotoSourceCollection*) self, source, alteration);
#line 4516 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34712 "Photo.c"
}


static MediaSourceHoldingTank* library_photo_source_collection_real_create_trashcan (MediaSourceCollection* base) {
	LibraryPhotoSourceCollection * self;
	MediaSourceHoldingTank* result = NULL;
	LibraryPhotoSourceHoldingTank* _tmp0_;
#line 4515 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4516 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = library_photo_source_holding_tank_new (self, _library_photo_source_collection_check_if_trashed_photo_source_holding_tank_check_to_keep, self, _photo_get_photo_key_get_source_database_key, NULL);
#line 4516 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTank);
#line 4516 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34728 "Photo.c"
}


static gboolean _library_photo_source_collection_check_if_offline_photo_source_holding_tank_check_to_keep (DataSource* source, Alteration* alteration, gpointer self) {
	gboolean result;
	result = library_photo_source_collection_check_if_offline_photo ((LibraryPhotoSourceCollection*) self, source, alteration);
#line 4520 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34737 "Photo.c"
}


static MediaSourceHoldingTank* library_photo_source_collection_real_create_offline_bin (MediaSourceCollection* base) {
	LibraryPhotoSourceCollection * self;
	MediaSourceHoldingTank* result = NULL;
	LibraryPhotoSourceHoldingTank* _tmp0_;
#line 4519 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4520 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = library_photo_source_holding_tank_new (self, _library_photo_source_collection_check_if_offline_photo_source_holding_tank_check_to_keep, self, _photo_get_photo_key_get_source_database_key, NULL);
#line 4520 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTank);
#line 4520 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34753 "Photo.c"
}


static MediaMonitor* library_photo_source_collection_real_create_media_monitor (MediaSourceCollection* base, Workers* workers, GCancellable* cancellable) {
	LibraryPhotoSourceCollection * self;
	MediaMonitor* result = NULL;
	Workers* _tmp0_;
	GCancellable* _tmp1_;
	PhotoMonitor* _tmp2_;
#line 4523 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4523 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_WORKERS (workers), NULL);
#line 4523 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_CANCELLABLE (cancellable), NULL);
#line 4524 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = workers;
#line 4524 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = cancellable;
#line 4524 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_monitor_new (_tmp0_, _tmp1_);
#line 4524 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_MEDIA_MONITOR, MediaMonitor);
#line 4524 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34779 "Photo.c"
}


static gboolean library_photo_source_collection_real_holds_type_of_source (SourceCollection* base, DataSource* source) {
	LibraryPhotoSourceCollection * self;
	gboolean result = FALSE;
	DataSource* _tmp0_;
#line 4527 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4527 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
#line 4528 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = source;
#line 4528 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_LIBRARY_PHOTO);
#line 4528 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34797 "Photo.c"
}


static gchar* library_photo_source_collection_real_get_typename (MediaSourceCollection* base) {
	LibraryPhotoSourceCollection * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 4531 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4532 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = g_strdup (PHOTO_TYPENAME);
#line 4532 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 4532 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34813 "Photo.c"
}


static gboolean library_photo_source_collection_real_is_file_recognized (MediaSourceCollection* base, GFile* file) {
	LibraryPhotoSourceCollection * self;
	gboolean result = FALSE;
	GFile* _tmp0_;
	gboolean _tmp1_;
#line 4535 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4535 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 4536 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 4536 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_file_format_is_file_supported (_tmp0_);
#line 4536 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 4536 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 34834 "Photo.c"
}


static void _library_photo_source_collection_on_editable_replaced_photo_editable_replaced (Photo* _sender, GFile* old_file, GFile* new_file, gpointer self) {
#line 4548 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_on_editable_replaced ((LibraryPhotoSourceCollection*) self, _sender, old_file, new_file);
#line 34841 "Photo.c"
}


static void _library_photo_source_collection_on_raw_development_modified_photo_raw_development_modified (Photo* _sender, gpointer self) {
#line 4554 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_on_raw_development_modified ((LibraryPhotoSourceCollection*) self, _sender);
#line 34848 "Photo.c"
}


static void library_photo_source_collection_real_notify_contents_altered (DataCollection* base, GeeIterable* added, GeeIterable* removed) {
	LibraryPhotoSourceCollection * self;
	GeeIterable* _tmp0_;
	GeeIterable* _tmp75_;
	GeeIterable* _tmp153_;
	GeeIterable* _tmp154_;
#line 4539 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4539 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((added == NULL) || GEE_IS_ITERABLE (added));
#line 4539 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_ITERABLE (removed));
#line 4541 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = added;
#line 4541 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != NULL) {
#line 34868 "Photo.c"
		{
			GeeIterator* _object_it = NULL;
			GeeIterable* _tmp1_;
			GeeIterator* _tmp2_;
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = added;
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = gee_iterable_iterator (_tmp1_);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
			_object_it = _tmp2_;
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 34881 "Photo.c"
				GeeIterator* _tmp3_;
				gboolean _tmp4_;
				DataObject* object = NULL;
				GeeIterator* _tmp5_;
				gpointer _tmp6_;
				LibraryPhoto* photo = NULL;
				DataObject* _tmp7_;
				LibraryPhoto* _tmp8_;
				GFile* editable = NULL;
				LibraryPhoto* _tmp9_;
				GFile* _tmp10_;
				GFile* _tmp11_;
				LibraryPhoto* _tmp15_;
				GeeCollection* raw_list = NULL;
				LibraryPhoto* _tmp16_;
				GeeCollection* _tmp17_;
				GeeCollection* _tmp18_;
				LibraryPhoto* _tmp28_;
				gint64 master_filesize = 0LL;
				LibraryPhoto* _tmp29_;
				BackingPhotoRow* _tmp30_;
				BackingPhotoRow* _tmp31_;
				gint64 _tmp32_;
				gint64 _tmp33_;
				gint64 _tmp34_ = 0LL;
				LibraryPhoto* _tmp35_;
				BackingPhotoRow* _tmp36_;
				BackingPhotoRow* _tmp37_;
				gboolean _tmp38_;
				gint64 editable_filesize = 0LL;
				GeeMultiMap* _tmp43_;
				gint64 _tmp44_;
				LibraryPhoto* _tmp45_;
				GeeHashMap* _tmp46_;
				LibraryPhoto* _tmp47_;
				gint64 _tmp48_;
				gint64 _tmp49_;
				GeeCollection* raw_rows = NULL;
				LibraryPhoto* _tmp56_;
				GeeCollection* _tmp57_;
				GeeCollection* _tmp58_;
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = _object_it;
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_iterator_next (_tmp3_);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp4_) {
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 34931 "Photo.c"
				}
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _object_it;
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = gee_iterator_get (_tmp5_);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				object = (DataObject*) _tmp6_;
#line 4543 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = object;
#line 4543 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 4543 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = _tmp8_;
#line 4545 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = photo;
#line 4545 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = photo_get_editable_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_PHOTO, Photo));
#line 4545 "/home/jens/Source/shotwell/src/Photo.vala"
				editable = _tmp10_;
#line 4546 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = editable;
#line 4546 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp11_ != NULL) {
#line 34955 "Photo.c"
					GeeHashMap* _tmp12_;
					GFile* _tmp13_;
					LibraryPhoto* _tmp14_;
#line 4547 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = self->priv->by_editable_file;
#line 4547 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = editable;
#line 4547 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = photo;
#line 4547 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp13_, _tmp14_);
#line 34967 "Photo.c"
				}
#line 4548 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = photo;
#line 4548 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, TYPE_PHOTO, Photo), "editable-replaced", (GCallback) _library_photo_source_collection_on_editable_replaced_photo_editable_replaced, self);
#line 4550 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = photo;
#line 4550 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = photo_get_raw_developer_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_PHOTO, Photo));
#line 4550 "/home/jens/Source/shotwell/src/Photo.vala"
				raw_list = _tmp17_;
#line 4551 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = raw_list;
#line 4551 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp18_ != NULL) {
#line 34983 "Photo.c"
					{
						GeeIterator* _f_it = NULL;
						GeeCollection* _tmp19_;
						GeeIterator* _tmp20_;
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp19_ = raw_list;
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp20_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
						_f_it = _tmp20_;
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 34996 "Photo.c"
							GeeIterator* _tmp21_;
							gboolean _tmp22_;
							GFile* f = NULL;
							GeeIterator* _tmp23_;
							gpointer _tmp24_;
							GeeHashMap* _tmp25_;
							GFile* _tmp26_;
							LibraryPhoto* _tmp27_;
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp21_ = _f_it;
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp22_ = gee_iterator_next (_tmp21_);
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp22_) {
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 35013 "Photo.c"
							}
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp23_ = _f_it;
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp24_ = gee_iterator_get (_tmp23_);
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							f = (GFile*) _tmp24_;
#line 4553 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp25_ = self->priv->by_raw_development_file;
#line 4553 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp26_ = f;
#line 4553 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp27_ = photo;
#line 4553 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp26_, _tmp27_);
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (f);
#line 35031 "Photo.c"
						}
#line 4552 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_f_it);
#line 35035 "Photo.c"
					}
				}
#line 4554 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = photo;
#line 4554 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, TYPE_PHOTO, Photo), "raw-development-modified", (GCallback) _library_photo_source_collection_on_raw_development_modified_photo_raw_development_modified, self);
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = photo;
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = photo_get_master_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_PHOTO, Photo));
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = _tmp30_;
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = _tmp31_->filesize;
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = _tmp32_;
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp31_);
#line 4556 "/home/jens/Source/shotwell/src/Photo.vala"
				master_filesize = _tmp33_;
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = photo;
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, TYPE_PHOTO, Photo));
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = _tmp36_;
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = _tmp37_ != NULL;
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp37_);
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp38_) {
#line 35068 "Photo.c"
					LibraryPhoto* _tmp39_;
					BackingPhotoRow* _tmp40_;
					BackingPhotoRow* _tmp41_;
					gint64 _tmp42_;
#line 4558 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp39_ = photo;
#line 4558 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp40_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, TYPE_PHOTO, Photo));
#line 4558 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp41_ = _tmp40_;
#line 4558 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp42_ = _tmp41_->filesize;
#line 4558 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp34_ = _tmp42_;
#line 4558 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp41_);
#line 35085 "Photo.c"
				} else {
#line 4559 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp34_ = (gint64) -1;
#line 35089 "Photo.c"
				}
#line 4557 "/home/jens/Source/shotwell/src/Photo.vala"
				editable_filesize = _tmp34_;
#line 4560 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = self->priv->filesize_to_photo;
#line 4560 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = master_filesize;
#line 4560 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = photo;
#line 4560 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_set (_tmp43_, &_tmp44_, _tmp45_);
#line 4561 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = self->priv->photo_to_master_filesize;
#line 4561 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = photo;
#line 4561 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = master_filesize;
#line 4561 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp47_, &_tmp48_);
#line 4562 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp49_ = editable_filesize;
#line 4562 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp49_ >= ((gint64) 0)) {
#line 35113 "Photo.c"
					GeeMultiMap* _tmp50_;
					gint64 _tmp51_;
					LibraryPhoto* _tmp52_;
					GeeHashMap* _tmp53_;
					LibraryPhoto* _tmp54_;
					gint64 _tmp55_;
#line 4563 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp50_ = self->priv->filesize_to_photo;
#line 4563 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp51_ = editable_filesize;
#line 4563 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp52_ = photo;
#line 4563 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_set (_tmp50_, &_tmp51_, _tmp52_);
#line 4564 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp53_ = self->priv->photo_to_editable_filesize;
#line 4564 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp54_ = photo;
#line 4564 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp55_ = editable_filesize;
#line 4564 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp54_, &_tmp55_);
#line 35136 "Photo.c"
				}
#line 4567 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp56_ = photo;
#line 4567 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp57_ = photo_get_raw_development_photo_rows (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, TYPE_PHOTO, Photo));
#line 4567 "/home/jens/Source/shotwell/src/Photo.vala"
				raw_rows = _tmp57_;
#line 4568 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp58_ = raw_rows;
#line 4568 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp58_ != NULL) {
#line 35148 "Photo.c"
					{
						GeeIterator* _row_it = NULL;
						GeeCollection* _tmp59_;
						GeeIterator* _tmp60_;
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp59_ = raw_rows;
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp60_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
						_row_it = _tmp60_;
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 35161 "Photo.c"
							GeeIterator* _tmp61_;
							gboolean _tmp62_;
							BackingPhotoRow* row = NULL;
							GeeIterator* _tmp63_;
							gpointer _tmp64_;
							BackingPhotoRow* _tmp65_;
							gint64 _tmp66_;
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp61_ = _row_it;
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp62_ = gee_iterator_next (_tmp61_);
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp62_) {
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 35177 "Photo.c"
							}
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp63_ = _row_it;
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp64_ = gee_iterator_get (_tmp63_);
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							row = (BackingPhotoRow*) _tmp64_;
#line 4570 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp65_ = row;
#line 4570 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp66_ = _tmp65_->filesize;
#line 4570 "/home/jens/Source/shotwell/src/Photo.vala"
							if (_tmp66_ >= ((gint64) 0)) {
#line 35191 "Photo.c"
								GeeMultiMap* _tmp67_;
								BackingPhotoRow* _tmp68_;
								gint64 _tmp69_;
								LibraryPhoto* _tmp70_;
								GeeMultiMap* _tmp71_;
								LibraryPhoto* _tmp72_;
								BackingPhotoRow* _tmp73_;
								gint64 _tmp74_;
#line 4571 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp67_ = self->priv->filesize_to_photo;
#line 4571 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp68_ = row;
#line 4571 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp69_ = _tmp68_->filesize;
#line 4571 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp70_ = photo;
#line 4571 "/home/jens/Source/shotwell/src/Photo.vala"
								gee_multi_map_set (_tmp67_, &_tmp69_, _tmp70_);
#line 4572 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp71_ = self->priv->photo_to_raw_development_filesize;
#line 4572 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp72_ = photo;
#line 4572 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp73_ = row;
#line 4572 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp74_ = _tmp73_->filesize;
#line 4572 "/home/jens/Source/shotwell/src/Photo.vala"
								gee_multi_map_set (_tmp71_, _tmp72_, &_tmp74_);
#line 35220 "Photo.c"
							}
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
							_backing_photo_row_unref0 (row);
#line 35224 "Photo.c"
						}
#line 4569 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_row_it);
#line 35228 "Photo.c"
					}
				}
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (raw_rows);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (raw_list);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (editable);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (object);
#line 35241 "Photo.c"
			}
#line 4542 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_object_it);
#line 35245 "Photo.c"
		}
	}
#line 4579 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp75_ = removed;
#line 4579 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp75_ != NULL) {
#line 35252 "Photo.c"
		{
			GeeIterator* _object_it = NULL;
			GeeIterable* _tmp76_;
			GeeIterator* _tmp77_;
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp76_ = removed;
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp77_ = gee_iterable_iterator (_tmp76_);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
			_object_it = _tmp77_;
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 35265 "Photo.c"
				GeeIterator* _tmp78_;
				gboolean _tmp79_;
				DataObject* object = NULL;
				GeeIterator* _tmp80_;
				gpointer _tmp81_;
				LibraryPhoto* photo = NULL;
				DataObject* _tmp82_;
				LibraryPhoto* _tmp83_;
				GFile* editable = NULL;
				LibraryPhoto* _tmp84_;
				GFile* _tmp85_;
				GFile* _tmp86_;
				LibraryPhoto* _tmp94_;
				guint _tmp95_;
				GeeCollection* raw_list = NULL;
				LibraryPhoto* _tmp96_;
				GeeCollection* _tmp97_;
				GeeCollection* _tmp98_;
				LibraryPhoto* _tmp107_;
				guint _tmp108_;
				gint64 master_filesize = 0LL;
				LibraryPhoto* _tmp109_;
				BackingPhotoRow* _tmp110_;
				BackingPhotoRow* _tmp111_;
				gint64 _tmp112_;
				gint64 _tmp113_;
				gint64 _tmp114_ = 0LL;
				LibraryPhoto* _tmp115_;
				BackingPhotoRow* _tmp116_;
				BackingPhotoRow* _tmp117_;
				gboolean _tmp118_;
				gint64 editable_filesize = 0LL;
				GeeMultiMap* _tmp123_;
				gint64 _tmp124_;
				LibraryPhoto* _tmp125_;
				GeeHashMap* _tmp126_;
				LibraryPhoto* _tmp127_;
				gint64 _tmp128_;
				GeeCollection* raw_rows = NULL;
				LibraryPhoto* _tmp134_;
				GeeCollection* _tmp135_;
				GeeCollection* _tmp136_;
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp78_ = _object_it;
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp79_ = gee_iterator_next (_tmp78_);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp79_) {
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 35316 "Photo.c"
				}
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp80_ = _object_it;
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp81_ = gee_iterator_get (_tmp80_);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				object = (DataObject*) _tmp81_;
#line 4581 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp82_ = object;
#line 4581 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp83_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 4581 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = _tmp83_;
#line 4583 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp84_ = photo;
#line 4583 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp85_ = photo_get_editable_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp84_, TYPE_PHOTO, Photo));
#line 4583 "/home/jens/Source/shotwell/src/Photo.vala"
				editable = _tmp85_;
#line 4584 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp86_ = editable;
#line 4584 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp86_ != NULL) {
#line 35340 "Photo.c"
					gboolean is_removed = FALSE;
					GeeHashMap* _tmp87_;
					LibraryPhoto* _tmp88_;
					GFile* _tmp89_;
					GFile* _tmp90_;
					gboolean _tmp91_;
					gboolean _tmp92_;
					gboolean _tmp93_;
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp87_ = self->priv->by_editable_file;
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp88_ = photo;
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp89_ = photo_get_editable_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp88_, TYPE_PHOTO, Photo));
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp90_ = _tmp89_;
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp91_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp90_, NULL);
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp92_ = _tmp91_;
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp90_);
#line 4585 "/home/jens/Source/shotwell/src/Photo.vala"
					is_removed = _tmp92_;
#line 4586 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp93_ = is_removed;
#line 4586 "/home/jens/Source/shotwell/src/Photo.vala"
					_vala_assert (_tmp93_, "is_removed");
#line 35369 "Photo.c"
				}
#line 4588 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp94_ = photo;
#line 4588 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_parse_name ("editable-replaced", TYPE_PHOTO, &_tmp95_, NULL, FALSE);
#line 4588 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp94_, TYPE_PHOTO, Photo), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp95_, 0, NULL, (GCallback) _library_photo_source_collection_on_editable_replaced_photo_editable_replaced, self);
#line 4590 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp96_ = photo;
#line 4590 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp97_ = photo_get_raw_developer_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, TYPE_PHOTO, Photo));
#line 4590 "/home/jens/Source/shotwell/src/Photo.vala"
				raw_list = _tmp97_;
#line 4591 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp98_ = raw_list;
#line 4591 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp98_ != NULL) {
#line 35387 "Photo.c"
					{
						GeeIterator* _f_it = NULL;
						GeeCollection* _tmp99_;
						GeeIterator* _tmp100_;
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp99_ = raw_list;
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp100_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
						_f_it = _tmp100_;
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 35400 "Photo.c"
							GeeIterator* _tmp101_;
							gboolean _tmp102_;
							GFile* f = NULL;
							GeeIterator* _tmp103_;
							gpointer _tmp104_;
							GeeHashMap* _tmp105_;
							GFile* _tmp106_;
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp101_ = _f_it;
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp102_ = gee_iterator_next (_tmp101_);
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp102_) {
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 35416 "Photo.c"
							}
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp103_ = _f_it;
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp104_ = gee_iterator_get (_tmp103_);
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							f = (GFile*) _tmp104_;
#line 4593 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp105_ = self->priv->by_raw_development_file;
#line 4593 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp106_ = f;
#line 4593 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp105_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp106_, NULL);
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (f);
#line 35432 "Photo.c"
						}
#line 4592 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_f_it);
#line 35436 "Photo.c"
					}
				}
#line 4594 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp107_ = photo;
#line 4594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_parse_name ("raw-development-modified", TYPE_PHOTO, &_tmp108_, NULL, FALSE);
#line 4594 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp107_, TYPE_PHOTO, Photo), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp108_, 0, NULL, (GCallback) _library_photo_source_collection_on_raw_development_modified_photo_raw_development_modified, self);
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp109_ = photo;
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp110_ = photo_get_master_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp109_, TYPE_PHOTO, Photo));
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp111_ = _tmp110_;
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp112_ = _tmp111_->filesize;
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp113_ = _tmp112_;
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp111_);
#line 4596 "/home/jens/Source/shotwell/src/Photo.vala"
				master_filesize = _tmp113_;
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp115_ = photo;
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp116_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp115_, TYPE_PHOTO, Photo));
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp117_ = _tmp116_;
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp118_ = _tmp117_ != NULL;
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp117_);
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp118_) {
#line 35471 "Photo.c"
					LibraryPhoto* _tmp119_;
					BackingPhotoRow* _tmp120_;
					BackingPhotoRow* _tmp121_;
					gint64 _tmp122_;
#line 4598 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp119_ = photo;
#line 4598 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp120_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp119_, TYPE_PHOTO, Photo));
#line 4598 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp121_ = _tmp120_;
#line 4598 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp122_ = _tmp121_->filesize;
#line 4598 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp114_ = _tmp122_;
#line 4598 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp121_);
#line 35488 "Photo.c"
				} else {
#line 4599 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp114_ = (gint64) -1;
#line 35492 "Photo.c"
				}
#line 4597 "/home/jens/Source/shotwell/src/Photo.vala"
				editable_filesize = _tmp114_;
#line 4600 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp123_ = self->priv->filesize_to_photo;
#line 4600 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp124_ = master_filesize;
#line 4600 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp125_ = photo;
#line 4600 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_remove (_tmp123_, &_tmp124_, _tmp125_);
#line 4601 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp126_ = self->priv->photo_to_master_filesize;
#line 4601 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp127_ = photo;
#line 4601 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp127_, NULL);
#line 4602 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp128_ = editable_filesize;
#line 4602 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp128_ >= ((gint64) 0)) {
#line 35514 "Photo.c"
					GeeMultiMap* _tmp129_;
					gint64 _tmp130_;
					LibraryPhoto* _tmp131_;
					GeeHashMap* _tmp132_;
					LibraryPhoto* _tmp133_;
#line 4603 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp129_ = self->priv->filesize_to_photo;
#line 4603 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp130_ = editable_filesize;
#line 4603 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp131_ = photo;
#line 4603 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_remove (_tmp129_, &_tmp130_, _tmp131_);
#line 4604 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp132_ = self->priv->photo_to_editable_filesize;
#line 4604 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp133_ = photo;
#line 4604 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp132_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp133_, NULL);
#line 35534 "Photo.c"
				}
#line 4607 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp134_ = photo;
#line 4607 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp135_ = photo_get_raw_development_photo_rows (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, TYPE_PHOTO, Photo));
#line 4607 "/home/jens/Source/shotwell/src/Photo.vala"
				raw_rows = _tmp135_;
#line 4608 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp136_ = raw_rows;
#line 4608 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp136_ != NULL) {
#line 35546 "Photo.c"
					{
						GeeIterator* _row_it = NULL;
						GeeCollection* _tmp137_;
						GeeIterator* _tmp138_;
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp137_ = raw_rows;
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp138_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp137_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
						_row_it = _tmp138_;
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 35559 "Photo.c"
							GeeIterator* _tmp139_;
							gboolean _tmp140_;
							BackingPhotoRow* row = NULL;
							GeeIterator* _tmp141_;
							gpointer _tmp142_;
							BackingPhotoRow* _tmp143_;
							gint64 _tmp144_;
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp139_ = _row_it;
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp140_ = gee_iterator_next (_tmp139_);
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp140_) {
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 35575 "Photo.c"
							}
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp141_ = _row_it;
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp142_ = gee_iterator_get (_tmp141_);
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							row = (BackingPhotoRow*) _tmp142_;
#line 4610 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp143_ = row;
#line 4610 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp144_ = _tmp143_->filesize;
#line 4610 "/home/jens/Source/shotwell/src/Photo.vala"
							if (_tmp144_ >= ((gint64) 0)) {
#line 35589 "Photo.c"
								GeeMultiMap* _tmp145_;
								BackingPhotoRow* _tmp146_;
								gint64 _tmp147_;
								LibraryPhoto* _tmp148_;
								GeeMultiMap* _tmp149_;
								LibraryPhoto* _tmp150_;
								BackingPhotoRow* _tmp151_;
								gint64 _tmp152_;
#line 4611 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp145_ = self->priv->filesize_to_photo;
#line 4611 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp146_ = row;
#line 4611 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp147_ = _tmp146_->filesize;
#line 4611 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp148_ = photo;
#line 4611 "/home/jens/Source/shotwell/src/Photo.vala"
								gee_multi_map_remove (_tmp145_, &_tmp147_, _tmp148_);
#line 4612 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp149_ = self->priv->photo_to_raw_development_filesize;
#line 4612 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp150_ = photo;
#line 4612 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp151_ = row;
#line 4612 "/home/jens/Source/shotwell/src/Photo.vala"
								_tmp152_ = _tmp151_->filesize;
#line 4612 "/home/jens/Source/shotwell/src/Photo.vala"
								gee_multi_map_remove (_tmp149_, _tmp150_, &_tmp152_);
#line 35618 "Photo.c"
							}
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
							_backing_photo_row_unref0 (row);
#line 35622 "Photo.c"
						}
#line 4609 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_row_it);
#line 35626 "Photo.c"
					}
				}
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (raw_rows);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (raw_list);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (editable);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (object);
#line 35639 "Photo.c"
			}
#line 4580 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_object_it);
#line 35643 "Photo.c"
		}
	}
#line 4619 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp153_ = added;
#line 4619 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp154_ = removed;
#line 4619 "/home/jens/Source/shotwell/src/Photo.vala"
	DATA_COLLECTION_CLASS (library_photo_source_collection_parent_class)->notify_contents_altered (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), TYPE_DATA_COLLECTION, DataCollection), _tmp153_, _tmp154_);
#line 35652 "Photo.c"
}


static void library_photo_source_collection_on_editable_replaced (LibraryPhotoSourceCollection* self, Photo* photo, GFile* old_file, GFile* new_file) {
	GFile* _tmp0_;
	GFile* _tmp5_;
#line 4622 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4622 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (photo));
#line 4622 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((old_file == NULL) || G_IS_FILE (old_file));
#line 4622 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((new_file == NULL) || G_IS_FILE (new_file));
#line 4623 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = old_file;
#line 4623 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != NULL) {
#line 35671 "Photo.c"
		gboolean is_removed = FALSE;
		GeeHashMap* _tmp1_;
		GFile* _tmp2_;
		gboolean _tmp3_;
		gboolean _tmp4_;
#line 4624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = self->priv->by_editable_file;
#line 4624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = old_file;
#line 4624 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp2_, NULL);
#line 4624 "/home/jens/Source/shotwell/src/Photo.vala"
		is_removed = _tmp3_;
#line 4625 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = is_removed;
#line 4625 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_assert (_tmp4_, "is_removed");
#line 35689 "Photo.c"
	}
#line 4628 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = new_file;
#line 4628 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_ != NULL) {
#line 35695 "Photo.c"
		GeeHashMap* _tmp6_;
		GFile* _tmp7_;
		Photo* _tmp8_;
#line 4629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = self->priv->by_editable_file;
#line 4629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = new_file;
#line 4629 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = photo;
#line 4629 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp7_, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 35707 "Photo.c"
	}
}


static void library_photo_source_collection_on_raw_development_modified (LibraryPhotoSourceCollection* self, Photo* _photo) {
	LibraryPhoto* photo = NULL;
	Photo* _tmp0_;
	LibraryPhoto* _tmp1_;
	LibraryPhoto* _tmp2_;
	GeeMultiMap* _tmp3_;
	LibraryPhoto* _tmp4_;
	gboolean _tmp5_;
	GeeCollection* raw_list = NULL;
	LibraryPhoto* _tmp23_;
	GeeCollection* _tmp24_;
	GeeCollection* _tmp25_;
	GeeCollection* raw_rows = NULL;
	LibraryPhoto* _tmp35_;
	GeeCollection* _tmp36_;
	GeeCollection* _tmp37_;
#line 4632 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4632 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (_photo));
#line 4633 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _photo;
#line 4633 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_LIBRARY_PHOTO) ? ((LibraryPhoto*) _tmp0_) : NULL);
#line 4633 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp1_;
#line 4634 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo;
#line 4634 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ == NULL) {
#line 4635 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (photo);
#line 4635 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 35746 "Photo.c"
	}
#line 4638 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = self->priv->photo_to_raw_development_filesize;
#line 4638 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo;
#line 4638 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = gee_multi_map_contains (_tmp3_, _tmp4_);
#line 4638 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 35756 "Photo.c"
		GeeMultiMap* _tmp21_;
		LibraryPhoto* _tmp22_;
		{
			GeeIterator* _s_it = NULL;
			GeeMultiMap* _tmp6_;
			LibraryPhoto* _tmp7_;
			GeeCollection* _tmp8_;
			GeeCollection* _tmp9_;
			GeeIterator* _tmp10_;
			GeeIterator* _tmp11_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->priv->photo_to_raw_development_filesize;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = photo;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = gee_multi_map_get (_tmp6_, _tmp7_);
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = _tmp10_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp9_);
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_s_it = _tmp11_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 35785 "Photo.c"
				GeeIterator* _tmp12_;
				gboolean _tmp13_;
				gint64 s = 0LL;
				GeeIterator* _tmp14_;
				gpointer _tmp15_;
				gint64* _tmp16_;
				gint64 _tmp17_;
				GeeMultiMap* _tmp18_;
				gint64 _tmp19_;
				LibraryPhoto* _tmp20_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _s_it;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = gee_iterator_next (_tmp12_);
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp13_) {
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 35804 "Photo.c"
				}
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = _s_it;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = gee_iterator_get (_tmp14_);
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = (gint64*) _tmp15_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = *_tmp16_;
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp16_);
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
				s = _tmp17_;
#line 4640 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = self->priv->filesize_to_photo;
#line 4640 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = s;
#line 4640 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = photo;
#line 4640 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_remove (_tmp18_, &_tmp19_, _tmp20_);
#line 35826 "Photo.c"
			}
#line 4639 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_s_it);
#line 35830 "Photo.c"
		}
#line 4641 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = self->priv->photo_to_raw_development_filesize;
#line 4641 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp22_ = photo;
#line 4641 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_multi_map_remove_all (_tmp21_, _tmp22_);
#line 35838 "Photo.c"
	}
#line 4645 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = photo;
#line 4645 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = photo_get_raw_developer_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_PHOTO, Photo));
#line 4645 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_list = _tmp24_;
#line 4646 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = raw_list;
#line 4646 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp25_ != NULL) {
#line 35850 "Photo.c"
		{
			GeeIterator* _f_it = NULL;
			GeeCollection* _tmp26_;
			GeeIterator* _tmp27_;
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = raw_list;
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
			_f_it = _tmp27_;
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 35863 "Photo.c"
				GeeIterator* _tmp28_;
				gboolean _tmp29_;
				GFile* f = NULL;
				GeeIterator* _tmp30_;
				gpointer _tmp31_;
				GeeHashMap* _tmp32_;
				GFile* _tmp33_;
				LibraryPhoto* _tmp34_;
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = _f_it;
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = gee_iterator_next (_tmp28_);
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp29_) {
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 35880 "Photo.c"
				}
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = _f_it;
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = gee_iterator_get (_tmp30_);
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				f = (GFile*) _tmp31_;
#line 4648 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = self->priv->by_raw_development_file;
#line 4648 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = f;
#line 4648 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = photo;
#line 4648 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp33_, _tmp34_);
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (f);
#line 35898 "Photo.c"
			}
#line 4647 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_f_it);
#line 35902 "Photo.c"
		}
	}
#line 4650 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = photo;
#line 4650 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = photo_get_raw_development_photo_rows (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, TYPE_PHOTO, Photo));
#line 4650 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_rows = _tmp36_;
#line 4651 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = raw_rows;
#line 4651 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp37_ != NULL) {
#line 35915 "Photo.c"
		{
			GeeIterator* _row_it = NULL;
			GeeCollection* _tmp38_;
			GeeIterator* _tmp39_;
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp38_ = raw_rows;
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp39_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
			_row_it = _tmp39_;
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 35928 "Photo.c"
				GeeIterator* _tmp40_;
				gboolean _tmp41_;
				BackingPhotoRow* row = NULL;
				GeeIterator* _tmp42_;
				gpointer _tmp43_;
				BackingPhotoRow* _tmp44_;
				gint64 _tmp45_;
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = _row_it;
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp41_ = gee_iterator_next (_tmp40_);
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp41_) {
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 35944 "Photo.c"
				}
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp42_ = _row_it;
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = gee_iterator_get (_tmp42_);
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				row = (BackingPhotoRow*) _tmp43_;
#line 4653 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = row;
#line 4653 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = _tmp44_->filesize;
#line 4653 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp45_ > ((gint64) 0)) {
#line 35958 "Photo.c"
					GeeMultiMap* _tmp46_;
					BackingPhotoRow* _tmp47_;
					gint64 _tmp48_;
					LibraryPhoto* _tmp49_;
					GeeMultiMap* _tmp50_;
					LibraryPhoto* _tmp51_;
					BackingPhotoRow* _tmp52_;
					gint64 _tmp53_;
#line 4654 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp46_ = self->priv->filesize_to_photo;
#line 4654 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp47_ = row;
#line 4654 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp48_ = _tmp47_->filesize;
#line 4654 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp49_ = photo;
#line 4654 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_set (_tmp46_, &_tmp48_, _tmp49_);
#line 4655 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp50_ = self->priv->photo_to_raw_development_filesize;
#line 4655 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp51_ = photo;
#line 4655 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp52_ = row;
#line 4655 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp53_ = _tmp52_->filesize;
#line 4655 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_set (_tmp50_, _tmp51_, &_tmp53_);
#line 35987 "Photo.c"
				}
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (row);
#line 35991 "Photo.c"
			}
#line 4652 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_row_it);
#line 35995 "Photo.c"
		}
	}
#line 4632 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (raw_rows);
#line 4632 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (raw_list);
#line 4632 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 36004 "Photo.c"
}


static gpointer __int64_dup0 (gpointer self) {
#line 4671 "/home/jens/Source/shotwell/src/Photo.vala"
	return self ? _int64_dup (self) : NULL;
#line 36011 "Photo.c"
}


static void library_photo_source_collection_real_items_altered (DataCollection* base, GeeMap* items) {
	LibraryPhotoSourceCollection * self;
	GeeMap* _tmp72_;
#line 4661 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4661 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_MAP (items));
#line 36022 "Photo.c"
	{
		GeeIterator* _object_it = NULL;
		GeeMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = items;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = gee_map_get_keys (_tmp0_);
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp1_;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_object_it = _tmp5_;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 36049 "Photo.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			DataObject* object = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			Alteration* alteration = NULL;
			GeeMap* _tmp10_;
			DataObject* _tmp11_;
			gpointer _tmp12_;
			LibraryPhoto* photo = NULL;
			DataObject* _tmp13_;
			LibraryPhoto* _tmp14_;
			gboolean _tmp15_ = FALSE;
			Alteration* _tmp16_;
			gboolean _tmp17_;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _object_it;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp7_) {
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 36073 "Photo.c"
			}
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _object_it;
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			object = (DataObject*) _tmp9_;
#line 4663 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = items;
#line 4663 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = object;
#line 4663 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = gee_map_get (_tmp10_, _tmp11_);
#line 4663 "/home/jens/Source/shotwell/src/Photo.vala"
			alteration = (Alteration*) _tmp12_;
#line 4665 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = object;
#line 4665 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 4665 "/home/jens/Source/shotwell/src/Photo.vala"
			photo = _tmp14_;
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = alteration;
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = alteration_has_detail (_tmp16_, "image", "master");
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp17_) {
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = TRUE;
#line 36103 "Photo.c"
			} else {
				Alteration* _tmp18_;
				gboolean _tmp19_;
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = alteration;
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = alteration_has_detail (_tmp18_, "image", "editable");
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = _tmp19_;
#line 36113 "Photo.c"
			}
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp15_) {
#line 36117 "Photo.c"
				gint64 old_master_filesize = 0LL;
				GeeHashMap* _tmp20_;
				LibraryPhoto* _tmp21_;
				gpointer _tmp22_;
				gint64* _tmp23_;
				gint64 _tmp24_;
				gint64* _tmp25_ = NULL;
				GeeHashMap* _tmp26_;
				LibraryPhoto* _tmp27_;
				gboolean _tmp28_;
				gint64 old_editable_filesize = 0LL;
				GeeHashMap* _tmp34_;
				LibraryPhoto* _tmp35_;
				GeeMultiMap* _tmp36_;
				gint64 _tmp37_;
				LibraryPhoto* _tmp38_;
				gint64 _tmp39_;
				gint64 master_filesize = 0LL;
				LibraryPhoto* _tmp45_;
				BackingPhotoRow* _tmp46_;
				BackingPhotoRow* _tmp47_;
				gint64 _tmp48_;
				gint64 _tmp49_;
				gint64 _tmp50_ = 0LL;
				LibraryPhoto* _tmp51_;
				BackingPhotoRow* _tmp52_;
				BackingPhotoRow* _tmp53_;
				gboolean _tmp54_;
				gint64 editable_filesize = 0LL;
				GeeHashMap* _tmp59_;
				LibraryPhoto* _tmp60_;
				gint64 _tmp61_;
				GeeMultiMap* _tmp62_;
				gint64 _tmp63_;
				LibraryPhoto* _tmp64_;
				gint64 _tmp65_;
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = self->priv->photo_to_master_filesize;
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = photo;
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp21_);
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = (gint64*) _tmp22_;
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = *_tmp23_;
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp23_);
#line 4668 "/home/jens/Source/shotwell/src/Photo.vala"
				old_master_filesize = _tmp24_;
#line 4669 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = self->priv->photo_to_editable_filesize;
#line 4669 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = photo;
#line 4669 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp27_);
#line 4669 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp28_) {
#line 36176 "Photo.c"
					GeeHashMap* _tmp29_;
					LibraryPhoto* _tmp30_;
					gpointer _tmp31_;
#line 4670 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp29_ = self->priv->photo_to_editable_filesize;
#line 4670 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp30_ = photo;
#line 4670 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp30_);
#line 4670 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (_tmp25_);
#line 4670 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp25_ = (gint64*) _tmp31_;
#line 36190 "Photo.c"
				} else {
					gint64 _tmp32_;
					gint64* _tmp33_;
#line 4671 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp32_ = (gint64) -1;
#line 4671 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp33_ = __int64_dup0 (&_tmp32_);
#line 4671 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (_tmp25_);
#line 4671 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp25_ = _tmp33_;
#line 36202 "Photo.c"
				}
#line 4669 "/home/jens/Source/shotwell/src/Photo.vala"
				old_editable_filesize = *_tmp25_;
#line 4673 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = self->priv->photo_to_master_filesize;
#line 4673 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp35_ = photo;
#line 4673 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp35_, NULL);
#line 4674 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = self->priv->filesize_to_photo;
#line 4674 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = old_master_filesize;
#line 4674 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = photo;
#line 4674 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_remove (_tmp36_, &_tmp37_, _tmp38_);
#line 4675 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = old_editable_filesize;
#line 4675 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp39_ >= ((gint64) 0)) {
#line 36224 "Photo.c"
					GeeHashMap* _tmp40_;
					LibraryPhoto* _tmp41_;
					GeeMultiMap* _tmp42_;
					gint64 _tmp43_;
					LibraryPhoto* _tmp44_;
#line 4676 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp40_ = self->priv->photo_to_editable_filesize;
#line 4676 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp41_ = photo;
#line 4676 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp41_, NULL);
#line 4677 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp42_ = self->priv->filesize_to_photo;
#line 4677 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp43_ = old_editable_filesize;
#line 4677 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp44_ = photo;
#line 4677 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_remove (_tmp42_, &_tmp43_, _tmp44_);
#line 36244 "Photo.c"
				}
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = photo;
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = photo_get_master_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, TYPE_PHOTO, Photo));
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = _tmp46_;
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = _tmp47_->filesize;
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp49_ = _tmp48_;
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp47_);
#line 4680 "/home/jens/Source/shotwell/src/Photo.vala"
				master_filesize = _tmp49_;
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp51_ = photo;
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp52_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, TYPE_PHOTO, Photo));
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp53_ = _tmp52_;
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp54_ = _tmp53_ != NULL;
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (_tmp53_);
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp54_) {
#line 36272 "Photo.c"
					LibraryPhoto* _tmp55_;
					BackingPhotoRow* _tmp56_;
					BackingPhotoRow* _tmp57_;
					gint64 _tmp58_;
#line 4682 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp55_ = photo;
#line 4682 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp56_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, TYPE_PHOTO, Photo));
#line 4682 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp57_ = _tmp56_;
#line 4682 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp58_ = _tmp57_->filesize;
#line 4682 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp50_ = _tmp58_;
#line 4682 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (_tmp57_);
#line 36289 "Photo.c"
				} else {
#line 4683 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp50_ = (gint64) -1;
#line 36293 "Photo.c"
				}
#line 4681 "/home/jens/Source/shotwell/src/Photo.vala"
				editable_filesize = _tmp50_;
#line 4684 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp59_ = self->priv->photo_to_master_filesize;
#line 4684 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp60_ = photo;
#line 4684 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp61_ = master_filesize;
#line 4684 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp60_, &_tmp61_);
#line 4685 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp62_ = self->priv->filesize_to_photo;
#line 4685 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp63_ = master_filesize;
#line 4685 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp64_ = photo;
#line 4685 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_set (_tmp62_, &_tmp63_, _tmp64_);
#line 4686 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp65_ = editable_filesize;
#line 4686 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp65_ >= ((gint64) 0)) {
#line 36317 "Photo.c"
					GeeHashMap* _tmp66_;
					LibraryPhoto* _tmp67_;
					gint64 _tmp68_;
					GeeMultiMap* _tmp69_;
					gint64 _tmp70_;
					LibraryPhoto* _tmp71_;
#line 4687 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp66_ = self->priv->photo_to_editable_filesize;
#line 4687 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp67_ = photo;
#line 4687 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp68_ = editable_filesize;
#line 4687 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp67_, &_tmp68_);
#line 4688 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp69_ = self->priv->filesize_to_photo;
#line 4688 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp70_ = editable_filesize;
#line 4688 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp71_ = photo;
#line 4688 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_set (_tmp69_, &_tmp70_, _tmp71_);
#line 36340 "Photo.c"
				}
#line 4667 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp25_);
#line 36344 "Photo.c"
			}
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (photo);
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_alteration_unref0 (alteration);
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (object);
#line 36352 "Photo.c"
		}
#line 4662 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_object_it);
#line 36356 "Photo.c"
	}
#line 4693 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp72_ = items;
#line 4693 "/home/jens/Source/shotwell/src/Photo.vala"
	DATA_COLLECTION_CLASS (library_photo_source_collection_parent_class)->items_altered (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), TYPE_DATA_COLLECTION, DataCollection), _tmp72_);
#line 36362 "Photo.c"
}


static void library_photo_source_collection_real_postprocess_imported_media (MediaSourceCollection* base, GeeCollection* media_sources) {
	LibraryPhotoSourceCollection * self;
	GeeHashMultiMap* map = NULL;
	GeeHashMultiMap* _tmp0_;
	GeeCollection* _tmp97_;
#line 4697 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4697 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (media_sources));
#line 4698 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = gee_hash_multi_map_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 4698 "/home/jens/Source/shotwell/src/Photo.vala"
	map = _tmp0_;
#line 36379 "Photo.c"
	{
		GeeIterator* _media_it = NULL;
		GeeCollection* _tmp1_;
		GeeIterator* _tmp2_;
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = media_sources;
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_it = _tmp2_;
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 36392 "Photo.c"
			GeeIterator* _tmp3_;
			gboolean _tmp4_;
			MediaSource* media = NULL;
			GeeIterator* _tmp5_;
			gpointer _tmp6_;
			LibraryPhoto* photo = NULL;
			MediaSource* _tmp7_;
			LibraryPhoto* _tmp8_;
			PhotoMetadata* metadata = NULL;
			LibraryPhoto* _tmp9_;
			PhotoMetadata* _tmp10_;
			HierarchicalTagIndex* global_index = NULL;
			HierarchicalTagIndex* _tmp11_;
			HierarchicalTagIndex* htag_index = NULL;
			PhotoMetadata* _tmp12_;
			gboolean _tmp13_;
			LibraryPhoto* _tmp18_;
			GeeCollection* _tmp19_;
			GeeCollection* _tmp20_;
			gboolean _tmp21_;
			PhotoMetadata* _tmp55_;
			gboolean _tmp56_;
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp3_ = _media_it;
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = gee_iterator_next (_tmp3_);
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp4_) {
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 36423 "Photo.c"
			}
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _media_it;
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = gee_iterator_get (_tmp5_);
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			media = (MediaSource*) _tmp6_;
#line 4700 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = media;
#line 4700 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 4700 "/home/jens/Source/shotwell/src/Photo.vala"
			photo = _tmp8_;
#line 4701 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = photo;
#line 4701 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = photo_source_get_metadata (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_PHOTO_SOURCE, PhotoSource));
#line 4701 "/home/jens/Source/shotwell/src/Photo.vala"
			metadata = _tmp10_;
#line 4704 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = hierarchical_tag_index_get_global_index ();
#line 4704 "/home/jens/Source/shotwell/src/Photo.vala"
			global_index = _tmp11_;
#line 4711 "/home/jens/Source/shotwell/src/Photo.vala"
			htag_index = NULL;
#line 4712 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = metadata;
#line 4712 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = photo_metadata_has_hierarchical_keywords (_tmp12_);
#line 4712 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp13_) {
#line 36455 "Photo.c"
				PhotoMetadata* _tmp14_;
				GeeSet* _tmp15_;
				GeeSet* _tmp16_;
				HierarchicalTagIndex* _tmp17_;
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = metadata;
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = photo_metadata_get_hierarchical_keywords (_tmp14_);
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = _tmp15_;
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = hierarchical_tag_utilities_process_hierarchical_import_keywords (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_COLLECTION, GeeCollection));
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				_hierarchical_tag_index_unref0 (htag_index);
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				htag_index = _tmp17_;
#line 4713 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp16_);
#line 36474 "Photo.c"
			}
#line 4717 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = photo;
#line 4717 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = library_photo_get_import_keywords (_tmp18_);
#line 4717 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = _tmp19_;
#line 4717 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = _tmp20_ != NULL;
#line 4717 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp20_);
#line 4717 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp21_) {
#line 36488 "Photo.c"
				{
					GeeIterator* _keyword_it = NULL;
					LibraryPhoto* _tmp22_;
					GeeCollection* _tmp23_;
					GeeCollection* _tmp24_;
					GeeIterator* _tmp25_;
					GeeIterator* _tmp26_;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp22_ = photo;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp23_ = library_photo_get_import_keywords (_tmp22_);
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp24_ = _tmp23_;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp25_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp26_ = _tmp25_;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp24_);
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_keyword_it = _tmp26_;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					while (TRUE) {
#line 36512 "Photo.c"
						GeeIterator* _tmp27_;
						gboolean _tmp28_;
						gchar* keyword = NULL;
						GeeIterator* _tmp29_;
						gpointer _tmp30_;
						gboolean _tmp31_ = FALSE;
						HierarchicalTagIndex* _tmp32_;
						gchar* name = NULL;
						const gchar* _tmp36_;
						gchar* _tmp37_;
						HierarchicalTagIndex* _tmp38_;
						const gchar* _tmp39_;
						gboolean _tmp40_;
						const gchar* _tmp49_;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp27_ = _keyword_it;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp28_ = gee_iterator_next (_tmp27_);
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						if (!_tmp28_) {
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
							break;
#line 36535 "Photo.c"
						}
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp29_ = _keyword_it;
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp30_ = gee_iterator_get (_tmp29_);
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						keyword = (gchar*) _tmp30_;
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp32_ = htag_index;
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp32_ != NULL) {
#line 36547 "Photo.c"
							HierarchicalTagIndex* _tmp33_;
							const gchar* _tmp34_;
							gboolean _tmp35_;
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp33_ = htag_index;
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp34_ = keyword;
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp35_ = hierarchical_tag_index_is_tag_in_index (_tmp33_, _tmp34_);
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp31_ = _tmp35_;
#line 36559 "Photo.c"
						} else {
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp31_ = FALSE;
#line 36563 "Photo.c"
						}
#line 4719 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp31_) {
#line 4720 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (keyword);
#line 4720 "/home/jens/Source/shotwell/src/Photo.vala"
							continue;
#line 36571 "Photo.c"
						}
#line 4722 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp36_ = keyword;
#line 4722 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp37_ = tag_prep_tag_name (_tmp36_);
#line 4722 "/home/jens/Source/shotwell/src/Photo.vala"
						name = _tmp37_;
#line 4724 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp38_ = global_index;
#line 4724 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp39_ = name;
#line 4724 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp40_ = hierarchical_tag_index_is_tag_in_index (_tmp38_, _tmp39_);
#line 4724 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp40_) {
#line 36587 "Photo.c"
							gchar* most_derived_path = NULL;
							HierarchicalTagIndex* _tmp41_;
							const gchar* _tmp42_;
							gchar* _tmp43_;
							GeeHashMultiMap* _tmp44_;
							const gchar* _tmp45_;
							Tag* _tmp46_;
							Tag* _tmp47_;
							LibraryPhoto* _tmp48_;
#line 4725 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp41_ = global_index;
#line 4725 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp42_ = name;
#line 4725 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp43_ = hierarchical_tag_index_get_path_for_name (_tmp41_, _tmp42_);
#line 4725 "/home/jens/Source/shotwell/src/Photo.vala"
							most_derived_path = _tmp43_;
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp44_ = map;
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp45_ = most_derived_path;
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp46_ = tag_for_path (_tmp45_);
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp47_ = _tmp46_;
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp48_ = photo;
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_multi_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, GEE_TYPE_MULTI_MAP, GeeMultiMap), _tmp47_, _tmp48_);
#line 4726 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp47_);
#line 4727 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (most_derived_path);
#line 4727 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (name);
#line 4727 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_free0 (keyword);
#line 4727 "/home/jens/Source/shotwell/src/Photo.vala"
							continue;
#line 36627 "Photo.c"
						}
#line 4730 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp49_ = name;
#line 4730 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp49_ != NULL) {
#line 36633 "Photo.c"
							GeeHashMultiMap* _tmp50_;
							const gchar* _tmp51_;
							Tag* _tmp52_;
							Tag* _tmp53_;
							LibraryPhoto* _tmp54_;
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp50_ = map;
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp51_ = name;
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp52_ = tag_for_path (_tmp51_);
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp53_ = _tmp52_;
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp54_ = photo;
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_multi_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GEE_TYPE_MULTI_MAP, GeeMultiMap), _tmp53_, _tmp54_);
#line 4731 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp53_);
#line 36653 "Photo.c"
						}
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_free0 (name);
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_free0 (keyword);
#line 36659 "Photo.c"
					}
#line 4718 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_keyword_it);
#line 36663 "Photo.c"
				}
			}
#line 4735 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp55_ = metadata;
#line 4735 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp56_ = photo_metadata_has_hierarchical_keywords (_tmp55_);
#line 4735 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp56_) {
#line 36672 "Photo.c"
				{
					GeeIterator* _path_it = NULL;
					HierarchicalTagIndex* _tmp57_;
					GeeCollection* _tmp58_;
					GeeCollection* _tmp59_;
					GeeIterator* _tmp60_;
					GeeIterator* _tmp61_;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp57_ = htag_index;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp58_ = hierarchical_tag_index_get_all_paths (_tmp57_);
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp59_ = _tmp58_;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp60_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp61_ = _tmp60_;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp59_);
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_path_it = _tmp61_;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					while (TRUE) {
#line 36696 "Photo.c"
						GeeIterator* _tmp62_;
						gboolean _tmp63_;
						gchar* path = NULL;
						GeeIterator* _tmp64_;
						gpointer _tmp65_;
						gchar* name = NULL;
						const gchar* _tmp66_;
						gchar* _tmp67_;
						const gchar* _tmp68_;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp62_ = _path_it;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp63_ = gee_iterator_next (_tmp62_);
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						if (!_tmp63_) {
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
							break;
#line 36714 "Photo.c"
						}
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp64_ = _path_it;
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp65_ = gee_iterator_get (_tmp64_);
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						path = (gchar*) _tmp65_;
#line 4737 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp66_ = path;
#line 4737 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp67_ = tag_prep_tag_name (_tmp66_);
#line 4737 "/home/jens/Source/shotwell/src/Photo.vala"
						name = _tmp67_;
#line 4738 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp68_ = name;
#line 4738 "/home/jens/Source/shotwell/src/Photo.vala"
						if (_tmp68_ != NULL) {
#line 36732 "Photo.c"
							GeeHashMultiMap* _tmp69_;
							const gchar* _tmp70_;
							Tag* _tmp71_;
							Tag* _tmp72_;
							LibraryPhoto* _tmp73_;
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp69_ = map;
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp70_ = name;
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp71_ = tag_for_path (_tmp70_);
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp72_ = _tmp71_;
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp73_ = photo;
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_multi_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, GEE_TYPE_MULTI_MAP, GeeMultiMap), _tmp72_, _tmp73_);
#line 4739 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (_tmp72_);
#line 36752 "Photo.c"
						}
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_free0 (name);
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_free0 (path);
#line 36758 "Photo.c"
					}
#line 4736 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_path_it);
#line 36762 "Photo.c"
				}
			}
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_hierarchical_tag_index_unref0 (htag_index);
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_hierarchical_tag_index_unref0 (global_index);
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_media_metadata_unref0 (metadata);
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (photo);
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (media);
#line 36775 "Photo.c"
		}
#line 4699 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_media_it);
#line 36779 "Photo.c"
	}
	{
		GeeIterator* _media_it = NULL;
		GeeCollection* _tmp74_;
		GeeIterator* _tmp75_;
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp74_ = media_sources;
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp75_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_it = _tmp75_;
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 36793 "Photo.c"
			GeeIterator* _tmp76_;
			gboolean _tmp77_;
			MediaSource* media = NULL;
			GeeIterator* _tmp78_;
			gpointer _tmp79_;
			LibraryPhoto* photo = NULL;
			MediaSource* _tmp80_;
			LibraryPhoto* _tmp81_;
			LibraryPhoto* _tmp82_;
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp76_ = _media_it;
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp77_ = gee_iterator_next (_tmp76_);
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp77_) {
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 36811 "Photo.c"
			}
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp78_ = _media_it;
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp79_ = gee_iterator_get (_tmp78_);
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			media = (MediaSource*) _tmp79_;
#line 4745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp80_ = media;
#line 4745 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp81_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 4745 "/home/jens/Source/shotwell/src/Photo.vala"
			photo = _tmp81_;
#line 4746 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp82_ = photo;
#line 4746 "/home/jens/Source/shotwell/src/Photo.vala"
			library_photo_clear_import_keywords (_tmp82_);
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (photo);
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (media);
#line 36833 "Photo.c"
		}
#line 4744 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_media_it);
#line 36837 "Photo.c"
	}
	{
		GeeIterator* _tag_it = NULL;
		GeeHashMultiMap* _tmp83_;
		GeeSet* _tmp84_;
		GeeSet* _tmp85_;
		GeeIterator* _tmp86_;
		GeeIterator* _tmp87_;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp83_ = map;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp84_ = gee_multi_map_get_keys (G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, GEE_TYPE_MULTI_MAP, GeeMultiMap));
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp85_ = _tmp84_;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp86_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp85_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp87_ = _tmp86_;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp85_);
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_tag_it = _tmp87_;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 36862 "Photo.c"
			GeeIterator* _tmp88_;
			gboolean _tmp89_;
			Tag* tag = NULL;
			GeeIterator* _tmp90_;
			gpointer _tmp91_;
			Tag* _tmp92_;
			GeeHashMultiMap* _tmp93_;
			Tag* _tmp94_;
			GeeCollection* _tmp95_;
			GeeCollection* _tmp96_;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp88_ = _tag_it;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp89_ = gee_iterator_next (_tmp88_);
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp89_) {
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 36881 "Photo.c"
			}
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp90_ = _tag_it;
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp91_ = gee_iterator_get (_tmp90_);
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			tag = (Tag*) _tmp91_;
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp92_ = tag;
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp93_ = map;
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp94_ = tag;
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp95_ = gee_multi_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp93_, GEE_TYPE_MULTI_MAP, GeeMultiMap), _tmp94_);
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp96_ = _tmp95_;
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			tag_attach_many (_tmp92_, _tmp96_);
#line 4750 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp96_);
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (tag);
#line 36905 "Photo.c"
		}
#line 4749 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tag_it);
#line 36909 "Photo.c"
	}
#line 4752 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp97_ = media_sources;
#line 4752 "/home/jens/Source/shotwell/src/Photo.vala"
	MEDIA_SOURCE_COLLECTION_CLASS (library_photo_source_collection_parent_class)->postprocess_imported_media (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), _tmp97_);
#line 4697 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (map);
#line 36917 "Photo.c"
}


static void library_photo_source_collection_real_notify_master_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
	LibraryPhoto* _tmp0_;
	PhotoMetadata* _tmp1_;
#line 4756 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4756 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 4757 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 4757 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = metadata;
#line 4757 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_MASTER_REIMPORTED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 36934 "Photo.c"
}


void library_photo_source_collection_notify_master_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4756 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4756 "/home/jens/Source/shotwell/src/Photo.vala"
	LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS (self)->notify_master_reimported (self, photo, metadata);
#line 36943 "Photo.c"
}


static void library_photo_source_collection_real_notify_editable_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
	LibraryPhoto* _tmp0_;
	PhotoMetadata* _tmp1_;
#line 4761 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4761 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 4762 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 4762 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = metadata;
#line 4762 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_EDITABLE_REIMPORTED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 36960 "Photo.c"
}


void library_photo_source_collection_notify_editable_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4761 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4761 "/home/jens/Source/shotwell/src/Photo.vala"
	LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS (self)->notify_editable_reimported (self, photo, metadata);
#line 36969 "Photo.c"
}


static void library_photo_source_collection_real_notify_source_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
	LibraryPhoto* _tmp0_;
	PhotoMetadata* _tmp1_;
#line 4766 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4766 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 4767 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 4767 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = metadata;
#line 4767 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_SOURCE_REIMPORTED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 36986 "Photo.c"
}


void library_photo_source_collection_notify_source_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4766 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4766 "/home/jens/Source/shotwell/src/Photo.vala"
	LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS (self)->notify_source_reimported (self, photo, metadata);
#line 36995 "Photo.c"
}


static void library_photo_source_collection_real_notify_baseline_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
	LibraryPhoto* _tmp0_;
	PhotoMetadata* _tmp1_;
#line 4771 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4771 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 4772 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 4772 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = metadata;
#line 4772 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit (self, library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_BASELINE_REIMPORTED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 37012 "Photo.c"
}


void library_photo_source_collection_notify_baseline_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4771 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4771 "/home/jens/Source/shotwell/src/Photo.vala"
	LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS (self)->notify_baseline_reimported (self, photo, metadata);
#line 37021 "Photo.c"
}


static MediaSource* library_photo_source_collection_real_fetch_by_numeric_id (MediaSourceCollection* base, gint64 numeric_id) {
	LibraryPhotoSourceCollection * self;
	MediaSource* result = NULL;
	gint64 _tmp0_;
	PhotoID _tmp1_ = {0};
	LibraryPhoto* _tmp2_;
#line 4775 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4776 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = numeric_id;
#line 4776 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id_init (&_tmp1_, _tmp0_);
#line 4776 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = library_photo_source_collection_fetch (self, &_tmp1_);
#line 4776 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_MEDIA_SOURCE, MediaSource);
#line 4776 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37043 "Photo.c"
}


static void library_photo_source_collection_on_trashcan_contents_altered (LibraryPhotoSourceCollection* self, GeeCollection* added, GeeCollection* removed) {
	GeeCollection* _tmp0_;
	GeeCollection* _tmp1_;
#line 4779 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4779 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((added == NULL) || GEE_IS_COLLECTION (added));
#line 4779 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_COLLECTION (removed));
#line 4781 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = added;
#line 4781 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = removed;
#line 4781 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), "trashcan-contents-altered", G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 37062 "Photo.c"
}


static gboolean library_photo_source_collection_check_if_trashed_photo (LibraryPhotoSourceCollection* self, DataSource* source, Alteration* alteration) {
	gboolean result = FALSE;
	DataSource* _tmp0_;
	gboolean _tmp1_;
#line 4785 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), FALSE);
#line 4785 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
#line 4785 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_ALTERATION (alteration), FALSE);
#line 4786 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = source;
#line 4786 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = media_source_is_trashed (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_LIBRARY_PHOTO, LibraryPhoto), TYPE_MEDIA_SOURCE, MediaSource));
#line 4786 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 4786 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37084 "Photo.c"
}


static void library_photo_source_collection_on_offline_contents_altered (LibraryPhotoSourceCollection* self, GeeCollection* added, GeeCollection* removed) {
	GeeCollection* _tmp0_;
	GeeCollection* _tmp1_;
#line 4789 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4789 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((added == NULL) || GEE_IS_COLLECTION (added));
#line 4789 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_COLLECTION (removed));
#line 4791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = added;
#line 4791 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = removed;
#line 4791 "/home/jens/Source/shotwell/src/Photo.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), "offline-contents-altered", G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 37103 "Photo.c"
}


static gboolean library_photo_source_collection_check_if_offline_photo (LibraryPhotoSourceCollection* self, DataSource* source, Alteration* alteration) {
	gboolean result = FALSE;
	DataSource* _tmp0_;
	gboolean _tmp1_;
#line 4795 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), FALSE);
#line 4795 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
#line 4795 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_ALTERATION (alteration), FALSE);
#line 4796 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = source;
#line 4796 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = media_source_is_offline (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_LIBRARY_PHOTO, LibraryPhoto), TYPE_MEDIA_SOURCE, MediaSource));
#line 4796 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 4796 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37125 "Photo.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_;
	glong _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1323 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1323 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 37148 "Photo.c"
		glong _tmp4_;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 37156 "Photo.c"
	} else {
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 37168 "Photo.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_;
	glong _tmp8_;
	glong _tmp14_;
	glong _tmp17_;
	glong _tmp18_;
	glong _tmp19_;
	glong _tmp20_;
	glong _tmp21_;
	gchar* _tmp22_;
#line 1333 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 37192 "Photo.c"
		glong _tmp2_;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 37198 "Photo.c"
	} else {
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 37202 "Photo.c"
	}
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 37206 "Photo.c"
		glong _tmp3_;
		glong _tmp4_;
		glong _tmp5_;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 37218 "Photo.c"
	} else {
		gint _tmp6_;
		gint _tmp7_;
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 37228 "Photo.c"
	}
#line 1342 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1342 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 37234 "Photo.c"
		glong _tmp9_;
		glong _tmp10_;
		glong _tmp11_;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1344 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1344 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 37248 "Photo.c"
	} else {
		glong _tmp12_;
		glong _tmp13_;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 37258 "Photo.c"
	}
#line 1348 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1348 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 37264 "Photo.c"
		glong _tmp15_;
		glong _tmp16_;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 37273 "Photo.c"
	}
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 37293 "Photo.c"
}


static MediaSource* library_photo_source_collection_real_fetch_by_source_id (MediaSourceCollection* base, const gchar* source_id) {
	LibraryPhotoSourceCollection * self;
	MediaSource* result = NULL;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	gchar* numeric_only = NULL;
	const gchar* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	gchar* _tmp5_;
	gint64 _tmp6_;
	MediaSource* _tmp7_;
#line 4799 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4799 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (source_id != NULL, NULL);
#line 4800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = source_id;
#line 4800 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = g_str_has_prefix (_tmp0_, PHOTO_TYPENAME);
#line 4800 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp1_, "source_id.has_prefix(Photo.TYPENAME)");
#line 4801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = source_id;
#line 4801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = strlen (PHOTO_TYPENAME);
#line 4801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 4801 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = string_substring (_tmp2_, (glong) _tmp4_, (glong) -1);
#line 4801 "/home/jens/Source/shotwell/src/Photo.vala"
	numeric_only = _tmp5_;
#line 4803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = parse_int64 (numeric_only, 16);
#line 4803 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = media_source_collection_fetch_by_numeric_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), _tmp6_);
#line 4803 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp7_;
#line 4803 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (numeric_only);
#line 4803 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37339 "Photo.c"
}


static GeeCollection* library_photo_source_collection_real_get_event_source_ids (MediaSourceCollection* base, EventID* event_id) {
	LibraryPhotoSourceCollection * self;
	GeeCollection* result = NULL;
	PhotoTable* _tmp0_;
	PhotoTable* _tmp1_;
	EventID _tmp2_;
	GeeArrayList* _tmp3_;
	GeeCollection* _tmp4_;
#line 4806 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4806 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (event_id != NULL, NULL);
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_table_get_instance ();
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = *event_id;
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_table_get_event_source_ids (_tmp1_, &_tmp2_);
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection);
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp1_);
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 4807 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37371 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_fetch (LibraryPhotoSourceCollection* self, PhotoID* photo_id) {
	LibraryPhoto* result = NULL;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	DataSource* _tmp2_;
#line 4810 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4810 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (photo_id != NULL, NULL);
#line 4811 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = *photo_id;
#line 4811 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_.id;
#line 4811 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = database_source_collection_fetch_by_key (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection), _tmp1_);
#line 4811 "/home/jens/Source/shotwell/src/Photo.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4811 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37394 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_fetch_by_editable_file (LibraryPhotoSourceCollection* self, GFile* file) {
	LibraryPhoto* result = NULL;
	GeeHashMap* _tmp0_;
	GFile* _tmp1_;
	gpointer _tmp2_;
#line 4814 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4814 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 4815 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->by_editable_file;
#line 4815 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 4815 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 4815 "/home/jens/Source/shotwell/src/Photo.vala"
	result = (LibraryPhoto*) _tmp2_;
#line 4815 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37417 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_fetch_by_raw_development_file (LibraryPhotoSourceCollection* self, GFile* file) {
	LibraryPhoto* result = NULL;
	GeeHashMap* _tmp0_;
	GFile* _tmp1_;
	gpointer _tmp2_;
#line 4818 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4818 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 4819 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->by_raw_development_file;
#line 4819 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 4819 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 4819 "/home/jens/Source/shotwell/src/Photo.vala"
	result = (LibraryPhoto*) _tmp2_;
#line 4819 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37440 "Photo.c"
}


static void library_photo_source_collection_compare_backing (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, GFileInfo* info, GeeCollection* matches_master, GeeCollection* matches_editable, GeeCollection* matches_development) {
	LibraryPhoto* _tmp0_;
	BackingPhotoRow* _tmp1_;
	BackingPhotoRow* _tmp2_;
	GFileInfo* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	BackingPhotoRow* editable = NULL;
	LibraryPhoto* _tmp8_;
	BackingPhotoRow* _tmp9_;
	gboolean _tmp10_ = FALSE;
	BackingPhotoRow* _tmp11_;
	GeeCollection* development = NULL;
	LibraryPhoto* _tmp17_;
	GeeCollection* _tmp18_;
	GeeCollection* _tmp19_;
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE_INFO (info));
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (matches_master));
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (matches_editable));
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (matches_development));
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo;
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_get_master_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO, Photo));
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_;
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = info;
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = backing_photo_row_matches_file_info (_tmp2_, _tmp3_);
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_;
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp2_);
#line 4825 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 37488 "Photo.c"
		GeeCollection* _tmp6_;
		LibraryPhoto* _tmp7_;
#line 4826 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = matches_master;
#line 4826 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = photo;
#line 4826 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_collection_add (_tmp6_, _tmp7_);
#line 37497 "Photo.c"
	}
#line 4828 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo;
#line 4828 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_PHOTO, Photo));
#line 4828 "/home/jens/Source/shotwell/src/Photo.vala"
	editable = _tmp9_;
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = editable;
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_ != NULL) {
#line 37509 "Photo.c"
		BackingPhotoRow* _tmp12_;
		GFileInfo* _tmp13_;
		gboolean _tmp14_;
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = editable;
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = info;
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = backing_photo_row_matches_file_info (_tmp12_, _tmp13_);
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = _tmp14_;
#line 37521 "Photo.c"
	} else {
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = FALSE;
#line 37525 "Photo.c"
	}
#line 4829 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp10_) {
#line 37529 "Photo.c"
		GeeCollection* _tmp15_;
		LibraryPhoto* _tmp16_;
#line 4830 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp15_ = matches_editable;
#line 4830 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = photo;
#line 4830 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_collection_add (_tmp15_, _tmp16_);
#line 37538 "Photo.c"
	}
#line 4832 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = photo;
#line 4832 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp18_ = photo_get_raw_development_photo_rows (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, TYPE_PHOTO, Photo));
#line 4832 "/home/jens/Source/shotwell/src/Photo.vala"
	development = _tmp18_;
#line 4833 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = development;
#line 4833 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp19_ != NULL) {
#line 37550 "Photo.c"
		{
			GeeIterator* _row_it = NULL;
			GeeCollection* _tmp20_;
			GeeIterator* _tmp21_;
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = development;
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
			_row_it = _tmp21_;
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 37563 "Photo.c"
				GeeIterator* _tmp22_;
				gboolean _tmp23_;
				BackingPhotoRow* row = NULL;
				GeeIterator* _tmp24_;
				gpointer _tmp25_;
				BackingPhotoRow* _tmp26_;
				GFileInfo* _tmp27_;
				gboolean _tmp28_;
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = _row_it;
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = gee_iterator_next (_tmp22_);
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp23_) {
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 37580 "Photo.c"
				}
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = _row_it;
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = gee_iterator_get (_tmp24_);
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				row = (BackingPhotoRow*) _tmp25_;
#line 4835 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = row;
#line 4835 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = info;
#line 4835 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = backing_photo_row_matches_file_info (_tmp26_, _tmp27_);
#line 4835 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp28_) {
#line 37596 "Photo.c"
					GeeCollection* _tmp29_;
					LibraryPhoto* _tmp30_;
#line 4836 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp29_ = matches_development;
#line 4836 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp30_ = photo;
#line 4836 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_collection_add (_tmp29_, _tmp30_);
#line 4838 "/home/jens/Source/shotwell/src/Photo.vala"
					_backing_photo_row_unref0 (row);
#line 4838 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 37609 "Photo.c"
				}
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (row);
#line 37613 "Photo.c"
			}
#line 4834 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_row_it);
#line 37617 "Photo.c"
		}
	}
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (development);
#line 4822 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (editable);
#line 37624 "Photo.c"
}


void library_photo_source_collection_fetch_by_matching_backing (LibraryPhotoSourceCollection* self, GFileInfo* info, GeeCollection* matches_master, GeeCollection* matches_editable, GeeCollection* matched_development) {
#line 4846 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4846 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (G_IS_FILE_INFO (info));
#line 4846 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (matches_master));
#line 4846 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (matches_editable));
#line 4846 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (GEE_IS_COLLECTION (matched_development));
#line 37639 "Photo.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeMultiMap* _tmp0_;
		GFileInfo* _tmp1_;
		gint64 _tmp2_;
		GeeCollection* _tmp3_;
		GeeCollection* _tmp4_;
		GeeIterator* _tmp5_;
		GeeIterator* _tmp6_;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->filesize_to_photo;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = info;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = g_file_info_get_size (_tmp1_);
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = gee_multi_map_get (_tmp0_, &_tmp2_);
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp3_;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp4_);
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_it = _tmp6_;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 37669 "Photo.c"
			GeeIterator* _tmp7_;
			gboolean _tmp8_;
			LibraryPhoto* photo = NULL;
			GeeIterator* _tmp9_;
			gpointer _tmp10_;
			LibraryPhoto* _tmp11_;
			GFileInfo* _tmp12_;
			GeeCollection* _tmp13_;
			GeeCollection* _tmp14_;
			GeeCollection* _tmp15_;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = _photo_it;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp8_) {
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 37688 "Photo.c"
			}
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _photo_it;
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			photo = (LibraryPhoto*) _tmp10_;
#line 4849 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = photo;
#line 4849 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = info;
#line 4849 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = matches_master;
#line 4849 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = matches_editable;
#line 4849 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = matched_development;
#line 4849 "/home/jens/Source/shotwell/src/Photo.vala"
			library_photo_source_collection_compare_backing (self, _tmp11_, _tmp12_, _tmp13_, _tmp14_, _tmp15_);
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (photo);
#line 37710 "Photo.c"
		}
#line 4848 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_photo_it);
#line 37714 "Photo.c"
	}
	{
		GeeIterator* _media_it = NULL;
		GeeCollection* _tmp16_;
		GeeCollection* _tmp17_;
		GeeIterator* _tmp18_;
		GeeIterator* _tmp19_;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = media_source_collection_get_offline_bin_contents (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = _tmp16_;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = _tmp18_;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp17_);
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_it = _tmp19_;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 37736 "Photo.c"
			GeeIterator* _tmp20_;
			gboolean _tmp21_;
			MediaSource* media = NULL;
			GeeIterator* _tmp22_;
			gpointer _tmp23_;
			MediaSource* _tmp24_;
			GFileInfo* _tmp25_;
			GeeCollection* _tmp26_;
			GeeCollection* _tmp27_;
			GeeCollection* _tmp28_;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp20_ = _media_it;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp21_ = gee_iterator_next (_tmp20_);
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp21_) {
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 37755 "Photo.c"
			}
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp22_ = _media_it;
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_ = gee_iterator_get (_tmp22_);
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			media = (MediaSource*) _tmp23_;
#line 4852 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = media;
#line 4852 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp25_ = info;
#line 4852 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp26_ = matches_master;
#line 4852 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp27_ = matches_editable;
#line 4852 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp28_ = matched_development;
#line 4852 "/home/jens/Source/shotwell/src/Photo.vala"
			library_photo_source_collection_compare_backing (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_LIBRARY_PHOTO, LibraryPhoto), _tmp25_, _tmp26_, _tmp27_, _tmp28_);
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (media);
#line 37777 "Photo.c"
		}
#line 4851 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_media_it);
#line 37781 "Photo.c"
	}
}


void library_photo_source_collection_get_basename_filesize_duplicate (LibraryPhotoSourceCollection* self, const gchar* basename, gint64 filesize, PhotoID* result) {
	PhotoID _tmp19_ = {0};
#line 4855 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self));
#line 4855 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (basename != NULL);
#line 37792 "Photo.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeMultiMap* _tmp0_;
		gint64 _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = self->priv->filesize_to_photo;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = filesize;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = gee_multi_map_get (_tmp0_, &_tmp1_);
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp3_);
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_photo_it = _tmp5_;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		while (TRUE) {
#line 37819 "Photo.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			LibraryPhoto* photo = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			LibraryPhoto* _tmp10_;
			GFile* _tmp11_;
			GFile* _tmp12_;
			gchar* _tmp13_;
			const gchar* _tmp14_;
			gint _tmp15_;
			gboolean _tmp16_;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _photo_it;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			if (!_tmp7_) {
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
				break;
#line 37840 "Photo.c"
			}
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _photo_it;
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			photo = (LibraryPhoto*) _tmp9_;
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = photo;
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_MEDIA_SOURCE, MediaSource));
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp12_ = _tmp11_;
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp13_ = g_file_get_basename (_tmp12_);
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp14_ = basename;
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = utf8_ci_compare (_tmp13_, _tmp14_);
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = _tmp15_ == 0;
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp12_);
#line 4857 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_tmp16_) {
#line 37866 "Photo.c"
				LibraryPhoto* _tmp17_;
				PhotoID _tmp18_ = {0};
#line 4858 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = photo;
#line 4858 "/home/jens/Source/shotwell/src/Photo.vala"
				photo_get_photo_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, TYPE_PHOTO, Photo), &_tmp18_);
#line 4858 "/home/jens/Source/shotwell/src/Photo.vala"
				*result = _tmp18_;
#line 4858 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 4858 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_photo_it);
#line 4858 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 37881 "Photo.c"
			}
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (photo);
#line 37885 "Photo.c"
		}
#line 4856 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_photo_it);
#line 37889 "Photo.c"
	}
#line 4861 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id_init (&_tmp19_, PHOTO_ID_INVALID);
#line 4861 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = _tmp19_;
#line 4861 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 37897 "Photo.c"
}


gboolean library_photo_source_collection_has_basename_filesize_duplicate (LibraryPhotoSourceCollection* self, const gchar* basename, gint64 filesize) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gint64 _tmp1_;
	PhotoID _tmp2_ = {0};
	gboolean _tmp3_;
#line 4865 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), FALSE);
#line 4865 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (basename != NULL, FALSE);
#line 4866 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = basename;
#line 4866 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = filesize;
#line 4866 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_get_basename_filesize_duplicate (self, _tmp0_, _tmp1_, &_tmp2_);
#line 4866 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_id_is_valid (&_tmp2_);
#line 4866 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 4866 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37923 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_get_trashed_by_file (LibraryPhotoSourceCollection* self, GFile* file) {
	LibraryPhoto* result = NULL;
	LibraryPhoto* photo = NULL;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	GFile* _tmp2_;
	MediaSource* _tmp3_;
	LibraryPhoto* _tmp4_;
	LibraryPhoto* _tmp5_;
#line 4869 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4869 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_trashcan (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = file;
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = media_source_holding_tank_fetch_by_master_file (_tmp1_, _tmp2_);
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4870 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp4_;
#line 4871 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo;
#line 4871 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_ == NULL) {
#line 37958 "Photo.c"
		MediaSourceHoldingTank* _tmp6_;
		LibraryPhotoSourceHoldingTank* _tmp7_;
		GFile* _tmp8_;
		LibraryPhoto* _tmp9_;
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = media_source_collection_get_trashcan (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTank);
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = file;
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = library_photo_source_holding_tank_fetch_by_backing_file (_tmp7_, _tmp8_);
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (photo);
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		photo = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4872 "/home/jens/Source/shotwell/src/Photo.vala"
		_source_holding_tank_unref0 (_tmp7_);
#line 37977 "Photo.c"
	}
#line 4875 "/home/jens/Source/shotwell/src/Photo.vala"
	result = photo;
#line 4875 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 37983 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_get_trashed_by_md5 (LibraryPhotoSourceCollection* self, const gchar* md5) {
	LibraryPhoto* result = NULL;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	const gchar* _tmp2_;
	MediaSource* _tmp3_;
	LibraryPhoto* _tmp4_;
#line 4878 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4878 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (md5 != NULL, NULL);
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_trashcan (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = md5;
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = media_source_holding_tank_fetch_by_md5 (_tmp1_, _tmp2_);
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 4879 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38014 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_get_offline_by_file (LibraryPhotoSourceCollection* self, GFile* file) {
	LibraryPhoto* result = NULL;
	LibraryPhoto* photo = NULL;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	GFile* _tmp2_;
	MediaSource* _tmp3_;
	LibraryPhoto* _tmp4_;
	LibraryPhoto* _tmp5_;
#line 4882 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4882 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = file;
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = media_source_holding_tank_fetch_by_master_file (_tmp1_, _tmp2_);
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4883 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp4_;
#line 4884 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo;
#line 4884 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_ == NULL) {
#line 38049 "Photo.c"
		MediaSourceHoldingTank* _tmp6_;
		LibraryPhotoSourceHoldingTank* _tmp7_;
		GFile* _tmp8_;
		LibraryPhoto* _tmp9_;
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTank);
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = file;
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = library_photo_source_holding_tank_fetch_by_backing_file (_tmp7_, _tmp8_);
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (photo);
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		photo = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4885 "/home/jens/Source/shotwell/src/Photo.vala"
		_source_holding_tank_unref0 (_tmp7_);
#line 38068 "Photo.c"
	}
#line 4888 "/home/jens/Source/shotwell/src/Photo.vala"
	result = photo;
#line 4888 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38074 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_get_offline_by_md5 (LibraryPhotoSourceCollection* self, const gchar* md5) {
	LibraryPhoto* result = NULL;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	const gchar* _tmp2_;
	MediaSource* _tmp3_;
	LibraryPhoto* _tmp4_;
#line 4891 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4891 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (md5 != NULL, NULL);
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = md5;
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = media_source_holding_tank_fetch_by_md5 (_tmp1_, _tmp2_);
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp4_;
#line 4892 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38105 "Photo.c"
}


gint library_photo_source_collection_get_offline_count (LibraryPhotoSourceCollection* self) {
	gint result = 0;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
#line 4895 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), 0);
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = source_holding_tank_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank));
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 4896 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38131 "Photo.c"
}


LibraryPhoto* library_photo_source_collection_get_state_by_file (LibraryPhotoSourceCollection* self, GFile* file, LibraryPhotoSourceCollectionState* state) {
	LibraryPhotoSourceCollectionState _vala_state = 0;
	LibraryPhoto* result = NULL;
	LibraryPhoto* photo = NULL;
	GFile* _tmp0_;
	MediaSource* _tmp1_;
	LibraryPhoto* _tmp2_;
	GFile* _tmp3_;
	LibraryPhoto* _tmp4_;
	LibraryPhoto* _tmp5_;
	GFile* _tmp6_;
	LibraryPhoto* _tmp7_;
	LibraryPhoto* _tmp8_;
	GFile* _tmp9_;
	LibraryPhoto* _tmp10_;
	LibraryPhoto* _tmp11_;
	LibraryPhoto* _tmp12_;
	GFile* _tmp13_;
	LibraryPhoto* _tmp14_;
	LibraryPhoto* _tmp15_;
	LibraryPhoto* _tmp16_;
#line 4899 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (self), NULL);
#line 4899 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 4900 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 4900 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = media_source_collection_fetch_by_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), _tmp0_);
#line 4900 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4901 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo;
#line 4901 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ != NULL) {
#line 4902 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_state = LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_ONLINE;
#line 4904 "/home/jens/Source/shotwell/src/Photo.vala"
		result = photo;
#line 4904 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 4904 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 38178 "Photo.c"
		}
#line 4904 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38182 "Photo.c"
	}
#line 4907 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = file;
#line 4907 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = library_photo_source_collection_fetch_by_editable_file (self, _tmp3_);
#line 4907 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 4907 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp4_;
#line 4908 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo;
#line 4908 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_ != NULL) {
#line 4909 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_state = LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_EDITABLE;
#line 4911 "/home/jens/Source/shotwell/src/Photo.vala"
		result = photo;
#line 4911 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 4911 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 38204 "Photo.c"
		}
#line 4911 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38208 "Photo.c"
	}
#line 4914 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = file;
#line 4914 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = library_photo_source_collection_fetch_by_raw_development_file (self, _tmp6_);
#line 4914 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 4914 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp7_;
#line 4915 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo;
#line 4915 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_ != NULL) {
#line 4916 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_state = LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_DEVELOPER;
#line 4918 "/home/jens/Source/shotwell/src/Photo.vala"
		result = photo;
#line 4918 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 4918 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 38230 "Photo.c"
		}
#line 4918 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38234 "Photo.c"
	}
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = file;
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = library_photo_source_collection_get_trashed_by_file (self, _tmp9_);
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, TYPE_LIBRARY_PHOTO) ? ((LibraryPhoto*) _tmp10_) : NULL;
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_ == NULL) {
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp10_);
#line 38246 "Photo.c"
	}
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 4921 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp11_;
#line 4922 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = photo;
#line 4922 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp12_ != NULL) {
#line 4923 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_state = LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_TRASH;
#line 4925 "/home/jens/Source/shotwell/src/Photo.vala"
		result = photo;
#line 4925 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 4925 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 38264 "Photo.c"
		}
#line 4925 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38268 "Photo.c"
	}
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = file;
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = library_photo_source_collection_get_offline_by_file (self, _tmp13_);
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, TYPE_LIBRARY_PHOTO) ? ((LibraryPhoto*) _tmp14_) : NULL;
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp15_ == NULL) {
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp14_);
#line 38280 "Photo.c"
	}
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 4928 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp15_;
#line 4929 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = photo;
#line 4929 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp16_ != NULL) {
#line 4930 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_state = LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_OFFLINE;
#line 4932 "/home/jens/Source/shotwell/src/Photo.vala"
		result = photo;
#line 4932 "/home/jens/Source/shotwell/src/Photo.vala"
		if (state) {
#line 4932 "/home/jens/Source/shotwell/src/Photo.vala"
			*state = _vala_state;
#line 38298 "Photo.c"
		}
#line 4932 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38302 "Photo.c"
	}
#line 4935 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_state = LIBRARY_PHOTO_SOURCE_COLLECTION_STATE_UNKNOWN;
#line 4937 "/home/jens/Source/shotwell/src/Photo.vala"
	result = NULL;
#line 4937 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 4937 "/home/jens/Source/shotwell/src/Photo.vala"
	if (state) {
#line 4937 "/home/jens/Source/shotwell/src/Photo.vala"
		*state = _vala_state;
#line 38314 "Photo.c"
	}
#line 4937 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38318 "Photo.c"
}


static gboolean library_photo_source_collection_real_has_backlink (SourceCollection* base, SourceBacklink* backlink) {
	LibraryPhotoSourceCollection * self;
	gboolean result = FALSE;
	SourceBacklink* _tmp0_;
	gboolean _tmp1_;
	MediaSourceHoldingTank* _tmp2_;
	MediaSourceHoldingTank* _tmp3_;
	SourceBacklink* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	MediaSourceHoldingTank* _tmp7_;
	MediaSourceHoldingTank* _tmp8_;
	SourceBacklink* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
#line 4940 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4940 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_SOURCE_BACKLINK (backlink), FALSE);
#line 4941 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = backlink;
#line 4941 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = SOURCE_COLLECTION_CLASS (library_photo_source_collection_parent_class)->has_backlink (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), TYPE_SOURCE_COLLECTION, SourceCollection), _tmp0_);
#line 4941 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 4942 "/home/jens/Source/shotwell/src/Photo.vala"
		result = TRUE;
#line 4942 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38351 "Photo.c"
	}
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = media_source_collection_get_trashcan (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = backlink;
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = source_holding_tank_has_backlink (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), _tmp4_);
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = _tmp5_;
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp3_);
#line 4944 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_) {
#line 4945 "/home/jens/Source/shotwell/src/Photo.vala"
		result = TRUE;
#line 4945 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38371 "Photo.c"
	}
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_;
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = backlink;
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = source_holding_tank_has_backlink (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), _tmp9_);
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp10_;
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp8_);
#line 4947 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_) {
#line 4948 "/home/jens/Source/shotwell/src/Photo.vala"
		result = TRUE;
#line 4948 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 38391 "Photo.c"
	}
#line 4950 "/home/jens/Source/shotwell/src/Photo.vala"
	result = FALSE;
#line 4950 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38397 "Photo.c"
}


static void library_photo_source_collection_real_remove_backlink (SourceCollection* base, SourceBacklink* backlink) {
	LibraryPhotoSourceCollection * self;
	MediaSourceHoldingTank* _tmp0_;
	MediaSourceHoldingTank* _tmp1_;
	SourceBacklink* _tmp2_;
	MediaSourceHoldingTank* _tmp3_;
	MediaSourceHoldingTank* _tmp4_;
	SourceBacklink* _tmp5_;
	SourceBacklink* _tmp6_;
#line 4953 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4953 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_SOURCE_BACKLINK (backlink));
#line 4954 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_collection_get_trashcan (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4954 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 4954 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = backlink;
#line 4954 "/home/jens/Source/shotwell/src/Photo.vala"
	source_holding_tank_remove_backlink (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), _tmp2_);
#line 4954 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp1_);
#line 4955 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = media_source_collection_get_offline_bin (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4955 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 4955 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = backlink;
#line 4955 "/home/jens/Source/shotwell/src/Photo.vala"
	source_holding_tank_remove_backlink (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), _tmp5_);
#line 4955 "/home/jens/Source/shotwell/src/Photo.vala"
	_source_holding_tank_unref0 (_tmp4_);
#line 4957 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = backlink;
#line 4957 "/home/jens/Source/shotwell/src/Photo.vala"
	SOURCE_COLLECTION_CLASS (library_photo_source_collection_parent_class)->remove_backlink (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), TYPE_SOURCE_COLLECTION, SourceCollection), _tmp6_);
#line 38438 "Photo.c"
}


static TransactionController* library_photo_source_collection_real_get_transaction_controller (MediaSourceCollection* base) {
	TransactionController* result;
	LibraryPhotoSourceCollection* self;
	TransactionController* _tmp0_;
	TransactionController* _tmp2_;
#line 4474 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4475 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->_transaction_controller;
#line 4475 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ == NULL) {
#line 38453 "Photo.c"
		MediaSourceTransactionController* _tmp1_;
#line 4476 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = media_source_transaction_controller_new (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 4476 "/home/jens/Source/shotwell/src/Photo.vala"
		_transaction_controller_unref0 (self->priv->_transaction_controller);
#line 4476 "/home/jens/Source/shotwell/src/Photo.vala"
		self->priv->_transaction_controller = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_TRANSACTION_CONTROLLER, TransactionController);
#line 38461 "Photo.c"
	}
#line 4478 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = self->priv->_transaction_controller;
#line 4478 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp2_;
#line 4478 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 38469 "Photo.c"
}


static void library_photo_source_collection_real_master_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4496 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4496 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 38478 "Photo.c"
}


static void g_cclosure_user_marshal_VOID__OBJECT_MEDIA_METADATA (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__OBJECT_MEDIA_METADATA) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_MEDIA_METADATA callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (n_param_values == 3);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
		data1 = closure->data;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
		data2 = param_values->data[0].v_pointer;
#line 38497 "Photo.c"
	} else {
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
		data1 = param_values->data[0].v_pointer;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
		data2 = closure->data;
#line 38503 "Photo.c"
	}
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	callback = (GMarshalFunc_VOID__OBJECT_MEDIA_METADATA) (marshal_data ? marshal_data : cc->callback);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	callback (data1, g_value_get_object (param_values + 1), value_get_media_metadata (param_values + 2), data2);
#line 38509 "Photo.c"
}


static void library_photo_source_collection_real_editable_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4499 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4499 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 38518 "Photo.c"
}


static void library_photo_source_collection_real_baseline_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4502 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4502 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 38527 "Photo.c"
}


static void library_photo_source_collection_real_source_reimported (LibraryPhotoSourceCollection* self, LibraryPhoto* photo, PhotoMetadata* metadata) {
#line 4505 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 4505 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 38536 "Photo.c"
}


static void library_photo_source_collection_class_init (LibraryPhotoSourceCollectionClass * klass) {
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_parent_class = g_type_class_peek_parent (klass);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataCollectionClass *) klass)->finalize = library_photo_source_collection_finalize;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	g_type_class_add_private (klass, sizeof (LibraryPhotoSourceCollectionPrivate));
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->create_trashcan = (MediaSourceHoldingTank* (*) (MediaSourceCollection *)) library_photo_source_collection_real_create_trashcan;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->create_offline_bin = (MediaSourceHoldingTank* (*) (MediaSourceCollection *)) library_photo_source_collection_real_create_offline_bin;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->create_media_monitor = (MediaMonitor* (*) (MediaSourceCollection *, Workers*, GCancellable*)) library_photo_source_collection_real_create_media_monitor;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((SourceCollectionClass *) klass)->holds_type_of_source = (gboolean (*) (SourceCollection *, DataSource*)) library_photo_source_collection_real_holds_type_of_source;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->get_typename = (gchar* (*) (MediaSourceCollection *)) library_photo_source_collection_real_get_typename;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->is_file_recognized = (gboolean (*) (MediaSourceCollection *, GFile*)) library_photo_source_collection_real_is_file_recognized;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataCollectionClass *) klass)->notify_contents_altered = (void (*) (DataCollection *, GeeIterable*, GeeIterable*)) library_photo_source_collection_real_notify_contents_altered;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataCollectionClass *) klass)->items_altered = (void (*) (DataCollection *, GeeMap*)) library_photo_source_collection_real_items_altered;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->postprocess_imported_media = (void (*) (MediaSourceCollection *, GeeCollection*)) library_photo_source_collection_real_postprocess_imported_media;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->notify_master_reimported = (void (*) (LibraryPhotoSourceCollection *, LibraryPhoto*, PhotoMetadata*)) library_photo_source_collection_real_notify_master_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->notify_editable_reimported = (void (*) (LibraryPhotoSourceCollection *, LibraryPhoto*, PhotoMetadata*)) library_photo_source_collection_real_notify_editable_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->notify_source_reimported = (void (*) (LibraryPhotoSourceCollection *, LibraryPhoto*, PhotoMetadata*)) library_photo_source_collection_real_notify_source_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->notify_baseline_reimported = (void (*) (LibraryPhotoSourceCollection *, LibraryPhoto*, PhotoMetadata*)) library_photo_source_collection_real_notify_baseline_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->fetch_by_numeric_id = (MediaSource* (*) (MediaSourceCollection *, gint64)) library_photo_source_collection_real_fetch_by_numeric_id;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->fetch_by_source_id = (MediaSource* (*) (MediaSourceCollection *, const gchar*)) library_photo_source_collection_real_fetch_by_source_id;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceCollectionClass *) klass)->get_event_source_ids = (GeeCollection* (*) (MediaSourceCollection *, EventID*)) library_photo_source_collection_real_get_event_source_ids;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((SourceCollectionClass *) klass)->has_backlink = (gboolean (*) (SourceCollection *, SourceBacklink*)) library_photo_source_collection_real_has_backlink;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((SourceCollectionClass *) klass)->remove_backlink = (void (*) (SourceCollection *, SourceBacklink*)) library_photo_source_collection_real_remove_backlink;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->master_reimported = library_photo_source_collection_real_master_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->editable_reimported = library_photo_source_collection_real_editable_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->baseline_reimported = library_photo_source_collection_real_baseline_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	((LibraryPhotoSourceCollectionClass *) klass)->source_reimported = library_photo_source_collection_real_source_reimported;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	MEDIA_SOURCE_COLLECTION_CLASS (klass)->get_transaction_controller = library_photo_source_collection_real_get_transaction_controller;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_MASTER_REIMPORTED_SIGNAL] = g_signal_new ("master-reimported", TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (LibraryPhotoSourceCollectionClass, master_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_MEDIA_METADATA, G_TYPE_NONE, 2, TYPE_LIBRARY_PHOTO, TYPE_PHOTO_METADATA);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_EDITABLE_REIMPORTED_SIGNAL] = g_signal_new ("editable-reimported", TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (LibraryPhotoSourceCollectionClass, editable_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_MEDIA_METADATA, G_TYPE_NONE, 2, TYPE_LIBRARY_PHOTO, TYPE_PHOTO_METADATA);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_BASELINE_REIMPORTED_SIGNAL] = g_signal_new ("baseline-reimported", TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (LibraryPhotoSourceCollectionClass, baseline_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_MEDIA_METADATA, G_TYPE_NONE, 2, TYPE_LIBRARY_PHOTO, TYPE_PHOTO_METADATA);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_signals[LIBRARY_PHOTO_SOURCE_COLLECTION_SOURCE_REIMPORTED_SIGNAL] = g_signal_new ("source-reimported", TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (LibraryPhotoSourceCollectionClass, source_reimported), NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_MEDIA_METADATA, G_TYPE_NONE, 2, TYPE_LIBRARY_PHOTO, TYPE_PHOTO_METADATA);
#line 38601 "Photo.c"
}


static void library_photo_source_collection_instance_init (LibraryPhotoSourceCollection * self) {
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeTreeMultiMap* _tmp2_;
	GeeHashMap* _tmp3_;
	GeeHashMap* _tmp4_;
	GeeTreeMultiMap* _tmp5_;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv = LIBRARY_PHOTO_SOURCE_COLLECTION_GET_PRIVATE (self);
#line 4482 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->_transaction_controller = NULL;
#line 4483 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = gee_hash_map_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
#line 4483 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->by_editable_file = _tmp0_;
#line 4485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = gee_hash_map_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
#line 4485 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->by_raw_development_file = _tmp1_;
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gee_tree_multi_map_new (G_TYPE_INT64, (GBoxedCopyFunc) _int64_dup, (GDestroyNotify) g_free, TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _int64_compare_gcompare_data_func, NULL, NULL, NULL, NULL, NULL);
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->filesize_to_photo = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_MULTI_MAP, GeeMultiMap);
#line 4489 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = gee_hash_map_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT64, (GBoxedCopyFunc) _int64_dup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, _int64_equal_gee_equal_data_func, NULL, NULL);
#line 4489 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->photo_to_master_filesize = _tmp3_;
#line 4491 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = gee_hash_map_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT64, (GBoxedCopyFunc) _int64_dup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, _int64_equal_gee_equal_data_func, NULL, NULL);
#line 4491 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->photo_to_editable_filesize = _tmp4_;
#line 4493 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = gee_tree_multi_map_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT64, (GBoxedCopyFunc) _int64_dup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 4493 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->photo_to_raw_development_filesize = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_MULTI_MAP, GeeMultiMap);
#line 38640 "Photo.c"
}


static void library_photo_source_collection_finalize (DataCollection * obj) {
	LibraryPhotoSourceCollection * self;
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection);
#line 4482 "/home/jens/Source/shotwell/src/Photo.vala"
	_transaction_controller_unref0 (self->priv->_transaction_controller);
#line 4483 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->by_editable_file);
#line 4485 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->by_raw_development_file);
#line 4487 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->filesize_to_photo);
#line 4489 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->photo_to_master_filesize);
#line 4491 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->photo_to_editable_filesize);
#line 4493 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->photo_to_raw_development_filesize);
#line 4463 "/home/jens/Source/shotwell/src/Photo.vala"
	DATA_COLLECTION_CLASS (library_photo_source_collection_parent_class)->finalize (obj);
#line 38664 "Photo.c"
}


GType library_photo_source_collection_get_type (void) {
	static volatile gsize library_photo_source_collection_type_id__volatile = 0;
	if (g_once_init_enter (&library_photo_source_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryPhotoSourceCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_photo_source_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryPhotoSourceCollection), 0, (GInstanceInitFunc) library_photo_source_collection_instance_init, NULL };
		GType library_photo_source_collection_type_id;
		library_photo_source_collection_type_id = g_type_register_static (TYPE_MEDIA_SOURCE_COLLECTION, "LibraryPhotoSourceCollection", &g_define_type_info, 0);
		g_once_init_leave (&library_photo_source_collection_type_id__volatile, library_photo_source_collection_type_id);
	}
	return library_photo_source_collection_type_id__volatile;
}


static void _library_photo_generate_thumbnails_one_shot_callback (gpointer self) {
#line 4985 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_generate_thumbnails ((LibraryPhoto*) self);
#line 38683 "Photo.c"
}


static LibraryPhoto* library_photo_construct (GType object_type, PhotoRow* row) {
	LibraryPhoto * self = NULL;
	PhotoRow* _tmp0_;
	OneShotScheduler* _tmp1_;
	PhotoRow* _tmp2_;
	guint64 _tmp3_;
	PhotoRow* _tmp7_;
	guint64 _tmp8_;
#line 4980 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_ROW (row), NULL);
#line 4981 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = row;
#line 4981 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (LibraryPhoto*) photo_construct (object_type, _tmp0_);
#line 4983 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->import_keywords);
#line 4983 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->import_keywords = NULL;
#line 4985 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = one_shot_scheduler_new ("LibraryPhoto", _library_photo_generate_thumbnails_one_shot_callback, self);
#line 4985 "/home/jens/Source/shotwell/src/Photo.vala"
	_one_shot_scheduler_unref0 (self->priv->thumbnail_scheduler);
#line 4985 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->thumbnail_scheduler = _tmp1_;
#line 4988 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = row;
#line 4988 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_->flags;
#line 4988 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp3_ & (LIBRARY_PHOTO_FLAG_TRASH | LIBRARY_PHOTO_FLAG_OFFLINE)) != ((guint64) 0)) {
#line 38717 "Photo.c"
		LibraryPhotoSourceCollection* _tmp4_;
		PhotoRow* _tmp5_;
		const gchar* _tmp6_;
#line 4989 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = library_photo_global;
#line 4989 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = row;
#line 4989 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp5_->backlinks;
#line 4989 "/home/jens/Source/shotwell/src/Photo.vala"
		data_source_rehydrate_backlinks (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_SOURCE, DataSource), G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_SOURCE_COLLECTION, SourceCollection), _tmp6_);
#line 38729 "Photo.c"
	}
#line 4991 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = row;
#line 4991 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_->flags;
#line 4991 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp8_ & (LIBRARY_PHOTO_FLAG_HIDDEN | LIBRARY_PHOTO_FLAG_FAVORITE)) != ((guint64) 0)) {
#line 38737 "Photo.c"
		PhotoRow* _tmp9_;
		guint64 _tmp10_;
#line 4992 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = row;
#line 4992 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = _tmp9_->flags;
#line 4992 "/home/jens/Source/shotwell/src/Photo.vala"
		library_photo_upgrade_rating_flags (self, _tmp10_);
#line 38746 "Photo.c"
	}
#line 4980 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 38750 "Photo.c"
}


static LibraryPhoto* library_photo_new (PhotoRow* row) {
#line 4980 "/home/jens/Source/shotwell/src/Photo.vala"
	return library_photo_construct (TYPE_LIBRARY_PHOTO, row);
#line 38757 "Photo.c"
}


static LibraryPhoto* library_photo_construct_from_import_params (GType object_type, PhotoImportParams* import_params) {
	LibraryPhoto * self = NULL;
	PhotoImportParams* _tmp0_;
	PhotoRow* _tmp1_;
	PhotoImportParams* _tmp2_;
	GeeCollection* _tmp3_;
	GeeCollection* _tmp4_;
	OneShotScheduler* _tmp5_;
	PhotoImportParams* _tmp6_;
	PhotoRow* _tmp7_;
	guint64 _tmp8_;
	PhotoImportParams* _tmp13_;
	PhotoRow* _tmp14_;
	guint64 _tmp15_;
#line 4995 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_PARAMS (import_params), NULL);
#line 4996 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = import_params;
#line 4996 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_->row;
#line 4996 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (LibraryPhoto*) photo_construct (object_type, _tmp1_);
#line 4998 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = import_params;
#line 4998 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_->keywords;
#line 4998 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 4998 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->import_keywords);
#line 4998 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->import_keywords = _tmp4_;
#line 4999 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = one_shot_scheduler_new ("LibraryPhoto", _library_photo_generate_thumbnails_one_shot_callback, self);
#line 4999 "/home/jens/Source/shotwell/src/Photo.vala"
	_one_shot_scheduler_unref0 (self->priv->thumbnail_scheduler);
#line 4999 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->thumbnail_scheduler = _tmp5_;
#line 5002 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = import_params;
#line 5002 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = _tmp6_->row;
#line 5002 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = _tmp7_->flags;
#line 5002 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp8_ & (LIBRARY_PHOTO_FLAG_TRASH | LIBRARY_PHOTO_FLAG_OFFLINE)) != ((guint64) 0)) {
#line 38807 "Photo.c"
		LibraryPhotoSourceCollection* _tmp9_;
		PhotoImportParams* _tmp10_;
		PhotoRow* _tmp11_;
		const gchar* _tmp12_;
#line 5003 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = library_photo_global;
#line 5003 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = import_params;
#line 5003 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = _tmp10_->row;
#line 5003 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = _tmp11_->backlinks;
#line 5003 "/home/jens/Source/shotwell/src/Photo.vala"
		data_source_rehydrate_backlinks (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_SOURCE, DataSource), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_SOURCE_COLLECTION, SourceCollection), _tmp12_);
#line 38822 "Photo.c"
	}
#line 5005 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = import_params;
#line 5005 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = _tmp13_->row;
#line 5005 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_->flags;
#line 5005 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp15_ & (LIBRARY_PHOTO_FLAG_HIDDEN | LIBRARY_PHOTO_FLAG_FAVORITE)) != ((guint64) 0)) {
#line 38832 "Photo.c"
		PhotoImportParams* _tmp16_;
		PhotoRow* _tmp17_;
		guint64 _tmp18_;
#line 5006 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = import_params;
#line 5006 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp17_ = _tmp16_->row;
#line 5006 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = _tmp17_->flags;
#line 5006 "/home/jens/Source/shotwell/src/Photo.vala"
		library_photo_upgrade_rating_flags (self, _tmp18_);
#line 38844 "Photo.c"
	}
#line 4995 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 38848 "Photo.c"
}


static LibraryPhoto* library_photo_new_from_import_params (PhotoImportParams* import_params) {
#line 4995 "/home/jens/Source/shotwell/src/Photo.vala"
	return library_photo_construct_from_import_params (TYPE_LIBRARY_PHOTO, import_params);
#line 38855 "Photo.c"
}


void library_photo_init (ProgressMonitor monitor, void* monitor_target) {
	LibraryPhotoSourceCollection* _tmp0_;
	GeeArrayList* all = NULL;
	PhotoTable* _tmp1_;
	PhotoTable* _tmp2_;
	GeeArrayList* _tmp3_;
	GeeArrayList* _tmp4_;
	GeeArrayList* all_photos = NULL;
	GeeArrayList* _tmp5_;
	GeeArrayList* trashed_photos = NULL;
	GeeArrayList* _tmp6_;
	GeeArrayList* offline_photos = NULL;
	GeeArrayList* _tmp7_;
	gint count = 0;
	GeeArrayList* _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	LibraryPhotoSourceCollection* _tmp34_;
	GeeArrayList* _tmp35_;
	GeeCollection* _tmp36_;
	GeeCollection* _tmp37_;
	LibraryPhotoSourceCollection* _tmp38_;
	GeeArrayList* _tmp39_;
	LibraryPhotoSourceCollection* _tmp40_;
	GeeArrayList* _tmp41_;
#line 5010 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_init_photo ();
#line 5012 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = library_photo_source_collection_new ();
#line 5012 "/home/jens/Source/shotwell/src/Photo.vala"
	_data_collection_unref0 (library_photo_global);
#line 5012 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_global = _tmp0_;
#line 5016 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_table_get_instance ();
#line 5016 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = _tmp1_;
#line 5016 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = photo_table_get_all (_tmp2_);
#line 5016 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = _tmp3_;
#line 5016 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp2_);
#line 5016 "/home/jens/Source/shotwell/src/Photo.vala"
	all = _tmp4_;
#line 5017 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 5017 "/home/jens/Source/shotwell/src/Photo.vala"
	all_photos = _tmp5_;
#line 5018 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 5018 "/home/jens/Source/shotwell/src/Photo.vala"
	trashed_photos = _tmp6_;
#line 5019 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 5019 "/home/jens/Source/shotwell/src/Photo.vala"
	offline_photos = _tmp7_;
#line 5020 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = all;
#line 5020 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 5020 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = _tmp9_;
#line 5020 "/home/jens/Source/shotwell/src/Photo.vala"
	count = _tmp10_;
#line 38924 "Photo.c"
	{
		gint ctr = 0;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
		ctr = 0;
#line 38929 "Photo.c"
		{
			gboolean _tmp11_ = FALSE;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = TRUE;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 38936 "Photo.c"
				gint _tmp13_;
				gint _tmp14_;
				PhotoRow* row = NULL;
				GeeArrayList* _tmp15_;
				gint _tmp16_;
				gpointer _tmp17_;
				LibraryPhoto* photo = NULL;
				PhotoRow* _tmp18_;
				LibraryPhoto* _tmp19_;
				guint64 flags = 0ULL;
				PhotoRow* _tmp20_;
				guint64 _tmp21_;
				guint64 _tmp22_;
				ProgressMonitor _tmp30_;
				void* _tmp30__target;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp11_) {
#line 38954 "Photo.c"
					gint _tmp12_;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp12_ = ctr;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
					ctr = _tmp12_ + 1;
#line 38960 "Photo.c"
				}
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = FALSE;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = ctr;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = count;
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp13_ < _tmp14_)) {
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 38972 "Photo.c"
				}
#line 5022 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = all;
#line 5022 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = ctr;
#line 5022 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp16_);
#line 5022 "/home/jens/Source/shotwell/src/Photo.vala"
				row = (PhotoRow*) _tmp17_;
#line 5023 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = row;
#line 5023 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp19_ = library_photo_new (_tmp18_);
#line 5023 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = _tmp19_;
#line 5024 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = row;
#line 5024 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = _tmp20_->flags;
#line 5024 "/home/jens/Source/shotwell/src/Photo.vala"
				flags = _tmp21_;
#line 5026 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = flags;
#line 5026 "/home/jens/Source/shotwell/src/Photo.vala"
				if ((_tmp22_ & LIBRARY_PHOTO_FLAG_TRASH) != ((guint64) 0)) {
#line 38998 "Photo.c"
					GeeArrayList* _tmp23_;
					LibraryPhoto* _tmp24_;
#line 5027 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp23_ = trashed_photos;
#line 5027 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp24_ = photo;
#line 5027 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp24_);
#line 39007 "Photo.c"
				} else {
					guint64 _tmp25_;
#line 5028 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp25_ = flags;
#line 5028 "/home/jens/Source/shotwell/src/Photo.vala"
					if ((_tmp25_ & LIBRARY_PHOTO_FLAG_OFFLINE) != ((guint64) 0)) {
#line 39014 "Photo.c"
						GeeArrayList* _tmp26_;
						LibraryPhoto* _tmp27_;
#line 5029 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp26_ = offline_photos;
#line 5029 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp27_ = photo;
#line 5029 "/home/jens/Source/shotwell/src/Photo.vala"
						gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp27_);
#line 39023 "Photo.c"
					} else {
						GeeArrayList* _tmp28_;
						LibraryPhoto* _tmp29_;
#line 5031 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp28_ = all_photos;
#line 5031 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp29_ = photo;
#line 5031 "/home/jens/Source/shotwell/src/Photo.vala"
						gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp29_);
#line 39033 "Photo.c"
					}
				}
#line 5033 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = monitor;
#line 5033 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30__target = monitor_target;
#line 5033 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp30_ != NULL) {
#line 39042 "Photo.c"
					ProgressMonitor _tmp31_;
					void* _tmp31__target;
					gint _tmp32_;
					gint _tmp33_;
#line 5034 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31_ = monitor;
#line 5034 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31__target = monitor_target;
#line 5034 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp32_ = ctr;
#line 5034 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp33_ = count;
#line 5034 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp31_ ((guint64) _tmp32_, (guint64) _tmp33_, TRUE, _tmp31__target);
#line 39057 "Photo.c"
				}
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 5021 "/home/jens/Source/shotwell/src/Photo.vala"
				_photo_row_unref0 (row);
#line 39063 "Photo.c"
			}
		}
	}
#line 5037 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = library_photo_global;
#line 5037 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = all_photos;
#line 5037 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = data_collection_add_many (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, GEE_TYPE_COLLECTION, GeeCollection), NULL, NULL);
#line 5037 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = _tmp36_;
#line 5037 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp37_);
#line 5038 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = library_photo_global;
#line 5038 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = trashed_photos;
#line 5038 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_collection_add_many_to_trash (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5039 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = library_photo_global;
#line 5039 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = offline_photos;
#line 5039 "/home/jens/Source/shotwell/src/Photo.vala"
	media_source_collection_add_many_to_offline (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5009 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (offline_photos);
#line 5009 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (trashed_photos);
#line 5009 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (all_photos);
#line 5009 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (all);
#line 39097 "Photo.c"
}


void library_photo_terminate (void) {
#line 5043 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_terminate_photo ();
#line 39104 "Photo.c"
}


ImportResult library_photo_import_create (PhotoImportParams* params, LibraryPhoto* * photo) {
	LibraryPhoto* _vala_photo = NULL;
	ImportResult result = 0;
	PhotoID photo_id = {0};
	PhotoTable* _tmp0_;
	PhotoTable* _tmp1_;
	PhotoImportParams* _tmp2_;
	PhotoRow* _tmp3_;
	PhotoID _tmp4_ = {0};
	PhotoID _tmp5_;
	gboolean _tmp6_;
	PhotoImportParams* _tmp7_;
	LibraryPhoto* _tmp8_;
#line 5050 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_PARAMS (params), 0);
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_table_get_instance ();
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = params;
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_->row;
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_table_add (_tmp1_, _tmp3_, &_tmp4_);
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_;
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp1_);
#line 5052 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id = _tmp5_;
#line 5053 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = photo_id_is_invalid (&photo_id);
#line 5053 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_) {
#line 5054 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_vala_photo);
#line 5054 "/home/jens/Source/shotwell/src/Photo.vala"
		_vala_photo = NULL;
#line 5056 "/home/jens/Source/shotwell/src/Photo.vala"
		result = IMPORT_RESULT_DATABASE_ERROR;
#line 5056 "/home/jens/Source/shotwell/src/Photo.vala"
		if (photo) {
#line 5056 "/home/jens/Source/shotwell/src/Photo.vala"
			*photo = _vala_photo;
#line 39153 "Photo.c"
		} else {
#line 5056 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_vala_photo);
#line 39157 "Photo.c"
		}
#line 5056 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 39161 "Photo.c"
	}
#line 5060 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = params;
#line 5060 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = library_photo_new_from_import_params (_tmp7_);
#line 5060 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_vala_photo);
#line 5060 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_photo = _tmp8_;
#line 5062 "/home/jens/Source/shotwell/src/Photo.vala"
	result = IMPORT_RESULT_SUCCESS;
#line 5062 "/home/jens/Source/shotwell/src/Photo.vala"
	if (photo) {
#line 5062 "/home/jens/Source/shotwell/src/Photo.vala"
		*photo = _vala_photo;
#line 39177 "Photo.c"
	} else {
#line 5062 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_vala_photo);
#line 39181 "Photo.c"
	}
#line 5062 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 39185 "Photo.c"
}


void library_photo_import_failed (LibraryPhoto* photo) {
	GError * _inner_error_ = NULL;
#line 5065 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (photo));
#line 39193 "Photo.c"
	{
		PhotoTable* _tmp0_;
		PhotoTable* _tmp1_;
		LibraryPhoto* _tmp2_;
		PhotoID _tmp3_ = {0};
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = photo_table_get_instance ();
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp0_;
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = photo;
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_get_photo_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_PHOTO, Photo), &_tmp3_);
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_table_remove (_tmp1_, &_tmp3_, &_inner_error_);
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		_database_table_unref0 (_tmp1_);
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 39215 "Photo.c"
				goto __catch419_database_error;
			}
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 5067 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 39224 "Photo.c"
		}
	}
	goto __finally419;
	__catch419_database_error:
	{
		GError* err = NULL;
		GError* _tmp4_;
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 5069 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = err;
#line 5069 "/home/jens/Source/shotwell/src/Photo.vala"
		app_window_database_error (_tmp4_);
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 39242 "Photo.c"
	}
	__finally419:
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 5066 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 39253 "Photo.c"
	}
}


static void library_photo_real_notify_master_reimported (Photo* base, PhotoMetadata* metadata) {
	LibraryPhoto * self;
	PhotoMetadata* _tmp0_;
	LibraryPhotoSourceCollection* _tmp1_;
	PhotoMetadata* _tmp2_;
#line 5073 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5073 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 5074 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 5074 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_CLASS (library_photo_parent_class)->notify_master_reimported (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), _tmp0_);
#line 5076 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = library_photo_global;
#line 5076 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 5076 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_notify_master_reimported (_tmp1_, self, _tmp2_);
#line 39277 "Photo.c"
}


static void library_photo_real_notify_editable_reimported (Photo* base, PhotoMetadata* metadata) {
	LibraryPhoto * self;
	PhotoMetadata* _tmp0_;
	LibraryPhotoSourceCollection* _tmp1_;
	PhotoMetadata* _tmp2_;
#line 5079 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5079 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 5080 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 5080 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_CLASS (library_photo_parent_class)->notify_editable_reimported (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), _tmp0_);
#line 5082 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = library_photo_global;
#line 5082 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 5082 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_notify_editable_reimported (_tmp1_, self, _tmp2_);
#line 39300 "Photo.c"
}


static void library_photo_real_notify_source_reimported (Photo* base, PhotoMetadata* metadata) {
	LibraryPhoto * self;
	PhotoMetadata* _tmp0_;
	LibraryPhotoSourceCollection* _tmp1_;
	PhotoMetadata* _tmp2_;
#line 5085 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5085 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 5086 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 5086 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_CLASS (library_photo_parent_class)->notify_source_reimported (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), _tmp0_);
#line 5088 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = library_photo_global;
#line 5088 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 5088 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_notify_source_reimported (_tmp1_, self, _tmp2_);
#line 39323 "Photo.c"
}


static void library_photo_real_notify_baseline_reimported (Photo* base, PhotoMetadata* metadata) {
	LibraryPhoto * self;
	PhotoMetadata* _tmp0_;
	LibraryPhotoSourceCollection* _tmp1_;
	PhotoMetadata* _tmp2_;
#line 5091 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5091 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 5092 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 5092 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_CLASS (library_photo_parent_class)->notify_baseline_reimported (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), _tmp0_);
#line 5094 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = library_photo_global;
#line 5094 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = metadata;
#line 5094 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_collection_notify_baseline_reimported (_tmp1_, self, _tmp2_);
#line 39346 "Photo.c"
}


static void library_photo_generate_thumbnails (LibraryPhoto* self) {
	GError * _inner_error_ = NULL;
#line 5097 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (self));
#line 39354 "Photo.c"
	{
#line 5099 "/home/jens/Source/shotwell/src/Photo.vala"
		thumbnail_cache_import_from_source (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), TRUE, &_inner_error_);
#line 5099 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 39360 "Photo.c"
			goto __catch420_g_error;
		}
	}
	goto __finally420;
	__catch420_g_error:
	{
		GError* err = NULL;
		gchar* _tmp0_;
		gchar* _tmp1_;
		GError* _tmp2_;
		const gchar* _tmp3_;
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 5101 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 5101 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = _tmp0_;
#line 5101 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = err;
#line 5101 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_->message;
#line 5101 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:5101: Unable to generate thumbnails for %s: %s", _tmp1_, _tmp3_);
#line 5101 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp1_);
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 39390 "Photo.c"
	}
	__finally420:
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 5098 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 39401 "Photo.c"
	}
#line 5105 "/home/jens/Source/shotwell/src/Photo.vala"
	thumbnail_source_notify_thumbnail_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource));
#line 39405 "Photo.c"
}


GeeCollection* library_photo_get_import_keywords (LibraryPhoto* self) {
	GeeCollection* result = NULL;
	GeeCollection* _tmp0_;
	GeeCollection* _tmp1_;
#line 5109 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO (self), NULL);
#line 5110 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->import_keywords;
#line 5110 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 5110 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 5110 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 39423 "Photo.c"
}


void library_photo_clear_import_keywords (LibraryPhoto* self) {
#line 5113 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (self));
#line 5114 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->import_keywords);
#line 5114 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->import_keywords = NULL;
#line 39434 "Photo.c"
}


static void library_photo_real_notify_altered (DataObject* base, Alteration* alteration) {
	LibraryPhoto * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	Alteration* _tmp5_;
#line 5117 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5117 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_ALTERATION (alteration));
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = self->priv->block_thumbnail_generation;
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp1_) {
#line 39451 "Photo.c"
		Alteration* _tmp2_;
		gboolean _tmp3_;
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = alteration;
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = alteration_has_subject (_tmp2_, "image");
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp3_;
#line 39460 "Photo.c"
	} else {
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = FALSE;
#line 39464 "Photo.c"
	}
#line 5119 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_) {
#line 39468 "Photo.c"
		OneShotScheduler* _tmp4_;
#line 5120 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = self->priv->thumbnail_scheduler;
#line 5120 "/home/jens/Source/shotwell/src/Photo.vala"
		one_shot_scheduler_at_priority_idle (_tmp4_, G_PRIORITY_LOW);
#line 39474 "Photo.c"
	}
#line 5122 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = alteration;
#line 5122 "/home/jens/Source/shotwell/src/Photo.vala"
	DATA_OBJECT_CLASS (library_photo_parent_class)->notify_altered (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), TYPE_DATA_OBJECT, DataObject), _tmp5_);
#line 39480 "Photo.c"
}


static GdkPixbuf* library_photo_real_get_preview_pixbuf (MediaSource* base, Scaling* scaling, GError** error) {
	LibraryPhoto * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* pixbuf = NULL;
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
	GError * _inner_error_ = NULL;
#line 5125 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5125 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (scaling != NULL, NULL);
#line 5126 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = thumbnail_source_get_thumbnail (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), (gint) THUMBNAIL_CACHE_SIZE_BIG, &_inner_error_);
#line 5126 "/home/jens/Source/shotwell/src/Photo.vala"
	pixbuf = _tmp0_;
#line 5126 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5126 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5126 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39505 "Photo.c"
	}
#line 5128 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = scaling_perform_on_pixbuf (scaling, pixbuf, GDK_INTERP_BILINEAR, TRUE);
#line 5128 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp1_;
#line 5128 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (pixbuf);
#line 5128 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 39515 "Photo.c"
}


static void library_photo_real_rotate (Photo* base, Rotation rotation) {
	LibraryPhoto * self;
	Rotation _tmp0_;
	GError * _inner_error_ = NULL;
#line 5131 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5133 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->block_thumbnail_generation = TRUE;
#line 5134 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = rotation;
#line 5134 "/home/jens/Source/shotwell/src/Photo.vala"
	PHOTO_CLASS (library_photo_parent_class)->rotate (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), _tmp0_);
#line 5135 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->block_thumbnail_generation = FALSE;
#line 39533 "Photo.c"
	{
		Rotation _tmp1_;
#line 5143 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = rotation;
#line 5143 "/home/jens/Source/shotwell/src/Photo.vala"
		thumbnail_cache_rotate (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), _tmp1_, &_inner_error_);
#line 5143 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 39542 "Photo.c"
			goto __catch421_g_error;
		}
	}
	goto __finally421;
	__catch421_g_error:
	{
		GError* err = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		GError* _tmp4_;
		const gchar* _tmp5_;
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 5146 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 5146 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_;
#line 5146 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = err;
#line 5146 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = _tmp4_->message;
#line 5146 "/home/jens/Source/shotwell/src/Photo.vala"
		g_warning ("Photo.vala:5146: Unable to update thumbnails for %s: %s", _tmp3_, _tmp5_);
#line 5146 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_free0 (_tmp3_);
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 39572 "Photo.c"
	}
	__finally421:
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 5142 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 39583 "Photo.c"
	}
#line 5149 "/home/jens/Source/shotwell/src/Photo.vala"
	thumbnail_source_notify_thumbnail_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource));
#line 39587 "Photo.c"
}


static GdkPixbuf* library_photo_real_get_thumbnail (ThumbnailSource* base, gint scale, GError** error) {
	LibraryPhoto * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	gint _tmp1_;
	GdkPixbuf* _tmp2_;
	GdkPixbuf* _tmp3_;
	GError * _inner_error_ = NULL;
#line 5153 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = scale;
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = thumbnail_cache_fetch (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), _tmp1_, &_inner_error_);
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp2_;
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39613 "Photo.c"
	}
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp0_;
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = NULL;
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp0_);
#line 5154 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 39625 "Photo.c"
}


static void _library_photo_on_duplicate_progress_gfile_progress_callback (gint64 current_num_bytes, gint64 total_num_bytes, gpointer self) {
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_on_duplicate_progress ((LibraryPhoto*) self, current_num_bytes, total_num_bytes);
#line 39632 "Photo.c"
}


static void library_photo_duplicate_backing_photo (LibraryPhoto* self, BackingPhotoRow* backing, BackingPhotoID* result, GError** error) {
	BackingPhotoID backing_id = {0};
	gboolean _tmp0_ = FALSE;
	BackingPhotoRow* _tmp1_;
	GFile* file = NULL;
	BackingPhotoRow* _tmp4_;
	const gchar* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	gboolean _tmp8_;
	GError * _inner_error_ = NULL;
#line 5159 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (self));
#line 5159 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((backing == NULL) || IS_BACKING_PHOTO_ROW (backing));
#line 5160 "/home/jens/Source/shotwell/src/Photo.vala"
	backing_photo_id_init (&backing_id, BACKING_PHOTO_ID_INVALID);
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = backing;
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_ == NULL) {
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = TRUE;
#line 39659 "Photo.c"
	} else {
		BackingPhotoRow* _tmp2_;
		const gchar* _tmp3_;
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = backing;
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = _tmp2_->filepath;
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp0_ = _tmp3_ == NULL;
#line 39669 "Photo.c"
	}
#line 5161 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_) {
#line 5162 "/home/jens/Source/shotwell/src/Photo.vala"
		*result = backing_id;
#line 5162 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 39677 "Photo.c"
	}
#line 5164 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = backing;
#line 5164 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_->filepath;
#line 5164 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = g_file_new_for_path (_tmp5_);
#line 5164 "/home/jens/Source/shotwell/src/Photo.vala"
	file = _tmp6_;
#line 5165 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = file;
#line 5165 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = g_file_query_exists (_tmp7_, NULL);
#line 5165 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_) {
#line 39693 "Photo.c"
		GFile* dupe_file = NULL;
		GFile* _tmp9_;
		GFile* _tmp10_;
		DetectedPhotoInformation* detected = NULL;
		BackingPhotoRow* state = NULL;
		GFile* _tmp11_;
		DetectedPhotoInformation* _tmp12_ = NULL;
		BackingPhotoRow* _tmp13_;
		BackingPhotoRow* _tmp14_;
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp9_ = file;
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = library_files_duplicate (_tmp9_, _library_photo_on_duplicate_progress_gfile_progress_callback, self, TRUE, &_inner_error_);
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
		dupe_file = _tmp10_;
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 5166 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 39717 "Photo.c"
		}
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = dupe_file;
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp13_ = photo_query_backing_photo_row (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), _tmp11_, PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5, &_tmp12_, &_inner_error_);
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
		detected = _tmp12_;
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
		state = _tmp13_;
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
			g_propagate_error (error, _inner_error_);
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
			_detected_photo_information_unref0 (detected);
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (dupe_file);
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (file);
#line 5169 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 39741 "Photo.c"
		}
#line 5171 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp14_ = state;
#line 5171 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp14_ != NULL) {
#line 39747 "Photo.c"
			BackingPhotoTable* _tmp15_;
			BackingPhotoTable* _tmp16_;
			BackingPhotoRow* _tmp17_;
			BackingPhotoRow* _tmp18_;
			BackingPhotoID _tmp19_;
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp15_ = backing_photo_table_get_instance ();
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp16_ = _tmp15_;
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp17_ = state;
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
			backing_photo_table_add (_tmp16_, _tmp17_, &_inner_error_);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
			_database_table_unref0 (_tmp16_);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
				g_propagate_error (error, _inner_error_);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
				_backing_photo_row_unref0 (state);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
				_detected_photo_information_unref0 (detected);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (dupe_file);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (file);
#line 5172 "/home/jens/Source/shotwell/src/Photo.vala"
				return;
#line 39777 "Photo.c"
			}
#line 5173 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp18_ = state;
#line 5173 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp19_ = _tmp18_->id;
#line 5173 "/home/jens/Source/shotwell/src/Photo.vala"
			backing_id = _tmp19_;
#line 39785 "Photo.c"
		}
#line 5165 "/home/jens/Source/shotwell/src/Photo.vala"
		_backing_photo_row_unref0 (state);
#line 5165 "/home/jens/Source/shotwell/src/Photo.vala"
		_detected_photo_information_unref0 (detected);
#line 5165 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dupe_file);
#line 39793 "Photo.c"
	}
#line 5177 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = backing_id;
#line 5177 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (file);
#line 5177 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 39801 "Photo.c"
}


LibraryPhoto* library_photo_duplicate (LibraryPhoto* self, GError** error) {
	LibraryPhoto* result = NULL;
	GFile* dupe_file = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GFile* _tmp2_;
	GFile* _tmp3_;
	BackingPhotoID dupe_editable_id = {0};
	BackingPhotoRow* _tmp4_;
	BackingPhotoRow* _tmp5_;
	BackingPhotoID _tmp6_ = {0};
	BackingPhotoID _tmp7_;
	BackingPhotoID dupe_raw_shotwell_id = {0};
	BackingPhotoRow* _tmp8_;
	BackingPhotoRow* _tmp9_;
	BackingPhotoID _tmp10_ = {0};
	BackingPhotoID _tmp11_;
	BackingPhotoID dupe_raw_camera_id = {0};
	BackingPhotoRow* _tmp12_;
	BackingPhotoRow* _tmp13_;
	BackingPhotoID _tmp14_ = {0};
	BackingPhotoID _tmp15_;
	BackingPhotoID dupe_raw_embedded_id = {0};
	BackingPhotoRow* _tmp16_;
	BackingPhotoRow* _tmp17_;
	BackingPhotoID _tmp18_ = {0};
	BackingPhotoID _tmp19_;
	PhotoID dupe_id = {0};
	PhotoTable* _tmp20_;
	PhotoTable* _tmp21_;
	PhotoID _tmp22_ = {0};
	GFile* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	BackingPhotoID _tmp26_;
	BackingPhotoID _tmp27_;
	BackingPhotoID _tmp28_;
	BackingPhotoID _tmp29_;
	PhotoID _tmp30_ = {0};
	PhotoID _tmp31_;
	PhotoRow* dupe_row = NULL;
	PhotoTable* _tmp32_;
	PhotoTable* _tmp33_;
	PhotoID _tmp34_;
	PhotoRow* _tmp35_;
	PhotoRow* _tmp36_;
	LibraryPhoto* dupe = NULL;
	PhotoRow* _tmp37_;
	LibraryPhoto* _tmp38_;
	LibraryPhoto* _tmp39_;
	LibraryPhotoSourceCollection* _tmp40_;
	LibraryPhoto* _tmp41_;
	LibraryPhoto* _tmp42_;
	Event* _tmp43_;
	Event* _tmp44_;
	gboolean _tmp45_;
	GeeCollection* tags = NULL;
	TagSourceCollection* _tmp50_;
	GeeList* _tmp51_;
	GeeCollection* _tmp52_;
	GError * _inner_error_ = NULL;
#line 5180 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO (self), NULL);
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = library_files_duplicate (_tmp1_, _library_photo_on_duplicate_progress_gfile_progress_callback, self, TRUE, &_inner_error_);
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = _tmp2_;
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp1_);
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_file = _tmp3_;
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5182 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39886 "Photo.c"
	}
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo_get_editable_photo_row (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo));
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = _tmp4_;
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_duplicate_backing_photo (self, _tmp5_, &_tmp6_, &_inner_error_);
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = _tmp6_;
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp5_);
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_editable_id = _tmp7_;
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dupe_file);
#line 5185 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39908 "Photo.c"
	}
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = photo_get_raw_development_photo_row (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), RAW_DEVELOPER_SHOTWELL);
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = _tmp8_;
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_duplicate_backing_photo (self, _tmp9_, &_tmp10_, &_inner_error_);
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = _tmp10_;
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp9_);
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_raw_shotwell_id = _tmp11_;
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dupe_file);
#line 5186 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39930 "Photo.c"
	}
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = photo_get_raw_development_photo_row (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), RAW_DEVELOPER_CAMERA);
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = _tmp12_;
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_duplicate_backing_photo (self, _tmp13_, &_tmp14_, &_inner_error_);
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = _tmp14_;
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp13_);
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_raw_camera_id = _tmp15_;
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dupe_file);
#line 5188 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39952 "Photo.c"
	}
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp16_ = photo_get_raw_development_photo_row (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), RAW_DEVELOPER_EMBEDDED);
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = _tmp16_;
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_duplicate_backing_photo (self, _tmp17_, &_tmp18_, &_inner_error_);
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp19_ = _tmp18_;
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	_backing_photo_row_unref0 (_tmp17_);
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_raw_embedded_id = _tmp19_;
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (dupe_file);
#line 5190 "/home/jens/Source/shotwell/src/Photo.vala"
		return NULL;
#line 39974 "Photo.c"
	}
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = photo_table_get_instance ();
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = _tmp20_;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_photo_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), &_tmp22_);
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = dupe_file;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp24_ = g_file_get_path (_tmp23_);
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp25_ = _tmp24_;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = dupe_editable_id;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = dupe_raw_shotwell_id;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp28_ = dupe_raw_camera_id;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = dupe_raw_embedded_id;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_table_duplicate (_tmp21_, &_tmp22_, _tmp25_, &_tmp26_, &_tmp27_, &_tmp28_, &_tmp29_, &_tmp30_);
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp31_ = _tmp30_;
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_free0 (_tmp25_);
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp21_);
#line 5194 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_id = _tmp31_;
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp32_ = photo_table_get_instance ();
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp33_ = _tmp32_;
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp34_ = dupe_id;
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp35_ = photo_table_get_row (_tmp33_, &_tmp34_);
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp36_ = _tmp35_;
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	_database_table_unref0 (_tmp33_);
#line 5196 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe_row = _tmp36_;
#line 5199 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp37_ = dupe_row;
#line 5199 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp38_ = library_photo_new (_tmp37_);
#line 5199 "/home/jens/Source/shotwell/src/Photo.vala"
	dupe = _tmp38_;
#line 5202 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = dupe;
#line 5202 "/home/jens/Source/shotwell/src/Photo.vala"
	thumbnail_cache_duplicate (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource));
#line 5205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = library_photo_global;
#line 5205 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp41_ = dupe;
#line 5205 "/home/jens/Source/shotwell/src/Photo.vala"
	data_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, TYPE_DATA_OBJECT, DataObject));
#line 5208 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp42_ = dupe;
#line 5208 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp43_ = media_source_get_event (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, TYPE_MEDIA_SOURCE, MediaSource));
#line 5208 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp44_ = _tmp43_;
#line 5208 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp45_ = _tmp44_ != NULL;
#line 5208 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (_tmp44_);
#line 5208 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp45_) {
#line 40048 "Photo.c"
		LibraryPhoto* _tmp46_;
		Event* _tmp47_;
		Event* _tmp48_;
		LibraryPhoto* _tmp49_;
#line 5209 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp46_ = dupe;
#line 5209 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp47_ = media_source_get_event (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, TYPE_MEDIA_SOURCE, MediaSource));
#line 5209 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp48_ = _tmp47_;
#line 5209 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp49_ = dupe;
#line 5209 "/home/jens/Source/shotwell/src/Photo.vala"
		event_attach (_tmp48_, G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, TYPE_MEDIA_SOURCE, MediaSource));
#line 5209 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp48_);
#line 40065 "Photo.c"
	}
#line 5212 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp50_ = tag_global;
#line 5212 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp51_ = tag_source_collection_fetch_for_source (_tmp50_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5212 "/home/jens/Source/shotwell/src/Photo.vala"
	tags = G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, GEE_TYPE_COLLECTION, GeeCollection);
#line 5213 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp52_ = tags;
#line 5213 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp52_ != NULL) {
#line 40077 "Photo.c"
		{
			GeeIterator* _tag_it = NULL;
			GeeCollection* _tmp53_;
			GeeIterator* _tmp54_;
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp53_ = tags;
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp54_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_it = _tmp54_;
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 40090 "Photo.c"
				GeeIterator* _tmp55_;
				gboolean _tmp56_;
				Tag* tag = NULL;
				GeeIterator* _tmp57_;
				gpointer _tmp58_;
				Tag* _tmp59_;
				LibraryPhoto* _tmp60_;
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp55_ = _tag_it;
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp56_ = gee_iterator_next (_tmp55_);
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp56_) {
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 40106 "Photo.c"
				}
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp57_ = _tag_it;
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp58_ = gee_iterator_get (_tmp57_);
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				tag = (Tag*) _tmp58_;
#line 5215 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp59_ = tag;
#line 5215 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp60_ = dupe;
#line 5215 "/home/jens/Source/shotwell/src/Photo.vala"
				tag_attach (_tmp59_, G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, TYPE_MEDIA_SOURCE, MediaSource));
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (tag);
#line 40122 "Photo.c"
			}
#line 5214 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tag_it);
#line 40126 "Photo.c"
		}
	}
#line 5219 "/home/jens/Source/shotwell/src/Photo.vala"
	result = dupe;
#line 5219 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (tags);
#line 5219 "/home/jens/Source/shotwell/src/Photo.vala"
	_photo_row_unref0 (dupe_row);
#line 5219 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (dupe_file);
#line 5219 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40139 "Photo.c"
}


static void library_photo_on_duplicate_progress (LibraryPhoto* self, gint64 current, gint64 total) {
#line 5222 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (self));
#line 5223 "/home/jens/Source/shotwell/src/Photo.vala"
	spin_event_loop ();
#line 40148 "Photo.c"
}


static void library_photo_upgrade_rating_flags (LibraryPhoto* self, guint64 flags) {
	guint64 _tmp0_;
	guint64 _tmp1_;
#line 5226 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO (self));
#line 5227 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = flags;
#line 5227 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp0_ & LIBRARY_PHOTO_FLAG_HIDDEN) != ((guint64) 0)) {
#line 5228 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), RATING_REJECTED);
#line 5229 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_remove_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_HIDDEN, NULL);
#line 40165 "Photo.c"
	}
#line 5232 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = flags;
#line 5232 "/home/jens/Source/shotwell/src/Photo.vala"
	if ((_tmp1_ & LIBRARY_PHOTO_FLAG_FAVORITE) != ((guint64) 0)) {
#line 5233 "/home/jens/Source/shotwell/src/Photo.vala"
		media_source_set_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource), RATING_FIVE);
#line 5234 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_remove_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_FAVORITE, NULL);
#line 40175 "Photo.c"
	}
}


static gboolean library_photo_real_is_trashed (MediaSource* base) {
	LibraryPhoto * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 5239 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5240 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_is_flag_set (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_TRASH);
#line 5240 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 5240 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40192 "Photo.c"
}


static void library_photo_real_trash (MediaSource* base) {
	LibraryPhoto * self;
#line 5243 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5244 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_add_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_TRASH, NULL);
#line 40202 "Photo.c"
}


static void library_photo_real_untrash (MediaSource* base) {
	LibraryPhoto * self;
#line 5247 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5248 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_remove_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_TRASH, NULL);
#line 40212 "Photo.c"
}


static gboolean library_photo_real_is_offline (Monitorable* base) {
	LibraryPhoto * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 5251 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5252 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_is_flag_set (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_OFFLINE);
#line 5252 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 5252 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40228 "Photo.c"
}


static void library_photo_real_mark_offline (Monitorable* base) {
	LibraryPhoto * self;
#line 5255 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5256 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_add_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_OFFLINE, NULL);
#line 40238 "Photo.c"
}


static void library_photo_real_mark_online (Monitorable* base) {
	LibraryPhoto * self;
#line 5259 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5260 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_remove_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_OFFLINE, NULL);
#line 40248 "Photo.c"
}


static gboolean library_photo_real_is_flagged (Flaggable* base) {
	LibraryPhoto * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 5263 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5264 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = photo_is_flag_set (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_FLAGGED);
#line 5264 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp0_;
#line 5264 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40264 "Photo.c"
}


static void library_photo_real_mark_flagged (Flaggable* base) {
	LibraryPhoto * self;
	Alteration* _tmp0_;
	Alteration* _tmp1_;
#line 5267 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = alteration_new ("metadata", "flagged");
#line 5268 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 5268 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_add_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_FLAGGED, _tmp1_);
#line 5268 "/home/jens/Source/shotwell/src/Photo.vala"
	_alteration_unref0 (_tmp1_);
#line 40282 "Photo.c"
}


static void library_photo_real_mark_unflagged (Flaggable* base) {
	LibraryPhoto * self;
	Alteration* _tmp0_;
	Alteration* _tmp1_;
#line 5271 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5272 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = alteration_new ("metadata", "flagged");
#line 5272 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _tmp0_;
#line 5272 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_remove_flags (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), LIBRARY_PHOTO_FLAG_FLAGGED, _tmp1_);
#line 5272 "/home/jens/Source/shotwell/src/Photo.vala"
	_alteration_unref0 (_tmp1_);
#line 40300 "Photo.c"
}


static gboolean library_photo_real_internal_delete_backing (DataSource* base, GError** error) {
	LibraryPhoto * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp3_;
	GError * _inner_error_ = NULL;
#line 5275 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5278 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = DATA_SOURCE_CLASS (library_photo_parent_class)->internal_delete_backing (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), TYPE_DATA_SOURCE, DataSource), &_inner_error_);
#line 5278 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _tmp1_;
#line 5278 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 40319 "Photo.c"
		gboolean _tmp2_ = FALSE;
#line 5278 "/home/jens/Source/shotwell/src/Photo.vala"
		g_propagate_error (error, _inner_error_);
#line 5278 "/home/jens/Source/shotwell/src/Photo.vala"
		return _tmp2_;
#line 40325 "Photo.c"
	}
#line 5278 "/home/jens/Source/shotwell/src/Photo.vala"
	if (!_tmp0_) {
#line 5279 "/home/jens/Source/shotwell/src/Photo.vala"
		result = FALSE;
#line 5279 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 40333 "Photo.c"
	}
#line 5281 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = media_source_delete_original_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5281 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp3_;
#line 5281 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40341 "Photo.c"
}


static void library_photo_real_destroy (DataSource* base) {
	LibraryPhoto * self;
	PhotoID photo_id = {0};
	PhotoID _tmp0_ = {0};
	GError * _inner_error_ = NULL;
#line 5284 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5285 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_get_photo_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), &_tmp0_);
#line 5285 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id = _tmp0_;
#line 5288 "/home/jens/Source/shotwell/src/Photo.vala"
	thumbnail_cache_remove (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource));
#line 40358 "Photo.c"
	{
		PhotoTable* _tmp1_;
		PhotoTable* _tmp2_;
		PhotoID _tmp3_;
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp1_ = photo_table_get_instance ();
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = _tmp1_;
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_id;
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_table_remove (_tmp2_, &_tmp3_, &_inner_error_);
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
		_database_table_unref0 (_tmp2_);
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 40377 "Photo.c"
				goto __catch422_database_error;
			}
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
			g_clear_error (&_inner_error_);
#line 5294 "/home/jens/Source/shotwell/src/Photo.vala"
			return;
#line 40386 "Photo.c"
		}
	}
	goto __finally422;
	__catch422_database_error:
	{
		GError* err = NULL;
		GError* _tmp4_;
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
		err = _inner_error_;
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
		_inner_error_ = NULL;
#line 5296 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = err;
#line 5296 "/home/jens/Source/shotwell/src/Photo.vala"
		app_window_database_error (_tmp4_);
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_error_free0 (err);
#line 40404 "Photo.c"
	}
	__finally422:
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
		g_clear_error (&_inner_error_);
#line 5293 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 40415 "Photo.c"
	}
#line 5299 "/home/jens/Source/shotwell/src/Photo.vala"
	DATA_SOURCE_CLASS (library_photo_parent_class)->destroy (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO, Photo), TYPE_DATA_SOURCE, DataSource));
#line 40419 "Photo.c"
}


gboolean library_photo_has_nontrash_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format) {
	gboolean result = FALSE;
	GFile* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	PhotoFileFormat _tmp3_;
	PhotoID _tmp4_ = {0};
	gboolean _tmp5_;
#line 5302 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail ((file == NULL) || G_IS_FILE (file), FALSE);
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = thumbnail_md5;
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = full_md5;
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = file_format;
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_get_nontrash_duplicate (_tmp0_, _tmp1_, _tmp2_, _tmp3_, &_tmp4_);
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_id_is_valid (&_tmp4_);
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	result = _tmp5_;
#line 5304 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40449 "Photo.c"
}


void library_photo_get_nontrash_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format, PhotoID* result) {
	PhotoID* ids = NULL;
	GFile* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	PhotoFileFormat _tmp3_;
	gint _tmp4_;
	PhotoID* _tmp5_;
	gint ids_length1;
	gint _ids_size_;
	gboolean _tmp6_ = FALSE;
	PhotoID* _tmp7_;
	gint _tmp7__length1;
	PhotoID* _tmp10_;
	gint _tmp10__length1;
	PhotoID _tmp18_ = {0};
#line 5307 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((file == NULL) || G_IS_FILE (file));
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = file;
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = thumbnail_md5;
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = full_md5;
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = file_format;
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = photo_get_duplicate_ids (_tmp0_, _tmp1_, _tmp2_, _tmp3_, &_tmp4_);
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	ids = _tmp5_;
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	ids_length1 = _tmp4_;
#line 5309 "/home/jens/Source/shotwell/src/Photo.vala"
	_ids_size_ = ids_length1;
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = ids;
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7__length1 = ids_length1;
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp7_ == NULL) {
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = TRUE;
#line 40495 "Photo.c"
	} else {
		PhotoID* _tmp8_;
		gint _tmp8__length1;
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = ids;
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8__length1 = ids_length1;
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = _tmp8__length1 == 0;
#line 40505 "Photo.c"
	}
#line 5311 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp6_) {
#line 40509 "Photo.c"
		PhotoID _tmp9_ = {0};
#line 5312 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_id_init (&_tmp9_, PHOTO_ID_INVALID);
#line 5312 "/home/jens/Source/shotwell/src/Photo.vala"
		*result = _tmp9_;
#line 5312 "/home/jens/Source/shotwell/src/Photo.vala"
		ids = (g_free (ids), NULL);
#line 5312 "/home/jens/Source/shotwell/src/Photo.vala"
		return;
#line 40519 "Photo.c"
	}
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10_ = ids;
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp10__length1 = ids_length1;
#line 40525 "Photo.c"
	{
		PhotoID* id_collection = NULL;
		gint id_collection_length1 = 0;
		gint _id_collection_size_ = 0;
		gint id_it = 0;
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
		id_collection = _tmp10_;
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
		id_collection_length1 = _tmp10__length1;
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
		for (id_it = 0; id_it < _tmp10__length1; id_it = id_it + 1) {
#line 40537 "Photo.c"
			PhotoID id = {0};
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
			id = id_collection[id_it];
#line 40541 "Photo.c"
			{
				LibraryPhoto* photo = NULL;
				LibraryPhotoSourceCollection* _tmp11_;
				PhotoID _tmp12_;
				LibraryPhoto* _tmp13_;
				gboolean _tmp14_ = FALSE;
				LibraryPhoto* _tmp15_;
#line 5315 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = library_photo_global;
#line 5315 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = id;
#line 5315 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = library_photo_source_collection_fetch (_tmp11_, &_tmp12_);
#line 5315 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = _tmp13_;
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = photo;
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp15_ != NULL) {
#line 40561 "Photo.c"
					LibraryPhoto* _tmp16_;
					gboolean _tmp17_;
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = photo;
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = media_source_is_trashed (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_MEDIA_SOURCE, MediaSource));
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = !_tmp17_;
#line 40570 "Photo.c"
				} else {
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = FALSE;
#line 40574 "Photo.c"
				}
#line 5316 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp14_) {
#line 5317 "/home/jens/Source/shotwell/src/Photo.vala"
					*result = id;
#line 5317 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (photo);
#line 5317 "/home/jens/Source/shotwell/src/Photo.vala"
					ids = (g_free (ids), NULL);
#line 5317 "/home/jens/Source/shotwell/src/Photo.vala"
					return;
#line 40586 "Photo.c"
				}
#line 5314 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 40590 "Photo.c"
			}
		}
	}
#line 5320 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_id_init (&_tmp18_, PHOTO_ID_INVALID);
#line 5320 "/home/jens/Source/shotwell/src/Photo.vala"
	*result = _tmp18_;
#line 5320 "/home/jens/Source/shotwell/src/Photo.vala"
	ids = (g_free (ids), NULL);
#line 5320 "/home/jens/Source/shotwell/src/Photo.vala"
	return;
#line 40602 "Photo.c"
}


static gboolean library_photo_real_has_user_generated_metadata (Photo* base) {
	LibraryPhoto * self;
	gboolean result = FALSE;
	GeeList* tags = NULL;
	TagSourceCollection* _tmp0_;
	GeeList* _tmp1_;
	PhotoMetadata* metadata = NULL;
	PhotoMetadata* _tmp2_;
	PhotoMetadata* _tmp3_;
	Rating _tmp11_;
	PhotoMetadata* _tmp12_;
	Rating _tmp13_;
	GeeSet* keywords = NULL;
	PhotoMetadata* _tmp14_;
	GeeSet* _tmp15_;
	gint _tmp16_ = 0;
	GeeList* _tmp17_;
	gint tags_count = 0;
	gint _tmp21_ = 0;
	GeeSet* _tmp22_;
	gint keywords_count = 0;
	gint _tmp26_;
	gint _tmp27_;
	gboolean _tmp28_ = FALSE;
	GeeList* _tmp29_;
#line 5323 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5324 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = tag_global;
#line 5324 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = tag_source_collection_fetch_for_source (_tmp0_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5324 "/home/jens/Source/shotwell/src/Photo.vala"
	tags = _tmp1_;
#line 5326 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_source_get_metadata (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_SOURCE, PhotoSource));
#line 5326 "/home/jens/Source/shotwell/src/Photo.vala"
	metadata = _tmp2_;
#line 5327 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = metadata;
#line 5327 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp3_ == NULL) {
#line 40647 "Photo.c"
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
		GeeList* _tmp6_;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = tags;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp6_ != NULL) {
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = TRUE;
#line 40657 "Photo.c"
		} else {
			GeeList* _tmp7_;
			gint _tmp8_;
			gint _tmp9_;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = tags;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _tmp9_ > 0;
#line 40670 "Photo.c"
		}
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		if (_tmp5_) {
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = TRUE;
#line 40676 "Photo.c"
		} else {
			Rating _tmp10_;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = media_source_get_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = _tmp10_ != RATING_UNRATED;
#line 40683 "Photo.c"
		}
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		result = _tmp4_;
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (tags);
#line 5328 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 40693 "Photo.c"
	}
#line 5330 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp11_ = media_source_get_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5330 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp12_ = metadata;
#line 5330 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = photo_metadata_get_rating (_tmp12_);
#line 5330 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp11_ != _tmp13_) {
#line 5331 "/home/jens/Source/shotwell/src/Photo.vala"
		result = TRUE;
#line 5331 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 5331 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (tags);
#line 5331 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 40711 "Photo.c"
	}
#line 5333 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = metadata;
#line 5333 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = photo_metadata_get_keywords (_tmp14_, NULL, NULL, NULL);
#line 5333 "/home/jens/Source/shotwell/src/Photo.vala"
	keywords = _tmp15_;
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp17_ = tags;
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp17_ != NULL) {
#line 40723 "Photo.c"
		GeeList* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = tags;
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = _tmp19_;
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = _tmp20_;
#line 40735 "Photo.c"
	} else {
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp16_ = 0;
#line 40739 "Photo.c"
	}
#line 5334 "/home/jens/Source/shotwell/src/Photo.vala"
	tags_count = _tmp16_;
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = keywords;
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp22_ != NULL) {
#line 40747 "Photo.c"
		GeeSet* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp23_ = keywords;
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp24_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp25_ = _tmp24_;
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = _tmp25_;
#line 40759 "Photo.c"
	} else {
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = 0;
#line 40763 "Photo.c"
	}
#line 5335 "/home/jens/Source/shotwell/src/Photo.vala"
	keywords_count = _tmp21_;
#line 5337 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp26_ = tags_count;
#line 5337 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp27_ = keywords_count;
#line 5337 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp26_ != _tmp27_) {
#line 5338 "/home/jens/Source/shotwell/src/Photo.vala"
		result = TRUE;
#line 5338 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (keywords);
#line 5338 "/home/jens/Source/shotwell/src/Photo.vala"
		_media_metadata_unref0 (metadata);
#line 5338 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (tags);
#line 5338 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 40783 "Photo.c"
	}
#line 5340 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp29_ = tags;
#line 5340 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp29_ != NULL) {
#line 40789 "Photo.c"
		GeeSet* _tmp30_;
#line 5340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp30_ = keywords;
#line 5340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = _tmp30_ != NULL;
#line 40795 "Photo.c"
	} else {
#line 5340 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp28_ = FALSE;
#line 40799 "Photo.c"
	}
#line 5340 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp28_) {
#line 40803 "Photo.c"
		{
			GeeList* _tag_list = NULL;
			GeeList* _tmp31_;
			GeeList* _tmp32_;
			gint _tag_size = 0;
			GeeList* _tmp33_;
			gint _tmp34_;
			gint _tmp35_;
			gint _tag_index = 0;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp31_ = tags;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp32_ = _g_object_ref0 (_tmp31_);
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_list = _tmp32_;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp33_ = _tag_list;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp34_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp35_ = _tmp34_;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_size = _tmp35_;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_index = -1;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 40831 "Photo.c"
				gint _tmp36_;
				gint _tmp37_;
				gint _tmp38_;
				Tag* tag = NULL;
				GeeList* _tmp39_;
				gint _tmp40_;
				gpointer _tmp41_;
				GeeSet* _tmp42_;
				Tag* _tmp43_;
				gchar* _tmp44_;
				gchar* _tmp45_;
				gchar* _tmp46_;
				gchar* _tmp47_;
				gboolean _tmp48_;
				gboolean _tmp49_;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = _tag_index;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tag_index = _tmp36_ + 1;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = _tag_index;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = _tag_size;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp37_ < _tmp38_)) {
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 40859 "Photo.c"
				}
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = _tag_list;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp40_ = _tag_index;
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp41_ = gee_list_get (_tmp39_, _tmp40_);
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				tag = (Tag*) _tmp41_;
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp42_ = keywords;
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = tag;
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, TYPE_DATA_OBJECT, DataObject));
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = _tmp44_;
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = g_utf8_normalize (_tmp45_, (gssize) -1, G_NORMALIZE_DEFAULT);
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = _tmp46_;
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, GEE_TYPE_COLLECTION, GeeCollection), _tmp47_);
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp49_ = !_tmp48_;
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp47_);
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp45_);
#line 5342 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp49_) {
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					result = TRUE;
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (tag);
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tag_list);
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (keywords);
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					_media_metadata_unref0 (metadata);
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (tags);
#line 5343 "/home/jens/Source/shotwell/src/Photo.vala"
					return result;
#line 40905 "Photo.c"
				}
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (tag);
#line 40909 "Photo.c"
			}
#line 5341 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tag_list);
#line 40913 "Photo.c"
		}
	}
#line 5347 "/home/jens/Source/shotwell/src/Photo.vala"
	result = FALSE;
#line 5347 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (keywords);
#line 5347 "/home/jens/Source/shotwell/src/Photo.vala"
	_media_metadata_unref0 (metadata);
#line 5347 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (tags);
#line 5347 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 40926 "Photo.c"
}


static void library_photo_real_set_user_metadata_for_export (Photo* base, PhotoMetadata* metadata) {
	LibraryPhoto * self;
	GeeList* photo_tags = NULL;
	TagSourceCollection* _tmp0_;
	GeeList* _tmp1_;
	GeeList* _tmp2_;
	PhotoMetadata* _tmp22_;
	Rating _tmp23_;
#line 5350 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5350 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO_METADATA (metadata));
#line 5351 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = tag_global;
#line 5351 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = tag_source_collection_fetch_for_source (_tmp0_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5351 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_tags = _tmp1_;
#line 5352 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo_tags;
#line 5352 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp2_ != NULL) {
#line 40952 "Photo.c"
		GeeCollection* string_tags = NULL;
		GeeArrayList* _tmp3_;
		PhotoMetadata* _tmp19_;
		GeeCollection* _tmp20_;
#line 5353 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 5353 "/home/jens/Source/shotwell/src/Photo.vala"
		string_tags = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection);
#line 40961 "Photo.c"
		{
			GeeList* _tag_list = NULL;
			GeeList* _tmp4_;
			GeeList* _tmp5_;
			gint _tag_size = 0;
			GeeList* _tmp6_;
			gint _tmp7_;
			gint _tmp8_;
			gint _tag_index = 0;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp4_ = photo_tags;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp5_ = _g_object_ref0 (_tmp4_);
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_list = _tmp5_;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = _tag_list;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = _tmp7_;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_size = _tmp8_;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_tag_index = -1;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 40989 "Photo.c"
				gint _tmp9_;
				gint _tmp10_;
				gint _tmp11_;
				Tag* tag = NULL;
				GeeList* _tmp12_;
				gint _tmp13_;
				gpointer _tmp14_;
				GeeCollection* _tmp15_;
				Tag* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = _tag_index;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tag_index = _tmp9_ + 1;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = _tag_index;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _tag_size;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!(_tmp10_ < _tmp11_)) {
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 41013 "Photo.c"
				}
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tag_list;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _tag_index;
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = gee_list_get (_tmp12_, _tmp13_);
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				tag = (Tag*) _tmp14_;
#line 5355 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = string_tags;
#line 5355 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = tag;
#line 5355 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_DATA_OBJECT, DataObject));
#line 5355 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp18_ = _tmp17_;
#line 5355 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_collection_add (_tmp15_, _tmp18_);
#line 5355 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (_tmp18_);
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (tag);
#line 41037 "Photo.c"
			}
#line 5354 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tag_list);
#line 41041 "Photo.c"
		}
#line 5357 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = metadata;
#line 5357 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp20_ = string_tags;
#line 5357 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_keywords (_tmp19_, _tmp20_, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 5352 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (string_tags);
#line 41051 "Photo.c"
	} else {
		PhotoMetadata* _tmp21_;
#line 5359 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp21_ = metadata;
#line 5359 "/home/jens/Source/shotwell/src/Photo.vala"
		photo_metadata_set_keywords (_tmp21_, NULL, PHOTO_METADATA_SET_OPTION_ALL_DOMAINS);
#line 41058 "Photo.c"
	}
#line 5361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = metadata;
#line 5361 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp23_ = media_source_get_rating (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5361 "/home/jens/Source/shotwell/src/Photo.vala"
	photo_metadata_set_rating (_tmp22_, _tmp23_);
#line 5350 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo_tags);
#line 41068 "Photo.c"
}


static void library_photo_real_apply_user_metadata_for_reimport (Photo* base, PhotoMetadata* metadata) {
	LibraryPhoto * self;
	HierarchicalTagIndex* new_htag_index = NULL;
	PhotoMetadata* _tmp0_;
	gboolean _tmp1_;
	GeeCollection* keywords = NULL;
	PhotoMetadata* _tmp6_;
	GeeSet* _tmp7_;
	GeeCollection* _tmp8_;
	HierarchicalTagIndex* _tmp39_;
#line 5364 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 5364 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO_METADATA (metadata));
#line 5365 "/home/jens/Source/shotwell/src/Photo.vala"
	new_htag_index = NULL;
#line 5367 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = metadata;
#line 5367 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = photo_metadata_has_hierarchical_keywords (_tmp0_);
#line 5367 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp1_) {
#line 41094 "Photo.c"
		PhotoMetadata* _tmp2_;
		GeeSet* _tmp3_;
		GeeSet* _tmp4_;
		HierarchicalTagIndex* _tmp5_;
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp2_ = metadata;
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp3_ = photo_metadata_get_hierarchical_keywords (_tmp2_);
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = _tmp3_;
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = hierarchical_tag_utilities_process_hierarchical_import_keywords (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		_hierarchical_tag_index_unref0 (new_htag_index);
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		new_htag_index = _tmp5_;
#line 5368 "/home/jens/Source/shotwell/src/Photo.vala"
		_g_object_unref0 (_tmp4_);
#line 41113 "Photo.c"
	}
#line 5372 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = metadata;
#line 5372 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp7_ = photo_metadata_get_keywords (_tmp6_, NULL, NULL, NULL);
#line 5372 "/home/jens/Source/shotwell/src/Photo.vala"
	keywords = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection);
#line 5373 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp8_ = keywords;
#line 5373 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp8_ != NULL) {
#line 41125 "Photo.c"
		{
			GeeIterator* _keyword_it = NULL;
			GeeCollection* _tmp9_;
			GeeIterator* _tmp10_;
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = keywords;
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
			_keyword_it = _tmp10_;
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 41138 "Photo.c"
				GeeIterator* _tmp11_;
				gboolean _tmp12_;
				gchar* keyword = NULL;
				GeeIterator* _tmp13_;
				gpointer _tmp14_;
				gboolean _tmp15_ = FALSE;
				HierarchicalTagIndex* _tmp16_;
				gchar* safe_keyword = NULL;
				const gchar* _tmp20_;
				gchar* _tmp21_;
				gchar* promoted_keyword = NULL;
				const gchar* _tmp22_;
				gchar* _tmp23_;
				TagSourceCollection* _tmp24_;
				const gchar* _tmp25_;
				gboolean _tmp26_;
				TagSourceCollection* _tmp30_;
				const gchar* _tmp31_;
				gboolean _tmp32_;
				const gchar* _tmp36_;
				Tag* _tmp37_;
				Tag* _tmp38_;
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _keyword_it;
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = gee_iterator_next (_tmp11_);
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp12_) {
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 41169 "Photo.c"
				}
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = _keyword_it;
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = gee_iterator_get (_tmp13_);
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				keyword = (gchar*) _tmp14_;
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = new_htag_index;
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp16_ != NULL) {
#line 41181 "Photo.c"
					HierarchicalTagIndex* _tmp17_;
					const gchar* _tmp18_;
					gboolean _tmp19_;
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = new_htag_index;
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = keyword;
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = hierarchical_tag_index_is_tag_in_index (_tmp17_, _tmp18_);
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = _tmp19_;
#line 41193 "Photo.c"
				} else {
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = FALSE;
#line 41197 "Photo.c"
				}
#line 5375 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp15_) {
#line 5376 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (keyword);
#line 5376 "/home/jens/Source/shotwell/src/Photo.vala"
					continue;
#line 41205 "Photo.c"
				}
#line 5378 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp20_ = keyword;
#line 5378 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp21_ = hierarchical_tag_utilities_make_flat_tag_safe (_tmp20_);
#line 5378 "/home/jens/Source/shotwell/src/Photo.vala"
				safe_keyword = _tmp21_;
#line 5379 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp22_ = safe_keyword;
#line 5379 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = hierarchical_tag_utilities_flat_to_hierarchical (_tmp22_);
#line 5379 "/home/jens/Source/shotwell/src/Photo.vala"
				promoted_keyword = _tmp23_;
#line 5382 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = tag_global;
#line 5382 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = safe_keyword;
#line 5382 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = tag_source_collection_exists (_tmp24_, _tmp25_, FALSE);
#line 5382 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp26_) {
#line 41227 "Photo.c"
					const gchar* _tmp27_;
					Tag* _tmp28_;
					Tag* _tmp29_;
#line 5383 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp27_ = safe_keyword;
#line 5383 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp28_ = tag_for_path (_tmp27_);
#line 5383 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp29_ = _tmp28_;
#line 5383 "/home/jens/Source/shotwell/src/Photo.vala"
					tag_attach (_tmp29_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5383 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp29_);
#line 5384 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (promoted_keyword);
#line 5384 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (safe_keyword);
#line 5384 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (keyword);
#line 5384 "/home/jens/Source/shotwell/src/Photo.vala"
					continue;
#line 41249 "Photo.c"
				}
#line 5387 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = tag_global;
#line 5387 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = promoted_keyword;
#line 5387 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = tag_source_collection_exists (_tmp30_, _tmp31_, FALSE);
#line 5387 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp32_) {
#line 41259 "Photo.c"
					const gchar* _tmp33_;
					Tag* _tmp34_;
					Tag* _tmp35_;
#line 5388 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp33_ = promoted_keyword;
#line 5388 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp34_ = tag_for_path (_tmp33_);
#line 5388 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp35_ = _tmp34_;
#line 5388 "/home/jens/Source/shotwell/src/Photo.vala"
					tag_attach (_tmp35_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5388 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp35_);
#line 5389 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (promoted_keyword);
#line 5389 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (safe_keyword);
#line 5389 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_free0 (keyword);
#line 5389 "/home/jens/Source/shotwell/src/Photo.vala"
					continue;
#line 41281 "Photo.c"
				}
#line 5392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp36_ = keyword;
#line 5392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp37_ = tag_for_path (_tmp36_);
#line 5392 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = _tmp37_;
#line 5392 "/home/jens/Source/shotwell/src/Photo.vala"
				tag_attach (_tmp38_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5392 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp38_);
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (promoted_keyword);
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (safe_keyword);
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (keyword);
#line 41299 "Photo.c"
			}
#line 5374 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_keyword_it);
#line 41303 "Photo.c"
		}
	}
#line 5396 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp39_ = new_htag_index;
#line 5396 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp39_ != NULL) {
#line 41310 "Photo.c"
		{
			GeeIterator* _path_it = NULL;
			HierarchicalTagIndex* _tmp40_;
			GeeCollection* _tmp41_;
			GeeCollection* _tmp42_;
			GeeIterator* _tmp43_;
			GeeIterator* _tmp44_;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp40_ = new_htag_index;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = hierarchical_tag_index_get_all_paths (_tmp40_);
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = _tmp41_;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp43_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp44_ = _tmp43_;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp42_);
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_path_it = _tmp44_;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 41334 "Photo.c"
				GeeIterator* _tmp45_;
				gboolean _tmp46_;
				gchar* path = NULL;
				GeeIterator* _tmp47_;
				gpointer _tmp48_;
				const gchar* _tmp49_;
				Tag* _tmp50_;
				Tag* _tmp51_;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = _path_it;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = gee_iterator_next (_tmp45_);
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp46_) {
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 41351 "Photo.c"
				}
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = _path_it;
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = gee_iterator_get (_tmp47_);
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				path = (gchar*) _tmp48_;
#line 5398 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp49_ = path;
#line 5398 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp50_ = tag_for_path (_tmp49_);
#line 5398 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp51_ = _tmp50_;
#line 5398 "/home/jens/Source/shotwell/src/Photo.vala"
				tag_attach (_tmp51_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE, MediaSource));
#line 5398 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp51_);
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_free0 (path);
#line 41371 "Photo.c"
			}
#line 5397 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_path_it);
#line 41375 "Photo.c"
		}
	}
#line 5364 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (keywords);
#line 5364 "/home/jens/Source/shotwell/src/Photo.vala"
	_hierarchical_tag_index_unref0 (new_htag_index);
#line 41382 "Photo.c"
}


static void library_photo_class_init (LibraryPhotoClass * klass) {
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_parent_class = g_type_class_peek_parent (klass);
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	g_type_class_add_private (klass, sizeof (LibraryPhotoPrivate));
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_master_reimported = (void (*) (Photo *, PhotoMetadata*)) library_photo_real_notify_master_reimported;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_editable_reimported = (void (*) (Photo *, PhotoMetadata*)) library_photo_real_notify_editable_reimported;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_source_reimported = (void (*) (Photo *, PhotoMetadata*)) library_photo_real_notify_source_reimported;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->notify_baseline_reimported = (void (*) (Photo *, PhotoMetadata*)) library_photo_real_notify_baseline_reimported;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataObjectClass *) klass)->notify_altered = (void (*) (DataObject *, Alteration*)) library_photo_real_notify_altered;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->get_preview_pixbuf = (GdkPixbuf* (*) (MediaSource *, Scaling*, GError**)) library_photo_real_get_preview_pixbuf;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->rotate = (void (*) (Photo *, Rotation)) library_photo_real_rotate;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((ThumbnailSourceClass *) klass)->get_thumbnail = (GdkPixbuf* (*) (ThumbnailSource *, gint, GError**)) library_photo_real_get_thumbnail;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->is_trashed = (gboolean (*) (MediaSource *)) library_photo_real_is_trashed;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->trash = (void (*) (MediaSource *)) library_photo_real_trash;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->untrash = (void (*) (MediaSource *)) library_photo_real_untrash;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->is_offline = (gboolean (*) (MediaSource *)) library_photo_real_is_offline;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->mark_offline = (void (*) (MediaSource *)) library_photo_real_mark_offline;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((MediaSourceClass *) klass)->mark_online = (void (*) (MediaSource *)) library_photo_real_mark_online;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->internal_delete_backing = (gboolean (*) (DataSource *, GError**)) library_photo_real_internal_delete_backing;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((DataSourceClass *) klass)->destroy = (void (*) (DataSource *)) library_photo_real_destroy;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->has_user_generated_metadata = (gboolean (*) (Photo *)) library_photo_real_has_user_generated_metadata;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->set_user_metadata_for_export = (void (*) (Photo *, PhotoMetadata*)) library_photo_real_set_user_metadata_for_export;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	((PhotoClass *) klass)->apply_user_metadata_for_reimport = (void (*) (Photo *, PhotoMetadata*)) library_photo_real_apply_user_metadata_for_reimport;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (klass)->finalize = library_photo_finalize;
#line 41431 "Photo.c"
}


static void library_photo_flaggable_interface_init (FlaggableIface * iface) {
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_flaggable_parent_iface = g_type_interface_peek_parent (iface);
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->is_flagged = (gboolean (*) (Flaggable *)) library_photo_real_is_flagged;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->mark_flagged = (void (*) (Flaggable *)) library_photo_real_mark_flagged;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->mark_unflagged = (void (*) (Flaggable *)) library_photo_real_mark_unflagged;
#line 41444 "Photo.c"
}


static void library_photo_monitorable_interface_init (MonitorableIface * iface) {
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_monitorable_parent_iface = g_type_interface_peek_parent (iface);
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->is_offline = (gboolean (*) (Monitorable *)) library_photo_real_is_offline;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->mark_offline = (void (*) (Monitorable *)) library_photo_real_mark_offline;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->mark_online = (void (*) (Monitorable *)) library_photo_real_mark_online;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->set_master_file = (void (*) (Monitorable *, GFile*)) photo_set_master_file;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	iface->set_master_timestamp = (void (*) (Monitorable *, GFileInfo*)) photo_set_master_timestamp;
#line 41461 "Photo.c"
}


static void library_photo_instance_init (LibraryPhoto * self) {
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv = LIBRARY_PHOTO_GET_PRIVATE (self);
#line 4976 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->block_thumbnail_generation = FALSE;
#line 4977 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->thumbnail_scheduler = NULL;
#line 41472 "Photo.c"
}


static void library_photo_finalize (GObject * obj) {
	LibraryPhoto * self;
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LIBRARY_PHOTO, LibraryPhoto);
#line 4977 "/home/jens/Source/shotwell/src/Photo.vala"
	_one_shot_scheduler_unref0 (self->priv->thumbnail_scheduler);
#line 4978 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->import_keywords);
#line 4965 "/home/jens/Source/shotwell/src/Photo.vala"
	G_OBJECT_CLASS (library_photo_parent_class)->finalize (obj);
#line 41486 "Photo.c"
}


GType library_photo_get_type (void) {
	static volatile gsize library_photo_type_id__volatile = 0;
	if (g_once_init_enter (&library_photo_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryPhotoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_photo_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryPhoto), 0, (GInstanceInitFunc) library_photo_instance_init, NULL };
		static const GInterfaceInfo flaggable_info = { (GInterfaceInitFunc) library_photo_flaggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo monitorable_info = { (GInterfaceInitFunc) library_photo_monitorable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType library_photo_type_id;
		library_photo_type_id = g_type_register_static (TYPE_PHOTO, "LibraryPhoto", &g_define_type_info, 0);
		g_type_add_interface_static (library_photo_type_id, TYPE_FLAGGABLE, &flaggable_info);
		g_type_add_interface_static (library_photo_type_id, TYPE_MONITORABLE, &monitorable_info);
		g_once_init_leave (&library_photo_type_id__volatile, library_photo_type_id);
	}
	return library_photo_type_id__volatile;
}


LibraryPhotoSourceHoldingTank* library_photo_source_holding_tank_construct (GType object_type, LibraryPhotoSourceCollection* sources, SourceHoldingTankCheckToKeep check_to_keep, void* check_to_keep_target, GetSourceDatabaseKey get_key, void* get_key_target) {
	LibraryPhotoSourceHoldingTank* self = NULL;
	LibraryPhotoSourceCollection* _tmp0_;
	SourceHoldingTankCheckToKeep _tmp1_;
	void* _tmp1__target;
	GetSourceDatabaseKey _tmp2_;
	void* _tmp2__target;
#line 5414 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_COLLECTION (sources), NULL);
#line 5416 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = sources;
#line 5416 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = check_to_keep;
#line 5416 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1__target = check_to_keep_target;
#line 5416 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = get_key;
#line 5416 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2__target = get_key_target;
#line 5416 "/home/jens/Source/shotwell/src/Photo.vala"
	self = (LibraryPhotoSourceHoldingTank*) media_source_holding_tank_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), _tmp1_, _tmp1__target, _tmp2_, _tmp2__target);
#line 5414 "/home/jens/Source/shotwell/src/Photo.vala"
	return self;
#line 41529 "Photo.c"
}


LibraryPhotoSourceHoldingTank* library_photo_source_holding_tank_new (LibraryPhotoSourceCollection* sources, SourceHoldingTankCheckToKeep check_to_keep, void* check_to_keep_target, GetSourceDatabaseKey get_key, void* get_key_target) {
#line 5414 "/home/jens/Source/shotwell/src/Photo.vala"
	return library_photo_source_holding_tank_construct (TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, sources, check_to_keep, check_to_keep_target, get_key, get_key_target);
#line 41536 "Photo.c"
}


LibraryPhoto* library_photo_source_holding_tank_fetch_by_backing_file (LibraryPhotoSourceHoldingTank* self, GFile* file) {
	LibraryPhoto* result = NULL;
	LibraryPhoto* ret = NULL;
	GeeHashMap* _tmp0_;
	GFile* _tmp1_;
	gpointer _tmp2_;
	LibraryPhoto* _tmp3_;
	GeeHashMap* _tmp4_;
	GFile* _tmp5_;
	gpointer _tmp6_;
#line 5419 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (IS_LIBRARY_PHOTO_SOURCE_HOLDING_TANK (self), NULL);
#line 5419 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 5420 "/home/jens/Source/shotwell/src/Photo.vala"
	ret = NULL;
#line 5421 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = self->priv->editable_file_map;
#line 5421 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = file;
#line 5421 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 5421 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (ret);
#line 5421 "/home/jens/Source/shotwell/src/Photo.vala"
	ret = (LibraryPhoto*) _tmp2_;
#line 5422 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = ret;
#line 5422 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp3_ != NULL) {
#line 5423 "/home/jens/Source/shotwell/src/Photo.vala"
		result = ret;
#line 5423 "/home/jens/Source/shotwell/src/Photo.vala"
		return result;
#line 41574 "Photo.c"
	}
#line 5425 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = self->priv->development_file_map;
#line 5425 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = file;
#line 5425 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp6_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_);
#line 5425 "/home/jens/Source/shotwell/src/Photo.vala"
	result = (LibraryPhoto*) _tmp6_;
#line 5425 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (ret);
#line 5425 "/home/jens/Source/shotwell/src/Photo.vala"
	return result;
#line 41588 "Photo.c"
}


static void _library_photo_source_holding_tank_on_editable_replaced_photo_editable_replaced (Photo* _sender, GFile* old_file, GFile* new_file, gpointer self) {
#line 5449 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_holding_tank_on_editable_replaced ((LibraryPhotoSourceHoldingTank*) self, _sender, old_file, new_file);
#line 41595 "Photo.c"
}


static void _library_photo_source_holding_tank_on_raw_development_modified_photo_raw_development_modified (Photo* _sender, gpointer self) {
#line 5450 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_holding_tank_on_raw_development_modified ((LibraryPhotoSourceHoldingTank*) self, _sender);
#line 41602 "Photo.c"
}


static void library_photo_source_holding_tank_real_notify_contents_altered (SourceHoldingTank* base, GeeCollection* added, GeeCollection* removed) {
	LibraryPhotoSourceHoldingTank * self;
	GeeCollection* _tmp0_;
	GeeCollection* _tmp40_;
	GeeCollection* _tmp81_;
	GeeCollection* _tmp82_;
#line 5428 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTank);
#line 5428 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((added == NULL) || GEE_IS_COLLECTION (added));
#line 5428 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_COLLECTION (removed));
#line 5430 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = added;
#line 5430 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp0_ != NULL) {
#line 41622 "Photo.c"
		{
			GeeIterator* _source_it = NULL;
			GeeCollection* _tmp1_;
			GeeIterator* _tmp2_;
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp1_ = added;
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp2_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
			_source_it = _tmp2_;
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 41635 "Photo.c"
				GeeIterator* _tmp3_;
				gboolean _tmp4_;
				DataSource* source = NULL;
				GeeIterator* _tmp5_;
				gpointer _tmp6_;
				LibraryPhoto* photo = NULL;
				DataSource* _tmp7_;
				LibraryPhoto* _tmp8_;
				LibraryPhoto* _tmp9_;
				GFile* _tmp10_;
				GFile* _tmp11_;
				gboolean _tmp12_;
				GeeCollection* raw_files = NULL;
				LibraryPhoto* _tmp23_;
				GeeCollection* _tmp24_;
				GeeCollection* _tmp25_;
				LibraryPhoto* _tmp38_;
				LibraryPhoto* _tmp39_;
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp3_ = _source_it;
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp4_ = gee_iterator_next (_tmp3_);
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp4_) {
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 41662 "Photo.c"
				}
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp5_ = _source_it;
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp6_ = gee_iterator_get (_tmp5_);
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				source = (DataSource*) _tmp6_;
#line 5432 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp7_ = source;
#line 5432 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 5432 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = _tmp8_;
#line 5435 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp9_ = photo;
#line 5435 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp10_ = photo_get_editable_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_PHOTO, Photo));
#line 5435 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp11_ = _tmp10_;
#line 5435 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _tmp11_ != NULL;
#line 5435 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (_tmp11_);
#line 5435 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp12_) {
#line 41688 "Photo.c"
					GeeHashMap* _tmp13_;
					LibraryPhoto* _tmp14_;
					GFile* _tmp15_;
					GFile* _tmp16_;
					LibraryPhoto* _tmp17_;
					GeeMultiMap* _tmp18_;
					LibraryPhoto* _tmp19_;
					LibraryPhoto* _tmp20_;
					GFile* _tmp21_;
					GFile* _tmp22_;
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp13_ = self->priv->editable_file_map;
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp14_ = photo;
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp15_ = photo_get_editable_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_PHOTO, Photo));
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp16_ = _tmp15_;
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp17_ = photo;
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp16_, _tmp17_);
#line 5436 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp16_);
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp18_ = self->priv->reverse_editable_file_map;
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp19_ = photo;
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp20_ = photo;
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp21_ = photo_get_editable_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TYPE_PHOTO, Photo));
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp22_ = _tmp21_;
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					gee_multi_map_set (_tmp18_, _tmp19_, _tmp22_);
#line 5437 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp22_);
#line 41727 "Photo.c"
				}
#line 5441 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp23_ = photo;
#line 5441 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp24_ = photo_get_raw_developer_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_PHOTO, Photo));
#line 5441 "/home/jens/Source/shotwell/src/Photo.vala"
				raw_files = _tmp24_;
#line 5442 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = raw_files;
#line 5442 "/home/jens/Source/shotwell/src/Photo.vala"
				if (_tmp25_ != NULL) {
#line 41739 "Photo.c"
					{
						GeeIterator* _f_it = NULL;
						GeeCollection* _tmp26_;
						GeeIterator* _tmp27_;
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp26_ = raw_files;
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp27_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
						_f_it = _tmp27_;
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
						while (TRUE) {
#line 41752 "Photo.c"
							GeeIterator* _tmp28_;
							gboolean _tmp29_;
							GFile* f = NULL;
							GeeIterator* _tmp30_;
							gpointer _tmp31_;
							GeeHashMap* _tmp32_;
							GFile* _tmp33_;
							LibraryPhoto* _tmp34_;
							GeeMultiMap* _tmp35_;
							LibraryPhoto* _tmp36_;
							GFile* _tmp37_;
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp28_ = _f_it;
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp29_ = gee_iterator_next (_tmp28_);
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							if (!_tmp29_) {
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
								break;
#line 41772 "Photo.c"
							}
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp30_ = _f_it;
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp31_ = gee_iterator_get (_tmp30_);
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							f = (GFile*) _tmp31_;
#line 5444 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp32_ = self->priv->development_file_map;
#line 5444 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp33_ = f;
#line 5444 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp34_ = photo;
#line 5444 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp33_, _tmp34_);
#line 5445 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp35_ = self->priv->reverse_development_file_map;
#line 5445 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp36_ = photo;
#line 5445 "/home/jens/Source/shotwell/src/Photo.vala"
							_tmp37_ = f;
#line 5445 "/home/jens/Source/shotwell/src/Photo.vala"
							gee_multi_map_set (_tmp35_, _tmp36_, _tmp37_);
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
							_g_object_unref0 (f);
#line 41798 "Photo.c"
						}
#line 5443 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (_f_it);
#line 41802 "Photo.c"
					}
				}
#line 5449 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp38_ = photo;
#line 5449 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, TYPE_PHOTO, Photo), "editable-replaced", (GCallback) _library_photo_source_holding_tank_on_editable_replaced_photo_editable_replaced, self);
#line 5450 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp39_ = photo;
#line 5450 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, TYPE_PHOTO, Photo), "raw-development-modified", (GCallback) _library_photo_source_holding_tank_on_raw_development_modified_photo_raw_development_modified, self);
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (raw_files);
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (source);
#line 41819 "Photo.c"
			}
#line 5431 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_source_it);
#line 41823 "Photo.c"
		}
	}
#line 5454 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp40_ = removed;
#line 5454 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp40_ != NULL) {
#line 41830 "Photo.c"
		{
			GeeIterator* _source_it = NULL;
			GeeCollection* _tmp41_;
			GeeIterator* _tmp42_;
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp41_ = removed;
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp42_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
			_source_it = _tmp42_;
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 41843 "Photo.c"
				GeeIterator* _tmp43_;
				gboolean _tmp44_;
				DataSource* source = NULL;
				GeeIterator* _tmp45_;
				gpointer _tmp46_;
				LibraryPhoto* photo = NULL;
				DataSource* _tmp47_;
				LibraryPhoto* _tmp48_;
				GeeMultiMap* _tmp73_;
				LibraryPhoto* _tmp74_;
				GeeMultiMap* _tmp75_;
				LibraryPhoto* _tmp76_;
				LibraryPhoto* _tmp77_;
				guint _tmp78_;
				LibraryPhoto* _tmp79_;
				guint _tmp80_;
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp43_ = _source_it;
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp44_ = gee_iterator_next (_tmp43_);
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp44_) {
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 41868 "Photo.c"
				}
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp45_ = _source_it;
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp46_ = gee_iterator_get (_tmp45_);
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				source = (DataSource*) _tmp46_;
#line 5456 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp47_ = source;
#line 5456 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp48_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, TYPE_LIBRARY_PHOTO, LibraryPhoto));
#line 5456 "/home/jens/Source/shotwell/src/Photo.vala"
				photo = _tmp48_;
#line 41882 "Photo.c"
				{
					GeeIterator* _f_it = NULL;
					GeeMultiMap* _tmp49_;
					LibraryPhoto* _tmp50_;
					GeeCollection* _tmp51_;
					GeeCollection* _tmp52_;
					GeeIterator* _tmp53_;
					GeeIterator* _tmp54_;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp49_ = self->priv->reverse_editable_file_map;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp50_ = photo;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp51_ = gee_multi_map_get (_tmp49_, _tmp50_);
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp52_ = _tmp51_;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp53_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp54_ = _tmp53_;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp52_);
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_f_it = _tmp54_;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					while (TRUE) {
#line 41909 "Photo.c"
						GeeIterator* _tmp55_;
						gboolean _tmp56_;
						GFile* f = NULL;
						GeeIterator* _tmp57_;
						gpointer _tmp58_;
						GeeHashMap* _tmp59_;
						GFile* _tmp60_;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp55_ = _f_it;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp56_ = gee_iterator_next (_tmp55_);
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						if (!_tmp56_) {
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
							break;
#line 41925 "Photo.c"
						}
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp57_ = _f_it;
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp58_ = gee_iterator_get (_tmp57_);
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						f = (GFile*) _tmp58_;
#line 5458 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp59_ = self->priv->editable_file_map;
#line 5458 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp60_ = f;
#line 5458 "/home/jens/Source/shotwell/src/Photo.vala"
						gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp60_, NULL);
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (f);
#line 41941 "Photo.c"
					}
#line 5457 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_f_it);
#line 41945 "Photo.c"
				}
				{
					GeeIterator* _f_it = NULL;
					GeeMultiMap* _tmp61_;
					LibraryPhoto* _tmp62_;
					GeeCollection* _tmp63_;
					GeeCollection* _tmp64_;
					GeeIterator* _tmp65_;
					GeeIterator* _tmp66_;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp61_ = self->priv->reverse_development_file_map;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp62_ = photo;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp63_ = gee_multi_map_get (_tmp61_, _tmp62_);
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp64_ = _tmp63_;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp65_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_tmp66_ = _tmp65_;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_tmp64_);
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_f_it = _tmp66_;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					while (TRUE) {
#line 41973 "Photo.c"
						GeeIterator* _tmp67_;
						gboolean _tmp68_;
						GFile* f = NULL;
						GeeIterator* _tmp69_;
						gpointer _tmp70_;
						GeeHashMap* _tmp71_;
						GFile* _tmp72_;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp67_ = _f_it;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp68_ = gee_iterator_next (_tmp67_);
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						if (!_tmp68_) {
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
							break;
#line 41989 "Photo.c"
						}
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp69_ = _f_it;
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp70_ = gee_iterator_get (_tmp69_);
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						f = (GFile*) _tmp70_;
#line 5461 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp71_ = self->priv->development_file_map;
#line 5461 "/home/jens/Source/shotwell/src/Photo.vala"
						_tmp72_ = f;
#line 5461 "/home/jens/Source/shotwell/src/Photo.vala"
						gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp72_, NULL);
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
						_g_object_unref0 (f);
#line 42005 "Photo.c"
					}
#line 5460 "/home/jens/Source/shotwell/src/Photo.vala"
					_g_object_unref0 (_f_it);
#line 42009 "Photo.c"
				}
#line 5463 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp73_ = self->priv->reverse_editable_file_map;
#line 5463 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp74_ = photo;
#line 5463 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_remove_all (_tmp73_, _tmp74_);
#line 5464 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp75_ = self->priv->reverse_development_file_map;
#line 5464 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp76_ = photo;
#line 5464 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_remove_all (_tmp75_, _tmp76_);
#line 5466 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp77_ = photo;
#line 5466 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_parse_name ("editable-replaced", TYPE_PHOTO, &_tmp78_, NULL, FALSE);
#line 5466 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, TYPE_PHOTO, Photo), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp78_, 0, NULL, (GCallback) _library_photo_source_holding_tank_on_editable_replaced_photo_editable_replaced, self);
#line 5467 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp79_ = photo;
#line 5467 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_parse_name ("raw-development-modified", TYPE_PHOTO, &_tmp80_, NULL, FALSE);
#line 5467 "/home/jens/Source/shotwell/src/Photo.vala"
				g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, TYPE_PHOTO, Photo), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp80_, 0, NULL, (GCallback) _library_photo_source_holding_tank_on_raw_development_modified_photo_raw_development_modified, self);
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (photo);
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (source);
#line 42039 "Photo.c"
			}
#line 5455 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_source_it);
#line 42043 "Photo.c"
		}
	}
#line 5471 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp81_ = added;
#line 5471 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp82_ = removed;
#line 5471 "/home/jens/Source/shotwell/src/Photo.vala"
	SOURCE_HOLDING_TANK_CLASS (library_photo_source_holding_tank_parent_class)->notify_contents_altered (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTank), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank), _tmp81_, _tmp82_);
#line 42052 "Photo.c"
}


static void library_photo_source_holding_tank_on_editable_replaced (LibraryPhotoSourceHoldingTank* self, Photo* _photo, GFile* old_file, GFile* new_file) {
	LibraryPhoto* photo = NULL;
	Photo* _tmp0_;
	LibraryPhoto* _tmp1_;
	LibraryPhoto* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp9_;
	GeeMultiMap* _tmp13_;
	LibraryPhoto* _tmp14_;
	GFile* _tmp15_;
#line 5474 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_HOLDING_TANK (self));
#line 5474 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (_photo));
#line 5474 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((old_file == NULL) || G_IS_FILE (old_file));
#line 5474 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail ((new_file == NULL) || G_IS_FILE (new_file));
#line 5475 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _photo;
#line 5475 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_LIBRARY_PHOTO) ? ((LibraryPhoto*) _tmp0_) : NULL);
#line 5475 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp1_;
#line 5476 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo;
#line 5476 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp2_ != NULL, "photo != null");
#line 5478 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = old_file;
#line 5478 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp3_ != NULL) {
#line 42088 "Photo.c"
		GeeHashMap* _tmp4_;
		GFile* _tmp5_;
		GeeMultiMap* _tmp6_;
		LibraryPhoto* _tmp7_;
		GFile* _tmp8_;
#line 5479 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp4_ = self->priv->editable_file_map;
#line 5479 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp5_ = old_file;
#line 5479 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_, NULL);
#line 5480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp6_ = self->priv->reverse_editable_file_map;
#line 5480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp7_ = photo;
#line 5480 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp8_ = old_file;
#line 5480 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_multi_map_remove (_tmp6_, _tmp7_, _tmp8_);
#line 42108 "Photo.c"
	}
#line 5483 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp9_ = new_file;
#line 5483 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp9_ != NULL) {
#line 42114 "Photo.c"
		GeeHashMap* _tmp10_;
		GFile* _tmp11_;
		LibraryPhoto* _tmp12_;
#line 5484 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp10_ = self->priv->editable_file_map;
#line 5484 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp11_ = new_file;
#line 5484 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp12_ = photo;
#line 5484 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp11_, _tmp12_);
#line 42126 "Photo.c"
	}
#line 5485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp13_ = self->priv->reverse_editable_file_map;
#line 5485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp14_ = photo;
#line 5485 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp15_ = new_file;
#line 5485 "/home/jens/Source/shotwell/src/Photo.vala"
	gee_multi_map_set (_tmp13_, _tmp14_, _tmp15_);
#line 5474 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 42138 "Photo.c"
}


static void library_photo_source_holding_tank_on_raw_development_modified (LibraryPhotoSourceHoldingTank* self, Photo* _photo) {
	LibraryPhoto* photo = NULL;
	Photo* _tmp0_;
	LibraryPhoto* _tmp1_;
	LibraryPhoto* _tmp2_;
	GeeMultiMap* _tmp3_;
	LibraryPhoto* _tmp4_;
	gboolean _tmp5_;
	GeeCollection* raw_list = NULL;
	LibraryPhoto* _tmp20_;
	GeeCollection* _tmp21_;
	GeeCollection* _tmp22_;
#line 5488 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_LIBRARY_PHOTO_SOURCE_HOLDING_TANK (self));
#line 5488 "/home/jens/Source/shotwell/src/Photo.vala"
	g_return_if_fail (IS_PHOTO (_photo));
#line 5489 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = _photo;
#line 5489 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_LIBRARY_PHOTO) ? ((LibraryPhoto*) _tmp0_) : NULL);
#line 5489 "/home/jens/Source/shotwell/src/Photo.vala"
	photo = _tmp1_;
#line 5490 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = photo;
#line 5490 "/home/jens/Source/shotwell/src/Photo.vala"
	_vala_assert (_tmp2_ != NULL, "photo != null");
#line 5493 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = self->priv->reverse_development_file_map;
#line 5493 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp4_ = photo;
#line 5493 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp5_ = gee_multi_map_contains (_tmp3_, _tmp4_);
#line 5493 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp5_) {
#line 42176 "Photo.c"
		GeeMultiMap* _tmp18_;
		LibraryPhoto* _tmp19_;
		{
			GeeIterator* _f_it = NULL;
			GeeMultiMap* _tmp6_;
			LibraryPhoto* _tmp7_;
			GeeCollection* _tmp8_;
			GeeCollection* _tmp9_;
			GeeIterator* _tmp10_;
			GeeIterator* _tmp11_;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp6_ = self->priv->reverse_development_file_map;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp7_ = photo;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp8_ = gee_multi_map_get (_tmp6_, _tmp7_);
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp9_ = _tmp8_;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp10_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp11_ = _tmp10_;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_tmp9_);
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_f_it = _tmp11_;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 42205 "Photo.c"
				GeeIterator* _tmp12_;
				gboolean _tmp13_;
				GFile* f = NULL;
				GeeIterator* _tmp14_;
				gpointer _tmp15_;
				GeeHashMap* _tmp16_;
				GFile* _tmp17_;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp12_ = _f_it;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp13_ = gee_iterator_next (_tmp12_);
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp13_) {
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 42221 "Photo.c"
				}
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp14_ = _f_it;
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp15_ = gee_iterator_get (_tmp14_);
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				f = (GFile*) _tmp15_;
#line 5495 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp16_ = self->priv->development_file_map;
#line 5495 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp17_ = f;
#line 5495 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp17_, NULL);
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (f);
#line 42237 "Photo.c"
			}
#line 5494 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_f_it);
#line 42241 "Photo.c"
		}
#line 5496 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp18_ = self->priv->reverse_development_file_map;
#line 5496 "/home/jens/Source/shotwell/src/Photo.vala"
		_tmp19_ = photo;
#line 5496 "/home/jens/Source/shotwell/src/Photo.vala"
		gee_multi_map_remove_all (_tmp18_, _tmp19_);
#line 42249 "Photo.c"
	}
#line 5500 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp20_ = photo;
#line 5500 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp21_ = photo_get_raw_developer_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TYPE_PHOTO, Photo));
#line 5500 "/home/jens/Source/shotwell/src/Photo.vala"
	raw_list = _tmp21_;
#line 5501 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp22_ = raw_list;
#line 5501 "/home/jens/Source/shotwell/src/Photo.vala"
	if (_tmp22_ != NULL) {
#line 42261 "Photo.c"
		{
			GeeIterator* _f_it = NULL;
			GeeCollection* _tmp23_;
			GeeIterator* _tmp24_;
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp23_ = raw_list;
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
			_tmp24_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_ITERABLE, GeeIterable));
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
			_f_it = _tmp24_;
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
			while (TRUE) {
#line 42274 "Photo.c"
				GeeIterator* _tmp25_;
				gboolean _tmp26_;
				GFile* f = NULL;
				GeeIterator* _tmp27_;
				gpointer _tmp28_;
				GeeHashMap* _tmp29_;
				GFile* _tmp30_;
				LibraryPhoto* _tmp31_;
				GeeMultiMap* _tmp32_;
				LibraryPhoto* _tmp33_;
				GFile* _tmp34_;
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp25_ = _f_it;
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp26_ = gee_iterator_next (_tmp25_);
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				if (!_tmp26_) {
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
					break;
#line 42294 "Photo.c"
				}
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp27_ = _f_it;
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp28_ = gee_iterator_get (_tmp27_);
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				f = (GFile*) _tmp28_;
#line 5503 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp29_ = self->priv->development_file_map;
#line 5503 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp30_ = f;
#line 5503 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp31_ = photo;
#line 5503 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp30_, _tmp31_);
#line 5504 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp32_ = self->priv->reverse_development_file_map;
#line 5504 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp33_ = photo;
#line 5504 "/home/jens/Source/shotwell/src/Photo.vala"
				_tmp34_ = f;
#line 5504 "/home/jens/Source/shotwell/src/Photo.vala"
				gee_multi_map_set (_tmp32_, _tmp33_, _tmp34_);
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
				_g_object_unref0 (f);
#line 42320 "Photo.c"
			}
#line 5502 "/home/jens/Source/shotwell/src/Photo.vala"
			_g_object_unref0 (_f_it);
#line 42324 "Photo.c"
		}
	}
#line 5488 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (raw_list);
#line 5488 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (photo);
#line 42331 "Photo.c"
}


static void library_photo_source_holding_tank_class_init (LibraryPhotoSourceHoldingTankClass * klass) {
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	library_photo_source_holding_tank_parent_class = g_type_class_peek_parent (klass);
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	((SourceHoldingTankClass *) klass)->finalize = library_photo_source_holding_tank_finalize;
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	g_type_class_add_private (klass, sizeof (LibraryPhotoSourceHoldingTankPrivate));
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	((SourceHoldingTankClass *) klass)->notify_contents_altered = (void (*) (SourceHoldingTank *, GeeCollection*, GeeCollection*)) library_photo_source_holding_tank_real_notify_contents_altered;
#line 42344 "Photo.c"
}


static void library_photo_source_holding_tank_instance_init (LibraryPhotoSourceHoldingTank * self) {
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMultiMap* _tmp2_;
	GeeHashMultiMap* _tmp3_;
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv = LIBRARY_PHOTO_SOURCE_HOLDING_TANK_GET_PRIVATE (self);
#line 5405 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp0_ = gee_hash_map_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
#line 5405 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->editable_file_map = _tmp0_;
#line 5407 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp1_ = gee_hash_map_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
#line 5407 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->development_file_map = _tmp1_;
#line 5409 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp2_ = gee_hash_multi_map_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL);
#line 5409 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->reverse_editable_file_map = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_MULTI_MAP, GeeMultiMap);
#line 5411 "/home/jens/Source/shotwell/src/Photo.vala"
	_tmp3_ = gee_hash_multi_map_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL);
#line 5411 "/home/jens/Source/shotwell/src/Photo.vala"
	self->priv->reverse_development_file_map = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_MULTI_MAP, GeeMultiMap);
#line 42371 "Photo.c"
}


static void library_photo_source_holding_tank_finalize (SourceHoldingTank * obj) {
	LibraryPhotoSourceHoldingTank * self;
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LIBRARY_PHOTO_SOURCE_HOLDING_TANK, LibraryPhotoSourceHoldingTank);
#line 5405 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->editable_file_map);
#line 5407 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->development_file_map);
#line 5409 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->reverse_editable_file_map);
#line 5411 "/home/jens/Source/shotwell/src/Photo.vala"
	_g_object_unref0 (self->priv->reverse_development_file_map);
#line 5404 "/home/jens/Source/shotwell/src/Photo.vala"
	SOURCE_HOLDING_TANK_CLASS (library_photo_source_holding_tank_parent_class)->finalize (obj);
#line 42389 "Photo.c"
}


GType library_photo_source_holding_tank_get_type (void) {
	static volatile gsize library_photo_source_holding_tank_type_id__volatile = 0;
	if (g_once_init_enter (&library_photo_source_holding_tank_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryPhotoSourceHoldingTankClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_photo_source_holding_tank_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryPhotoSourceHoldingTank), 0, (GInstanceInitFunc) library_photo_source_holding_tank_instance_init, NULL };
		GType library_photo_source_holding_tank_type_id;
		library_photo_source_holding_tank_type_id = g_type_register_static (TYPE_MEDIA_SOURCE_HOLDING_TANK, "LibraryPhotoSourceHoldingTank", &g_define_type_info, 0);
		g_once_init_leave (&library_photo_source_holding_tank_type_id__volatile, library_photo_source_holding_tank_type_id);
	}
	return library_photo_source_holding_tank_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



